"Main interface for pinpoint Client"
from __future__ import annotations

from datetime import datetime
from typing import Dict, List
from botocore.client import BaseClient
from botocore.exceptions import ClientError as Boto3ClientError

# pylint: disable=import-self
import mypy_boto3_pinpoint.client as client_scope
from mypy_boto3_pinpoint.type_defs import (
    ClientCreateAppCreateApplicationRequestTypeDef,
    ClientCreateAppResponseTypeDef,
    ClientCreateCampaignResponseTypeDef,
    ClientCreateCampaignWriteCampaignRequestTypeDef,
    ClientCreateEmailTemplateEmailTemplateRequestTypeDef,
    ClientCreateEmailTemplateResponseTypeDef,
    ClientCreateExportJobExportJobRequestTypeDef,
    ClientCreateExportJobResponseTypeDef,
    ClientCreateImportJobImportJobRequestTypeDef,
    ClientCreateImportJobResponseTypeDef,
    ClientCreateJourneyResponseTypeDef,
    ClientCreateJourneyWriteJourneyRequestTypeDef,
    ClientCreatePushTemplatePushNotificationTemplateRequestTypeDef,
    ClientCreatePushTemplateResponseTypeDef,
    ClientCreateSegmentResponseTypeDef,
    ClientCreateSegmentWriteSegmentRequestTypeDef,
    ClientCreateSmsTemplateResponseTypeDef,
    ClientCreateSmsTemplateSMSTemplateRequestTypeDef,
    ClientCreateVoiceTemplateResponseTypeDef,
    ClientCreateVoiceTemplateVoiceTemplateRequestTypeDef,
    ClientDeleteAdmChannelResponseTypeDef,
    ClientDeleteApnsChannelResponseTypeDef,
    ClientDeleteApnsSandboxChannelResponseTypeDef,
    ClientDeleteApnsVoipChannelResponseTypeDef,
    ClientDeleteApnsVoipSandboxChannelResponseTypeDef,
    ClientDeleteAppResponseTypeDef,
    ClientDeleteBaiduChannelResponseTypeDef,
    ClientDeleteCampaignResponseTypeDef,
    ClientDeleteEmailChannelResponseTypeDef,
    ClientDeleteEmailTemplateResponseTypeDef,
    ClientDeleteEndpointResponseTypeDef,
    ClientDeleteEventStreamResponseTypeDef,
    ClientDeleteGcmChannelResponseTypeDef,
    ClientDeleteJourneyResponseTypeDef,
    ClientDeletePushTemplateResponseTypeDef,
    ClientDeleteSegmentResponseTypeDef,
    ClientDeleteSmsChannelResponseTypeDef,
    ClientDeleteSmsTemplateResponseTypeDef,
    ClientDeleteUserEndpointsResponseTypeDef,
    ClientDeleteVoiceChannelResponseTypeDef,
    ClientDeleteVoiceTemplateResponseTypeDef,
    ClientGetAdmChannelResponseTypeDef,
    ClientGetApnsChannelResponseTypeDef,
    ClientGetApnsSandboxChannelResponseTypeDef,
    ClientGetApnsVoipChannelResponseTypeDef,
    ClientGetApnsVoipSandboxChannelResponseTypeDef,
    ClientGetAppResponseTypeDef,
    ClientGetApplicationDateRangeKpiResponseTypeDef,
    ClientGetApplicationSettingsResponseTypeDef,
    ClientGetAppsResponseTypeDef,
    ClientGetBaiduChannelResponseTypeDef,
    ClientGetCampaignActivitiesResponseTypeDef,
    ClientGetCampaignDateRangeKpiResponseTypeDef,
    ClientGetCampaignResponseTypeDef,
    ClientGetCampaignVersionResponseTypeDef,
    ClientGetCampaignVersionsResponseTypeDef,
    ClientGetCampaignsResponseTypeDef,
    ClientGetChannelsResponseTypeDef,
    ClientGetEmailChannelResponseTypeDef,
    ClientGetEmailTemplateResponseTypeDef,
    ClientGetEndpointResponseTypeDef,
    ClientGetEventStreamResponseTypeDef,
    ClientGetExportJobResponseTypeDef,
    ClientGetExportJobsResponseTypeDef,
    ClientGetGcmChannelResponseTypeDef,
    ClientGetImportJobResponseTypeDef,
    ClientGetImportJobsResponseTypeDef,
    ClientGetJourneyDateRangeKpiResponseTypeDef,
    ClientGetJourneyExecutionActivityMetricsResponseTypeDef,
    ClientGetJourneyExecutionMetricsResponseTypeDef,
    ClientGetJourneyResponseTypeDef,
    ClientGetPushTemplateResponseTypeDef,
    ClientGetSegmentExportJobsResponseTypeDef,
    ClientGetSegmentImportJobsResponseTypeDef,
    ClientGetSegmentResponseTypeDef,
    ClientGetSegmentVersionResponseTypeDef,
    ClientGetSegmentVersionsResponseTypeDef,
    ClientGetSegmentsResponseTypeDef,
    ClientGetSmsChannelResponseTypeDef,
    ClientGetSmsTemplateResponseTypeDef,
    ClientGetUserEndpointsResponseTypeDef,
    ClientGetVoiceChannelResponseTypeDef,
    ClientGetVoiceTemplateResponseTypeDef,
    ClientListJourneysResponseTypeDef,
    ClientListTagsForResourceResponseTypeDef,
    ClientListTemplatesResponseTypeDef,
    ClientPhoneNumberValidateNumberValidateRequestTypeDef,
    ClientPhoneNumberValidateResponseTypeDef,
    ClientPutEventStreamResponseTypeDef,
    ClientPutEventStreamWriteEventStreamTypeDef,
    ClientPutEventsEventsRequestTypeDef,
    ClientPutEventsResponseTypeDef,
    ClientRemoveAttributesResponseTypeDef,
    ClientRemoveAttributesUpdateAttributesRequestTypeDef,
    ClientSendMessagesMessageRequestTypeDef,
    ClientSendMessagesResponseTypeDef,
    ClientSendUsersMessagesResponseTypeDef,
    ClientSendUsersMessagesSendUsersMessageRequestTypeDef,
    ClientTagResourceTagsModelTypeDef,
    ClientUpdateAdmChannelADMChannelRequestTypeDef,
    ClientUpdateAdmChannelResponseTypeDef,
    ClientUpdateApnsChannelAPNSChannelRequestTypeDef,
    ClientUpdateApnsChannelResponseTypeDef,
    ClientUpdateApnsSandboxChannelAPNSSandboxChannelRequestTypeDef,
    ClientUpdateApnsSandboxChannelResponseTypeDef,
    ClientUpdateApnsVoipChannelAPNSVoipChannelRequestTypeDef,
    ClientUpdateApnsVoipChannelResponseTypeDef,
    ClientUpdateApnsVoipSandboxChannelAPNSVoipSandboxChannelRequestTypeDef,
    ClientUpdateApnsVoipSandboxChannelResponseTypeDef,
    ClientUpdateApplicationSettingsResponseTypeDef,
    ClientUpdateApplicationSettingsWriteApplicationSettingsRequestTypeDef,
    ClientUpdateBaiduChannelBaiduChannelRequestTypeDef,
    ClientUpdateBaiduChannelResponseTypeDef,
    ClientUpdateCampaignResponseTypeDef,
    ClientUpdateCampaignWriteCampaignRequestTypeDef,
    ClientUpdateEmailChannelEmailChannelRequestTypeDef,
    ClientUpdateEmailChannelResponseTypeDef,
    ClientUpdateEmailTemplateEmailTemplateRequestTypeDef,
    ClientUpdateEmailTemplateResponseTypeDef,
    ClientUpdateEndpointEndpointRequestTypeDef,
    ClientUpdateEndpointResponseTypeDef,
    ClientUpdateEndpointsBatchEndpointBatchRequestTypeDef,
    ClientUpdateEndpointsBatchResponseTypeDef,
    ClientUpdateGcmChannelGCMChannelRequestTypeDef,
    ClientUpdateGcmChannelResponseTypeDef,
    ClientUpdateJourneyResponseTypeDef,
    ClientUpdateJourneyStateJourneyStateRequestTypeDef,
    ClientUpdateJourneyStateResponseTypeDef,
    ClientUpdateJourneyWriteJourneyRequestTypeDef,
    ClientUpdatePushTemplatePushNotificationTemplateRequestTypeDef,
    ClientUpdatePushTemplateResponseTypeDef,
    ClientUpdateSegmentResponseTypeDef,
    ClientUpdateSegmentWriteSegmentRequestTypeDef,
    ClientUpdateSmsChannelResponseTypeDef,
    ClientUpdateSmsChannelSMSChannelRequestTypeDef,
    ClientUpdateSmsTemplateResponseTypeDef,
    ClientUpdateSmsTemplateSMSTemplateRequestTypeDef,
    ClientUpdateVoiceChannelResponseTypeDef,
    ClientUpdateVoiceChannelVoiceChannelRequestTypeDef,
    ClientUpdateVoiceTemplateResponseTypeDef,
    ClientUpdateVoiceTemplateVoiceTemplateRequestTypeDef,
)


__all__ = ("Client",)


class Client(BaseClient):
    exceptions: client_scope.Exceptions

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def can_paginate(self, operation_name: str) -> None:
        """
        Check if an operation can be paginated.

        :type operation_name: string
        :param operation_name: The operation name.  This is the same name
            as the method name on the client.  For example, if the
            method name is ``create_foo``, and you'd normally invoke the
            operation as ``client.create_foo(**kwargs)``, if the
            ``create_foo`` operation can be paginated, you can use the
            call ``client.get_paginator("create_foo")``.

        :return: ``True`` if the operation can be paginated,
            ``False`` otherwise.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_app(
        self, CreateApplicationRequest: ClientCreateAppCreateApplicationRequestTypeDef
    ) -> ClientCreateAppResponseTypeDef:
        """
        Creates an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/CreateApp>`_

        **Request Syntax**
        ::

          response = client.create_app(
              CreateApplicationRequest={
                  'Name': 'string',
                  'tags': {
                      'string': 'string'
                  }
              }
          )
        :type CreateApplicationRequest: dict
        :param CreateApplicationRequest: **[REQUIRED]**

          Specifies the display name of an application and the tags to associate with the
          application.

          - **Name** *(string) --* **[REQUIRED]**

            The display name of the application. This name is displayed as the **Project name** on
            the Amazon Pinpoint console.

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            application. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ApplicationResponse': {
                    'Arn': 'string',
                    'Id': 'string',
                    'Name': 'string',
                    'tags': {
                        'string': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded and the specified resource was created.

            - **ApplicationResponse** *(dict) --*

              Provides information about an application.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the application.

              - **Id** *(string) --*

                The unique identifier for the application. This identifier is displayed as the
                **Project ID** on the Amazon Pinpoint console.

              - **Name** *(string) --*

                The display name of the application. This name is displayed as the **Project name**
                on the Amazon Pinpoint console.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the application. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_campaign(
        self,
        ApplicationId: str,
        WriteCampaignRequest: ClientCreateCampaignWriteCampaignRequestTypeDef,
    ) -> ClientCreateCampaignResponseTypeDef:
        """
        Creates a new campaign for an application or updates the settings of an existing campaign
        for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/CreateCampaign>`_

        **Request Syntax**
        ::

          response = client.create_campaign(
              ApplicationId='string',
              WriteCampaignRequest={
                  'AdditionalTreatments': [
                      {
                          'MessageConfiguration': {
                              'ADMMessage': {
                                  'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                  'Body': 'string',
                                  'ImageIconUrl': 'string',
                                  'ImageSmallIconUrl': 'string',
                                  'ImageUrl': 'string',
                                  'JsonBody': 'string',
                                  'MediaUrl': 'string',
                                  'RawContent': 'string',
                                  'SilentPush': True|False,
                                  'TimeToLive': 123,
                                  'Title': 'string',
                                  'Url': 'string'
                              },
                              'APNSMessage': {
                                  'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                  'Body': 'string',
                                  'ImageIconUrl': 'string',
                                  'ImageSmallIconUrl': 'string',
                                  'ImageUrl': 'string',
                                  'JsonBody': 'string',
                                  'MediaUrl': 'string',
                                  'RawContent': 'string',
                                  'SilentPush': True|False,
                                  'TimeToLive': 123,
                                  'Title': 'string',
                                  'Url': 'string'
                              },
                              'BaiduMessage': {
                                  'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                  'Body': 'string',
                                  'ImageIconUrl': 'string',
                                  'ImageSmallIconUrl': 'string',
                                  'ImageUrl': 'string',
                                  'JsonBody': 'string',
                                  'MediaUrl': 'string',
                                  'RawContent': 'string',
                                  'SilentPush': True|False,
                                  'TimeToLive': 123,
                                  'Title': 'string',
                                  'Url': 'string'
                              },
                              'DefaultMessage': {
                                  'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                  'Body': 'string',
                                  'ImageIconUrl': 'string',
                                  'ImageSmallIconUrl': 'string',
                                  'ImageUrl': 'string',
                                  'JsonBody': 'string',
                                  'MediaUrl': 'string',
                                  'RawContent': 'string',
                                  'SilentPush': True|False,
                                  'TimeToLive': 123,
                                  'Title': 'string',
                                  'Url': 'string'
                              },
                              'EmailMessage': {
                                  'Body': 'string',
                                  'FromAddress': 'string',
                                  'HtmlBody': 'string',
                                  'Title': 'string'
                              },
                              'GCMMessage': {
                                  'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                  'Body': 'string',
                                  'ImageIconUrl': 'string',
                                  'ImageSmallIconUrl': 'string',
                                  'ImageUrl': 'string',
                                  'JsonBody': 'string',
                                  'MediaUrl': 'string',
                                  'RawContent': 'string',
                                  'SilentPush': True|False,
                                  'TimeToLive': 123,
                                  'Title': 'string',
                                  'Url': 'string'
                              },
                              'SMSMessage': {
                                  'Body': 'string',
                                  'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                  'SenderId': 'string'
                              }
                          },
                          'Schedule': {
                              'EndTime': 'string',
                              'EventFilter': {
                                  'Dimensions': {
                                      'Attributes': {
                                          'string': {
                                              'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          }
                                      },
                                      'EventType': {
                                          'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                          'Values': [
                                              'string',
                                          ]
                                      },
                                      'Metrics': {
                                          'string': {
                                              'ComparisonOperator': 'string',
                                              'Value': 123.0
                                          }
                                      }
                                  },
                                  'FilterType': 'SYSTEM'|'ENDPOINT'
                              },
                              'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                              'IsLocalTime': True|False,
                              'QuietTime': {
                                  'End': 'string',
                                  'Start': 'string'
                              },
                              'StartTime': 'string',
                              'Timezone': 'string'
                          },
                          'SizePercent': 123,
                          'TemplateConfiguration': {
                              'EmailTemplate': {
                                  'Name': 'string'
                              },
                              'PushTemplate': {
                                  'Name': 'string'
                              },
                              'SMSTemplate': {
                                  'Name': 'string'
                              },
                              'VoiceTemplate': {
                                  'Name': 'string'
                              }
                          },
                          'TreatmentDescription': 'string',
                          'TreatmentName': 'string'
                      },
                  ],
                  'Description': 'string',
                  'HoldoutPercent': 123,
                  'Hook': {
                      'LambdaFunctionName': 'string',
                      'Mode': 'DELIVERY'|'FILTER',
                      'WebUrl': 'string'
                  },
                  'IsPaused': True|False,
                  'Limits': {
                      'Daily': 123,
                      'MaximumDuration': 123,
                      'MessagesPerSecond': 123,
                      'Total': 123
                  },
                  'MessageConfiguration': {
                      'ADMMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ImageIconUrl': 'string',
                          'ImageSmallIconUrl': 'string',
                          'ImageUrl': 'string',
                          'JsonBody': 'string',
                          'MediaUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'APNSMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ImageIconUrl': 'string',
                          'ImageSmallIconUrl': 'string',
                          'ImageUrl': 'string',
                          'JsonBody': 'string',
                          'MediaUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'BaiduMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ImageIconUrl': 'string',
                          'ImageSmallIconUrl': 'string',
                          'ImageUrl': 'string',
                          'JsonBody': 'string',
                          'MediaUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'DefaultMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ImageIconUrl': 'string',
                          'ImageSmallIconUrl': 'string',
                          'ImageUrl': 'string',
                          'JsonBody': 'string',
                          'MediaUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'EmailMessage': {
                          'Body': 'string',
                          'FromAddress': 'string',
                          'HtmlBody': 'string',
                          'Title': 'string'
                      },
                      'GCMMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ImageIconUrl': 'string',
                          'ImageSmallIconUrl': 'string',
                          'ImageUrl': 'string',
                          'JsonBody': 'string',
                          'MediaUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'SMSMessage': {
                          'Body': 'string',
                          'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                          'SenderId': 'string'
                      }
                  },
                  'Name': 'string',
                  'Schedule': {
                      'EndTime': 'string',
                      'EventFilter': {
                          'Dimensions': {
                              'Attributes': {
                                  'string': {
                                      'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                      'Values': [
                                          'string',
                                      ]
                                  }
                              },
                              'EventType': {
                                  'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                  'Values': [
                                      'string',
                                  ]
                              },
                              'Metrics': {
                                  'string': {
                                      'ComparisonOperator': 'string',
                                      'Value': 123.0
                                  }
                              }
                          },
                          'FilterType': 'SYSTEM'|'ENDPOINT'
                      },
                      'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                      'IsLocalTime': True|False,
                      'QuietTime': {
                          'End': 'string',
                          'Start': 'string'
                      },
                      'StartTime': 'string',
                      'Timezone': 'string'
                  },
                  'SegmentId': 'string',
                  'SegmentVersion': 123,
                  'tags': {
                      'string': 'string'
                  },
                  'TemplateConfiguration': {
                      'EmailTemplate': {
                          'Name': 'string'
                      },
                      'PushTemplate': {
                          'Name': 'string'
                      },
                      'SMSTemplate': {
                          'Name': 'string'
                      },
                      'VoiceTemplate': {
                          'Name': 'string'
                      }
                  },
                  'TreatmentDescription': 'string',
                  'TreatmentName': 'string'
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type WriteCampaignRequest: dict
        :param WriteCampaignRequest: **[REQUIRED]**

          Specifies the configuration and other settings for a campaign.

          - **AdditionalTreatments** *(list) --*

            An array of requests that defines additional treatments for the campaign, in addition to
            the default treatment for the campaign.

            - *(dict) --*

              Specifies the settings for a campaign treatment. A treatment is a variation of a
              campaign that's used for A/B testing of a campaign.

              - **MessageConfiguration** *(dict) --*

                The message configuration settings for the treatment.

                - **ADMMessage** *(dict) --*

                  The message that the campaign sends through the ADM (Amazon Device Messaging)
                  channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **APNSMessage** *(dict) --*

                  The message that the campaign sends through the APNs (Apple Push Notification
                  service) channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **BaiduMessage** *(dict) --*

                  The message that the campaign sends through the Baidu (Baidu Cloud Push) channel.
                  This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **DefaultMessage** *(dict) --*

                  The default message that the campaign sends through all the channels that are
                  configured for the campaign.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **EmailMessage** *(dict) --*

                  The message that the campaign sends through the email channel.

                  - **Body** *(string) --*

                    The body of the email for recipients whose email clients don't render HTML
                    content.

                  - **FromAddress** *(string) --*

                    The verified email address to send the email from. The default address is the
                    FromAddress specified for the email channel for the application.

                  - **HtmlBody** *(string) --*

                    The body of the email, in HTML format, for recipients whose email clients render
                    HTML content.

                  - **Title** *(string) --* **[REQUIRED]**

                    The subject line, or title, of the email.

                - **GCMMessage** *(dict) --*

                  The message that the campaign sends through the GCM channel, which enables Amazon
                  Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM),
                  formerly Google Cloud Messaging (GCM), service. This message overrides the default
                  message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **SMSMessage** *(dict) --*

                  The message that the campaign sends through the SMS channel.

                  - **Body** *(string) --*

                    The body of the SMS message.

                  - **MessageType** *(string) --*

                    The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                    critical or time-sensitive, such as a one-time password that supports a customer
                    transaction; and, PROMOTIONAL, the message isn't critical or time-sensitive,
                    such as a marketing message.

                  - **SenderId** *(string) --*

                    The sender ID to display on recipients' devices when they receive the SMS
                    message.

              - **Schedule** *(dict) --*

                The schedule settings for the treatment.

                - **EndTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                - **EventFilter** *(dict) --*

                  The type of event that causes the campaign to be sent, if the value of the
                  Frequency property is EVENT.

                  - **Dimensions** *(dict) --* **[REQUIRED]**

                    The dimension settings of the event filter for the campaign.

                    - **Attributes** *(dict) --*

                      One or more custom attributes that your application reports to Amazon
                      Pinpoint. You can use these attributes as selection criteria when you create
                      an event filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --* **[REQUIRED]**

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                    - **EventType** *(dict) --*

                      The name of the event that causes the campaign to be sent or the journey
                      activity to be performed. This can be a standard type of event that Amazon
                      Pinpoint generates, such as _email.delivered, or a custom event that's
                      specific to your application.

                      - **DimensionType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --* **[REQUIRED]**

                        The criteria values to use for the segment dimension. Depending on the value
                        of the DimensionType property, endpoints are included or excluded from the
                        segment if their values match the criteria values.

                        - *(string) --*

                    - **Metrics** *(dict) --*

                      One or more custom metrics that your application reports to Amazon Pinpoint.
                      You can use these metrics as selection criteria when you create an event
                      filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies metric-based criteria for including or excluding endpoints from
                          a segment. These criteria derive from custom metrics that you define for
                          endpoints.

                          - **ComparisonOperator** *(string) --* **[REQUIRED]**

                            The operator to use when comparing metric values. Valid values are:
                            GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                            EQUAL.

                          - **Value** *(float) --* **[REQUIRED]**

                            The value to compare.

                  - **FilterType** *(string) --* **[REQUIRED]**

                    The type of event that causes the campaign to be sent. Valid values are: SYSTEM,
                    sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign
                    when an endpoint event (Events resource) occurs.

                - **Frequency** *(string) --*

                  Specifies how often the campaign is sent or whether the campaign is sent in
                  response to a specific event.

                - **IsLocalTime** *(boolean) --*

                  Specifies whether the start and end times for the campaign schedule use each
                  recipient's local time. To base the schedule on each recipient's local time, set
                  this value to true.

                - **QuietTime** *(dict) --*

                  The default quiet time for the campaign. Quiet time is a specific time range when
                  a campaign doesn't send messages to endpoints, if all the following conditions are
                  met:

                  * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                  value.

                  * The current time in the endpoint's time zone is later than or equal to the time
                  specified by the QuietTime.Start property for the campaign.

                  * The current time in the endpoint's time zone is earlier than or equal to the
                  time specified by the QuietTime.End property for the campaign.

                  If any of the preceding conditions isn't met, the endpoint will receive messages
                  from the campaign, even if quiet time is enabled.

                  - **End** *(string) --*

                    The specific time when quiet time ends. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                  - **Start** *(string) --*

                    The specific time when quiet time begins. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                - **StartTime** *(string) --* **[REQUIRED]**

                  The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the campaign schedule, if the value of the IsLocalTime
                  property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30,
                  UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07,
                  UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02,
                  UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.

              - **SizePercent** *(integer) --* **[REQUIRED]**

                The allocated percentage of users (segment members) to send the treatment to.

              - **TemplateConfiguration** *(dict) --*

                The message template to use for the treatment.

                - **EmailTemplate** *(dict) --*

                  The email template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **PushTemplate** *(dict) --*

                  The push notification template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **SMSTemplate** *(dict) --*

                  The SMS template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **VoiceTemplate** *(dict) --*

                  The voice template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

              - **TreatmentDescription** *(string) --*

                A custom description of the treatment.

              - **TreatmentName** *(string) --*

                The custom name of the treatment. A treatment is a variation of a campaign that's
                used for A/B testing of a campaign.

          - **Description** *(string) --*

            A custom description of the campaign.

          - **HoldoutPercent** *(integer) --*

            The allocated percentage of users (segment members) who shouldn't receive messages from
            the campaign.

          - **Hook** *(dict) --*

            The settings for the AWS Lambda function to use as a code hook for the campaign.

            - **LambdaFunctionName** *(string) --*

              The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint
              invokes to send messages for a campaign.

            - **Mode** *(string) --*

              Specifies which Lambda mode to use when invoking the AWS Lambda function.

            - **WebUrl** *(string) --*

              The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.

          - **IsPaused** *(boolean) --*

            Specifies whether to pause the campaign. A paused campaign doesn't run unless you resume
            it by setting this value to false.

          - **Limits** *(dict) --*

            The messaging limits for the campaign.

            - **Daily** *(integer) --*

              The maximum number of messages that a campaign can send to a single endpoint during a
              24-hour period. The maximum value is 100.

            - **MaximumDuration** *(integer) --*

              The maximum amount of time, in seconds, that a campaign can attempt to deliver a
              message after the scheduled start time for the campaign. The minimum value is 60
              seconds.

            - **MessagesPerSecond** *(integer) --*

              The maximum number of messages that a campaign can send each second. The minimum value
              is 50. The maximum value is 20,000.

            - **Total** *(integer) --*

              The maximum number of messages that a campaign can send to a single endpoint during
              the course of the campaign. The maximum value is 100.

          - **MessageConfiguration** *(dict) --*

            The message configuration settings for the campaign.

            - **ADMMessage** *(dict) --*

              The message that the campaign sends through the ADM (Amazon Device Messaging) channel.
              This message overrides the default message.

              - **Action** *(string) --*

                The action to occur if a recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of iOS and Android.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message. The maximum number of characters is 200.

              - **ImageIconUrl** *(string) --*

                The URL of the image to display as the push-notification icon, such as the icon for
                the app.

              - **ImageSmallIconUrl** *(string) --*

                The URL of the image to display as the small, push-notification icon, such as a
                small version of the icon for the app.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **JsonBody** *(string) --*

                The JSON payload to use for a silent push notification.

              - **MediaUrl** *(string) --*

                The URL of the image or video to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration, displaying messages
                in an in-app message center, or supporting phone home functionality.

              - **TimeToLive** *(integer) --*

                The number of seconds that the push-notification service should keep the message, if
                the service is unable to deliver the notification the first time. This value is
                converted to an expiration value when it's sent to a push-notification service. If
                this value is 0, the service treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                This value doesn't apply to messages that are sent through the Amazon Device
                Messaging (ADM) service.

              - **Title** *(string) --*

                The title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The URL to open in a recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **APNSMessage** *(dict) --*

              The message that the campaign sends through the APNs (Apple Push Notification service)
              channel. This message overrides the default message.

              - **Action** *(string) --*

                The action to occur if a recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of iOS and Android.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message. The maximum number of characters is 200.

              - **ImageIconUrl** *(string) --*

                The URL of the image to display as the push-notification icon, such as the icon for
                the app.

              - **ImageSmallIconUrl** *(string) --*

                The URL of the image to display as the small, push-notification icon, such as a
                small version of the icon for the app.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **JsonBody** *(string) --*

                The JSON payload to use for a silent push notification.

              - **MediaUrl** *(string) --*

                The URL of the image or video to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration, displaying messages
                in an in-app message center, or supporting phone home functionality.

              - **TimeToLive** *(integer) --*

                The number of seconds that the push-notification service should keep the message, if
                the service is unable to deliver the notification the first time. This value is
                converted to an expiration value when it's sent to a push-notification service. If
                this value is 0, the service treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                This value doesn't apply to messages that are sent through the Amazon Device
                Messaging (ADM) service.

              - **Title** *(string) --*

                The title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The URL to open in a recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **BaiduMessage** *(dict) --*

              The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. This
              message overrides the default message.

              - **Action** *(string) --*

                The action to occur if a recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of iOS and Android.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message. The maximum number of characters is 200.

              - **ImageIconUrl** *(string) --*

                The URL of the image to display as the push-notification icon, such as the icon for
                the app.

              - **ImageSmallIconUrl** *(string) --*

                The URL of the image to display as the small, push-notification icon, such as a
                small version of the icon for the app.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **JsonBody** *(string) --*

                The JSON payload to use for a silent push notification.

              - **MediaUrl** *(string) --*

                The URL of the image or video to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration, displaying messages
                in an in-app message center, or supporting phone home functionality.

              - **TimeToLive** *(integer) --*

                The number of seconds that the push-notification service should keep the message, if
                the service is unable to deliver the notification the first time. This value is
                converted to an expiration value when it's sent to a push-notification service. If
                this value is 0, the service treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                This value doesn't apply to messages that are sent through the Amazon Device
                Messaging (ADM) service.

              - **Title** *(string) --*

                The title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The URL to open in a recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **DefaultMessage** *(dict) --*

              The default message that the campaign sends through all the channels that are
              configured for the campaign.

              - **Action** *(string) --*

                The action to occur if a recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of iOS and Android.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message. The maximum number of characters is 200.

              - **ImageIconUrl** *(string) --*

                The URL of the image to display as the push-notification icon, such as the icon for
                the app.

              - **ImageSmallIconUrl** *(string) --*

                The URL of the image to display as the small, push-notification icon, such as a
                small version of the icon for the app.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **JsonBody** *(string) --*

                The JSON payload to use for a silent push notification.

              - **MediaUrl** *(string) --*

                The URL of the image or video to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration, displaying messages
                in an in-app message center, or supporting phone home functionality.

              - **TimeToLive** *(integer) --*

                The number of seconds that the push-notification service should keep the message, if
                the service is unable to deliver the notification the first time. This value is
                converted to an expiration value when it's sent to a push-notification service. If
                this value is 0, the service treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                This value doesn't apply to messages that are sent through the Amazon Device
                Messaging (ADM) service.

              - **Title** *(string) --*

                The title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The URL to open in a recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **EmailMessage** *(dict) --*

              The message that the campaign sends through the email channel.

              - **Body** *(string) --*

                The body of the email for recipients whose email clients don't render HTML content.

              - **FromAddress** *(string) --*

                The verified email address to send the email from. The default address is the
                FromAddress specified for the email channel for the application.

              - **HtmlBody** *(string) --*

                The body of the email, in HTML format, for recipients whose email clients render
                HTML content.

              - **Title** *(string) --* **[REQUIRED]**

                The subject line, or title, of the email.

            - **GCMMessage** *(dict) --*

              The message that the campaign sends through the GCM channel, which enables Amazon
              Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM),
              formerly Google Cloud Messaging (GCM), service. This message overrides the default
              message.

              - **Action** *(string) --*

                The action to occur if a recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of iOS and Android.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message. The maximum number of characters is 200.

              - **ImageIconUrl** *(string) --*

                The URL of the image to display as the push-notification icon, such as the icon for
                the app.

              - **ImageSmallIconUrl** *(string) --*

                The URL of the image to display as the small, push-notification icon, such as a
                small version of the icon for the app.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **JsonBody** *(string) --*

                The JSON payload to use for a silent push notification.

              - **MediaUrl** *(string) --*

                The URL of the image or video to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration, displaying messages
                in an in-app message center, or supporting phone home functionality.

              - **TimeToLive** *(integer) --*

                The number of seconds that the push-notification service should keep the message, if
                the service is unable to deliver the notification the first time. This value is
                converted to an expiration value when it's sent to a push-notification service. If
                this value is 0, the service treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                This value doesn't apply to messages that are sent through the Amazon Device
                Messaging (ADM) service.

              - **Title** *(string) --*

                The title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The URL to open in a recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **SMSMessage** *(dict) --*

              The message that the campaign sends through the SMS channel.

              - **Body** *(string) --*

                The body of the SMS message.

              - **MessageType** *(string) --*

                The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or
                time-sensitive, such as a one-time password that supports a customer transaction;
                and, PROMOTIONAL, the message isn't critical or time-sensitive, such as a marketing
                message.

              - **SenderId** *(string) --*

                The sender ID to display on recipients' devices when they receive the SMS message.

          - **Name** *(string) --*

            The custom name of the campaign.

          - **Schedule** *(dict) --*

            The schedule settings for the campaign.

            - **EndTime** *(string) --*

              The scheduled time, in ISO 8601 format, when the campaign ended or will end.

            - **EventFilter** *(dict) --*

              The type of event that causes the campaign to be sent, if the value of the Frequency
              property is EVENT.

              - **Dimensions** *(dict) --* **[REQUIRED]**

                The dimension settings of the event filter for the campaign.

                - **Attributes** *(dict) --*

                  One or more custom attributes that your application reports to Amazon Pinpoint.
                  You can use these attributes as selection criteria when you create an event
                  filter.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --* **[REQUIRED]**

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

                - **EventType** *(dict) --*

                  The name of the event that causes the campaign to be sent or the journey activity
                  to be performed. This can be a standard type of event that Amazon Pinpoint
                  generates, such as _email.delivered, or a custom event that's specific to your
                  application.

                  - **DimensionType** *(string) --*

                    The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                    that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                    that match the criteria are excluded from the segment.

                  - **Values** *(list) --* **[REQUIRED]**

                    The criteria values to use for the segment dimension. Depending on the value of
                    the DimensionType property, endpoints are included or excluded from the segment
                    if their values match the criteria values.

                    - *(string) --*

                - **Metrics** *(dict) --*

                  One or more custom metrics that your application reports to Amazon Pinpoint. You
                  can use these metrics as selection criteria when you create an event filter.

                  - *(string) --*

                    - *(dict) --*

                      Specifies metric-based criteria for including or excluding endpoints from a
                      segment. These criteria derive from custom metrics that you define for
                      endpoints.

                      - **ComparisonOperator** *(string) --* **[REQUIRED]**

                        The operator to use when comparing metric values. Valid values are:
                        GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                        EQUAL.

                      - **Value** *(float) --* **[REQUIRED]**

                        The value to compare.

              - **FilterType** *(string) --* **[REQUIRED]**

                The type of event that causes the campaign to be sent. Valid values are: SYSTEM,
                sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign
                when an endpoint event (Events resource) occurs.

            - **Frequency** *(string) --*

              Specifies how often the campaign is sent or whether the campaign is sent in response
              to a specific event.

            - **IsLocalTime** *(boolean) --*

              Specifies whether the start and end times for the campaign schedule use each
              recipient's local time. To base the schedule on each recipient's local time, set this
              value to true.

            - **QuietTime** *(dict) --*

              The default quiet time for the campaign. Quiet time is a specific time range when a
              campaign doesn't send messages to endpoints, if all the following conditions are met:

              * The EndpointDemographic.Timezone property of the endpoint is set to a valid value.

              * The current time in the endpoint's time zone is later than or equal to the time
              specified by the QuietTime.Start property for the campaign.

              * The current time in the endpoint's time zone is earlier than or equal to the time
              specified by the QuietTime.End property for the campaign.

              If any of the preceding conditions isn't met, the endpoint will receive messages from
              the campaign, even if quiet time is enabled.

              - **End** *(string) --*

                The specific time when quiet time ends. This value has to use 24-hour notation and
                be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM
                is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent
                2:30 PM.

              - **Start** *(string) --*

                The specific time when quiet time begins. This value has to use 24-hour notation and
                be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM
                is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent
                2:30 PM.

            - **StartTime** *(string) --* **[REQUIRED]**

              The scheduled time, in ISO 8601 format, when the campaign began or will begin.

            - **Timezone** *(string) --*

              The starting UTC offset for the campaign schedule, if the value of the IsLocalTime
              property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04,
              UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09,
              UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05,
              UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.

          - **SegmentId** *(string) --*

            The unique identifier for the segment to associate with the campaign.

          - **SegmentVersion** *(integer) --*

            The version of the segment to associate with the campaign.

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            campaign. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

          - **TemplateConfiguration** *(dict) --*

            The message template to use for the campaign.

            - **EmailTemplate** *(dict) --*

              The email template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **PushTemplate** *(dict) --*

              The push notification template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **SMSTemplate** *(dict) --*

              The SMS template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **VoiceTemplate** *(dict) --*

              The voice template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

          - **TreatmentDescription** *(string) --*

            A custom description of a variation of the campaign to use for A/B testing.

          - **TreatmentName** *(string) --*

            The custom name of a variation of the campaign to use for A/B testing.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CampaignResponse': {
                    'AdditionalTreatments': [
                        {
                            'Id': 'string',
                            'MessageConfiguration': {
                                'ADMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'APNSMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'BaiduMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'DefaultMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'EmailMessage': {
                                    'Body': 'string',
                                    'FromAddress': 'string',
                                    'HtmlBody': 'string',
                                    'Title': 'string'
                                },
                                'GCMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'SMSMessage': {
                                    'Body': 'string',
                                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                    'SenderId': 'string'
                                }
                            },
                            'Schedule': {
                                'EndTime': 'string',
                                'EventFilter': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'FilterType': 'SYSTEM'|'ENDPOINT'
                                },
                                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                                'IsLocalTime': True|False,
                                'QuietTime': {
                                    'End': 'string',
                                    'Start': 'string'
                                },
                                'StartTime': 'string',
                                'Timezone': 'string'
                            },
                            'SizePercent': 123,
                            'State': {
                                'CampaignStatus':
                                'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'
                                |'COMPLETED'|'PAUSED'|'DELETED'
                            },
                            'TemplateConfiguration': {
                                'EmailTemplate': {
                                    'Name': 'string'
                                },
                                'PushTemplate': {
                                    'Name': 'string'
                                },
                                'SMSTemplate': {
                                    'Name': 'string'
                                },
                                'VoiceTemplate': {
                                    'Name': 'string'
                                }
                            },
                            'TreatmentDescription': 'string',
                            'TreatmentName': 'string'
                        },
                    ],
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'DefaultState': {
                        'CampaignStatus':
                        'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'
                        |'PAUSED'|'DELETED'
                    },
                    'Description': 'string',
                    'HoldoutPercent': 123,
                    'Hook': {
                        'LambdaFunctionName': 'string',
                        'Mode': 'DELIVERY'|'FILTER',
                        'WebUrl': 'string'
                    },
                    'Id': 'string',
                    'IsPaused': True|False,
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'Daily': 123,
                        'MaximumDuration': 123,
                        'MessagesPerSecond': 123,
                        'Total': 123
                    },
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Name': 'string',
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SegmentId': 'string',
                    'SegmentVersion': 123,
                    'State': {
                        'CampaignStatus':
                        'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'
                        |'PAUSED'|'DELETED'
                    },
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded and the specified resource was created.

            - **CampaignResponse** *(dict) --*

              Provides information about the status, configuration, and other settings for a
              campaign.

              - **AdditionalTreatments** *(list) --*

                An array of responses, one for each treatment that you defined for the campaign, in
                addition to the default treatment.

                - *(dict) --*

                  Specifies the settings for a campaign treatment. A treatment is a variation of a
                  campaign that's used for A/B testing of a campaign.

                  - **Id** *(string) --*

                    The unique identifier for the treatment.

                  - **MessageConfiguration** *(dict) --*

                    The message configuration settings for the treatment.

                    - **ADMMessage** *(dict) --*

                      The message that the campaign sends through the ADM (Amazon Device Messaging)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **APNSMessage** *(dict) --*

                      The message that the campaign sends through the APNs (Apple Push Notification
                      service) channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **BaiduMessage** *(dict) --*

                      The message that the campaign sends through the Baidu (Baidu Cloud Push)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **DefaultMessage** *(dict) --*

                      The default message that the campaign sends through all the channels that are
                      configured for the campaign.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **EmailMessage** *(dict) --*

                      The message that the campaign sends through the email channel.

                      - **Body** *(string) --*

                        The body of the email for recipients whose email clients don't render HTML
                        content.

                      - **FromAddress** *(string) --*

                        The verified email address to send the email from. The default address is
                        the FromAddress specified for the email channel for the application.

                      - **HtmlBody** *(string) --*

                        The body of the email, in HTML format, for recipients whose email clients
                        render HTML content.

                      - **Title** *(string) --*

                        The subject line, or title, of the email.

                    - **GCMMessage** *(dict) --*

                      The message that the campaign sends through the GCM channel, which enables
                      Amazon Pinpoint to send push notifications through the Firebase Cloud
                      Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message
                      overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **SMSMessage** *(dict) --*

                      The message that the campaign sends through the SMS channel.

                      - **Body** *(string) --*

                        The body of the SMS message.

                      - **MessageType** *(string) --*

                        The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                        critical or time-sensitive, such as a one-time password that supports a
                        customer transaction; and, PROMOTIONAL, the message isn't critical or
                        time-sensitive, such as a marketing message.

                      - **SenderId** *(string) --*

                        The sender ID to display on recipients' devices when they receive the SMS
                        message.

                  - **Schedule** *(dict) --*

                    The schedule settings for the treatment.

                    - **EndTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                    - **EventFilter** *(dict) --*

                      The type of event that causes the campaign to be sent, if the value of the
                      Frequency property is EVENT.

                      - **Dimensions** *(dict) --*

                        The dimension settings of the event filter for the campaign.

                        - **Attributes** *(dict) --*

                          One or more custom attributes that your application reports to Amazon
                          Pinpoint. You can use these attributes as selection criteria when you
                          create an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **EventType** *(dict) --*

                          The name of the event that causes the campaign to be sent or the journey
                          activity to be performed. This can be a standard type of event that Amazon
                          Pinpoint generates, such as _email.delivered, or a custom event that's
                          specific to your application.

                          - **DimensionType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the DimensionType property, endpoints are included or excluded
                            from the segment if their values match the criteria values.

                            - *(string) --*

                        - **Metrics** *(dict) --*

                          One or more custom metrics that your application reports to Amazon
                          Pinpoint. You can use these metrics as selection criteria when you create
                          an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                      - **FilterType** *(string) --*

                        The type of event that causes the campaign to be sent. Valid values are:
                        SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends
                        the campaign when an endpoint event (Events resource) occurs.

                    - **Frequency** *(string) --*

                      Specifies how often the campaign is sent or whether the campaign is sent in
                      response to a specific event.

                    - **IsLocalTime** *(boolean) --*

                      Specifies whether the start and end times for the campaign schedule use each
                      recipient's local time. To base the schedule on each recipient's local time,
                      set this value to true.

                    - **QuietTime** *(dict) --*

                      The default quiet time for the campaign. Quiet time is a specific time range
                      when a campaign doesn't send messages to endpoints, if all the following
                      conditions are met:

                      * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                      value.

                      * The current time in the endpoint's time zone is later than or equal to the
                      time specified by the QuietTime.Start property for the campaign.

                      * The current time in the endpoint's time zone is earlier than or equal to the
                      time specified by the QuietTime.End property for the campaign.

                      If any of the preceding conditions isn't met, the endpoint will receive
                      messages from the campaign, even if quiet time is enabled.

                      - **End** *(string) --*

                        The specific time when quiet time ends. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                      - **Start** *(string) --*

                        The specific time when quiet time begins. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                    - **StartTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                    - **Timezone** *(string) --*

                      The starting UTC offset for the campaign schedule, if the value of the
                      IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                      UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                      UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13,
                      UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and
                      UTC-11.

                  - **SizePercent** *(integer) --*

                    The allocated percentage of users (segment members) that the treatment is sent
                    to.

                  - **State** *(dict) --*

                    The current status of the treatment.

                    - **CampaignStatus** *(string) --*

                      The current status of the campaign, or the current status of a treatment that
                      belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign
                      has a status of COMPLETED only if all campaign treatments have a status of
                      COMPLETED.

                  - **TemplateConfiguration** *(dict) --*

                    The message template to use for the treatment.

                    - **EmailTemplate** *(dict) --*

                      The email template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **PushTemplate** *(dict) --*

                      The push notification template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **SMSTemplate** *(dict) --*

                      The SMS template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **VoiceTemplate** *(dict) --*

                      The voice template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                  - **TreatmentDescription** *(string) --*

                    The custom description of the treatment.

                  - **TreatmentName** *(string) --*

                    The custom name of the treatment. A treatment is a variation of a campaign
                    that's used for A/B testing of a campaign.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the campaign applies to.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the campaign.

              - **CreationDate** *(string) --*

                The date, ISO 8601 format, when the campaign was created.

              - **DefaultState** *(dict) --*

                The current status of the campaign's default treatment. This value exists only for
                campaigns that have more than one treatment, to support A/B testing.

                - **CampaignStatus** *(string) --*

                  The current status of the campaign, or the current status of a treatment that
                  belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign has
                  a status of COMPLETED only if all campaign treatments have a status of COMPLETED.

              - **Description** *(string) --*

                The custom description of the campaign.

              - **HoldoutPercent** *(integer) --*

                The allocated percentage of users (segment members) who shouldn't receive messages
                from the campaign.

              - **Hook** *(dict) --*

                The settings for the AWS Lambda function to use as a code hook for the campaign.

                - **LambdaFunctionName** *(string) --*

                  The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon
                  Pinpoint invokes to send messages for a campaign.

                - **Mode** *(string) --*

                  Specifies which Lambda mode to use when invoking the AWS Lambda function.

                - **WebUrl** *(string) --*

                  The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over
                  HTTPS.

              - **Id** *(string) --*

                The unique identifier for the campaign.

              - **IsPaused** *(boolean) --*

                Specifies whether the campaign is paused. A paused campaign doesn't run unless you
                resume it by changing this value to false.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the campaign was last modified.

              - **Limits** *(dict) --*

                The messaging limits for the campaign.

                - **Daily** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during a 24-hour period. The maximum value is 100.

                - **MaximumDuration** *(integer) --*

                  The maximum amount of time, in seconds, that a campaign can attempt to deliver a
                  message after the scheduled start time for the campaign. The minimum value is 60
                  seconds.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that a campaign can send each second. The minimum
                  value is 50. The maximum value is 20,000.

                - **Total** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during the course of the campaign. The maximum value is 100.

              - **MessageConfiguration** *(dict) --*

                The message configuration settings for the campaign.

                - **ADMMessage** *(dict) --*

                  The message that the campaign sends through the ADM (Amazon Device Messaging)
                  channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **APNSMessage** *(dict) --*

                  The message that the campaign sends through the APNs (Apple Push Notification
                  service) channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **BaiduMessage** *(dict) --*

                  The message that the campaign sends through the Baidu (Baidu Cloud Push) channel.
                  This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **DefaultMessage** *(dict) --*

                  The default message that the campaign sends through all the channels that are
                  configured for the campaign.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **EmailMessage** *(dict) --*

                  The message that the campaign sends through the email channel.

                  - **Body** *(string) --*

                    The body of the email for recipients whose email clients don't render HTML
                    content.

                  - **FromAddress** *(string) --*

                    The verified email address to send the email from. The default address is the
                    FromAddress specified for the email channel for the application.

                  - **HtmlBody** *(string) --*

                    The body of the email, in HTML format, for recipients whose email clients render
                    HTML content.

                  - **Title** *(string) --*

                    The subject line, or title, of the email.

                - **GCMMessage** *(dict) --*

                  The message that the campaign sends through the GCM channel, which enables Amazon
                  Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM),
                  formerly Google Cloud Messaging (GCM), service. This message overrides the default
                  message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **SMSMessage** *(dict) --*

                  The message that the campaign sends through the SMS channel.

                  - **Body** *(string) --*

                    The body of the SMS message.

                  - **MessageType** *(string) --*

                    The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                    critical or time-sensitive, such as a one-time password that supports a customer
                    transaction; and, PROMOTIONAL, the message isn't critical or time-sensitive,
                    such as a marketing message.

                  - **SenderId** *(string) --*

                    The sender ID to display on recipients' devices when they receive the SMS
                    message.

              - **Name** *(string) --*

                The name of the campaign.

              - **Schedule** *(dict) --*

                The schedule settings for the campaign.

                - **EndTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                - **EventFilter** *(dict) --*

                  The type of event that causes the campaign to be sent, if the value of the
                  Frequency property is EVENT.

                  - **Dimensions** *(dict) --*

                    The dimension settings of the event filter for the campaign.

                    - **Attributes** *(dict) --*

                      One or more custom attributes that your application reports to Amazon
                      Pinpoint. You can use these attributes as selection criteria when you create
                      an event filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                    - **EventType** *(dict) --*

                      The name of the event that causes the campaign to be sent or the journey
                      activity to be performed. This can be a standard type of event that Amazon
                      Pinpoint generates, such as _email.delivered, or a custom event that's
                      specific to your application.

                      - **DimensionType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the DimensionType property, endpoints are included or excluded from the
                        segment if their values match the criteria values.

                        - *(string) --*

                    - **Metrics** *(dict) --*

                      One or more custom metrics that your application reports to Amazon Pinpoint.
                      You can use these metrics as selection criteria when you create an event
                      filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies metric-based criteria for including or excluding endpoints from
                          a segment. These criteria derive from custom metrics that you define for
                          endpoints.

                          - **ComparisonOperator** *(string) --*

                            The operator to use when comparing metric values. Valid values are:
                            GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                            EQUAL.

                          - **Value** *(float) --*

                            The value to compare.

                  - **FilterType** *(string) --*

                    The type of event that causes the campaign to be sent. Valid values are: SYSTEM,
                    sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign
                    when an endpoint event (Events resource) occurs.

                - **Frequency** *(string) --*

                  Specifies how often the campaign is sent or whether the campaign is sent in
                  response to a specific event.

                - **IsLocalTime** *(boolean) --*

                  Specifies whether the start and end times for the campaign schedule use each
                  recipient's local time. To base the schedule on each recipient's local time, set
                  this value to true.

                - **QuietTime** *(dict) --*

                  The default quiet time for the campaign. Quiet time is a specific time range when
                  a campaign doesn't send messages to endpoints, if all the following conditions are
                  met:

                  * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                  value.

                  * The current time in the endpoint's time zone is later than or equal to the time
                  specified by the QuietTime.Start property for the campaign.

                  * The current time in the endpoint's time zone is earlier than or equal to the
                  time specified by the QuietTime.End property for the campaign.

                  If any of the preceding conditions isn't met, the endpoint will receive messages
                  from the campaign, even if quiet time is enabled.

                  - **End** *(string) --*

                    The specific time when quiet time ends. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                  - **Start** *(string) --*

                    The specific time when quiet time begins. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                - **StartTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the campaign schedule, if the value of the IsLocalTime
                  property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30,
                  UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07,
                  UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02,
                  UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.

              - **SegmentId** *(string) --*

                The unique identifier for the segment that's associated with the campaign.

              - **SegmentVersion** *(integer) --*

                The version number of the segment that's associated with the campaign.

              - **State** *(dict) --*

                The current status of the campaign.

                - **CampaignStatus** *(string) --*

                  The current status of the campaign, or the current status of a treatment that
                  belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign has
                  a status of COMPLETED only if all campaign treatments have a status of COMPLETED.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the campaign. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **TemplateConfiguration** *(dict) --*

                The message template that’s used for the campaign.

                - **EmailTemplate** *(dict) --*

                  The email template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **PushTemplate** *(dict) --*

                  The push notification template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **SMSTemplate** *(dict) --*

                  The SMS template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **VoiceTemplate** *(dict) --*

                  The voice template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

              - **TreatmentDescription** *(string) --*

                The custom description of a variation of the campaign that's used for A/B testing.

              - **TreatmentName** *(string) --*

                The custom name of a variation of the campaign that's used for A/B testing.

              - **Version** *(integer) --*

                The version number of the campaign.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_email_template(
        self,
        EmailTemplateRequest: ClientCreateEmailTemplateEmailTemplateRequestTypeDef,
        TemplateName: str,
    ) -> ClientCreateEmailTemplateResponseTypeDef:
        """
        Creates a message template that you can use in messages that are sent through the email
        channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/CreateEmailTemplate>`_

        **Request Syntax**
        ::

          response = client.create_email_template(
              EmailTemplateRequest={
                  'DefaultSubstitutions': 'string',
                  'HtmlPart': 'string',
                  'Subject': 'string',
                  'tags': {
                      'string': 'string'
                  },
                  'TemplateDescription': 'string',
                  'TextPart': 'string'
              },
              TemplateName='string'
          )
        :type EmailTemplateRequest: dict
        :param EmailTemplateRequest: **[REQUIRED]**

          Creates a new message template that you can use in messages that are sent through the
          email channel.

          - **DefaultSubstitutions** *(string) --*

            A JSON object that specifies the default values to use for message variables in the
            message template. This object is a set of key-value pairs. Each key defines a message
            variable in the template. The corresponding value defines the default value for that
            variable. When you create a message that's based on the template, you can override these
            defaults with message-specific and address-specific variables and values.

          - **HtmlPart** *(string) --*

            The message body, in HTML format, to use in email messages that are based on the message
            template. We recommend using HTML format for email clients that render HTML content. You
            can include links, formatted text, and more in an HTML message.

          - **Subject** *(string) --*

            The subject line, or title, to use in email messages that are based on the message
            template.

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            message template. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

          - **TemplateDescription** *(string) --*

            A custom description of the message template.

          - **TextPart** *(string) --*

            The message body, in plain text format, to use in email messages that are based on the
            message template. We recommend using plain text format for email clients that don't
            render HTML content and clients that are connected to high-latency networks, such as
            mobile devices.

        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CreateTemplateMessageBody': {
                    'Arn': 'string',
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded and the specified resource was created.

            - **CreateTemplateMessageBody** *(dict) --*

              Provides information about a request to create a message template.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the message template that was created.

              - **Message** *(string) --*

                The message that's returned from the API for the request to create the message
                template.

              - **RequestID** *(string) --*

                The unique identifier for the request to create the message template.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_export_job(
        self, ApplicationId: str, ExportJobRequest: ClientCreateExportJobExportJobRequestTypeDef
    ) -> ClientCreateExportJobResponseTypeDef:
        """
        Creates an export job for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/CreateExportJob>`_

        **Request Syntax**
        ::

          response = client.create_export_job(
              ApplicationId='string',
              ExportJobRequest={
                  'RoleArn': 'string',
                  'S3UrlPrefix': 'string',
                  'SegmentId': 'string',
                  'SegmentVersion': 123
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type ExportJobRequest: dict
        :param ExportJobRequest: **[REQUIRED]**

          Specifies the settings for a job that exports endpoint definitions to an Amazon Simple
          Storage Service (Amazon S3) bucket.

          - **RoleArn** *(string) --* **[REQUIRED]**

            The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that
            authorizes Amazon Pinpoint to access the Amazon S3 location where you want to export
            endpoint definitions to.

          - **S3UrlPrefix** *(string) --* **[REQUIRED]**

            The URL of the location in an Amazon Simple Storage Service (Amazon S3) bucket where you
            want to export endpoint definitions to. This location is typically a folder that
            contains multiple files. The URL should be in the following format:
            s3://bucket-name/folder-name/.

          - **SegmentId** *(string) --*

            The identifier for the segment to export endpoint definitions from. If you don't specify
            this value, Amazon Pinpoint exports definitions for all the endpoints that are
            associated with the application.

          - **SegmentVersion** *(integer) --*

            The version of the segment to export endpoint definitions from, if specified.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ExportJobResponse': {
                    'ApplicationId': 'string',
                    'CompletedPieces': 123,
                    'CompletionDate': 'string',
                    'CreationDate': 'string',
                    'Definition': {
                        'RoleArn': 'string',
                        'S3UrlPrefix': 'string',
                        'SegmentId': 'string',
                        'SegmentVersion': 123
                    },
                    'FailedPieces': 123,
                    'Failures': [
                        'string',
                    ],
                    'Id': 'string',
                    'JobStatus':
                    'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'
                    |'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                    'TotalFailures': 123,
                    'TotalPieces': 123,
                    'TotalProcessed': 123,
                    'Type': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **ExportJobResponse** *(dict) --*

              Provides information about the status and settings of a job that exports endpoint
              definitions to a file. The file can be added directly to an Amazon Simple Storage
              Service (Amazon S3) bucket by using the Amazon Pinpoint API or downloaded directly to
              a computer by using the Amazon Pinpoint console.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that's associated with the export job.

              - **CompletedPieces** *(integer) --*

                The number of pieces that were processed successfully (completed) by the export job,
                as of the time of the request.

              - **CompletionDate** *(string) --*

                The date, in ISO 8601 format, when the export job was completed.

              - **CreationDate** *(string) --*

                The date, in ISO 8601 format, when the export job was created.

              - **Definition** *(dict) --*

                The resource settings that apply to the export job.

                - **RoleArn** *(string) --*

                  The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                  role that authorized Amazon Pinpoint to access the Amazon S3 location where the
                  endpoint definitions were exported to.

                - **S3UrlPrefix** *(string) --*

                  The URL of the location in an Amazon Simple Storage Service (Amazon S3) bucket
                  where the endpoint definitions were exported to. This location is typically a
                  folder that contains multiple files. The URL should be in the following format:
                  s3://bucket-name/folder-name/.

                - **SegmentId** *(string) --*

                  The identifier for the segment that the endpoint definitions were exported from.
                  If this value isn't present, Amazon Pinpoint exported definitions for all the
                  endpoints that are associated with the application.

                - **SegmentVersion** *(integer) --*

                  The version of the segment that the endpoint definitions were exported from.

              - **FailedPieces** *(integer) --*

                The number of pieces that weren't processed successfully (failed) by the export job,
                as of the time of the request.

              - **Failures** *(list) --*

                An array of entries, one for each of the first 100 entries that weren't processed
                successfully (failed) by the export job, if any.

                - *(string) --*

              - **Id** *(string) --*

                The unique identifier for the export job.

              - **JobStatus** *(string) --*

                The status of the export job. The job status is FAILED if Amazon Pinpoint wasn't
                able to process one or more pieces in the job.

              - **TotalFailures** *(integer) --*

                The total number of endpoint definitions that weren't processed successfully
                (failed) by the export job, typically because an error, such as a syntax error,
                occurred.

              - **TotalPieces** *(integer) --*

                The total number of pieces that must be processed to complete the export job. Each
                piece consists of an approximately equal portion of the endpoint definitions that
                are part of the export job.

              - **TotalProcessed** *(integer) --*

                The total number of endpoint definitions that were processed by the export job.

              - **Type** *(string) --*

                The job type. This value is EXPORT for export jobs.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_import_job(
        self, ApplicationId: str, ImportJobRequest: ClientCreateImportJobImportJobRequestTypeDef
    ) -> ClientCreateImportJobResponseTypeDef:
        """
        Creates an import job for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/CreateImportJob>`_

        **Request Syntax**
        ::

          response = client.create_import_job(
              ApplicationId='string',
              ImportJobRequest={
                  'DefineSegment': True|False,
                  'ExternalId': 'string',
                  'Format': 'CSV'|'JSON',
                  'RegisterEndpoints': True|False,
                  'RoleArn': 'string',
                  'S3Url': 'string',
                  'SegmentId': 'string',
                  'SegmentName': 'string'
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type ImportJobRequest: dict
        :param ImportJobRequest: **[REQUIRED]**

          Specifies the settings for a job that imports endpoint definitions from an Amazon Simple
          Storage Service (Amazon S3) bucket.

          - **DefineSegment** *(boolean) --*

            Specifies whether to create a segment that contains the endpoints, when the endpoint
            definitions are imported.

          - **ExternalId** *(string) --*

            (Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM
            trust policy. Amazon Pinpoint previously used this value to assume an IAM role when
            importing endpoint definitions, but we removed this requirement. We don't recommend use
            of external IDs for IAM roles that are assumed by Amazon Pinpoint.

          - **Format** *(string) --* **[REQUIRED]**

            The format of the files that contain the endpoint definitions to import. Valid values
            are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON
            format. If the Amazon S3 location stores multiple files that use different formats,
            Amazon Pinpoint imports data only from the files that use the specified format.

          - **RegisterEndpoints** *(boolean) --*

            Specifies whether to register the endpoints with Amazon Pinpoint, when the endpoint
            definitions are imported.

          - **RoleArn** *(string) --* **[REQUIRED]**

            The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that
            authorizes Amazon Pinpoint to access the Amazon S3 location to import endpoint
            definitions from.

          - **S3Url** *(string) --* **[REQUIRED]**

            The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains the
            endpoint definitions to import. This location can be a folder or a single file. If the
            location is a folder, Amazon Pinpoint imports endpoint definitions from the files in
            this location, including any subfolders that the folder contains.

            The URL should be in the following format: s3://bucket-name/folder-name/file-name. The
            location can end with the key for an individual object or a prefix that qualifies
            multiple objects.

          - **SegmentId** *(string) --*

            The identifier for the segment to update or add the imported endpoint definitions to, if
            the import job is meant to update an existing segment.

          - **SegmentName** *(string) --*

            The custom name for the segment that's created by the import job, if the value of the
            DefineSegment property is true.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ImportJobResponse': {
                    'ApplicationId': 'string',
                    'CompletedPieces': 123,
                    'CompletionDate': 'string',
                    'CreationDate': 'string',
                    'Definition': {
                        'DefineSegment': True|False,
                        'ExternalId': 'string',
                        'Format': 'CSV'|'JSON',
                        'RegisterEndpoints': True|False,
                        'RoleArn': 'string',
                        'S3Url': 'string',
                        'SegmentId': 'string',
                        'SegmentName': 'string'
                    },
                    'FailedPieces': 123,
                    'Failures': [
                        'string',
                    ],
                    'Id': 'string',
                    'JobStatus':
                    'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'
                    |'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                    'TotalFailures': 123,
                    'TotalPieces': 123,
                    'TotalProcessed': 123,
                    'Type': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded and the specified resource was created.

            - **ImportJobResponse** *(dict) --*

              Provides information about the status and settings of a job that imports endpoint
              definitions from one or more files. The files can be stored in an Amazon Simple
              Storage Service (Amazon S3) bucket or uploaded directly from a computer by using the
              Amazon Pinpoint console.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that's associated with the import job.

              - **CompletedPieces** *(integer) --*

                The number of pieces that were processed successfully (completed) by the import job,
                as of the time of the request.

              - **CompletionDate** *(string) --*

                The date, in ISO 8601 format, when the import job was completed.

              - **CreationDate** *(string) --*

                The date, in ISO 8601 format, when the import job was created.

              - **Definition** *(dict) --*

                The resource settings that apply to the import job.

                - **DefineSegment** *(boolean) --*

                  Specifies whether the import job creates a segment that contains the endpoints,
                  when the endpoint definitions are imported.

                - **ExternalId** *(string) --*

                  (Deprecated) Your AWS account ID, which you assigned to an external ID key in an
                  IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role
                  when importing endpoint definitions, but we removed this requirement. We don't
                  recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

                - **Format** *(string) --*

                  The format of the files that contain the endpoint definitions to import. Valid
                  values are: CSV, for comma-separated values format; and, JSON, for
                  newline-delimited JSON format.

                  If the files are stored in an Amazon S3 location and that location contains
                  multiple files that use different formats, Amazon Pinpoint imports data only from
                  the files that use the specified format.

                - **RegisterEndpoints** *(boolean) --*

                  Specifies whether the import job registers the endpoints with Amazon Pinpoint,
                  when the endpoint definitions are imported.

                - **RoleArn** *(string) --*

                  The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                  role that authorizes Amazon Pinpoint to access the Amazon S3 location to import
                  endpoint definitions from.

                - **S3Url** *(string) --*

                  The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains the
                  endpoint definitions to import. This location can be a folder or a single file. If
                  the location is a folder, Amazon Pinpoint imports endpoint definitions from the
                  files in this location, including any subfolders that the folder contains.

                  The URL should be in the following format: s3://bucket-name/folder-name/file-name.
                  The location can end with the key for an individual object or a prefix that
                  qualifies multiple objects.

                - **SegmentId** *(string) --*

                  The identifier for the segment that the import job updates or adds endpoint
                  definitions to, if the import job updates an existing segment.

                - **SegmentName** *(string) --*

                  The custom name for the segment that's created by the import job, if the value of
                  the DefineSegment property is true.

              - **FailedPieces** *(integer) --*

                The number of pieces that weren't processed successfully (failed) by the import job,
                as of the time of the request.

              - **Failures** *(list) --*

                An array of entries, one for each of the first 100 entries that weren't processed
                successfully (failed) by the import job, if any.

                - *(string) --*

              - **Id** *(string) --*

                The unique identifier for the import job.

              - **JobStatus** *(string) --*

                The status of the import job. The job status is FAILED if Amazon Pinpoint wasn't
                able to process one or more pieces in the job.

              - **TotalFailures** *(integer) --*

                The total number of endpoint definitions that weren't processed successfully
                (failed) by the import job, typically because an error, such as a syntax error,
                occurred.

              - **TotalPieces** *(integer) --*

                The total number of pieces that must be processed to complete the import job. Each
                piece consists of an approximately equal portion of the endpoint definitions that
                are part of the import job.

              - **TotalProcessed** *(integer) --*

                The total number of endpoint definitions that were processed by the import job.

              - **Type** *(string) --*

                The job type. This value is IMPORT for import jobs.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_journey(
        self, ApplicationId: str, WriteJourneyRequest: ClientCreateJourneyWriteJourneyRequestTypeDef
    ) -> ClientCreateJourneyResponseTypeDef:
        """
        Creates a journey for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/CreateJourney>`_

        **Request Syntax**
        ::

          response = client.create_journey(
              ApplicationId='string',
              WriteJourneyRequest={
                  'Activities': {
                      'string': {
                          'ConditionalSplit': {
                              'Condition': {
                                  'Conditions': [
                                      {
                                          'EventCondition': {
                                              'Dimensions': {
                                                  'Attributes': {
                                                      'string': {
                                                          'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                          'Values': [
                                                              'string',
                                                          ]
                                                      }
                                                  },
                                                  'EventType': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Metrics': {
                                                      'string': {
                                                          'ComparisonOperator': 'string',
                                                          'Value': 123.0
                                                      }
                                                  }
                                              },
                                              'MessageActivity': 'string'
                                          },
                                          'SegmentCondition': {
                                              'SegmentId': 'string'
                                          },
                                          'SegmentDimensions': {
                                              'Attributes': {
                                                  'string': {
                                                      'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              },
                                              'Behavior': {
                                                  'Recency': {
                                                      'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                      'RecencyType': 'ACTIVE'|'INACTIVE'
                                                  }
                                              },
                                              'Demographic': {
                                                  'AppVersion': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Channel': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'DeviceType': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Make': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Model': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Platform': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              },
                                              'Location': {
                                                  'Country': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'GPSPoint': {
                                                      'Coordinates': {
                                                          'Latitude': 123.0,
                                                          'Longitude': 123.0
                                                      },
                                                      'RangeInKilometers': 123.0
                                                  }
                                              },
                                              'Metrics': {
                                                  'string': {
                                                      'ComparisonOperator': 'string',
                                                      'Value': 123.0
                                                  }
                                              },
                                              'UserAttributes': {
                                                  'string': {
                                                      'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              }
                                          }
                                      },
                                  ],
                                  'Operator': 'ALL'|'ANY'
                              },
                              'EvaluationWaitTime': {
                                  'WaitFor': 'string',
                                  'WaitUntil': 'string'
                              },
                              'FalseActivity': 'string',
                              'TrueActivity': 'string'
                          },
                          'Description': 'string',
                          'EMAIL': {
                              'MessageConfig': {
                                  'FromAddress': 'string'
                              },
                              'NextActivity': 'string',
                              'TemplateName': 'string'
                          },
                          'Holdout': {
                              'NextActivity': 'string',
                              'Percentage': 123
                          },
                          'MultiCondition': {
                              'Branches': [
                                  {
                                      'Condition': {
                                          'EventCondition': {
                                              'Dimensions': {
                                                  'Attributes': {
                                                      'string': {
                                                          'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                          'Values': [
                                                              'string',
                                                          ]
                                                      }
                                                  },
                                                  'EventType': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Metrics': {
                                                      'string': {
                                                          'ComparisonOperator': 'string',
                                                          'Value': 123.0
                                                      }
                                                  }
                                              },
                                              'MessageActivity': 'string'
                                          },
                                          'SegmentCondition': {
                                              'SegmentId': 'string'
                                          },
                                          'SegmentDimensions': {
                                              'Attributes': {
                                                  'string': {
                                                      'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              },
                                              'Behavior': {
                                                  'Recency': {
                                                      'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                      'RecencyType': 'ACTIVE'|'INACTIVE'
                                                  }
                                              },
                                              'Demographic': {
                                                  'AppVersion': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Channel': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'DeviceType': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Make': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Model': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Platform': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              },
                                              'Location': {
                                                  'Country': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'GPSPoint': {
                                                      'Coordinates': {
                                                          'Latitude': 123.0,
                                                          'Longitude': 123.0
                                                      },
                                                      'RangeInKilometers': 123.0
                                                  }
                                              },
                                              'Metrics': {
                                                  'string': {
                                                      'ComparisonOperator': 'string',
                                                      'Value': 123.0
                                                  }
                                              },
                                              'UserAttributes': {
                                                  'string': {
                                                      'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              }
                                          }
                                      },
                                      'NextActivity': 'string'
                                  },
                              ],
                              'DefaultActivity': 'string',
                              'EvaluationWaitTime': {
                                  'WaitFor': 'string',
                                  'WaitUntil': 'string'
                              }
                          },
                          'RandomSplit': {
                              'Branches': [
                                  {
                                      'NextActivity': 'string',
                                      'Percentage': 123
                                  },
                              ]
                          },
                          'Wait': {
                              'NextActivity': 'string',
                              'WaitTime': {
                                  'WaitFor': 'string',
                                  'WaitUntil': 'string'
                              }
                          }
                      }
                  },
                  'CreationDate': 'string',
                  'LastModifiedDate': 'string',
                  'Limits': {
                      'DailyCap': 123,
                      'EndpointReentryCap': 123,
                      'MessagesPerSecond': 123
                  },
                  'LocalTime': True|False,
                  'Name': 'string',
                  'QuietTime': {
                      'End': 'string',
                      'Start': 'string'
                  },
                  'RefreshFrequency': 'string',
                  'Schedule': {
                      'EndTime': datetime(2015, 1, 1),
                      'StartTime': datetime(2015, 1, 1),
                      'Timezone': 'string'
                  },
                  'StartActivity': 'string',
                  'StartCondition': {
                      'Description': 'string',
                      'SegmentStartCondition': {
                          'SegmentId': 'string'
                      }
                  },
                  'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED'
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type WriteJourneyRequest: dict
        :param WriteJourneyRequest: **[REQUIRED]**

          Specifies the configuration and other settings for a journey.

          - **Activities** *(dict) --*

            The configuration and other settings for the activities that comprise the journey.

            - *(string) --*

              - *(dict) --*

                Specifies the configuration and other settings for an activity in a journey.

                - **ConditionalSplit** *(dict) --*

                  The settings for a yes/no split activity. This type of activity sends participants
                  down one of two paths in a journey, based on conditions that you specify.

                  - **Condition** *(dict) --*

                    The conditions that define the paths for the activity, and the relationship
                    between the conditions.

                    - **Conditions** *(list) --*

                      The conditions to evaluate for the activity.

                      - *(dict) --*

                        Specifies a condition to evaluate for an activity in a journey.

                        - **EventCondition** *(dict) --*

                          The dimension settings for the event that's associated with the activity.

                          - **Dimensions** *(dict) --* **[REQUIRED]**

                            The dimensions for the event filter to use for the activity.

                            - **Attributes** *(dict) --*

                              One or more custom attributes that your application reports to Amazon
                              Pinpoint. You can use these attributes as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies attribute-based criteria for including or excluding
                                  endpoints from a segment.

                                  - **AttributeType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --* **[REQUIRED]**

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the AttributeType property, endpoints are
                                    included or excluded from the segment if their attribute values
                                    match the criteria values.

                                    - *(string) --*

                            - **EventType** *(dict) --*

                              The name of the event that causes the campaign to be sent or the
                              journey activity to be performed. This can be a standard type of event
                              that Amazon Pinpoint generates, such as _email.delivered, or a custom
                              event that's specific to your application.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Metrics** *(dict) --*

                              One or more custom metrics that your application reports to Amazon
                              Pinpoint. You can use these metrics as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies metric-based criteria for including or excluding
                                  endpoints from a segment. These criteria derive from custom
                                  metrics that you define for endpoints.

                                  - **ComparisonOperator** *(string) --* **[REQUIRED]**

                                    The operator to use when comparing metric values. Valid values
                                    are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                    LESS_THAN_OR_EQUAL, and EQUAL.

                                  - **Value** *(float) --* **[REQUIRED]**

                                    The value to compare.

                          - **MessageActivity** *(string) --*

                            The message identifier (message_id) for the message to use when
                            determining whether message events meet the condition.

                        - **SegmentCondition** *(dict) --*

                          The segment that's associated with the activity.

                          - **SegmentId** *(string) --* **[REQUIRED]**

                            The unique identifier for the segment to associate with the activity.

                        - **SegmentDimensions** *(dict) --*

                          The dimension settings for the segment that's associated with the
                          activity.

                          - **Attributes** *(dict) --*

                            One or more custom attributes to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies attribute-based criteria for including or excluding
                                endpoints from a segment.

                                - **AttributeType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --* **[REQUIRED]**

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the AttributeType property, endpoints are included or
                                  excluded from the segment if their attribute values match the
                                  criteria values.

                                  - *(string) --*

                          - **Behavior** *(dict) --*

                            The behavior-based criteria, such as how recently users have used your
                            app, for the segment.

                            - **Recency** *(dict) --*

                              The dimension settings that are based on how recently an endpoint was
                              active.

                              - **Duration** *(string) --* **[REQUIRED]**

                                The duration to use when determining whether an endpoint is active
                                or inactive.

                              - **RecencyType** *(string) --* **[REQUIRED]**

                                The type of recency dimension to use for the segment. Valid values
                                are: ACTIVE, endpoints that were active within the specified
                                duration are included in the segment; and, INACTIVE, endpoints that
                                weren't active within the specified duration are included in the
                                segment.

                          - **Demographic** *(dict) --*

                            The demographic-based criteria, such as device platform, for the
                            segment.

                            - **AppVersion** *(dict) --*

                              The app version criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Channel** *(dict) --*

                              The channel criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **DeviceType** *(dict) --*

                              The device type criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Make** *(dict) --*

                              The device make criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Model** *(dict) --*

                              The device model criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Platform** *(dict) --*

                              The device platform criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                          - **Location** *(dict) --*

                            The location-based criteria, such as region or GPS coordinates, for the
                            segment.

                            - **Country** *(dict) --*

                              The country or region code, in ISO 3166-1 alpha-2 format, for the
                              segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **GPSPoint** *(dict) --*

                              The GPS location and range for the segment.

                              - **Coordinates** *(dict) --* **[REQUIRED]**

                                The GPS coordinates to measure distance from.

                                - **Latitude** *(float) --* **[REQUIRED]**

                                  The latitude coordinate of the location.

                                - **Longitude** *(float) --* **[REQUIRED]**

                                  The longitude coordinate of the location.

                              - **RangeInKilometers** *(float) --*

                                The range, in kilometers, from the GPS coordinates.

                          - **Metrics** *(dict) --*

                            One or more custom metrics to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies metric-based criteria for including or excluding endpoints
                                from a segment. These criteria derive from custom metrics that you
                                define for endpoints.

                                - **ComparisonOperator** *(string) --* **[REQUIRED]**

                                  The operator to use when comparing metric values. Valid values
                                  are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                  LESS_THAN_OR_EQUAL, and EQUAL.

                                - **Value** *(float) --* **[REQUIRED]**

                                  The value to compare.

                          - **UserAttributes** *(dict) --*

                            One or more custom user attributes to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies attribute-based criteria for including or excluding
                                endpoints from a segment.

                                - **AttributeType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --* **[REQUIRED]**

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the AttributeType property, endpoints are included or
                                  excluded from the segment if their attribute values match the
                                  criteria values.

                                  - *(string) --*

                    - **Operator** *(string) --*

                      Specifies how to handle multiple conditions for the activity. For example, if
                      you specify two conditions for an activity, whether both or only one of the
                      conditions must be met for the activity to be performed.

                  - **EvaluationWaitTime** *(dict) --*

                    The amount of time to wait before determining whether the conditions are met, or
                    the date and time when Amazon Pinpoint determines whether the conditions are
                    met.

                    - **WaitFor** *(string) --*

                      The amount of time to wait, as a duration in ISO 8601 format, before
                      determining whether the activity's conditions have been met or moving
                      participants to the next activity in the journey.

                    - **WaitUntil** *(string) --*

                      The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether
                      the activity's conditions have been met or the activity moves participants to
                      the next activity in the journey.

                  - **FalseActivity** *(string) --*

                    The unique identifier for the activity to perform if the condition isn't met.

                  - **TrueActivity** *(string) --*

                    The unique identifier for the activity to perform if the condition is met.

                - **Description** *(string) --*

                  The custom description of the activity.

                - **EMAIL** *(dict) --*

                  The settings for an email activity. This type of activity sends an email message
                  to participants.

                  - **MessageConfig** *(dict) --*

                    The "From" address to use for the message.

                    - **FromAddress** *(string) --*

                      The verified email address to send the email message from. The default address
                      is the FromAddress specified for the email channel for the application.

                  - **NextActivity** *(string) --*

                    The unique identifier for the next activity to perform, after the message is
                    sent.

                  - **TemplateName** *(string) --*

                    The name of the email template to use for the message.

                - **Holdout** *(dict) --*

                  The settings for a holdout activity. This type of activity stops a journey for a
                  specified percentage of participants.

                  - **NextActivity** *(string) --*

                    The unique identifier for the next activity to perform, after performing the
                    holdout activity.

                  - **Percentage** *(integer) --* **[REQUIRED]**

                    The percentage of participants who shouldn't continue the journey.

                - **MultiCondition** *(dict) --*

                  The settings for a multivariate split activity. This type of activity sends
                  participants down one of as many as five paths in a journey, based on conditions
                  that you specify.

                  - **Branches** *(list) --*

                    The paths for the activity, including the conditions for entering each path and
                    the activity to perform for each path.

                    - *(dict) --*

                      Specifies a condition to evaluate for an activity path in a journey.

                      - **Condition** *(dict) --*

                        The condition to evaluate for the activity path.

                        - **EventCondition** *(dict) --*

                          The dimension settings for the event that's associated with the activity.

                          - **Dimensions** *(dict) --* **[REQUIRED]**

                            The dimensions for the event filter to use for the activity.

                            - **Attributes** *(dict) --*

                              One or more custom attributes that your application reports to Amazon
                              Pinpoint. You can use these attributes as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies attribute-based criteria for including or excluding
                                  endpoints from a segment.

                                  - **AttributeType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --* **[REQUIRED]**

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the AttributeType property, endpoints are
                                    included or excluded from the segment if their attribute values
                                    match the criteria values.

                                    - *(string) --*

                            - **EventType** *(dict) --*

                              The name of the event that causes the campaign to be sent or the
                              journey activity to be performed. This can be a standard type of event
                              that Amazon Pinpoint generates, such as _email.delivered, or a custom
                              event that's specific to your application.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Metrics** *(dict) --*

                              One or more custom metrics that your application reports to Amazon
                              Pinpoint. You can use these metrics as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies metric-based criteria for including or excluding
                                  endpoints from a segment. These criteria derive from custom
                                  metrics that you define for endpoints.

                                  - **ComparisonOperator** *(string) --* **[REQUIRED]**

                                    The operator to use when comparing metric values. Valid values
                                    are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                    LESS_THAN_OR_EQUAL, and EQUAL.

                                  - **Value** *(float) --* **[REQUIRED]**

                                    The value to compare.

                          - **MessageActivity** *(string) --*

                            The message identifier (message_id) for the message to use when
                            determining whether message events meet the condition.

                        - **SegmentCondition** *(dict) --*

                          The segment that's associated with the activity.

                          - **SegmentId** *(string) --* **[REQUIRED]**

                            The unique identifier for the segment to associate with the activity.

                        - **SegmentDimensions** *(dict) --*

                          The dimension settings for the segment that's associated with the
                          activity.

                          - **Attributes** *(dict) --*

                            One or more custom attributes to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies attribute-based criteria for including or excluding
                                endpoints from a segment.

                                - **AttributeType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --* **[REQUIRED]**

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the AttributeType property, endpoints are included or
                                  excluded from the segment if their attribute values match the
                                  criteria values.

                                  - *(string) --*

                          - **Behavior** *(dict) --*

                            The behavior-based criteria, such as how recently users have used your
                            app, for the segment.

                            - **Recency** *(dict) --*

                              The dimension settings that are based on how recently an endpoint was
                              active.

                              - **Duration** *(string) --* **[REQUIRED]**

                                The duration to use when determining whether an endpoint is active
                                or inactive.

                              - **RecencyType** *(string) --* **[REQUIRED]**

                                The type of recency dimension to use for the segment. Valid values
                                are: ACTIVE, endpoints that were active within the specified
                                duration are included in the segment; and, INACTIVE, endpoints that
                                weren't active within the specified duration are included in the
                                segment.

                          - **Demographic** *(dict) --*

                            The demographic-based criteria, such as device platform, for the
                            segment.

                            - **AppVersion** *(dict) --*

                              The app version criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Channel** *(dict) --*

                              The channel criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **DeviceType** *(dict) --*

                              The device type criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Make** *(dict) --*

                              The device make criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Model** *(dict) --*

                              The device model criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Platform** *(dict) --*

                              The device platform criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                          - **Location** *(dict) --*

                            The location-based criteria, such as region or GPS coordinates, for the
                            segment.

                            - **Country** *(dict) --*

                              The country or region code, in ISO 3166-1 alpha-2 format, for the
                              segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **GPSPoint** *(dict) --*

                              The GPS location and range for the segment.

                              - **Coordinates** *(dict) --* **[REQUIRED]**

                                The GPS coordinates to measure distance from.

                                - **Latitude** *(float) --* **[REQUIRED]**

                                  The latitude coordinate of the location.

                                - **Longitude** *(float) --* **[REQUIRED]**

                                  The longitude coordinate of the location.

                              - **RangeInKilometers** *(float) --*

                                The range, in kilometers, from the GPS coordinates.

                          - **Metrics** *(dict) --*

                            One or more custom metrics to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies metric-based criteria for including or excluding endpoints
                                from a segment. These criteria derive from custom metrics that you
                                define for endpoints.

                                - **ComparisonOperator** *(string) --* **[REQUIRED]**

                                  The operator to use when comparing metric values. Valid values
                                  are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                  LESS_THAN_OR_EQUAL, and EQUAL.

                                - **Value** *(float) --* **[REQUIRED]**

                                  The value to compare.

                          - **UserAttributes** *(dict) --*

                            One or more custom user attributes to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies attribute-based criteria for including or excluding
                                endpoints from a segment.

                                - **AttributeType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --* **[REQUIRED]**

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the AttributeType property, endpoints are included or
                                  excluded from the segment if their attribute values match the
                                  criteria values.

                                  - *(string) --*

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after completing the
                        activity for the path.

                  - **DefaultActivity** *(string) --*

                    The activity to perform by default for any path in the activity.

                  - **EvaluationWaitTime** *(dict) --*

                    The amount of time to wait or the date and time when Amazon Pinpoint determines
                    whether the conditions are met.

                    - **WaitFor** *(string) --*

                      The amount of time to wait, as a duration in ISO 8601 format, before
                      determining whether the activity's conditions have been met or moving
                      participants to the next activity in the journey.

                    - **WaitUntil** *(string) --*

                      The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether
                      the activity's conditions have been met or the activity moves participants to
                      the next activity in the journey.

                - **RandomSplit** *(dict) --*

                  The settings for a random split activity. This type of activity randomly sends
                  specified percentages of participants down one of as many as five paths in a
                  journey, based on conditions that you specify.

                  - **Branches** *(list) --*

                    The paths for the activity, including the percentage of participants to enter
                    each path and the activity to perform for each path.

                    - *(dict) --*

                      Specifies the settings for a path in a random split activity in a journey.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after completing the
                        activity for the path.

                      - **Percentage** *(integer) --*

                        The percentage of participants to send down the activity path.

                - **Wait** *(dict) --*

                  The settings for a wait activity. This type of activity waits for a certain amount
                  of time or until a specific date and time before moving participants to the next
                  activity in a journey.

                  - **NextActivity** *(string) --*

                    The unique identifier for the next activity to perform, after performing the
                    wait activity.

                  - **WaitTime** *(dict) --*

                    The amount of time to wait or the date and time when the activity moves
                    participants to the next activity in the journey.

                    - **WaitFor** *(string) --*

                      The amount of time to wait, as a duration in ISO 8601 format, before
                      determining whether the activity's conditions have been met or moving
                      participants to the next activity in the journey.

                    - **WaitUntil** *(string) --*

                      The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether
                      the activity's conditions have been met or the activity moves participants to
                      the next activity in the journey.

          - **CreationDate** *(string) --*

            The date, in ISO 8601 format, when the journey was created.

          - **LastModifiedDate** *(string) --*

            The date, in ISO 8601 format, when the journey was last modified.

          - **Limits** *(dict) --*

            The messaging and entry limits for the journey.

            - **DailyCap** *(integer) --*

              The maximum number of messages that the journey can send to a single participant
              during a 24-hour period. The maximum value is 100.

            - **EndpointReentryCap** *(integer) --*

              The maximum number of times that a participant can enter the journey. The maximum
              value is 100. To allow participants to enter the journey an unlimited number of times,
              set this value to 0.

            - **MessagesPerSecond** *(integer) --*

              The maximum number of messages that the journey can send each second.

          - **LocalTime** *(boolean) --*

            Specifies whether the journey's scheduled start and end times use each participant's
            local time. To base the schedule on each participant's local time, set this value to
            true.

          - **Name** *(string) --* **[REQUIRED]**

            The name of the journey. A journey name can contain a maximum of 150 characters. The
            characters can be alphanumeric characters or symbols, such as underscores (_) or hyphens
            (-). A journey name can't contain any spaces.

          - **QuietTime** *(dict) --*

            The quiet time settings for the journey. Quiet time is a specific time range when a
            journey doesn't send messages to participants, if all the following conditions are met:

            * The EndpointDemographic.Timezone property of the endpoint for the participant is set
            to a valid value.

            * The current time in the participant's time zone is later than or equal to the time
            specified by the QuietTime.Start property for the journey.

            * The current time in the participant's time zone is earlier than or equal to the time
            specified by the QuietTime.End property for the journey.

            If any of the preceding conditions isn't met, the participant will receive messages from
            the journey, even if quiet time is enabled.

            - **End** *(string) --*

              The specific time when quiet time ends. This value has to use 24-hour notation and be
              in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is
              the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30
              PM.

            - **Start** *(string) --*

              The specific time when quiet time begins. This value has to use 24-hour notation and
              be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM
              is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent
              2:30 PM.

          - **RefreshFrequency** *(string) --*

            The frequency with which Amazon Pinpoint evaluates segment and event data for the
            journey, as a duration in ISO 8601 format.

          - **Schedule** *(dict) --*

            The schedule settings for the journey.

            - **EndTime** *(datetime) --*

              The scheduled time, in ISO 8601 format, when the journey ended or will end.

            - **StartTime** *(datetime) --*

              The scheduled time, in ISO 8601 format, when the journey began or will begin.

            - **Timezone** *(string) --*

              The starting UTC offset for the journey schedule, if the value of the journey's
              LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30,
              UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08,
              UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+12:45, UTC+13,
              UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04, UTC-05, UTC-06, UTC-07,
              UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.

          - **StartActivity** *(string) --*

            The unique identifier for the first activity in the journey.

          - **StartCondition** *(dict) --*

            The segment that defines which users are participants in the journey.

            - **Description** *(string) --*

              The custom description of the condition.

            - **SegmentStartCondition** *(dict) --*

              The segment that's associated with the first activity in the journey. This segment
              determines which users are participants in the journey.

              - **SegmentId** *(string) --* **[REQUIRED]**

                The unique identifier for the segment to associate with the activity.

          - **State** *(string) --*

            The status of the journey. Valid values are:

            * DRAFT - Saves the journey and doesn't publish it.

            * ACTIVE - Saves and publishes the journey. Depending on the journey's schedule, the
            journey starts running immediately or at the scheduled start time. If a journey's status
            is ACTIVE, you can't add, change, or remove activities from it.

            The CANCELLED, COMPLETED, and CLOSED values are not supported in requests to create or
            update a journey. To cancel a journey, use the Journey Stateresource.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'JourneyResponse': {
                    'Activities': {
                        'string': {
                            'ConditionalSplit': {
                                'Condition': {
                                    'Conditions': [
                                        {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType':
                                                            'INCLUSIVE'
                                                            |'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                    ],
                                    'Operator': 'ALL'|'ANY'
                                },
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                },
                                'FalseActivity': 'string',
                                'TrueActivity': 'string'
                            },
                            'Description': 'string',
                            'EMAIL': {
                                'MessageConfig': {
                                    'FromAddress': 'string'
                                },
                                'NextActivity': 'string',
                                'TemplateName': 'string'
                            },
                            'Holdout': {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                            'MultiCondition': {
                                'Branches': [
                                    {
                                        'Condition': {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType':
                                                            'INCLUSIVE'
                                                            |'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                        'NextActivity': 'string'
                                    },
                                ],
                                'DefaultActivity': 'string',
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            },
                            'RandomSplit': {
                                'Branches': [
                                    {
                                        'NextActivity': 'string',
                                        'Percentage': 123
                                    },
                                ]
                            },
                            'Wait': {
                                'NextActivity': 'string',
                                'WaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            }
                        }
                    },
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Id': 'string',
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'DailyCap': 123,
                        'EndpointReentryCap': 123,
                        'MessagesPerSecond': 123
                    },
                    'LocalTime': True|False,
                    'Name': 'string',
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'RefreshFrequency': 'string',
                    'Schedule': {
                        'EndTime': datetime(2015, 1, 1),
                        'StartTime': datetime(2015, 1, 1),
                        'Timezone': 'string'
                    },
                    'StartActivity': 'string',
                    'StartCondition': {
                        'Description': 'string',
                        'SegmentStartCondition': {
                            'SegmentId': 'string'
                        }
                    },
                    'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
                    'tags': {
                        'string': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded and the specified resource was created.

            - **JourneyResponse** *(dict) --*

              Provides information about the status, configuration, and other settings for a
              journey.

              - **Activities** *(dict) --*

                The configuration and other settings for the activities that comprise the journey.

                - *(string) --*

                  - *(dict) --*

                    Specifies the configuration and other settings for an activity in a journey.

                    - **ConditionalSplit** *(dict) --*

                      The settings for a yes/no split activity. This type of activity sends
                      participants down one of two paths in a journey, based on conditions that you
                      specify.

                      - **Condition** *(dict) --*

                        The conditions that define the paths for the activity, and the relationship
                        between the conditions.

                        - **Conditions** *(list) --*

                          The conditions to evaluate for the activity.

                          - *(dict) --*

                            Specifies a condition to evaluate for an activity in a journey.

                            - **EventCondition** *(dict) --*

                              The dimension settings for the event that's associated with the
                              activity.

                              - **Dimensions** *(dict) --*

                                The dimensions for the event filter to use for the activity.

                                - **Attributes** *(dict) --*

                                  One or more custom attributes that your application reports to
                                  Amazon Pinpoint. You can use these attributes as selection
                                  criteria when you create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies attribute-based criteria for including or excluding
                                      endpoints from a segment.

                                      - **AttributeType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the AttributeType property,
                                        endpoints are included or excluded from the segment if their
                                        attribute values match the criteria values.

                                        - *(string) --*

                                - **EventType** *(dict) --*

                                  The name of the event that causes the campaign to be sent or the
                                  journey activity to be performed. This can be a standard type of
                                  event that Amazon Pinpoint generates, such as _email.delivered, or
                                  a custom event that's specific to your application.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Metrics** *(dict) --*

                                  One or more custom metrics that your application reports to Amazon
                                  Pinpoint. You can use these metrics as selection criteria when you
                                  create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies metric-based criteria for including or excluding
                                      endpoints from a segment. These criteria derive from custom
                                      metrics that you define for endpoints.

                                      - **ComparisonOperator** *(string) --*

                                        The operator to use when comparing metric values. Valid
                                        values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                        LESS_THAN_OR_EQUAL, and EQUAL.

                                      - **Value** *(float) --*

                                        The value to compare.

                              - **MessageActivity** *(string) --*

                                The message identifier (message_id) for the message to use when
                                determining whether message events meet the condition.

                            - **SegmentCondition** *(dict) --*

                              The segment that's associated with the activity.

                              - **SegmentId** *(string) --*

                                The unique identifier for the segment to associate with the
                                activity.

                            - **SegmentDimensions** *(dict) --*

                              The dimension settings for the segment that's associated with the
                              activity.

                              - **Attributes** *(dict) --*

                                One or more custom attributes to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                              - **Behavior** *(dict) --*

                                The behavior-based criteria, such as how recently users have used
                                your app, for the segment.

                                - **Recency** *(dict) --*

                                  The dimension settings that are based on how recently an endpoint
                                  was active.

                                  - **Duration** *(string) --*

                                    The duration to use when determining whether an endpoint is
                                    active or inactive.

                                  - **RecencyType** *(string) --*

                                    The type of recency dimension to use for the segment. Valid
                                    values are: ACTIVE, endpoints that were active within the
                                    specified duration are included in the segment; and, INACTIVE,
                                    endpoints that weren't active within the specified duration are
                                    included in the segment.

                              - **Demographic** *(dict) --*

                                The demographic-based criteria, such as device platform, for the
                                segment.

                                - **AppVersion** *(dict) --*

                                  The app version criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Channel** *(dict) --*

                                  The channel criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **DeviceType** *(dict) --*

                                  The device type criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Make** *(dict) --*

                                  The device make criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Model** *(dict) --*

                                  The device model criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Platform** *(dict) --*

                                  The device platform criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                              - **Location** *(dict) --*

                                The location-based criteria, such as region or GPS coordinates, for
                                the segment.

                                - **Country** *(dict) --*

                                  The country or region code, in ISO 3166-1 alpha-2 format, for the
                                  segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **GPSPoint** *(dict) --*

                                  The GPS location and range for the segment.

                                  - **Coordinates** *(dict) --*

                                    The GPS coordinates to measure distance from.

                                    - **Latitude** *(float) --*

                                      The latitude coordinate of the location.

                                    - **Longitude** *(float) --*

                                      The longitude coordinate of the location.

                                  - **RangeInKilometers** *(float) --*

                                    The range, in kilometers, from the GPS coordinates.

                              - **Metrics** *(dict) --*

                                One or more custom metrics to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies metric-based criteria for including or excluding
                                    endpoints from a segment. These criteria derive from custom
                                    metrics that you define for endpoints.

                                    - **ComparisonOperator** *(string) --*

                                      The operator to use when comparing metric values. Valid values
                                      are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                      LESS_THAN_OR_EQUAL, and EQUAL.

                                    - **Value** *(float) --*

                                      The value to compare.

                              - **UserAttributes** *(dict) --*

                                One or more custom user attributes to use as criteria for the
                                segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                        - **Operator** *(string) --*

                          Specifies how to handle multiple conditions for the activity. For example,
                          if you specify two conditions for an activity, whether both or only one of
                          the conditions must be met for the activity to be performed.

                      - **EvaluationWaitTime** *(dict) --*

                        The amount of time to wait before determining whether the conditions are
                        met, or the date and time when Amazon Pinpoint determines whether the
                        conditions are met.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

                      - **FalseActivity** *(string) --*

                        The unique identifier for the activity to perform if the condition isn't
                        met.

                      - **TrueActivity** *(string) --*

                        The unique identifier for the activity to perform if the condition is met.

                    - **Description** *(string) --*

                      The custom description of the activity.

                    - **EMAIL** *(dict) --*

                      The settings for an email activity. This type of activity sends an email
                      message to participants.

                      - **MessageConfig** *(dict) --*

                        The "From" address to use for the message.

                        - **FromAddress** *(string) --*

                          The verified email address to send the email message from. The default
                          address is the FromAddress specified for the email channel for the
                          application.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after the message is
                        sent.

                      - **TemplateName** *(string) --*

                        The name of the email template to use for the message.

                    - **Holdout** *(dict) --*

                      The settings for a holdout activity. This type of activity stops a journey for
                      a specified percentage of participants.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after performing the
                        holdout activity.

                      - **Percentage** *(integer) --*

                        The percentage of participants who shouldn't continue the journey.

                    - **MultiCondition** *(dict) --*

                      The settings for a multivariate split activity. This type of activity sends
                      participants down one of as many as five paths in a journey, based on
                      conditions that you specify.

                      - **Branches** *(list) --*

                        The paths for the activity, including the conditions for entering each path
                        and the activity to perform for each path.

                        - *(dict) --*

                          Specifies a condition to evaluate for an activity path in a journey.

                          - **Condition** *(dict) --*

                            The condition to evaluate for the activity path.

                            - **EventCondition** *(dict) --*

                              The dimension settings for the event that's associated with the
                              activity.

                              - **Dimensions** *(dict) --*

                                The dimensions for the event filter to use for the activity.

                                - **Attributes** *(dict) --*

                                  One or more custom attributes that your application reports to
                                  Amazon Pinpoint. You can use these attributes as selection
                                  criteria when you create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies attribute-based criteria for including or excluding
                                      endpoints from a segment.

                                      - **AttributeType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the AttributeType property,
                                        endpoints are included or excluded from the segment if their
                                        attribute values match the criteria values.

                                        - *(string) --*

                                - **EventType** *(dict) --*

                                  The name of the event that causes the campaign to be sent or the
                                  journey activity to be performed. This can be a standard type of
                                  event that Amazon Pinpoint generates, such as _email.delivered, or
                                  a custom event that's specific to your application.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Metrics** *(dict) --*

                                  One or more custom metrics that your application reports to Amazon
                                  Pinpoint. You can use these metrics as selection criteria when you
                                  create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies metric-based criteria for including or excluding
                                      endpoints from a segment. These criteria derive from custom
                                      metrics that you define for endpoints.

                                      - **ComparisonOperator** *(string) --*

                                        The operator to use when comparing metric values. Valid
                                        values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                        LESS_THAN_OR_EQUAL, and EQUAL.

                                      - **Value** *(float) --*

                                        The value to compare.

                              - **MessageActivity** *(string) --*

                                The message identifier (message_id) for the message to use when
                                determining whether message events meet the condition.

                            - **SegmentCondition** *(dict) --*

                              The segment that's associated with the activity.

                              - **SegmentId** *(string) --*

                                The unique identifier for the segment to associate with the
                                activity.

                            - **SegmentDimensions** *(dict) --*

                              The dimension settings for the segment that's associated with the
                              activity.

                              - **Attributes** *(dict) --*

                                One or more custom attributes to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                              - **Behavior** *(dict) --*

                                The behavior-based criteria, such as how recently users have used
                                your app, for the segment.

                                - **Recency** *(dict) --*

                                  The dimension settings that are based on how recently an endpoint
                                  was active.

                                  - **Duration** *(string) --*

                                    The duration to use when determining whether an endpoint is
                                    active or inactive.

                                  - **RecencyType** *(string) --*

                                    The type of recency dimension to use for the segment. Valid
                                    values are: ACTIVE, endpoints that were active within the
                                    specified duration are included in the segment; and, INACTIVE,
                                    endpoints that weren't active within the specified duration are
                                    included in the segment.

                              - **Demographic** *(dict) --*

                                The demographic-based criteria, such as device platform, for the
                                segment.

                                - **AppVersion** *(dict) --*

                                  The app version criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Channel** *(dict) --*

                                  The channel criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **DeviceType** *(dict) --*

                                  The device type criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Make** *(dict) --*

                                  The device make criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Model** *(dict) --*

                                  The device model criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Platform** *(dict) --*

                                  The device platform criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                              - **Location** *(dict) --*

                                The location-based criteria, such as region or GPS coordinates, for
                                the segment.

                                - **Country** *(dict) --*

                                  The country or region code, in ISO 3166-1 alpha-2 format, for the
                                  segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **GPSPoint** *(dict) --*

                                  The GPS location and range for the segment.

                                  - **Coordinates** *(dict) --*

                                    The GPS coordinates to measure distance from.

                                    - **Latitude** *(float) --*

                                      The latitude coordinate of the location.

                                    - **Longitude** *(float) --*

                                      The longitude coordinate of the location.

                                  - **RangeInKilometers** *(float) --*

                                    The range, in kilometers, from the GPS coordinates.

                              - **Metrics** *(dict) --*

                                One or more custom metrics to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies metric-based criteria for including or excluding
                                    endpoints from a segment. These criteria derive from custom
                                    metrics that you define for endpoints.

                                    - **ComparisonOperator** *(string) --*

                                      The operator to use when comparing metric values. Valid values
                                      are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                      LESS_THAN_OR_EQUAL, and EQUAL.

                                    - **Value** *(float) --*

                                      The value to compare.

                              - **UserAttributes** *(dict) --*

                                One or more custom user attributes to use as criteria for the
                                segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after completing
                            the activity for the path.

                      - **DefaultActivity** *(string) --*

                        The activity to perform by default for any path in the activity.

                      - **EvaluationWaitTime** *(dict) --*

                        The amount of time to wait or the date and time when Amazon Pinpoint
                        determines whether the conditions are met.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

                    - **RandomSplit** *(dict) --*

                      The settings for a random split activity. This type of activity randomly sends
                      specified percentages of participants down one of as many as five paths in a
                      journey, based on conditions that you specify.

                      - **Branches** *(list) --*

                        The paths for the activity, including the percentage of participants to
                        enter each path and the activity to perform for each path.

                        - *(dict) --*

                          Specifies the settings for a path in a random split activity in a journey.

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after completing
                            the activity for the path.

                          - **Percentage** *(integer) --*

                            The percentage of participants to send down the activity path.

                    - **Wait** *(dict) --*

                      The settings for a wait activity. This type of activity waits for a certain
                      amount of time or until a specific date and time before moving participants to
                      the next activity in a journey.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after performing the
                        wait activity.

                      - **WaitTime** *(dict) --*

                        The amount of time to wait or the date and time when the activity moves
                        participants to the next activity in the journey.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the journey applies to.

              - **CreationDate** *(string) --*

                The date, in ISO 8601 format, when the journey was created.

              - **Id** *(string) --*

                The unique identifier for the journey.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the journey was last modified.

              - **Limits** *(dict) --*

                The messaging and entry limits for the journey.

                - **DailyCap** *(integer) --*

                  The maximum number of messages that the journey can send to a single participant
                  during a 24-hour period. The maximum value is 100.

                - **EndpointReentryCap** *(integer) --*

                  The maximum number of times that a participant can enter the journey. The maximum
                  value is 100. To allow participants to enter the journey an unlimited number of
                  times, set this value to 0.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that the journey can send each second.

              - **LocalTime** *(boolean) --*

                Specifies whether the journey's scheduled start and end times use each participant's
                local time. If this value is true, the schedule uses each participant's local time.

              - **Name** *(string) --*

                The name of the journey.

              - **QuietTime** *(dict) --*

                The quiet time settings for the journey. Quiet time is a specific time range when a
                journey doesn't send messages to participants, if all the following conditions are
                met:

                * The EndpointDemographic.Timezone property of the endpoint for the participant is
                set to a valid value.

                * The current time in the participant's time zone is later than or equal to the time
                specified by the QuietTime.Start property for the journey.

                * The current time in the participant's time zone is earlier than or equal to the
                time specified by the QuietTime.End property for the journey.

                If any of the preceding conditions isn't met, the participant will receive messages
                from the journey, even if quiet time is enabled.

                - **End** *(string) --*

                  The specific time when quiet time ends. This value has to use 24-hour notation and
                  be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and
                  MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

                - **Start** *(string) --*

                  The specific time when quiet time begins. This value has to use 24-hour notation
                  and be in HH:MM format, where HH is the hour (with a leading zero, if applicable)
                  and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

              - **RefreshFrequency** *(string) --*

                The frequency with which Amazon Pinpoint evaluates segment and event data for the
                journey, as a duration in ISO 8601 format.

              - **Schedule** *(dict) --*

                The schedule settings for the journey.

                - **EndTime** *(datetime) --*

                  The scheduled time, in ISO 8601 format, when the journey ended or will end.

                - **StartTime** *(datetime) --*

                  The scheduled time, in ISO 8601 format, when the journey began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the journey schedule, if the value of the journey's
                  LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                  UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                  UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12,
                  UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04,
                  UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.

              - **StartActivity** *(string) --*

                The unique identifier for the first activity in the journey.

              - **StartCondition** *(dict) --*

                The segment that defines which users are participants in the journey.

                - **Description** *(string) --*

                  The custom description of the condition.

                - **SegmentStartCondition** *(dict) --*

                  The segment that's associated with the first activity in the journey. This segment
                  determines which users are participants in the journey.

                  - **SegmentId** *(string) --*

                    The unique identifier for the segment to associate with the activity.

              - **State** *(string) --*

                The current status of the journey. Possible values are:

                * DRAFT - The journey is being developed and hasn't been published yet.

                * ACTIVE - The journey has been developed and published. Depending on the journey's
                schedule, the journey may currently be running or scheduled to start running at a
                later time. If a journey's status is ACTIVE, you can't add, change, or remove
                activities from it.

                * COMPLETED - The journey has been published and has finished running. All
                participants have entered the journey and no participants are waiting to complete
                the journey or any activities in the journey.

                * CANCELLED - The journey has been stopped. If a journey's status is CANCELLED, you
                can't add, change, or remove activities or segment settings from the journey.

                * CLOSED - The journey has been published and has started running. It may have also
                passed its scheduled end time, or passed its scheduled start time and a refresh
                frequency hasn't been specified for it. If a journey's status is CLOSED, you can't
                add participants to it, and no existing participants can enter the journey for the
                first time. However, any existing participants who are currently waiting to start an
                activity may resume the journey.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the journey. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_push_template(
        self,
        PushNotificationTemplateRequest: ClientCreatePushTemplatePushNotificationTemplateRequestTypeDef,
        TemplateName: str,
    ) -> ClientCreatePushTemplateResponseTypeDef:
        """
        Creates a message template that you can use in messages that are sent through a push
        notification channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/CreatePushTemplate>`_

        **Request Syntax**
        ::

          response = client.create_push_template(
              PushNotificationTemplateRequest={
                  'ADM': {
                      'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                      'Body': 'string',
                      'ImageIconUrl': 'string',
                      'ImageUrl': 'string',
                      'RawContent': 'string',
                      'SmallImageIconUrl': 'string',
                      'Sound': 'string',
                      'Title': 'string',
                      'Url': 'string'
                  },
                  'APNS': {
                      'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                      'Body': 'string',
                      'MediaUrl': 'string',
                      'RawContent': 'string',
                      'Sound': 'string',
                      'Title': 'string',
                      'Url': 'string'
                  },
                  'Baidu': {
                      'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                      'Body': 'string',
                      'ImageIconUrl': 'string',
                      'ImageUrl': 'string',
                      'RawContent': 'string',
                      'SmallImageIconUrl': 'string',
                      'Sound': 'string',
                      'Title': 'string',
                      'Url': 'string'
                  },
                  'Default': {
                      'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                      'Body': 'string',
                      'Sound': 'string',
                      'Title': 'string',
                      'Url': 'string'
                  },
                  'DefaultSubstitutions': 'string',
                  'GCM': {
                      'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                      'Body': 'string',
                      'ImageIconUrl': 'string',
                      'ImageUrl': 'string',
                      'RawContent': 'string',
                      'SmallImageIconUrl': 'string',
                      'Sound': 'string',
                      'Title': 'string',
                      'Url': 'string'
                  },
                  'tags': {
                      'string': 'string'
                  },
                  'TemplateDescription': 'string'
              },
              TemplateName='string'
          )
        :type PushNotificationTemplateRequest: dict
        :param PushNotificationTemplateRequest: **[REQUIRED]**

          Creates a message template that you can use in messages that are sent through a push
          notification channel.

          - **ADM** *(dict) --*

            The message template to use for the ADM (Amazon Device Messaging) channel. This message
            template overrides the default template for push notification channels
            (DefaultPushNotificationTemplate).

            - **Action** *(string) --*

              The action to occur if a recipient taps a push notification that's based on the
              message template. Valid values are:

              * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
              background. This is the default action.

              * DEEP_LINK - Your app opens and displays a designated user interface in the app. This
              action uses the deep-linking features of the Android platform.

              * URL - The default mobile browser on the recipient's device opens and loads the web
              page at a URL that you specify.

            - **Body** *(string) --*

              The message body to use in a push notification that's based on the message template.

            - **ImageIconUrl** *(string) --*

              The URL of the large icon image to display in the content view of a push notification
              that's based on the message template.

            - **ImageUrl** *(string) --*

              The URL of an image to display in a push notification that's based on the message
              template.

            - **RawContent** *(string) --*

              The raw, JSON-formatted string to use as the payload for a push notification that's
              based on the message template. If specified, this value overrides all other content
              for the message template.

            - **SmallImageIconUrl** *(string) --*

              The URL of the small icon image to display in the status bar and the content view of a
              push notification that's based on the message template.

            - **Sound** *(string) --*

              The sound to play when a recipient receives a push notification that's based on the
              message template. You can use the default stream or specify the file name of a sound
              resource that's bundled in your app. On an Android platform, the sound file must
              reside in /res/raw/.

            - **Title** *(string) --*

              The title to use in a push notification that's based on the message template. This
              title appears above the notification message on a recipient's device.

            - **Url** *(string) --*

              The URL to open in a recipient's default mobile browser, if a recipient taps a a push
              notification that's based on the message template and the value of the Action property
              is URL.

          - **APNS** *(dict) --*

            The message template to use for the APNs (Apple Push Notification service) channel. This
            message template overrides the default template for push notification channels
            (DefaultPushNotificationTemplate).

            - **Action** *(string) --*

              The action to occur if a recipient taps a push notification that's based on the
              message template. Valid values are:

              * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
              background. This is the default action.

              * DEEP_LINK - Your app opens and displays a designated user interface in the app. This
              setting uses the deep-linking features of the iOS platform.

              * URL - The default mobile browser on the recipient's device opens and loads the web
              page at a URL that you specify.

            - **Body** *(string) --*

              The message body to use in push notifications that are based on the message template.

            - **MediaUrl** *(string) --*

              The URL of an image or video to display in push notifications that are based on the
              message template.

            - **RawContent** *(string) --*

              The raw, JSON-formatted string to use as the payload for push notifications that are
              based on the message template. If specified, this value overrides all other content
              for the message template.

            - **Sound** *(string) --*

              The key for the sound to play when the recipient receives a push notification that's
              based on the message template. The value for this key is the name of a sound file in
              your app's main bundle or the Library/Sounds folder in your app's data container. If
              the sound file can't be found or you specify default for the value, the system plays
              the default alert sound.

            - **Title** *(string) --*

              The title to use in push notifications that are based on the message template. This
              title appears above the notification message on a recipient's device.

            - **Url** *(string) --*

              The URL to open in the recipient's default mobile browser, if a recipient taps a push
              notification that's based on the message template and the value of the Action property
              is URL.

          - **Baidu** *(dict) --*

            The message template to use for the Baidu (Baidu Cloud Push) channel. This message
            template overrides the default template for push notification channels
            (DefaultPushNotificationTemplate).

            - **Action** *(string) --*

              The action to occur if a recipient taps a push notification that's based on the
              message template. Valid values are:

              * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
              background. This is the default action.

              * DEEP_LINK - Your app opens and displays a designated user interface in the app. This
              action uses the deep-linking features of the Android platform.

              * URL - The default mobile browser on the recipient's device opens and loads the web
              page at a URL that you specify.

            - **Body** *(string) --*

              The message body to use in a push notification that's based on the message template.

            - **ImageIconUrl** *(string) --*

              The URL of the large icon image to display in the content view of a push notification
              that's based on the message template.

            - **ImageUrl** *(string) --*

              The URL of an image to display in a push notification that's based on the message
              template.

            - **RawContent** *(string) --*

              The raw, JSON-formatted string to use as the payload for a push notification that's
              based on the message template. If specified, this value overrides all other content
              for the message template.

            - **SmallImageIconUrl** *(string) --*

              The URL of the small icon image to display in the status bar and the content view of a
              push notification that's based on the message template.

            - **Sound** *(string) --*

              The sound to play when a recipient receives a push notification that's based on the
              message template. You can use the default stream or specify the file name of a sound
              resource that's bundled in your app. On an Android platform, the sound file must
              reside in /res/raw/.

            - **Title** *(string) --*

              The title to use in a push notification that's based on the message template. This
              title appears above the notification message on a recipient's device.

            - **Url** *(string) --*

              The URL to open in a recipient's default mobile browser, if a recipient taps a a push
              notification that's based on the message template and the value of the Action property
              is URL.

          - **Default** *(dict) --*

            The default message template to use for push notification channels.

            - **Action** *(string) --*

              The action to occur if a recipient taps a push notification that's based on the
              message template. Valid values are:

              * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
              background. This is the default action.

              * DEEP_LINK - Your app opens and displays a designated user interface in the app. This
              setting uses the deep-linking features of the iOS and Android platforms.

              * URL - The default mobile browser on the recipient's device opens and loads the web
              page at a URL that you specify.

            - **Body** *(string) --*

              The message body to use in push notifications that are based on the message template.

            - **Sound** *(string) --*

              The sound to play when a recipient receives a push notification that's based on the
              message template. You can use the default stream or specify the file name of a sound
              resource that's bundled in your app. On an Android platform, the sound file must
              reside in /res/raw/.

              For an iOS platform, this value is the key for the name of a sound file in your app's
              main bundle or the Library/Sounds folder in your app's data container. If the sound
              file can't be found or you specify default for the value, the system plays the default
              alert sound.

            - **Title** *(string) --*

              The title to use in push notifications that are based on the message template. This
              title appears above the notification message on a recipient's device.

            - **Url** *(string) --*

              The URL to open in a recipient's default mobile browser, if a recipient taps a push
              notification that's based on the message template and the value of the Action property
              is URL.

          - **DefaultSubstitutions** *(string) --*

            A JSON object that specifies the default values to use for message variables in the
            message template. This object is a set of key-value pairs. Each key defines a message
            variable in the template. The corresponding value defines the default value for that
            variable. When you create a message that's based on the template, you can override these
            defaults with message-specific and address-specific variables and values.

          - **GCM** *(dict) --*

            The message template to use for the GCM channel, which is used to send notifications
            through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM),
            service. This message template overrides the default template for push notification
            channels (DefaultPushNotificationTemplate).

            - **Action** *(string) --*

              The action to occur if a recipient taps a push notification that's based on the
              message template. Valid values are:

              * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
              background. This is the default action.

              * DEEP_LINK - Your app opens and displays a designated user interface in the app. This
              action uses the deep-linking features of the Android platform.

              * URL - The default mobile browser on the recipient's device opens and loads the web
              page at a URL that you specify.

            - **Body** *(string) --*

              The message body to use in a push notification that's based on the message template.

            - **ImageIconUrl** *(string) --*

              The URL of the large icon image to display in the content view of a push notification
              that's based on the message template.

            - **ImageUrl** *(string) --*

              The URL of an image to display in a push notification that's based on the message
              template.

            - **RawContent** *(string) --*

              The raw, JSON-formatted string to use as the payload for a push notification that's
              based on the message template. If specified, this value overrides all other content
              for the message template.

            - **SmallImageIconUrl** *(string) --*

              The URL of the small icon image to display in the status bar and the content view of a
              push notification that's based on the message template.

            - **Sound** *(string) --*

              The sound to play when a recipient receives a push notification that's based on the
              message template. You can use the default stream or specify the file name of a sound
              resource that's bundled in your app. On an Android platform, the sound file must
              reside in /res/raw/.

            - **Title** *(string) --*

              The title to use in a push notification that's based on the message template. This
              title appears above the notification message on a recipient's device.

            - **Url** *(string) --*

              The URL to open in a recipient's default mobile browser, if a recipient taps a a push
              notification that's based on the message template and the value of the Action property
              is URL.

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            message template. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

          - **TemplateDescription** *(string) --*

            A custom description of the message template.

        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CreateTemplateMessageBody': {
                    'Arn': 'string',
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded and the specified resource was created.

            - **CreateTemplateMessageBody** *(dict) --*

              Provides information about a request to create a message template.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the message template that was created.

              - **Message** *(string) --*

                The message that's returned from the API for the request to create the message
                template.

              - **RequestID** *(string) --*

                The unique identifier for the request to create the message template.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_segment(
        self, ApplicationId: str, WriteSegmentRequest: ClientCreateSegmentWriteSegmentRequestTypeDef
    ) -> ClientCreateSegmentResponseTypeDef:
        """
        Creates a new segment for an application or updates the configuration, dimension, and other
        settings for an existing segment that's associated with an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/CreateSegment>`_

        **Request Syntax**
        ::

          response = client.create_segment(
              ApplicationId='string',
              WriteSegmentRequest={
                  'Dimensions': {
                      'Attributes': {
                          'string': {
                              'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          }
                      },
                      'Behavior': {
                          'Recency': {
                              'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                              'RecencyType': 'ACTIVE'|'INACTIVE'
                          }
                      },
                      'Demographic': {
                          'AppVersion': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'Channel': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'DeviceType': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'Make': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'Model': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'Platform': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          }
                      },
                      'Location': {
                          'Country': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'GPSPoint': {
                              'Coordinates': {
                                  'Latitude': 123.0,
                                  'Longitude': 123.0
                              },
                              'RangeInKilometers': 123.0
                          }
                      },
                      'Metrics': {
                          'string': {
                              'ComparisonOperator': 'string',
                              'Value': 123.0
                          }
                      },
                      'UserAttributes': {
                          'string': {
                              'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          }
                      }
                  },
                  'Name': 'string',
                  'SegmentGroups': {
                      'Groups': [
                          {
                              'Dimensions': [
                                  {
                                      'Attributes': {
                                          'string': {
                                              'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          }
                                      },
                                      'Behavior': {
                                          'Recency': {
                                              'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                              'RecencyType': 'ACTIVE'|'INACTIVE'
                                          }
                                      },
                                      'Demographic': {
                                          'AppVersion': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'Channel': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'DeviceType': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'Make': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'Model': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'Platform': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          }
                                      },
                                      'Location': {
                                          'Country': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'GPSPoint': {
                                              'Coordinates': {
                                                  'Latitude': 123.0,
                                                  'Longitude': 123.0
                                              },
                                              'RangeInKilometers': 123.0
                                          }
                                      },
                                      'Metrics': {
                                          'string': {
                                              'ComparisonOperator': 'string',
                                              'Value': 123.0
                                          }
                                      },
                                      'UserAttributes': {
                                          'string': {
                                              'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          }
                                      }
                                  },
                              ],
                              'SourceSegments': [
                                  {
                                      'Id': 'string',
                                      'Version': 123
                                  },
                              ],
                              'SourceType': 'ALL'|'ANY'|'NONE',
                              'Type': 'ALL'|'ANY'|'NONE'
                          },
                      ],
                      'Include': 'ALL'|'ANY'|'NONE'
                  },
                  'tags': {
                      'string': 'string'
                  }
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type WriteSegmentRequest: dict
        :param WriteSegmentRequest: **[REQUIRED]**

          Specifies the configuration, dimension, and other settings for a segment. A
          WriteSegmentRequest object can include a Dimensions object or a SegmentGroups object, but
          not both.

          - **Dimensions** *(dict) --*

            The criteria that define the dimensions for the segment.

            - **Attributes** *(dict) --*

              One or more custom attributes to use as criteria for the segment.

              - *(string) --*

                - *(dict) --*

                  Specifies attribute-based criteria for including or excluding endpoints from a
                  segment.

                  - **AttributeType** *(string) --*

                    The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                    that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                    that match the criteria are excluded from the segment.

                  - **Values** *(list) --* **[REQUIRED]**

                    The criteria values to use for the segment dimension. Depending on the value of
                    the AttributeType property, endpoints are included or excluded from the segment
                    if their attribute values match the criteria values.

                    - *(string) --*

            - **Behavior** *(dict) --*

              The behavior-based criteria, such as how recently users have used your app, for the
              segment.

              - **Recency** *(dict) --*

                The dimension settings that are based on how recently an endpoint was active.

                - **Duration** *(string) --* **[REQUIRED]**

                  The duration to use when determining whether an endpoint is active or inactive.

                - **RecencyType** *(string) --* **[REQUIRED]**

                  The type of recency dimension to use for the segment. Valid values are: ACTIVE,
                  endpoints that were active within the specified duration are included in the
                  segment; and, INACTIVE, endpoints that weren't active within the specified
                  duration are included in the segment.

            - **Demographic** *(dict) --*

              The demographic-based criteria, such as device platform, for the segment.

              - **AppVersion** *(dict) --*

                The app version criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **Channel** *(dict) --*

                The channel criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **DeviceType** *(dict) --*

                The device type criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **Make** *(dict) --*

                The device make criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **Model** *(dict) --*

                The device model criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **Platform** *(dict) --*

                The device platform criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

            - **Location** *(dict) --*

              The location-based criteria, such as region or GPS coordinates, for the segment.

              - **Country** *(dict) --*

                The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **GPSPoint** *(dict) --*

                The GPS location and range for the segment.

                - **Coordinates** *(dict) --* **[REQUIRED]**

                  The GPS coordinates to measure distance from.

                  - **Latitude** *(float) --* **[REQUIRED]**

                    The latitude coordinate of the location.

                  - **Longitude** *(float) --* **[REQUIRED]**

                    The longitude coordinate of the location.

                - **RangeInKilometers** *(float) --*

                  The range, in kilometers, from the GPS coordinates.

            - **Metrics** *(dict) --*

              One or more custom metrics to use as criteria for the segment.

              - *(string) --*

                - *(dict) --*

                  Specifies metric-based criteria for including or excluding endpoints from a
                  segment. These criteria derive from custom metrics that you define for endpoints.

                  - **ComparisonOperator** *(string) --* **[REQUIRED]**

                    The operator to use when comparing metric values. Valid values are:
                    GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

                  - **Value** *(float) --* **[REQUIRED]**

                    The value to compare.

            - **UserAttributes** *(dict) --*

              One or more custom user attributes to use as criteria for the segment.

              - *(string) --*

                - *(dict) --*

                  Specifies attribute-based criteria for including or excluding endpoints from a
                  segment.

                  - **AttributeType** *(string) --*

                    The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                    that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                    that match the criteria are excluded from the segment.

                  - **Values** *(list) --* **[REQUIRED]**

                    The criteria values to use for the segment dimension. Depending on the value of
                    the AttributeType property, endpoints are included or excluded from the segment
                    if their attribute values match the criteria values.

                    - *(string) --*

          - **Name** *(string) --*

            The name of the segment.

          - **SegmentGroups** *(dict) --*

            The segment group to use and the dimensions to apply to the group's base segments in
            order to build the segment. A segment group can consist of zero or more base segments.
            Your request can include only one segment group.

            - **Groups** *(list) --*

              An array that defines the set of segment criteria to evaluate when handling segment
              groups for the segment.

              - *(dict) --*

                Specifies the base segments and dimensions for a segment, and the relationships
                between these base segments and dimensions.

                - **Dimensions** *(list) --*

                  An array that defines the dimensions for the segment.

                  - *(dict) --*

                    Specifies the dimension settings for a segment.

                    - **Attributes** *(dict) --*

                      One or more custom attributes to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --* **[REQUIRED]**

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                    - **Behavior** *(dict) --*

                      The behavior-based criteria, such as how recently users have used your app,
                      for the segment.

                      - **Recency** *(dict) --*

                        The dimension settings that are based on how recently an endpoint was
                        active.

                        - **Duration** *(string) --* **[REQUIRED]**

                          The duration to use when determining whether an endpoint is active or
                          inactive.

                        - **RecencyType** *(string) --* **[REQUIRED]**

                          The type of recency dimension to use for the segment. Valid values are:
                          ACTIVE, endpoints that were active within the specified duration are
                          included in the segment; and, INACTIVE, endpoints that weren't active
                          within the specified duration are included in the segment.

                    - **Demographic** *(dict) --*

                      The demographic-based criteria, such as device platform, for the segment.

                      - **AppVersion** *(dict) --*

                        The app version criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Channel** *(dict) --*

                        The channel criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **DeviceType** *(dict) --*

                        The device type criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Make** *(dict) --*

                        The device make criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Model** *(dict) --*

                        The device model criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Platform** *(dict) --*

                        The device platform criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                    - **Location** *(dict) --*

                      The location-based criteria, such as region or GPS coordinates, for the
                      segment.

                      - **Country** *(dict) --*

                        The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **GPSPoint** *(dict) --*

                        The GPS location and range for the segment.

                        - **Coordinates** *(dict) --* **[REQUIRED]**

                          The GPS coordinates to measure distance from.

                          - **Latitude** *(float) --* **[REQUIRED]**

                            The latitude coordinate of the location.

                          - **Longitude** *(float) --* **[REQUIRED]**

                            The longitude coordinate of the location.

                        - **RangeInKilometers** *(float) --*

                          The range, in kilometers, from the GPS coordinates.

                    - **Metrics** *(dict) --*

                      One or more custom metrics to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies metric-based criteria for including or excluding endpoints from
                          a segment. These criteria derive from custom metrics that you define for
                          endpoints.

                          - **ComparisonOperator** *(string) --* **[REQUIRED]**

                            The operator to use when comparing metric values. Valid values are:
                            GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                            EQUAL.

                          - **Value** *(float) --* **[REQUIRED]**

                            The value to compare.

                    - **UserAttributes** *(dict) --*

                      One or more custom user attributes to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --* **[REQUIRED]**

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                - **SourceSegments** *(list) --*

                  The base segment to build the segment on. A base segment, also referred to as a
                  *source segment* , defines the initial population of endpoints for a segment. When
                  you add dimensions to a segment, Amazon Pinpoint filters the base segment by using
                  the dimensions that you specify.

                  You can specify more than one dimensional segment or only one imported segment. If
                  you specify an imported segment, the Amazon Pinpoint console displays a segment
                  size estimate that indicates the size of the imported segment without any filters
                  applied to it.

                  - *(dict) --*

                    Specifies the segment identifier and version of a segment.

                    - **Id** *(string) --* **[REQUIRED]**

                      The unique identifier for the segment.

                    - **Version** *(integer) --*

                      The version number of the segment.

                - **SourceType** *(string) --*

                  Specifies how to handle multiple base segments for the segment. For example, if
                  you specify three base segments for the segment, whether the resulting segment is
                  based on all, any, or none of the base segments.

                - **Type** *(string) --*

                  Specifies how to handle multiple dimensions for the segment. For example, if you
                  specify three dimensions for the segment, whether the resulting segment includes
                  endpoints that match all, any, or none of the dimensions.

            - **Include** *(string) --*

              Specifies how to handle multiple segment groups for the segment. For example, if the
              segment includes three segment groups, whether the resulting segment includes
              endpoints that match all, any, or none of the segment groups.

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            segment. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SegmentResponse': {
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Behavior': {
                            'Recency': {
                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                'RecencyType': 'ACTIVE'|'INACTIVE'
                            }
                        },
                        'Demographic': {
                            'AppVersion': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Channel': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'DeviceType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Make': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Model': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Platform': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Location': {
                            'Country': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'GPSPoint': {
                                'Coordinates': {
                                    'Latitude': 123.0,
                                    'Longitude': 123.0
                                },
                                'RangeInKilometers': 123.0
                            }
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        },
                        'UserAttributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        }
                    },
                    'Id': 'string',
                    'ImportDefinition': {
                        'ChannelCounts': {
                            'string': 123
                        },
                        'ExternalId': 'string',
                        'Format': 'CSV'|'JSON',
                        'RoleArn': 'string',
                        'S3Url': 'string',
                        'Size': 123
                    },
                    'LastModifiedDate': 'string',
                    'Name': 'string',
                    'SegmentGroups': {
                        'Groups': [
                            {
                                'Dimensions': [
                                    {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    },
                                ],
                                'SourceSegments': [
                                    {
                                        'Id': 'string',
                                        'Version': 123
                                    },
                                ],
                                'SourceType': 'ALL'|'ANY'|'NONE',
                                'Type': 'ALL'|'ANY'|'NONE'
                            },
                        ],
                        'Include': 'ALL'|'ANY'|'NONE'
                    },
                    'SegmentType': 'DIMENSIONAL'|'IMPORT',
                    'tags': {
                        'string': 'string'
                    },
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded and the specified resource was created.

            - **SegmentResponse** *(dict) --*

              Provides information about the configuration, dimension, and other settings for a
              segment.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the segment is associated with.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the segment.

              - **CreationDate** *(string) --*

                The date and time when the segment was created.

              - **Dimensions** *(dict) --*

                The dimension settings for the segment.

                - **Attributes** *(dict) --*

                  One or more custom attributes to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

                - **Behavior** *(dict) --*

                  The behavior-based criteria, such as how recently users have used your app, for
                  the segment.

                  - **Recency** *(dict) --*

                    The dimension settings that are based on how recently an endpoint was active.

                    - **Duration** *(string) --*

                      The duration to use when determining whether an endpoint is active or
                      inactive.

                    - **RecencyType** *(string) --*

                      The type of recency dimension to use for the segment. Valid values are:
                      ACTIVE, endpoints that were active within the specified duration are included
                      in the segment; and, INACTIVE, endpoints that weren't active within the
                      specified duration are included in the segment.

                - **Demographic** *(dict) --*

                  The demographic-based criteria, such as device platform, for the segment.

                  - **AppVersion** *(dict) --*

                    The app version criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Channel** *(dict) --*

                    The channel criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **DeviceType** *(dict) --*

                    The device type criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Make** *(dict) --*

                    The device make criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Model** *(dict) --*

                    The device model criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Platform** *(dict) --*

                    The device platform criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                - **Location** *(dict) --*

                  The location-based criteria, such as region or GPS coordinates, for the segment.

                  - **Country** *(dict) --*

                    The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **GPSPoint** *(dict) --*

                    The GPS location and range for the segment.

                    - **Coordinates** *(dict) --*

                      The GPS coordinates to measure distance from.

                      - **Latitude** *(float) --*

                        The latitude coordinate of the location.

                      - **Longitude** *(float) --*

                        The longitude coordinate of the location.

                    - **RangeInKilometers** *(float) --*

                      The range, in kilometers, from the GPS coordinates.

                - **Metrics** *(dict) --*

                  One or more custom metrics to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies metric-based criteria for including or excluding endpoints from a
                      segment. These criteria derive from custom metrics that you define for
                      endpoints.

                      - **ComparisonOperator** *(string) --*

                        The operator to use when comparing metric values. Valid values are:
                        GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                        EQUAL.

                      - **Value** *(float) --*

                        The value to compare.

                - **UserAttributes** *(dict) --*

                  One or more custom user attributes to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

              - **Id** *(string) --*

                The unique identifier for the segment.

              - **ImportDefinition** *(dict) --*

                The settings for the import job that's associated with the segment.

                - **ChannelCounts** *(dict) --*

                  The number of channel types in the endpoint definitions that were imported to
                  create the segment.

                  - *(string) --*

                    - *(integer) --*

                - **ExternalId** *(string) --*

                  (Deprecated) Your AWS account ID, which you assigned to an external ID key in an
                  IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role
                  when importing endpoint definitions, but we removed this requirement. We don't
                  recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

                - **Format** *(string) --*

                  The format of the files that were imported to create the segment. Valid values
                  are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON
                  format.

                - **RoleArn** *(string) --*

                  The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                  role that authorized Amazon Pinpoint to access the Amazon S3 location to import
                  endpoint definitions from.

                - **S3Url** *(string) --*

                  The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint
                  definitions were imported from to create the segment.

                - **Size** *(integer) --*

                  The number of endpoint definitions that were imported successfully to create the
                  segment.

              - **LastModifiedDate** *(string) --*

                The date and time when the segment was last modified.

              - **Name** *(string) --*

                The name of the segment.

              - **SegmentGroups** *(dict) --*

                A list of one or more segment groups that apply to the segment. Each segment group
                consists of zero or more base segments and the dimensions that are applied to those
                base segments.

                - **Groups** *(list) --*

                  An array that defines the set of segment criteria to evaluate when handling
                  segment groups for the segment.

                  - *(dict) --*

                    Specifies the base segments and dimensions for a segment, and the relationships
                    between these base segments and dimensions.

                    - **Dimensions** *(list) --*

                      An array that defines the dimensions for the segment.

                      - *(dict) --*

                        Specifies the dimension settings for a segment.

                        - **Attributes** *(dict) --*

                          One or more custom attributes to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **Behavior** *(dict) --*

                          The behavior-based criteria, such as how recently users have used your
                          app, for the segment.

                          - **Recency** *(dict) --*

                            The dimension settings that are based on how recently an endpoint was
                            active.

                            - **Duration** *(string) --*

                              The duration to use when determining whether an endpoint is active or
                              inactive.

                            - **RecencyType** *(string) --*

                              The type of recency dimension to use for the segment. Valid values
                              are: ACTIVE, endpoints that were active within the specified duration
                              are included in the segment; and, INACTIVE, endpoints that weren't
                              active within the specified duration are included in the segment.

                        - **Demographic** *(dict) --*

                          The demographic-based criteria, such as device platform, for the segment.

                          - **AppVersion** *(dict) --*

                            The app version criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Channel** *(dict) --*

                            The channel criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **DeviceType** *(dict) --*

                            The device type criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Make** *(dict) --*

                            The device make criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Model** *(dict) --*

                            The device model criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Platform** *(dict) --*

                            The device platform criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                        - **Location** *(dict) --*

                          The location-based criteria, such as region or GPS coordinates, for the
                          segment.

                          - **Country** *(dict) --*

                            The country or region code, in ISO 3166-1 alpha-2 format, for the
                            segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **GPSPoint** *(dict) --*

                            The GPS location and range for the segment.

                            - **Coordinates** *(dict) --*

                              The GPS coordinates to measure distance from.

                              - **Latitude** *(float) --*

                                The latitude coordinate of the location.

                              - **Longitude** *(float) --*

                                The longitude coordinate of the location.

                            - **RangeInKilometers** *(float) --*

                              The range, in kilometers, from the GPS coordinates.

                        - **Metrics** *(dict) --*

                          One or more custom metrics to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                        - **UserAttributes** *(dict) --*

                          One or more custom user attributes to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                    - **SourceSegments** *(list) --*

                      The base segment to build the segment on. A base segment, also referred to as
                      a *source segment* , defines the initial population of endpoints for a
                      segment. When you add dimensions to a segment, Amazon Pinpoint filters the
                      base segment by using the dimensions that you specify.

                      You can specify more than one dimensional segment or only one imported
                      segment. If you specify an imported segment, the Amazon Pinpoint console
                      displays a segment size estimate that indicates the size of the imported
                      segment without any filters applied to it.

                      - *(dict) --*

                        Specifies the segment identifier and version of a segment.

                        - **Id** *(string) --*

                          The unique identifier for the segment.

                        - **Version** *(integer) --*

                          The version number of the segment.

                    - **SourceType** *(string) --*

                      Specifies how to handle multiple base segments for the segment. For example,
                      if you specify three base segments for the segment, whether the resulting
                      segment is based on all, any, or none of the base segments.

                    - **Type** *(string) --*

                      Specifies how to handle multiple dimensions for the segment. For example, if
                      you specify three dimensions for the segment, whether the resulting segment
                      includes endpoints that match all, any, or none of the dimensions.

                - **Include** *(string) --*

                  Specifies how to handle multiple segment groups for the segment. For example, if
                  the segment includes three segment groups, whether the resulting segment includes
                  endpoints that match all, any, or none of the segment groups.

              - **SegmentType** *(string) --*

                The segment type. Valid values are:

                * DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria
                that you specify and is based on endpoint data that's reported by your app. Dynamic
                segments can change over time.

                * IMPORT - A static segment, which is a segment that uses selection criteria that
                you specify and is based on endpoint definitions that you import from a file.
                Imported segments are static; they don't change over time.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the segment. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **Version** *(integer) --*

                The version number of the segment.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_sms_template(
        self,
        SMSTemplateRequest: ClientCreateSmsTemplateSMSTemplateRequestTypeDef,
        TemplateName: str,
    ) -> ClientCreateSmsTemplateResponseTypeDef:
        """
        Creates a message template that you can use in messages that are sent through the SMS
        channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/CreateSmsTemplate>`_

        **Request Syntax**
        ::

          response = client.create_sms_template(
              SMSTemplateRequest={
                  'Body': 'string',
                  'DefaultSubstitutions': 'string',
                  'tags': {
                      'string': 'string'
                  },
                  'TemplateDescription': 'string'
              },
              TemplateName='string'
          )
        :type SMSTemplateRequest: dict
        :param SMSTemplateRequest: **[REQUIRED]**

          Creates a message template that you can use in messages that are sent through the SMS
          channel.

          - **Body** *(string) --*

            The message body to use in text messages that are based on the message template.

          - **DefaultSubstitutions** *(string) --*

            A JSON object that specifies the default values to use for message variables in the
            message template. This object is a set of key-value pairs. Each key defines a message
            variable in the template. The corresponding value defines the default value for that
            variable. When you create a message that's based on the template, you can override these
            defaults with message-specific and address-specific variables and values.

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            message template. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

          - **TemplateDescription** *(string) --*

            A custom description of the message template.

        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CreateTemplateMessageBody': {
                    'Arn': 'string',
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded and the specified resource was created.

            - **CreateTemplateMessageBody** *(dict) --*

              Provides information about a request to create a message template.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the message template that was created.

              - **Message** *(string) --*

                The message that's returned from the API for the request to create the message
                template.

              - **RequestID** *(string) --*

                The unique identifier for the request to create the message template.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_voice_template(
        self,
        TemplateName: str,
        VoiceTemplateRequest: ClientCreateVoiceTemplateVoiceTemplateRequestTypeDef,
    ) -> ClientCreateVoiceTemplateResponseTypeDef:
        """
        Creates a message template that you can use in messages that are sent through the voice
        channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/CreateVoiceTemplate>`_

        **Request Syntax**
        ::

          response = client.create_voice_template(
              TemplateName='string',
              VoiceTemplateRequest={
                  'Body': 'string',
                  'DefaultSubstitutions': 'string',
                  'LanguageCode': 'string',
                  'tags': {
                      'string': 'string'
                  },
                  'TemplateDescription': 'string',
                  'VoiceId': 'string'
              }
          )
        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :type VoiceTemplateRequest: dict
        :param VoiceTemplateRequest: **[REQUIRED]**

          Specifies the content and settings for a message template that can be used in messages
          that are sent through the voice channel.

          - **Body** *(string) --*

            The text of the script to use in messages that are based on the message template, in
            plain text format.

          - **DefaultSubstitutions** *(string) --*

            A JSON object that specifies the default values to use for message variables in the
            message template. This object is a set of key-value pairs. Each key defines a message
            variable in the template. The corresponding value defines the default value for that
            variable. When you create a message that's based on the template, you can override these
            defaults with message-specific and address-specific variables and values.

          - **LanguageCode** *(string) --*

            The code for the language to use when synthesizing the text of the script in messages
            that are based on the message template. For a list of supported languages and the code
            for each one, see the `Amazon Polly Developer Guide
            <https://docs.aws.amazon.com/polly/latest/dg/what-is.html>`__ .

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            message template. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

          - **TemplateDescription** *(string) --*

            A custom description of the message template.

          - **VoiceId** *(string) --*

            The name of the voice to use when delivering messages that are based on the message
            template. For a list of supported voices, see the `Amazon Polly Developer Guide
            <https://docs.aws.amazon.com/polly/latest/dg/what-is.html>`__ .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CreateTemplateMessageBody': {
                    'Arn': 'string',
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded and the specified resource was created.

            - **CreateTemplateMessageBody** *(dict) --*

              Provides information about a request to create a message template.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the message template that was created.

              - **Message** *(string) --*

                The message that's returned from the API for the request to create the message
                template.

              - **RequestID** *(string) --*

                The unique identifier for the request to create the message template.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_adm_channel(self, ApplicationId: str) -> ClientDeleteAdmChannelResponseTypeDef:
        """
        Disables the ADM channel for an application and deletes any existing settings for the
        channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteAdmChannel>`_

        **Request Syntax**
        ::

          response = client.delete_adm_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ADMChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ADMChannelResponse** *(dict) --*

              Provides information about the status and settings of the ADM (Amazon Device
              Messaging) channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the ADM channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the ADM channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the ADM channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the ADM channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the ADM channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the ADM channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the ADM channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the ADM channel,
                this value is ADM.

              - **Version** *(integer) --*

                The current version of the ADM channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_apns_channel(self, ApplicationId: str) -> ClientDeleteApnsChannelResponseTypeDef:
        """
        Disables the APNs channel for an application and deletes any existing settings for the
        channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteApnsChannel>`_

        **Request Syntax**
        ::

          response = client.delete_apns_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the APNs channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with
                APNs for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs channel is configured to communicate with APNs by using
                APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey
                property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs
                channel, this value is APNS.

              - **Version** *(integer) --*

                The current version of the APNs channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_apns_sandbox_channel(
        self, ApplicationId: str
    ) -> ClientDeleteApnsSandboxChannelResponseTypeDef:
        """
        Disables the APNs sandbox channel for an application and deletes any existing settings for
        the channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteApnsSandboxChannel>`_

        **Request Syntax**
        ::

          response = client.delete_apns_sandbox_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSSandboxChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSSandboxChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) sandbox channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs sandbox channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the APNs sandbox channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with the
                APNs sandbox environment for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs sandbox channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs sandbox channel is configured to communicate with APNs by
                using APNs tokens. To provide an authentication key for APNs tokens, set the
                TokenKey property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs sandbox channel. This property is retained
                only for backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs sandbox channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs sandbox channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs sandbox channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs sandbox
                channel, this value is APNS_SANDBOX.

              - **Version** *(integer) --*

                The current version of the APNs sandbox channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_apns_voip_channel(
        self, ApplicationId: str
    ) -> ClientDeleteApnsVoipChannelResponseTypeDef:
        """
        Disables the APNs VoIP channel for an application and deletes any existing settings for the
        channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteApnsVoipChannel>`_

        **Request Syntax**
        ::

          response = client.delete_apns_voip_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSVoipChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSVoipChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) VoIP channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs VoIP channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the APNs VoIP channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with
                APNs for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs VoIP channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs VoIP channel is configured to communicate with APNs by
                using APNs tokens. To provide an authentication key for APNs tokens, set the
                TokenKey property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs VoIP channel. This property is retained only
                for backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs VoIP channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs VoIP channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs VoIP channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs VoIP
                channel, this value is APNS_VOIP.

              - **Version** *(integer) --*

                The current version of the APNs VoIP channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_apns_voip_sandbox_channel(
        self, ApplicationId: str
    ) -> ClientDeleteApnsVoipSandboxChannelResponseTypeDef:
        """
        Disables the APNs VoIP sandbox channel for an application and deletes any existing settings
        for the channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteApnsVoipSandboxChannel>`_

        **Request Syntax**
        ::

          response = client.delete_apns_voip_sandbox_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSVoipSandboxChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSVoipSandboxChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) VoIP sandbox channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs VoIP sandbox channel applies
                to.

              - **CreationDate** *(string) --*

                The date and time when the APNs VoIP sandbox channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with the
                APNs sandbox environment for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs VoIP sandbox channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs VoIP sandbox channel is configured to communicate with
                APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the
                TokenKey property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs VoIP sandbox channel. This property is
                retained only for backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs VoIP sandbox channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs VoIP sandbox channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs VoIP sandbox channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs VoIP
                sandbox channel, this value is APNS_VOIP_SANDBOX.

              - **Version** *(integer) --*

                The current version of the APNs VoIP sandbox channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_app(self, ApplicationId: str) -> ClientDeleteAppResponseTypeDef:
        """
        Deletes an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteApp>`_

        **Request Syntax**
        ::

          response = client.delete_app(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ApplicationResponse': {
                    'Arn': 'string',
                    'Id': 'string',
                    'Name': 'string',
                    'tags': {
                        'string': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ApplicationResponse** *(dict) --*

              Provides information about an application.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the application.

              - **Id** *(string) --*

                The unique identifier for the application. This identifier is displayed as the
                **Project ID** on the Amazon Pinpoint console.

              - **Name** *(string) --*

                The display name of the application. This name is displayed as the **Project name**
                on the Amazon Pinpoint console.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the application. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_baidu_channel(self, ApplicationId: str) -> ClientDeleteBaiduChannelResponseTypeDef:
        """
        Disables the Baidu channel for an application and deletes any existing settings for the
        channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteBaiduChannel>`_

        **Request Syntax**
        ::

          response = client.delete_baidu_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'BaiduChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Credential': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **BaiduChannelResponse** *(dict) --*

              Provides information about the status and settings of the Baidu (Baidu Cloud Push)
              channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the Baidu channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the Baidu channel was enabled.

              - **Credential** *(string) --*

                The API key that you received from the Baidu Cloud Push service to communicate with
                the service.

              - **Enabled** *(boolean) --*

                Specifies whether the Baidu channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the Baidu channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the Baidu channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the Baidu channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the Baidu channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the Baidu
                channel, this value is BAIDU.

              - **Version** *(integer) --*

                The current version of the Baidu channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_campaign(
        self, ApplicationId: str, CampaignId: str
    ) -> ClientDeleteCampaignResponseTypeDef:
        """
        Deletes a campaign from an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteCampaign>`_

        **Request Syntax**
        ::

          response = client.delete_campaign(
              ApplicationId='string',
              CampaignId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type CampaignId: string
        :param CampaignId: **[REQUIRED]**

          The unique identifier for the campaign.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CampaignResponse': {
                    'AdditionalTreatments': [
                        {
                            'Id': 'string',
                            'MessageConfiguration': {
                                'ADMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'APNSMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'BaiduMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'DefaultMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'EmailMessage': {
                                    'Body': 'string',
                                    'FromAddress': 'string',
                                    'HtmlBody': 'string',
                                    'Title': 'string'
                                },
                                'GCMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'SMSMessage': {
                                    'Body': 'string',
                                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                    'SenderId': 'string'
                                }
                            },
                            'Schedule': {
                                'EndTime': 'string',
                                'EventFilter': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'FilterType': 'SYSTEM'|'ENDPOINT'
                                },
                                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                                'IsLocalTime': True|False,
                                'QuietTime': {
                                    'End': 'string',
                                    'Start': 'string'
                                },
                                'StartTime': 'string',
                                'Timezone': 'string'
                            },
                            'SizePercent': 123,
                            'State': {
                                'CampaignStatus':
                                'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'
                                |'COMPLETED'|'PAUSED'|'DELETED'
                            },
                            'TemplateConfiguration': {
                                'EmailTemplate': {
                                    'Name': 'string'
                                },
                                'PushTemplate': {
                                    'Name': 'string'
                                },
                                'SMSTemplate': {
                                    'Name': 'string'
                                },
                                'VoiceTemplate': {
                                    'Name': 'string'
                                }
                            },
                            'TreatmentDescription': 'string',
                            'TreatmentName': 'string'
                        },
                    ],
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'DefaultState': {
                        'CampaignStatus':
                        'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'
                        |'PAUSED'|'DELETED'
                    },
                    'Description': 'string',
                    'HoldoutPercent': 123,
                    'Hook': {
                        'LambdaFunctionName': 'string',
                        'Mode': 'DELIVERY'|'FILTER',
                        'WebUrl': 'string'
                    },
                    'Id': 'string',
                    'IsPaused': True|False,
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'Daily': 123,
                        'MaximumDuration': 123,
                        'MessagesPerSecond': 123,
                        'Total': 123
                    },
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Name': 'string',
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SegmentId': 'string',
                    'SegmentVersion': 123,
                    'State': {
                        'CampaignStatus':
                        'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'
                        |'PAUSED'|'DELETED'
                    },
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **CampaignResponse** *(dict) --*

              Provides information about the status, configuration, and other settings for a
              campaign.

              - **AdditionalTreatments** *(list) --*

                An array of responses, one for each treatment that you defined for the campaign, in
                addition to the default treatment.

                - *(dict) --*

                  Specifies the settings for a campaign treatment. A treatment is a variation of a
                  campaign that's used for A/B testing of a campaign.

                  - **Id** *(string) --*

                    The unique identifier for the treatment.

                  - **MessageConfiguration** *(dict) --*

                    The message configuration settings for the treatment.

                    - **ADMMessage** *(dict) --*

                      The message that the campaign sends through the ADM (Amazon Device Messaging)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **APNSMessage** *(dict) --*

                      The message that the campaign sends through the APNs (Apple Push Notification
                      service) channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **BaiduMessage** *(dict) --*

                      The message that the campaign sends through the Baidu (Baidu Cloud Push)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **DefaultMessage** *(dict) --*

                      The default message that the campaign sends through all the channels that are
                      configured for the campaign.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **EmailMessage** *(dict) --*

                      The message that the campaign sends through the email channel.

                      - **Body** *(string) --*

                        The body of the email for recipients whose email clients don't render HTML
                        content.

                      - **FromAddress** *(string) --*

                        The verified email address to send the email from. The default address is
                        the FromAddress specified for the email channel for the application.

                      - **HtmlBody** *(string) --*

                        The body of the email, in HTML format, for recipients whose email clients
                        render HTML content.

                      - **Title** *(string) --*

                        The subject line, or title, of the email.

                    - **GCMMessage** *(dict) --*

                      The message that the campaign sends through the GCM channel, which enables
                      Amazon Pinpoint to send push notifications through the Firebase Cloud
                      Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message
                      overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **SMSMessage** *(dict) --*

                      The message that the campaign sends through the SMS channel.

                      - **Body** *(string) --*

                        The body of the SMS message.

                      - **MessageType** *(string) --*

                        The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                        critical or time-sensitive, such as a one-time password that supports a
                        customer transaction; and, PROMOTIONAL, the message isn't critical or
                        time-sensitive, such as a marketing message.

                      - **SenderId** *(string) --*

                        The sender ID to display on recipients' devices when they receive the SMS
                        message.

                  - **Schedule** *(dict) --*

                    The schedule settings for the treatment.

                    - **EndTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                    - **EventFilter** *(dict) --*

                      The type of event that causes the campaign to be sent, if the value of the
                      Frequency property is EVENT.

                      - **Dimensions** *(dict) --*

                        The dimension settings of the event filter for the campaign.

                        - **Attributes** *(dict) --*

                          One or more custom attributes that your application reports to Amazon
                          Pinpoint. You can use these attributes as selection criteria when you
                          create an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **EventType** *(dict) --*

                          The name of the event that causes the campaign to be sent or the journey
                          activity to be performed. This can be a standard type of event that Amazon
                          Pinpoint generates, such as _email.delivered, or a custom event that's
                          specific to your application.

                          - **DimensionType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the DimensionType property, endpoints are included or excluded
                            from the segment if their values match the criteria values.

                            - *(string) --*

                        - **Metrics** *(dict) --*

                          One or more custom metrics that your application reports to Amazon
                          Pinpoint. You can use these metrics as selection criteria when you create
                          an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                      - **FilterType** *(string) --*

                        The type of event that causes the campaign to be sent. Valid values are:
                        SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends
                        the campaign when an endpoint event (Events resource) occurs.

                    - **Frequency** *(string) --*

                      Specifies how often the campaign is sent or whether the campaign is sent in
                      response to a specific event.

                    - **IsLocalTime** *(boolean) --*

                      Specifies whether the start and end times for the campaign schedule use each
                      recipient's local time. To base the schedule on each recipient's local time,
                      set this value to true.

                    - **QuietTime** *(dict) --*

                      The default quiet time for the campaign. Quiet time is a specific time range
                      when a campaign doesn't send messages to endpoints, if all the following
                      conditions are met:

                      * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                      value.

                      * The current time in the endpoint's time zone is later than or equal to the
                      time specified by the QuietTime.Start property for the campaign.

                      * The current time in the endpoint's time zone is earlier than or equal to the
                      time specified by the QuietTime.End property for the campaign.

                      If any of the preceding conditions isn't met, the endpoint will receive
                      messages from the campaign, even if quiet time is enabled.

                      - **End** *(string) --*

                        The specific time when quiet time ends. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                      - **Start** *(string) --*

                        The specific time when quiet time begins. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                    - **StartTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                    - **Timezone** *(string) --*

                      The starting UTC offset for the campaign schedule, if the value of the
                      IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                      UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                      UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13,
                      UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and
                      UTC-11.

                  - **SizePercent** *(integer) --*

                    The allocated percentage of users (segment members) that the treatment is sent
                    to.

                  - **State** *(dict) --*

                    The current status of the treatment.

                    - **CampaignStatus** *(string) --*

                      The current status of the campaign, or the current status of a treatment that
                      belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign
                      has a status of COMPLETED only if all campaign treatments have a status of
                      COMPLETED.

                  - **TemplateConfiguration** *(dict) --*

                    The message template to use for the treatment.

                    - **EmailTemplate** *(dict) --*

                      The email template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **PushTemplate** *(dict) --*

                      The push notification template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **SMSTemplate** *(dict) --*

                      The SMS template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **VoiceTemplate** *(dict) --*

                      The voice template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                  - **TreatmentDescription** *(string) --*

                    The custom description of the treatment.

                  - **TreatmentName** *(string) --*

                    The custom name of the treatment. A treatment is a variation of a campaign
                    that's used for A/B testing of a campaign.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the campaign applies to.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the campaign.

              - **CreationDate** *(string) --*

                The date, ISO 8601 format, when the campaign was created.

              - **DefaultState** *(dict) --*

                The current status of the campaign's default treatment. This value exists only for
                campaigns that have more than one treatment, to support A/B testing.

                - **CampaignStatus** *(string) --*

                  The current status of the campaign, or the current status of a treatment that
                  belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign has
                  a status of COMPLETED only if all campaign treatments have a status of COMPLETED.

              - **Description** *(string) --*

                The custom description of the campaign.

              - **HoldoutPercent** *(integer) --*

                The allocated percentage of users (segment members) who shouldn't receive messages
                from the campaign.

              - **Hook** *(dict) --*

                The settings for the AWS Lambda function to use as a code hook for the campaign.

                - **LambdaFunctionName** *(string) --*

                  The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon
                  Pinpoint invokes to send messages for a campaign.

                - **Mode** *(string) --*

                  Specifies which Lambda mode to use when invoking the AWS Lambda function.

                - **WebUrl** *(string) --*

                  The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over
                  HTTPS.

              - **Id** *(string) --*

                The unique identifier for the campaign.

              - **IsPaused** *(boolean) --*

                Specifies whether the campaign is paused. A paused campaign doesn't run unless you
                resume it by changing this value to false.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the campaign was last modified.

              - **Limits** *(dict) --*

                The messaging limits for the campaign.

                - **Daily** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during a 24-hour period. The maximum value is 100.

                - **MaximumDuration** *(integer) --*

                  The maximum amount of time, in seconds, that a campaign can attempt to deliver a
                  message after the scheduled start time for the campaign. The minimum value is 60
                  seconds.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that a campaign can send each second. The minimum
                  value is 50. The maximum value is 20,000.

                - **Total** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during the course of the campaign. The maximum value is 100.

              - **MessageConfiguration** *(dict) --*

                The message configuration settings for the campaign.

                - **ADMMessage** *(dict) --*

                  The message that the campaign sends through the ADM (Amazon Device Messaging)
                  channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **APNSMessage** *(dict) --*

                  The message that the campaign sends through the APNs (Apple Push Notification
                  service) channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **BaiduMessage** *(dict) --*

                  The message that the campaign sends through the Baidu (Baidu Cloud Push) channel.
                  This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **DefaultMessage** *(dict) --*

                  The default message that the campaign sends through all the channels that are
                  configured for the campaign.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **EmailMessage** *(dict) --*

                  The message that the campaign sends through the email channel.

                  - **Body** *(string) --*

                    The body of the email for recipients whose email clients don't render HTML
                    content.

                  - **FromAddress** *(string) --*

                    The verified email address to send the email from. The default address is the
                    FromAddress specified for the email channel for the application.

                  - **HtmlBody** *(string) --*

                    The body of the email, in HTML format, for recipients whose email clients render
                    HTML content.

                  - **Title** *(string) --*

                    The subject line, or title, of the email.

                - **GCMMessage** *(dict) --*

                  The message that the campaign sends through the GCM channel, which enables Amazon
                  Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM),
                  formerly Google Cloud Messaging (GCM), service. This message overrides the default
                  message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **SMSMessage** *(dict) --*

                  The message that the campaign sends through the SMS channel.

                  - **Body** *(string) --*

                    The body of the SMS message.

                  - **MessageType** *(string) --*

                    The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                    critical or time-sensitive, such as a one-time password that supports a customer
                    transaction; and, PROMOTIONAL, the message isn't critical or time-sensitive,
                    such as a marketing message.

                  - **SenderId** *(string) --*

                    The sender ID to display on recipients' devices when they receive the SMS
                    message.

              - **Name** *(string) --*

                The name of the campaign.

              - **Schedule** *(dict) --*

                The schedule settings for the campaign.

                - **EndTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                - **EventFilter** *(dict) --*

                  The type of event that causes the campaign to be sent, if the value of the
                  Frequency property is EVENT.

                  - **Dimensions** *(dict) --*

                    The dimension settings of the event filter for the campaign.

                    - **Attributes** *(dict) --*

                      One or more custom attributes that your application reports to Amazon
                      Pinpoint. You can use these attributes as selection criteria when you create
                      an event filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                    - **EventType** *(dict) --*

                      The name of the event that causes the campaign to be sent or the journey
                      activity to be performed. This can be a standard type of event that Amazon
                      Pinpoint generates, such as _email.delivered, or a custom event that's
                      specific to your application.

                      - **DimensionType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the DimensionType property, endpoints are included or excluded from the
                        segment if their values match the criteria values.

                        - *(string) --*

                    - **Metrics** *(dict) --*

                      One or more custom metrics that your application reports to Amazon Pinpoint.
                      You can use these metrics as selection criteria when you create an event
                      filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies metric-based criteria for including or excluding endpoints from
                          a segment. These criteria derive from custom metrics that you define for
                          endpoints.

                          - **ComparisonOperator** *(string) --*

                            The operator to use when comparing metric values. Valid values are:
                            GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                            EQUAL.

                          - **Value** *(float) --*

                            The value to compare.

                  - **FilterType** *(string) --*

                    The type of event that causes the campaign to be sent. Valid values are: SYSTEM,
                    sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign
                    when an endpoint event (Events resource) occurs.

                - **Frequency** *(string) --*

                  Specifies how often the campaign is sent or whether the campaign is sent in
                  response to a specific event.

                - **IsLocalTime** *(boolean) --*

                  Specifies whether the start and end times for the campaign schedule use each
                  recipient's local time. To base the schedule on each recipient's local time, set
                  this value to true.

                - **QuietTime** *(dict) --*

                  The default quiet time for the campaign. Quiet time is a specific time range when
                  a campaign doesn't send messages to endpoints, if all the following conditions are
                  met:

                  * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                  value.

                  * The current time in the endpoint's time zone is later than or equal to the time
                  specified by the QuietTime.Start property for the campaign.

                  * The current time in the endpoint's time zone is earlier than or equal to the
                  time specified by the QuietTime.End property for the campaign.

                  If any of the preceding conditions isn't met, the endpoint will receive messages
                  from the campaign, even if quiet time is enabled.

                  - **End** *(string) --*

                    The specific time when quiet time ends. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                  - **Start** *(string) --*

                    The specific time when quiet time begins. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                - **StartTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the campaign schedule, if the value of the IsLocalTime
                  property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30,
                  UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07,
                  UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02,
                  UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.

              - **SegmentId** *(string) --*

                The unique identifier for the segment that's associated with the campaign.

              - **SegmentVersion** *(integer) --*

                The version number of the segment that's associated with the campaign.

              - **State** *(dict) --*

                The current status of the campaign.

                - **CampaignStatus** *(string) --*

                  The current status of the campaign, or the current status of a treatment that
                  belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign has
                  a status of COMPLETED only if all campaign treatments have a status of COMPLETED.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the campaign. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **TemplateConfiguration** *(dict) --*

                The message template that’s used for the campaign.

                - **EmailTemplate** *(dict) --*

                  The email template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **PushTemplate** *(dict) --*

                  The push notification template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **SMSTemplate** *(dict) --*

                  The SMS template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **VoiceTemplate** *(dict) --*

                  The voice template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

              - **TreatmentDescription** *(string) --*

                The custom description of a variation of the campaign that's used for A/B testing.

              - **TreatmentName** *(string) --*

                The custom name of a variation of the campaign that's used for A/B testing.

              - **Version** *(integer) --*

                The version number of the campaign.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_email_channel(self, ApplicationId: str) -> ClientDeleteEmailChannelResponseTypeDef:
        """
        Disables the email channel for an application and deletes any existing settings for the
        channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteEmailChannel>`_

        **Request Syntax**
        ::

          response = client.delete_email_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EmailChannelResponse': {
                    'ApplicationId': 'string',
                    'ConfigurationSet': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'FromAddress': 'string',
                    'HasCredential': True|False,
                    'Id': 'string',
                    'Identity': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'MessagesPerSecond': 123,
                    'Platform': 'string',
                    'RoleArn': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **EmailChannelResponse** *(dict) --*

              Provides information about the status and settings of the email channel for an
              application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the email channel applies to.

              - **ConfigurationSet** *(string) --*

                The configuration set that's applied to email that's sent through the channel by
                using the `Amazon Pinpoint Email API <emailAPIreference.html>`__ .

              - **CreationDate** *(string) --*

                The date and time, in ISO 8601 format, when the email channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the email channel is enabled for the application.

              - **FromAddress** *(string) --*

                The verified email address that you send email from when you send email through the
                channel.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the email channel. This property is retained only for
                backward compatibility.

              - **Identity** *(string) --*

                The Amazon Resource Name (ARN) of the identity, verified with Amazon Simple Email
                Service (Amazon SES), that you use when you send email through the channel.

              - **IsArchived** *(boolean) --*

                Specifies whether the email channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the email channel.

              - **LastModifiedDate** *(string) --*

                The date and time, in ISO 8601 format, when the email channel was last modified.

              - **MessagesPerSecond** *(integer) --*

                The maximum number of emails that you can send through the channel each second.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the email
                channel, this value is EMAIL.

              - **RoleArn** *(string) --*

                The ARN of the AWS Identity and Access Management (IAM) role that Amazon Pinpoint
                uses to submit email-related event data for the channel.

              - **Version** *(integer) --*

                The current version of the email channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_email_template(self, TemplateName: str) -> ClientDeleteEmailTemplateResponseTypeDef:
        """
        Deletes a message template that was designed for use in messages that were sent through the
        email channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteEmailTemplate>`_

        **Request Syntax**
        ::

          response = client.delete_email_template(
              TemplateName='string'
          )
        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MessageBody': {
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **MessageBody** *(dict) --*

              Provides information about an API request or response.

              - **Message** *(string) --*

                The message that's returned from the API.

              - **RequestID** *(string) --*

                The unique identifier for the request or response.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_endpoint(
        self, ApplicationId: str, EndpointId: str
    ) -> ClientDeleteEndpointResponseTypeDef:
        """
        Deletes an endpoint from an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteEndpoint>`_

        **Request Syntax**
        ::

          response = client.delete_endpoint(
              ApplicationId='string',
              EndpointId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type EndpointId: string
        :param EndpointId: **[REQUIRED]**

          The unique identifier for the endpoint.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EndpointResponse': {
                    'Address': 'string',
                    'ApplicationId': 'string',
                    'Attributes': {
                        'string': [
                            'string',
                        ]
                    },
                    'ChannelType':
                    'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'
                    |'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    'CohortId': 'string',
                    'CreationDate': 'string',
                    'Demographic': {
                        'AppVersion': 'string',
                        'Locale': 'string',
                        'Make': 'string',
                        'Model': 'string',
                        'ModelVersion': 'string',
                        'Platform': 'string',
                        'PlatformVersion': 'string',
                        'Timezone': 'string'
                    },
                    'EffectiveDate': 'string',
                    'EndpointStatus': 'string',
                    'Id': 'string',
                    'Location': {
                        'City': 'string',
                        'Country': 'string',
                        'Latitude': 123.0,
                        'Longitude': 123.0,
                        'PostalCode': 'string',
                        'Region': 'string'
                    },
                    'Metrics': {
                        'string': 123.0
                    },
                    'OptOut': 'string',
                    'RequestId': 'string',
                    'User': {
                        'UserAttributes': {
                            'string': [
                                'string',
                            ]
                        },
                        'UserId': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **EndpointResponse** *(dict) --*

              Provides information about the channel type and other settings for an endpoint.

              - **Address** *(string) --*

                The destination address for messages or push notifications that you send to the
                endpoint. The address varies by channel. For example, the address for a
                push-notification channel is typically the token provided by a push notification
                service, such as an Apple Push Notification service (APNs) device token or a
                Firebase Cloud Messaging (FCM) registration token. The address for the SMS channel
                is a phone number in E.164 format, such as +12065550100. The address for the email
                channel is an email address.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that's associated with the endpoint.

              - **Attributes** *(dict) --*

                One or more custom attributes that describe the endpoint by associating a name with
                an array of values. For example, the value of a custom attribute named Interests
                might be: ["science", "music", "travel"]. You can use these attributes as filter
                criteria when you create segments.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **ChannelType** *(string) --*

                The channel that's used when sending messages or push notifications to the endpoint.

              - **CohortId** *(string) --*

                A number from 0-99 that represents the cohort that the endpoint is assigned to.
                Endpoints are grouped into cohorts randomly, and each cohort contains approximately
                1 percent of the endpoints for an application. Amazon Pinpoint assigns cohorts to
                the holdout or treatment allocations for campaigns.

              - **CreationDate** *(string) --*

                The date and time, in ISO 8601 format, when the endpoint was created.

              - **Demographic** *(dict) --*

                The demographic information for the endpoint, such as the time zone and platform.

                - **AppVersion** *(string) --*

                  The version of the app that's associated with the endpoint.

                - **Locale** *(string) --*

                  The locale of the endpoint, in the following format: the ISO 639-1 alpha-2 code,
                  followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.

                - **Make** *(string) --*

                  The manufacturer of the endpoint device, such as Apple or Samsung.

                - **Model** *(string) --*

                  The model name or number of the endpoint device, such as iPhone.

                - **ModelVersion** *(string) --*

                  The model version of the endpoint device.

                - **Platform** *(string) --*

                  The platform of the endpoint device, such as iOS or Android.

                - **PlatformVersion** *(string) --*

                  The platform version of the endpoint device.

                - **Timezone** *(string) --*

                  The time zone of the endpoint, specified as a tz database name value, such as
                  America/Los_Angeles.

              - **EffectiveDate** *(string) --*

                The date and time, in ISO 8601 format, when the endpoint was last updated.

              - **EndpointStatus** *(string) --*

                Specifies whether messages or push notifications are sent to the endpoint. Possible
                values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages
                aren’t sent to the endpoint.

                Amazon Pinpoint automatically sets this value to ACTIVE when you create an endpoint
                or update an existing endpoint. Amazon Pinpoint automatically sets this value to
                INACTIVE if you update another endpoint that has the same address specified by the
                Address property.

              - **Id** *(string) --*

                The unique identifier that you assigned to the endpoint. The identifier should be a
                globally unique identifier (GUID) to ensure that it doesn't conflict with other
                endpoint identifiers that are associated with the application.

              - **Location** *(dict) --*

                The geographic information for the endpoint.

                - **City** *(string) --*

                  The name of the city where the endpoint is located.

                - **Country** *(string) --*

                  The two-character code, in ISO 3166-1 alpha-2 format, for the country or region
                  where the endpoint is located. For example, US for the United States.

                - **Latitude** *(float) --*

                  The latitude coordinate of the endpoint location, rounded to one decimal place.

                - **Longitude** *(float) --*

                  The longitude coordinate of the endpoint location, rounded to one decimal place.

                - **PostalCode** *(string) --*

                  The postal or ZIP code for the area where the endpoint is located.

                - **Region** *(string) --*

                  The name of the region where the endpoint is located. For locations in the United
                  States, this value is the name of a state.

              - **Metrics** *(dict) --*

                One or more custom metrics that your app reports to Amazon Pinpoint for the
                endpoint.

                - *(string) --*

                  - *(float) --*

              - **OptOut** *(string) --*

                Specifies whether the user who's associated with the endpoint has opted out of
                receiving messages and push notifications from you. Possible values are: ALL, the
                user has opted out and doesn't want to receive any messages or push notifications;
                and, NONE, the user hasn't opted out and wants to receive all messages and push
                notifications.

              - **RequestId** *(string) --*

                The unique identifier for the most recent request to update the endpoint.

              - **User** *(dict) --*

                One or more custom user attributes that your app reports to Amazon Pinpoint for the
                user who's associated with the endpoint.

                - **UserAttributes** *(dict) --*

                  One or more custom attributes that describe the user by associating a name with an
                  array of values. For example, the value of an attribute named Interests might be:
                  ["science", "music", "travel"]. You can use these attributes as filter criteria
                  when you create segments.

                  When you define the name of a custom attribute, avoid using the following
                  characters: number sign (#), colon (:), question mark (?), backslash (\\), and
                  slash (/). The Amazon Pinpoint console can't display attribute names that contain
                  these characters. This limitation doesn't apply to attribute values.

                  - *(string) --*

                    - *(list) --*

                      - *(string) --*

                - **UserId** *(string) --*

                  The unique identifier for the user.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_event_stream(self, ApplicationId: str) -> ClientDeleteEventStreamResponseTypeDef:
        """
        Deletes the event stream for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteEventStream>`_

        **Request Syntax**
        ::

          response = client.delete_event_stream(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EventStream': {
                    'ApplicationId': 'string',
                    'DestinationStreamArn': 'string',
                    'ExternalId': 'string',
                    'LastModifiedDate': 'string',
                    'LastUpdatedBy': 'string',
                    'RoleArn': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **EventStream** *(dict) --*

              Specifies settings for publishing event data to an Amazon Kinesis data stream or an
              Amazon Kinesis Data Firehose delivery stream.

              - **ApplicationId** *(string) --*

                The unique identifier for the application to publish event data for.

              - **DestinationStreamArn** *(string) --*

                The Amazon Resource Name (ARN) of the Amazon Kinesis data stream or Amazon Kinesis
                Data Firehose delivery stream to publish event data to.

                For a Kinesis data stream, the ARN format is:
                arn:aws:kinesis:region:account-id:stream/stream_name

                For a Kinesis Data Firehose delivery stream, the ARN format is:
                arn:aws:firehose:region:account-id:deliverystream/stream_name

              - **ExternalId** *(string) --*

                (Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM
                trust policy. Amazon Pinpoint previously used this value to assume an IAM role when
                publishing event data, but we removed this requirement. We don't recommend use of
                external IDs for IAM roles that are assumed by Amazon Pinpoint.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the event stream was last modified.

              - **LastUpdatedBy** *(string) --*

                The IAM user who last modified the event stream.

              - **RoleArn** *(string) --*

                The AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to
                publish event data to the stream in your AWS account.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_gcm_channel(self, ApplicationId: str) -> ClientDeleteGcmChannelResponseTypeDef:
        """
        Disables the GCM channel for an application and deletes any existing settings for the
        channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteGcmChannel>`_

        **Request Syntax**
        ::

          response = client.delete_gcm_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'GCMChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Credential': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **GCMChannelResponse** *(dict) --*

              Provides information about the status and settings of the GCM channel for an
              application. The GCM channel enables Amazon Pinpoint to send push notifications
              through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM),
              service.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the GCM channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the GCM channel was enabled.

              - **Credential** *(string) --*

                The Web API Key, also referred to as an *API_KEY* or *server key* , that you
                received from Google to communicate with Google services.

              - **Enabled** *(boolean) --*

                Specifies whether the GCM channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the GCM channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the GCM channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the GCM channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the GCM channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the GCM channel,
                this value is GCM.

              - **Version** *(integer) --*

                The current version of the GCM channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_journey(
        self, ApplicationId: str, JourneyId: str
    ) -> ClientDeleteJourneyResponseTypeDef:
        """
        Deletes a journey from an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteJourney>`_

        **Request Syntax**
        ::

          response = client.delete_journey(
              ApplicationId='string',
              JourneyId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type JourneyId: string
        :param JourneyId: **[REQUIRED]**

          The unique identifier for the journey.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'JourneyResponse': {
                    'Activities': {
                        'string': {
                            'ConditionalSplit': {
                                'Condition': {
                                    'Conditions': [
                                        {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType':
                                                            'INCLUSIVE'
                                                            |'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                    ],
                                    'Operator': 'ALL'|'ANY'
                                },
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                },
                                'FalseActivity': 'string',
                                'TrueActivity': 'string'
                            },
                            'Description': 'string',
                            'EMAIL': {
                                'MessageConfig': {
                                    'FromAddress': 'string'
                                },
                                'NextActivity': 'string',
                                'TemplateName': 'string'
                            },
                            'Holdout': {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                            'MultiCondition': {
                                'Branches': [
                                    {
                                        'Condition': {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType':
                                                            'INCLUSIVE'
                                                            |'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                        'NextActivity': 'string'
                                    },
                                ],
                                'DefaultActivity': 'string',
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            },
                            'RandomSplit': {
                                'Branches': [
                                    {
                                        'NextActivity': 'string',
                                        'Percentage': 123
                                    },
                                ]
                            },
                            'Wait': {
                                'NextActivity': 'string',
                                'WaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            }
                        }
                    },
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Id': 'string',
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'DailyCap': 123,
                        'EndpointReentryCap': 123,
                        'MessagesPerSecond': 123
                    },
                    'LocalTime': True|False,
                    'Name': 'string',
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'RefreshFrequency': 'string',
                    'Schedule': {
                        'EndTime': datetime(2015, 1, 1),
                        'StartTime': datetime(2015, 1, 1),
                        'Timezone': 'string'
                    },
                    'StartActivity': 'string',
                    'StartCondition': {
                        'Description': 'string',
                        'SegmentStartCondition': {
                            'SegmentId': 'string'
                        }
                    },
                    'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
                    'tags': {
                        'string': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **JourneyResponse** *(dict) --*

              Provides information about the status, configuration, and other settings for a
              journey.

              - **Activities** *(dict) --*

                The configuration and other settings for the activities that comprise the journey.

                - *(string) --*

                  - *(dict) --*

                    Specifies the configuration and other settings for an activity in a journey.

                    - **ConditionalSplit** *(dict) --*

                      The settings for a yes/no split activity. This type of activity sends
                      participants down one of two paths in a journey, based on conditions that you
                      specify.

                      - **Condition** *(dict) --*

                        The conditions that define the paths for the activity, and the relationship
                        between the conditions.

                        - **Conditions** *(list) --*

                          The conditions to evaluate for the activity.

                          - *(dict) --*

                            Specifies a condition to evaluate for an activity in a journey.

                            - **EventCondition** *(dict) --*

                              The dimension settings for the event that's associated with the
                              activity.

                              - **Dimensions** *(dict) --*

                                The dimensions for the event filter to use for the activity.

                                - **Attributes** *(dict) --*

                                  One or more custom attributes that your application reports to
                                  Amazon Pinpoint. You can use these attributes as selection
                                  criteria when you create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies attribute-based criteria for including or excluding
                                      endpoints from a segment.

                                      - **AttributeType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the AttributeType property,
                                        endpoints are included or excluded from the segment if their
                                        attribute values match the criteria values.

                                        - *(string) --*

                                - **EventType** *(dict) --*

                                  The name of the event that causes the campaign to be sent or the
                                  journey activity to be performed. This can be a standard type of
                                  event that Amazon Pinpoint generates, such as _email.delivered, or
                                  a custom event that's specific to your application.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Metrics** *(dict) --*

                                  One or more custom metrics that your application reports to Amazon
                                  Pinpoint. You can use these metrics as selection criteria when you
                                  create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies metric-based criteria for including or excluding
                                      endpoints from a segment. These criteria derive from custom
                                      metrics that you define for endpoints.

                                      - **ComparisonOperator** *(string) --*

                                        The operator to use when comparing metric values. Valid
                                        values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                        LESS_THAN_OR_EQUAL, and EQUAL.

                                      - **Value** *(float) --*

                                        The value to compare.

                              - **MessageActivity** *(string) --*

                                The message identifier (message_id) for the message to use when
                                determining whether message events meet the condition.

                            - **SegmentCondition** *(dict) --*

                              The segment that's associated with the activity.

                              - **SegmentId** *(string) --*

                                The unique identifier for the segment to associate with the
                                activity.

                            - **SegmentDimensions** *(dict) --*

                              The dimension settings for the segment that's associated with the
                              activity.

                              - **Attributes** *(dict) --*

                                One or more custom attributes to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                              - **Behavior** *(dict) --*

                                The behavior-based criteria, such as how recently users have used
                                your app, for the segment.

                                - **Recency** *(dict) --*

                                  The dimension settings that are based on how recently an endpoint
                                  was active.

                                  - **Duration** *(string) --*

                                    The duration to use when determining whether an endpoint is
                                    active or inactive.

                                  - **RecencyType** *(string) --*

                                    The type of recency dimension to use for the segment. Valid
                                    values are: ACTIVE, endpoints that were active within the
                                    specified duration are included in the segment; and, INACTIVE,
                                    endpoints that weren't active within the specified duration are
                                    included in the segment.

                              - **Demographic** *(dict) --*

                                The demographic-based criteria, such as device platform, for the
                                segment.

                                - **AppVersion** *(dict) --*

                                  The app version criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Channel** *(dict) --*

                                  The channel criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **DeviceType** *(dict) --*

                                  The device type criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Make** *(dict) --*

                                  The device make criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Model** *(dict) --*

                                  The device model criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Platform** *(dict) --*

                                  The device platform criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                              - **Location** *(dict) --*

                                The location-based criteria, such as region or GPS coordinates, for
                                the segment.

                                - **Country** *(dict) --*

                                  The country or region code, in ISO 3166-1 alpha-2 format, for the
                                  segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **GPSPoint** *(dict) --*

                                  The GPS location and range for the segment.

                                  - **Coordinates** *(dict) --*

                                    The GPS coordinates to measure distance from.

                                    - **Latitude** *(float) --*

                                      The latitude coordinate of the location.

                                    - **Longitude** *(float) --*

                                      The longitude coordinate of the location.

                                  - **RangeInKilometers** *(float) --*

                                    The range, in kilometers, from the GPS coordinates.

                              - **Metrics** *(dict) --*

                                One or more custom metrics to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies metric-based criteria for including or excluding
                                    endpoints from a segment. These criteria derive from custom
                                    metrics that you define for endpoints.

                                    - **ComparisonOperator** *(string) --*

                                      The operator to use when comparing metric values. Valid values
                                      are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                      LESS_THAN_OR_EQUAL, and EQUAL.

                                    - **Value** *(float) --*

                                      The value to compare.

                              - **UserAttributes** *(dict) --*

                                One or more custom user attributes to use as criteria for the
                                segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                        - **Operator** *(string) --*

                          Specifies how to handle multiple conditions for the activity. For example,
                          if you specify two conditions for an activity, whether both or only one of
                          the conditions must be met for the activity to be performed.

                      - **EvaluationWaitTime** *(dict) --*

                        The amount of time to wait before determining whether the conditions are
                        met, or the date and time when Amazon Pinpoint determines whether the
                        conditions are met.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

                      - **FalseActivity** *(string) --*

                        The unique identifier for the activity to perform if the condition isn't
                        met.

                      - **TrueActivity** *(string) --*

                        The unique identifier for the activity to perform if the condition is met.

                    - **Description** *(string) --*

                      The custom description of the activity.

                    - **EMAIL** *(dict) --*

                      The settings for an email activity. This type of activity sends an email
                      message to participants.

                      - **MessageConfig** *(dict) --*

                        The "From" address to use for the message.

                        - **FromAddress** *(string) --*

                          The verified email address to send the email message from. The default
                          address is the FromAddress specified for the email channel for the
                          application.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after the message is
                        sent.

                      - **TemplateName** *(string) --*

                        The name of the email template to use for the message.

                    - **Holdout** *(dict) --*

                      The settings for a holdout activity. This type of activity stops a journey for
                      a specified percentage of participants.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after performing the
                        holdout activity.

                      - **Percentage** *(integer) --*

                        The percentage of participants who shouldn't continue the journey.

                    - **MultiCondition** *(dict) --*

                      The settings for a multivariate split activity. This type of activity sends
                      participants down one of as many as five paths in a journey, based on
                      conditions that you specify.

                      - **Branches** *(list) --*

                        The paths for the activity, including the conditions for entering each path
                        and the activity to perform for each path.

                        - *(dict) --*

                          Specifies a condition to evaluate for an activity path in a journey.

                          - **Condition** *(dict) --*

                            The condition to evaluate for the activity path.

                            - **EventCondition** *(dict) --*

                              The dimension settings for the event that's associated with the
                              activity.

                              - **Dimensions** *(dict) --*

                                The dimensions for the event filter to use for the activity.

                                - **Attributes** *(dict) --*

                                  One or more custom attributes that your application reports to
                                  Amazon Pinpoint. You can use these attributes as selection
                                  criteria when you create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies attribute-based criteria for including or excluding
                                      endpoints from a segment.

                                      - **AttributeType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the AttributeType property,
                                        endpoints are included or excluded from the segment if their
                                        attribute values match the criteria values.

                                        - *(string) --*

                                - **EventType** *(dict) --*

                                  The name of the event that causes the campaign to be sent or the
                                  journey activity to be performed. This can be a standard type of
                                  event that Amazon Pinpoint generates, such as _email.delivered, or
                                  a custom event that's specific to your application.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Metrics** *(dict) --*

                                  One or more custom metrics that your application reports to Amazon
                                  Pinpoint. You can use these metrics as selection criteria when you
                                  create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies metric-based criteria for including or excluding
                                      endpoints from a segment. These criteria derive from custom
                                      metrics that you define for endpoints.

                                      - **ComparisonOperator** *(string) --*

                                        The operator to use when comparing metric values. Valid
                                        values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                        LESS_THAN_OR_EQUAL, and EQUAL.

                                      - **Value** *(float) --*

                                        The value to compare.

                              - **MessageActivity** *(string) --*

                                The message identifier (message_id) for the message to use when
                                determining whether message events meet the condition.

                            - **SegmentCondition** *(dict) --*

                              The segment that's associated with the activity.

                              - **SegmentId** *(string) --*

                                The unique identifier for the segment to associate with the
                                activity.

                            - **SegmentDimensions** *(dict) --*

                              The dimension settings for the segment that's associated with the
                              activity.

                              - **Attributes** *(dict) --*

                                One or more custom attributes to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                              - **Behavior** *(dict) --*

                                The behavior-based criteria, such as how recently users have used
                                your app, for the segment.

                                - **Recency** *(dict) --*

                                  The dimension settings that are based on how recently an endpoint
                                  was active.

                                  - **Duration** *(string) --*

                                    The duration to use when determining whether an endpoint is
                                    active or inactive.

                                  - **RecencyType** *(string) --*

                                    The type of recency dimension to use for the segment. Valid
                                    values are: ACTIVE, endpoints that were active within the
                                    specified duration are included in the segment; and, INACTIVE,
                                    endpoints that weren't active within the specified duration are
                                    included in the segment.

                              - **Demographic** *(dict) --*

                                The demographic-based criteria, such as device platform, for the
                                segment.

                                - **AppVersion** *(dict) --*

                                  The app version criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Channel** *(dict) --*

                                  The channel criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **DeviceType** *(dict) --*

                                  The device type criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Make** *(dict) --*

                                  The device make criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Model** *(dict) --*

                                  The device model criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Platform** *(dict) --*

                                  The device platform criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                              - **Location** *(dict) --*

                                The location-based criteria, such as region or GPS coordinates, for
                                the segment.

                                - **Country** *(dict) --*

                                  The country or region code, in ISO 3166-1 alpha-2 format, for the
                                  segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **GPSPoint** *(dict) --*

                                  The GPS location and range for the segment.

                                  - **Coordinates** *(dict) --*

                                    The GPS coordinates to measure distance from.

                                    - **Latitude** *(float) --*

                                      The latitude coordinate of the location.

                                    - **Longitude** *(float) --*

                                      The longitude coordinate of the location.

                                  - **RangeInKilometers** *(float) --*

                                    The range, in kilometers, from the GPS coordinates.

                              - **Metrics** *(dict) --*

                                One or more custom metrics to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies metric-based criteria for including or excluding
                                    endpoints from a segment. These criteria derive from custom
                                    metrics that you define for endpoints.

                                    - **ComparisonOperator** *(string) --*

                                      The operator to use when comparing metric values. Valid values
                                      are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                      LESS_THAN_OR_EQUAL, and EQUAL.

                                    - **Value** *(float) --*

                                      The value to compare.

                              - **UserAttributes** *(dict) --*

                                One or more custom user attributes to use as criteria for the
                                segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after completing
                            the activity for the path.

                      - **DefaultActivity** *(string) --*

                        The activity to perform by default for any path in the activity.

                      - **EvaluationWaitTime** *(dict) --*

                        The amount of time to wait or the date and time when Amazon Pinpoint
                        determines whether the conditions are met.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

                    - **RandomSplit** *(dict) --*

                      The settings for a random split activity. This type of activity randomly sends
                      specified percentages of participants down one of as many as five paths in a
                      journey, based on conditions that you specify.

                      - **Branches** *(list) --*

                        The paths for the activity, including the percentage of participants to
                        enter each path and the activity to perform for each path.

                        - *(dict) --*

                          Specifies the settings for a path in a random split activity in a journey.

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after completing
                            the activity for the path.

                          - **Percentage** *(integer) --*

                            The percentage of participants to send down the activity path.

                    - **Wait** *(dict) --*

                      The settings for a wait activity. This type of activity waits for a certain
                      amount of time or until a specific date and time before moving participants to
                      the next activity in a journey.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after performing the
                        wait activity.

                      - **WaitTime** *(dict) --*

                        The amount of time to wait or the date and time when the activity moves
                        participants to the next activity in the journey.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the journey applies to.

              - **CreationDate** *(string) --*

                The date, in ISO 8601 format, when the journey was created.

              - **Id** *(string) --*

                The unique identifier for the journey.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the journey was last modified.

              - **Limits** *(dict) --*

                The messaging and entry limits for the journey.

                - **DailyCap** *(integer) --*

                  The maximum number of messages that the journey can send to a single participant
                  during a 24-hour period. The maximum value is 100.

                - **EndpointReentryCap** *(integer) --*

                  The maximum number of times that a participant can enter the journey. The maximum
                  value is 100. To allow participants to enter the journey an unlimited number of
                  times, set this value to 0.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that the journey can send each second.

              - **LocalTime** *(boolean) --*

                Specifies whether the journey's scheduled start and end times use each participant's
                local time. If this value is true, the schedule uses each participant's local time.

              - **Name** *(string) --*

                The name of the journey.

              - **QuietTime** *(dict) --*

                The quiet time settings for the journey. Quiet time is a specific time range when a
                journey doesn't send messages to participants, if all the following conditions are
                met:

                * The EndpointDemographic.Timezone property of the endpoint for the participant is
                set to a valid value.

                * The current time in the participant's time zone is later than or equal to the time
                specified by the QuietTime.Start property for the journey.

                * The current time in the participant's time zone is earlier than or equal to the
                time specified by the QuietTime.End property for the journey.

                If any of the preceding conditions isn't met, the participant will receive messages
                from the journey, even if quiet time is enabled.

                - **End** *(string) --*

                  The specific time when quiet time ends. This value has to use 24-hour notation and
                  be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and
                  MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

                - **Start** *(string) --*

                  The specific time when quiet time begins. This value has to use 24-hour notation
                  and be in HH:MM format, where HH is the hour (with a leading zero, if applicable)
                  and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

              - **RefreshFrequency** *(string) --*

                The frequency with which Amazon Pinpoint evaluates segment and event data for the
                journey, as a duration in ISO 8601 format.

              - **Schedule** *(dict) --*

                The schedule settings for the journey.

                - **EndTime** *(datetime) --*

                  The scheduled time, in ISO 8601 format, when the journey ended or will end.

                - **StartTime** *(datetime) --*

                  The scheduled time, in ISO 8601 format, when the journey began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the journey schedule, if the value of the journey's
                  LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                  UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                  UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12,
                  UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04,
                  UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.

              - **StartActivity** *(string) --*

                The unique identifier for the first activity in the journey.

              - **StartCondition** *(dict) --*

                The segment that defines which users are participants in the journey.

                - **Description** *(string) --*

                  The custom description of the condition.

                - **SegmentStartCondition** *(dict) --*

                  The segment that's associated with the first activity in the journey. This segment
                  determines which users are participants in the journey.

                  - **SegmentId** *(string) --*

                    The unique identifier for the segment to associate with the activity.

              - **State** *(string) --*

                The current status of the journey. Possible values are:

                * DRAFT - The journey is being developed and hasn't been published yet.

                * ACTIVE - The journey has been developed and published. Depending on the journey's
                schedule, the journey may currently be running or scheduled to start running at a
                later time. If a journey's status is ACTIVE, you can't add, change, or remove
                activities from it.

                * COMPLETED - The journey has been published and has finished running. All
                participants have entered the journey and no participants are waiting to complete
                the journey or any activities in the journey.

                * CANCELLED - The journey has been stopped. If a journey's status is CANCELLED, you
                can't add, change, or remove activities or segment settings from the journey.

                * CLOSED - The journey has been published and has started running. It may have also
                passed its scheduled end time, or passed its scheduled start time and a refresh
                frequency hasn't been specified for it. If a journey's status is CLOSED, you can't
                add participants to it, and no existing participants can enter the journey for the
                first time. However, any existing participants who are currently waiting to start an
                activity may resume the journey.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the journey. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_push_template(self, TemplateName: str) -> ClientDeletePushTemplateResponseTypeDef:
        """
        Deletes a message template that was designed for use in messages that were sent through a
        push notification channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeletePushTemplate>`_

        **Request Syntax**
        ::

          response = client.delete_push_template(
              TemplateName='string'
          )
        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MessageBody': {
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **MessageBody** *(dict) --*

              Provides information about an API request or response.

              - **Message** *(string) --*

                The message that's returned from the API.

              - **RequestID** *(string) --*

                The unique identifier for the request or response.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_segment(
        self, ApplicationId: str, SegmentId: str
    ) -> ClientDeleteSegmentResponseTypeDef:
        """
        Deletes a segment from an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteSegment>`_

        **Request Syntax**
        ::

          response = client.delete_segment(
              ApplicationId='string',
              SegmentId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type SegmentId: string
        :param SegmentId: **[REQUIRED]**

          The unique identifier for the segment.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SegmentResponse': {
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Behavior': {
                            'Recency': {
                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                'RecencyType': 'ACTIVE'|'INACTIVE'
                            }
                        },
                        'Demographic': {
                            'AppVersion': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Channel': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'DeviceType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Make': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Model': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Platform': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Location': {
                            'Country': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'GPSPoint': {
                                'Coordinates': {
                                    'Latitude': 123.0,
                                    'Longitude': 123.0
                                },
                                'RangeInKilometers': 123.0
                            }
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        },
                        'UserAttributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        }
                    },
                    'Id': 'string',
                    'ImportDefinition': {
                        'ChannelCounts': {
                            'string': 123
                        },
                        'ExternalId': 'string',
                        'Format': 'CSV'|'JSON',
                        'RoleArn': 'string',
                        'S3Url': 'string',
                        'Size': 123
                    },
                    'LastModifiedDate': 'string',
                    'Name': 'string',
                    'SegmentGroups': {
                        'Groups': [
                            {
                                'Dimensions': [
                                    {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    },
                                ],
                                'SourceSegments': [
                                    {
                                        'Id': 'string',
                                        'Version': 123
                                    },
                                ],
                                'SourceType': 'ALL'|'ANY'|'NONE',
                                'Type': 'ALL'|'ANY'|'NONE'
                            },
                        ],
                        'Include': 'ALL'|'ANY'|'NONE'
                    },
                    'SegmentType': 'DIMENSIONAL'|'IMPORT',
                    'tags': {
                        'string': 'string'
                    },
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **SegmentResponse** *(dict) --*

              Provides information about the configuration, dimension, and other settings for a
              segment.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the segment is associated with.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the segment.

              - **CreationDate** *(string) --*

                The date and time when the segment was created.

              - **Dimensions** *(dict) --*

                The dimension settings for the segment.

                - **Attributes** *(dict) --*

                  One or more custom attributes to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

                - **Behavior** *(dict) --*

                  The behavior-based criteria, such as how recently users have used your app, for
                  the segment.

                  - **Recency** *(dict) --*

                    The dimension settings that are based on how recently an endpoint was active.

                    - **Duration** *(string) --*

                      The duration to use when determining whether an endpoint is active or
                      inactive.

                    - **RecencyType** *(string) --*

                      The type of recency dimension to use for the segment. Valid values are:
                      ACTIVE, endpoints that were active within the specified duration are included
                      in the segment; and, INACTIVE, endpoints that weren't active within the
                      specified duration are included in the segment.

                - **Demographic** *(dict) --*

                  The demographic-based criteria, such as device platform, for the segment.

                  - **AppVersion** *(dict) --*

                    The app version criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Channel** *(dict) --*

                    The channel criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **DeviceType** *(dict) --*

                    The device type criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Make** *(dict) --*

                    The device make criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Model** *(dict) --*

                    The device model criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Platform** *(dict) --*

                    The device platform criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                - **Location** *(dict) --*

                  The location-based criteria, such as region or GPS coordinates, for the segment.

                  - **Country** *(dict) --*

                    The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **GPSPoint** *(dict) --*

                    The GPS location and range for the segment.

                    - **Coordinates** *(dict) --*

                      The GPS coordinates to measure distance from.

                      - **Latitude** *(float) --*

                        The latitude coordinate of the location.

                      - **Longitude** *(float) --*

                        The longitude coordinate of the location.

                    - **RangeInKilometers** *(float) --*

                      The range, in kilometers, from the GPS coordinates.

                - **Metrics** *(dict) --*

                  One or more custom metrics to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies metric-based criteria for including or excluding endpoints from a
                      segment. These criteria derive from custom metrics that you define for
                      endpoints.

                      - **ComparisonOperator** *(string) --*

                        The operator to use when comparing metric values. Valid values are:
                        GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                        EQUAL.

                      - **Value** *(float) --*

                        The value to compare.

                - **UserAttributes** *(dict) --*

                  One or more custom user attributes to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

              - **Id** *(string) --*

                The unique identifier for the segment.

              - **ImportDefinition** *(dict) --*

                The settings for the import job that's associated with the segment.

                - **ChannelCounts** *(dict) --*

                  The number of channel types in the endpoint definitions that were imported to
                  create the segment.

                  - *(string) --*

                    - *(integer) --*

                - **ExternalId** *(string) --*

                  (Deprecated) Your AWS account ID, which you assigned to an external ID key in an
                  IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role
                  when importing endpoint definitions, but we removed this requirement. We don't
                  recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

                - **Format** *(string) --*

                  The format of the files that were imported to create the segment. Valid values
                  are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON
                  format.

                - **RoleArn** *(string) --*

                  The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                  role that authorized Amazon Pinpoint to access the Amazon S3 location to import
                  endpoint definitions from.

                - **S3Url** *(string) --*

                  The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint
                  definitions were imported from to create the segment.

                - **Size** *(integer) --*

                  The number of endpoint definitions that were imported successfully to create the
                  segment.

              - **LastModifiedDate** *(string) --*

                The date and time when the segment was last modified.

              - **Name** *(string) --*

                The name of the segment.

              - **SegmentGroups** *(dict) --*

                A list of one or more segment groups that apply to the segment. Each segment group
                consists of zero or more base segments and the dimensions that are applied to those
                base segments.

                - **Groups** *(list) --*

                  An array that defines the set of segment criteria to evaluate when handling
                  segment groups for the segment.

                  - *(dict) --*

                    Specifies the base segments and dimensions for a segment, and the relationships
                    between these base segments and dimensions.

                    - **Dimensions** *(list) --*

                      An array that defines the dimensions for the segment.

                      - *(dict) --*

                        Specifies the dimension settings for a segment.

                        - **Attributes** *(dict) --*

                          One or more custom attributes to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **Behavior** *(dict) --*

                          The behavior-based criteria, such as how recently users have used your
                          app, for the segment.

                          - **Recency** *(dict) --*

                            The dimension settings that are based on how recently an endpoint was
                            active.

                            - **Duration** *(string) --*

                              The duration to use when determining whether an endpoint is active or
                              inactive.

                            - **RecencyType** *(string) --*

                              The type of recency dimension to use for the segment. Valid values
                              are: ACTIVE, endpoints that were active within the specified duration
                              are included in the segment; and, INACTIVE, endpoints that weren't
                              active within the specified duration are included in the segment.

                        - **Demographic** *(dict) --*

                          The demographic-based criteria, such as device platform, for the segment.

                          - **AppVersion** *(dict) --*

                            The app version criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Channel** *(dict) --*

                            The channel criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **DeviceType** *(dict) --*

                            The device type criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Make** *(dict) --*

                            The device make criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Model** *(dict) --*

                            The device model criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Platform** *(dict) --*

                            The device platform criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                        - **Location** *(dict) --*

                          The location-based criteria, such as region or GPS coordinates, for the
                          segment.

                          - **Country** *(dict) --*

                            The country or region code, in ISO 3166-1 alpha-2 format, for the
                            segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **GPSPoint** *(dict) --*

                            The GPS location and range for the segment.

                            - **Coordinates** *(dict) --*

                              The GPS coordinates to measure distance from.

                              - **Latitude** *(float) --*

                                The latitude coordinate of the location.

                              - **Longitude** *(float) --*

                                The longitude coordinate of the location.

                            - **RangeInKilometers** *(float) --*

                              The range, in kilometers, from the GPS coordinates.

                        - **Metrics** *(dict) --*

                          One or more custom metrics to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                        - **UserAttributes** *(dict) --*

                          One or more custom user attributes to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                    - **SourceSegments** *(list) --*

                      The base segment to build the segment on. A base segment, also referred to as
                      a *source segment* , defines the initial population of endpoints for a
                      segment. When you add dimensions to a segment, Amazon Pinpoint filters the
                      base segment by using the dimensions that you specify.

                      You can specify more than one dimensional segment or only one imported
                      segment. If you specify an imported segment, the Amazon Pinpoint console
                      displays a segment size estimate that indicates the size of the imported
                      segment without any filters applied to it.

                      - *(dict) --*

                        Specifies the segment identifier and version of a segment.

                        - **Id** *(string) --*

                          The unique identifier for the segment.

                        - **Version** *(integer) --*

                          The version number of the segment.

                    - **SourceType** *(string) --*

                      Specifies how to handle multiple base segments for the segment. For example,
                      if you specify three base segments for the segment, whether the resulting
                      segment is based on all, any, or none of the base segments.

                    - **Type** *(string) --*

                      Specifies how to handle multiple dimensions for the segment. For example, if
                      you specify three dimensions for the segment, whether the resulting segment
                      includes endpoints that match all, any, or none of the dimensions.

                - **Include** *(string) --*

                  Specifies how to handle multiple segment groups for the segment. For example, if
                  the segment includes three segment groups, whether the resulting segment includes
                  endpoints that match all, any, or none of the segment groups.

              - **SegmentType** *(string) --*

                The segment type. Valid values are:

                * DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria
                that you specify and is based on endpoint data that's reported by your app. Dynamic
                segments can change over time.

                * IMPORT - A static segment, which is a segment that uses selection criteria that
                you specify and is based on endpoint definitions that you import from a file.
                Imported segments are static; they don't change over time.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the segment. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **Version** *(integer) --*

                The version number of the segment.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_sms_channel(self, ApplicationId: str) -> ClientDeleteSmsChannelResponseTypeDef:
        """
        Disables the SMS channel for an application and deletes any existing settings for the
        channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteSmsChannel>`_

        **Request Syntax**
        ::

          response = client.delete_sms_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SMSChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'PromotionalMessagesPerSecond': 123,
                    'SenderId': 'string',
                    'ShortCode': 'string',
                    'TransactionalMessagesPerSecond': 123,
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **SMSChannelResponse** *(dict) --*

              Provides information about the status and settings of the SMS channel for an
              application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the SMS channel applies to.

              - **CreationDate** *(string) --*

                The date and time, in ISO 8601 format, when the SMS channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the SMS channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the SMS channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the SMS channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the SMS channel.

              - **LastModifiedDate** *(string) --*

                The date and time, in ISO 8601 format, when the SMS channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the SMS channel,
                this value is SMS.

              - **PromotionalMessagesPerSecond** *(integer) --*

                The maximum number of promotional messages that you can send through the SMS channel
                each second.

              - **SenderId** *(string) --*

                The identity that displays on recipients' devices when they receive messages from
                the SMS channel.

              - **ShortCode** *(string) --*

                The registered short code to use when you send messages through the SMS channel.

              - **TransactionalMessagesPerSecond** *(integer) --*

                The maximum number of transactional messages that you can send through the SMS
                channel each second.

              - **Version** *(integer) --*

                The current version of the SMS channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_sms_template(self, TemplateName: str) -> ClientDeleteSmsTemplateResponseTypeDef:
        """
        Deletes a message template that was designed for use in messages that were sent through the
        SMS channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteSmsTemplate>`_

        **Request Syntax**
        ::

          response = client.delete_sms_template(
              TemplateName='string'
          )
        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MessageBody': {
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **MessageBody** *(dict) --*

              Provides information about an API request or response.

              - **Message** *(string) --*

                The message that's returned from the API.

              - **RequestID** *(string) --*

                The unique identifier for the request or response.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_user_endpoints(
        self, ApplicationId: str, UserId: str
    ) -> ClientDeleteUserEndpointsResponseTypeDef:
        """
        Deletes all the endpoints that are associated with a specific user ID.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteUserEndpoints>`_

        **Request Syntax**
        ::

          response = client.delete_user_endpoints(
              ApplicationId='string',
              UserId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type UserId: string
        :param UserId: **[REQUIRED]**

          The unique identifier for the user.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EndpointsResponse': {
                    'Item': [
                        {
                            'Address': 'string',
                            'ApplicationId': 'string',
                            'Attributes': {
                                'string': [
                                    'string',
                                ]
                            },
                            'ChannelType':
                            'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'
                            |'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'
                            |'BAIDU'|'CUSTOM',
                            'CohortId': 'string',
                            'CreationDate': 'string',
                            'Demographic': {
                                'AppVersion': 'string',
                                'Locale': 'string',
                                'Make': 'string',
                                'Model': 'string',
                                'ModelVersion': 'string',
                                'Platform': 'string',
                                'PlatformVersion': 'string',
                                'Timezone': 'string'
                            },
                            'EffectiveDate': 'string',
                            'EndpointStatus': 'string',
                            'Id': 'string',
                            'Location': {
                                'City': 'string',
                                'Country': 'string',
                                'Latitude': 123.0,
                                'Longitude': 123.0,
                                'PostalCode': 'string',
                                'Region': 'string'
                            },
                            'Metrics': {
                                'string': 123.0
                            },
                            'OptOut': 'string',
                            'RequestId': 'string',
                            'User': {
                                'UserAttributes': {
                                    'string': [
                                        'string',
                                    ]
                                },
                                'UserId': 'string'
                            }
                        },
                    ]
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **EndpointsResponse** *(dict) --*

              Provides information about all the endpoints that are associated with a user ID.

              - **Item** *(list) --*

                An array of responses, one for each endpoint that's associated with the user ID.

                - *(dict) --*

                  Provides information about the channel type and other settings for an endpoint.

                  - **Address** *(string) --*

                    The destination address for messages or push notifications that you send to the
                    endpoint. The address varies by channel. For example, the address for a
                    push-notification channel is typically the token provided by a push notification
                    service, such as an Apple Push Notification service (APNs) device token or a
                    Firebase Cloud Messaging (FCM) registration token. The address for the SMS
                    channel is a phone number in E.164 format, such as +12065550100. The address for
                    the email channel is an email address.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that's associated with the endpoint.

                  - **Attributes** *(dict) --*

                    One or more custom attributes that describe the endpoint by associating a name
                    with an array of values. For example, the value of a custom attribute named
                    Interests might be: ["science", "music", "travel"]. You can use these attributes
                    as filter criteria when you create segments.

                    - *(string) --*

                      - *(list) --*

                        - *(string) --*

                  - **ChannelType** *(string) --*

                    The channel that's used when sending messages or push notifications to the
                    endpoint.

                  - **CohortId** *(string) --*

                    A number from 0-99 that represents the cohort that the endpoint is assigned to.
                    Endpoints are grouped into cohorts randomly, and each cohort contains
                    approximately 1 percent of the endpoints for an application. Amazon Pinpoint
                    assigns cohorts to the holdout or treatment allocations for campaigns.

                  - **CreationDate** *(string) --*

                    The date and time, in ISO 8601 format, when the endpoint was created.

                  - **Demographic** *(dict) --*

                    The demographic information for the endpoint, such as the time zone and
                    platform.

                    - **AppVersion** *(string) --*

                      The version of the app that's associated with the endpoint.

                    - **Locale** *(string) --*

                      The locale of the endpoint, in the following format: the ISO 639-1 alpha-2
                      code, followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.

                    - **Make** *(string) --*

                      The manufacturer of the endpoint device, such as Apple or Samsung.

                    - **Model** *(string) --*

                      The model name or number of the endpoint device, such as iPhone.

                    - **ModelVersion** *(string) --*

                      The model version of the endpoint device.

                    - **Platform** *(string) --*

                      The platform of the endpoint device, such as iOS or Android.

                    - **PlatformVersion** *(string) --*

                      The platform version of the endpoint device.

                    - **Timezone** *(string) --*

                      The time zone of the endpoint, specified as a tz database name value, such as
                      America/Los_Angeles.

                  - **EffectiveDate** *(string) --*

                    The date and time, in ISO 8601 format, when the endpoint was last updated.

                  - **EndpointStatus** *(string) --*

                    Specifies whether messages or push notifications are sent to the endpoint.
                    Possible values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE,
                    messages aren’t sent to the endpoint.

                    Amazon Pinpoint automatically sets this value to ACTIVE when you create an
                    endpoint or update an existing endpoint. Amazon Pinpoint automatically sets this
                    value to INACTIVE if you update another endpoint that has the same address
                    specified by the Address property.

                  - **Id** *(string) --*

                    The unique identifier that you assigned to the endpoint. The identifier should
                    be a globally unique identifier (GUID) to ensure that it doesn't conflict with
                    other endpoint identifiers that are associated with the application.

                  - **Location** *(dict) --*

                    The geographic information for the endpoint.

                    - **City** *(string) --*

                      The name of the city where the endpoint is located.

                    - **Country** *(string) --*

                      The two-character code, in ISO 3166-1 alpha-2 format, for the country or
                      region where the endpoint is located. For example, US for the United States.

                    - **Latitude** *(float) --*

                      The latitude coordinate of the endpoint location, rounded to one decimal
                      place.

                    - **Longitude** *(float) --*

                      The longitude coordinate of the endpoint location, rounded to one decimal
                      place.

                    - **PostalCode** *(string) --*

                      The postal or ZIP code for the area where the endpoint is located.

                    - **Region** *(string) --*

                      The name of the region where the endpoint is located. For locations in the
                      United States, this value is the name of a state.

                  - **Metrics** *(dict) --*

                    One or more custom metrics that your app reports to Amazon Pinpoint for the
                    endpoint.

                    - *(string) --*

                      - *(float) --*

                  - **OptOut** *(string) --*

                    Specifies whether the user who's associated with the endpoint has opted out of
                    receiving messages and push notifications from you. Possible values are: ALL,
                    the user has opted out and doesn't want to receive any messages or push
                    notifications; and, NONE, the user hasn't opted out and wants to receive all
                    messages and push notifications.

                  - **RequestId** *(string) --*

                    The unique identifier for the most recent request to update the endpoint.

                  - **User** *(dict) --*

                    One or more custom user attributes that your app reports to Amazon Pinpoint for
                    the user who's associated with the endpoint.

                    - **UserAttributes** *(dict) --*

                      One or more custom attributes that describe the user by associating a name
                      with an array of values. For example, the value of an attribute named
                      Interests might be: ["science", "music", "travel"]. You can use these
                      attributes as filter criteria when you create segments.

                      When you define the name of a custom attribute, avoid using the following
                      characters: number sign (#), colon (:), question mark (?), backslash (\\), and
                      slash (/). The Amazon Pinpoint console can't display attribute names that
                      contain these characters. This limitation doesn't apply to attribute values.

                      - *(string) --*

                        - *(list) --*

                          - *(string) --*

                    - **UserId** *(string) --*

                      The unique identifier for the user.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_voice_channel(self, ApplicationId: str) -> ClientDeleteVoiceChannelResponseTypeDef:
        """
        Disables the voice channel for an application and deletes any existing settings for the
        channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteVoiceChannel>`_

        **Request Syntax**
        ::

          response = client.delete_voice_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'VoiceChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **VoiceChannelResponse** *(dict) --*

              Provides information about the status and settings of the voice channel for an
              application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the voice channel applies to.

              - **CreationDate** *(string) --*

                The date and time, in ISO 8601 format, when the voice channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the voice channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the voice channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the voice channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the voice channel.

              - **LastModifiedDate** *(string) --*

                The date and time, in ISO 8601 format, when the voice channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the voice
                channel, this value is VOICE.

              - **Version** *(integer) --*

                The current version of the voice channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_voice_template(self, TemplateName: str) -> ClientDeleteVoiceTemplateResponseTypeDef:
        """
        Deletes a message template that was designed for use in messages that were sent through the
        voice channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/DeleteVoiceTemplate>`_

        **Request Syntax**
        ::

          response = client.delete_voice_template(
              TemplateName='string'
          )
        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MessageBody': {
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **MessageBody** *(dict) --*

              Provides information about an API request or response.

              - **Message** *(string) --*

                The message that's returned from the API.

              - **RequestID** *(string) --*

                The unique identifier for the request or response.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def generate_presigned_url(
        self, ClientMethod: str, Params: Dict = None, ExpiresIn: int = 3600, HttpMethod: str = None
    ) -> None:
        """
        Generate a presigned url given a client, its method, and arguments

        :type ClientMethod: string
        :param ClientMethod: The client method to presign for

        :type Params: dict
        :param Params: The parameters normally passed to
            ``ClientMethod``.

        :type ExpiresIn: int
        :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

        :type HttpMethod: string
        :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

        :returns: The presigned url
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_adm_channel(self, ApplicationId: str) -> ClientGetAdmChannelResponseTypeDef:
        """
        Retrieves information about the status and settings of the ADM channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetAdmChannel>`_

        **Request Syntax**
        ::

          response = client.get_adm_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ADMChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ADMChannelResponse** *(dict) --*

              Provides information about the status and settings of the ADM (Amazon Device
              Messaging) channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the ADM channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the ADM channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the ADM channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the ADM channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the ADM channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the ADM channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the ADM channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the ADM channel,
                this value is ADM.

              - **Version** *(integer) --*

                The current version of the ADM channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_apns_channel(self, ApplicationId: str) -> ClientGetApnsChannelResponseTypeDef:
        """
        Retrieves information about the status and settings of the APNs channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetApnsChannel>`_

        **Request Syntax**
        ::

          response = client.get_apns_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the APNs channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with
                APNs for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs channel is configured to communicate with APNs by using
                APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey
                property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs
                channel, this value is APNS.

              - **Version** *(integer) --*

                The current version of the APNs channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_apns_sandbox_channel(
        self, ApplicationId: str
    ) -> ClientGetApnsSandboxChannelResponseTypeDef:
        """
        Retrieves information about the status and settings of the APNs sandbox channel for an
        application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetApnsSandboxChannel>`_

        **Request Syntax**
        ::

          response = client.get_apns_sandbox_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSSandboxChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSSandboxChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) sandbox channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs sandbox channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the APNs sandbox channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with the
                APNs sandbox environment for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs sandbox channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs sandbox channel is configured to communicate with APNs by
                using APNs tokens. To provide an authentication key for APNs tokens, set the
                TokenKey property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs sandbox channel. This property is retained
                only for backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs sandbox channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs sandbox channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs sandbox channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs sandbox
                channel, this value is APNS_SANDBOX.

              - **Version** *(integer) --*

                The current version of the APNs sandbox channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_apns_voip_channel(self, ApplicationId: str) -> ClientGetApnsVoipChannelResponseTypeDef:
        """
        Retrieves information about the status and settings of the APNs VoIP channel for an
        application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetApnsVoipChannel>`_

        **Request Syntax**
        ::

          response = client.get_apns_voip_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSVoipChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSVoipChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) VoIP channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs VoIP channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the APNs VoIP channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with
                APNs for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs VoIP channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs VoIP channel is configured to communicate with APNs by
                using APNs tokens. To provide an authentication key for APNs tokens, set the
                TokenKey property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs VoIP channel. This property is retained only
                for backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs VoIP channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs VoIP channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs VoIP channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs VoIP
                channel, this value is APNS_VOIP.

              - **Version** *(integer) --*

                The current version of the APNs VoIP channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_apns_voip_sandbox_channel(
        self, ApplicationId: str
    ) -> ClientGetApnsVoipSandboxChannelResponseTypeDef:
        """
        Retrieves information about the status and settings of the APNs VoIP sandbox channel for an
        application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetApnsVoipSandboxChannel>`_

        **Request Syntax**
        ::

          response = client.get_apns_voip_sandbox_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSVoipSandboxChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSVoipSandboxChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) VoIP sandbox channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs VoIP sandbox channel applies
                to.

              - **CreationDate** *(string) --*

                The date and time when the APNs VoIP sandbox channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with the
                APNs sandbox environment for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs VoIP sandbox channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs VoIP sandbox channel is configured to communicate with
                APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the
                TokenKey property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs VoIP sandbox channel. This property is
                retained only for backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs VoIP sandbox channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs VoIP sandbox channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs VoIP sandbox channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs VoIP
                sandbox channel, this value is APNS_VOIP_SANDBOX.

              - **Version** *(integer) --*

                The current version of the APNs VoIP sandbox channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_app(self, ApplicationId: str) -> ClientGetAppResponseTypeDef:
        """
        Retrieves information about an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetApp>`_

        **Request Syntax**
        ::

          response = client.get_app(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ApplicationResponse': {
                    'Arn': 'string',
                    'Id': 'string',
                    'Name': 'string',
                    'tags': {
                        'string': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ApplicationResponse** *(dict) --*

              Provides information about an application.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the application.

              - **Id** *(string) --*

                The unique identifier for the application. This identifier is displayed as the
                **Project ID** on the Amazon Pinpoint console.

              - **Name** *(string) --*

                The display name of the application. This name is displayed as the **Project name**
                on the Amazon Pinpoint console.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the application. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_application_date_range_kpi(
        self,
        ApplicationId: str,
        KpiName: str,
        EndTime: datetime = None,
        NextToken: str = None,
        PageSize: str = None,
        StartTime: datetime = None,
    ) -> ClientGetApplicationDateRangeKpiResponseTypeDef:
        """
        Retrieves (queries) pre-aggregated data for a standard metric that applies to an
        application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetApplicationDateRangeKpi>`_

        **Request Syntax**
        ::

          response = client.get_application_date_range_kpi(
              ApplicationId='string',
              EndTime=datetime(2015, 1, 1),
              KpiName='string',
              NextToken='string',
              PageSize='string',
              StartTime=datetime(2015, 1, 1)
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type EndTime: datetime
        :param EndTime:

          The last date and time to retrieve data for, as part of an inclusive date range that
          filters the query results. This value should be in extended ISO 8601 format, for example:
          2019-07-19T00:00:00Z for July 19, 2019 and 2019-07-19T20:00:00Z for 8:00 PM July 19, 2019.

        :type KpiName: string
        :param KpiName: **[REQUIRED]**

          The name of the metric, also referred to as a *key performance indicator (KPI)* , to
          retrieve data for. This value describes the associated metric and consists of two or more
          terms, which are comprised of lowercase alphanumeric characters, separated by a hyphen.
          Examples are email-open-rate and successful-delivery-rate. For a list of valid values, see
          the `Amazon Pinpoint Developer Guide
          <https://docs.aws.amazon.com/pinpoint/latest/developerguide/welcome.html>`__ .

        :type NextToken: string
        :param NextToken:

          The string that specifies which page of results to return in a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type StartTime: datetime
        :param StartTime:

          The first date and time to retrieve data for, as part of an inclusive date range that
          filters the query results. This value should be in extended ISO 8601 format, for example:
          2019-07-15T00:00:00Z for July 15, 2019 and 2019-07-15T16:00:00Z for 4:00 PM July 15, 2019.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ApplicationDateRangeKpiResponse': {
                    'ApplicationId': 'string',
                    'EndTime': datetime(2015, 1, 1),
                    'KpiName': 'string',
                    'KpiResult': {
                        'Rows': [
                            {
                                'GroupedBys': [
                                    {
                                        'Key': 'string',
                                        'Type': 'string',
                                        'Value': 'string'
                                    },
                                ],
                                'Values': [
                                    {
                                        'Key': 'string',
                                        'Type': 'string',
                                        'Value': 'string'
                                    },
                                ]
                            },
                        ]
                    },
                    'NextToken': 'string',
                    'StartTime': datetime(2015, 1, 1)
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ApplicationDateRangeKpiResponse** *(dict) --*

              Provides the results of a query that retrieved the data for a standard metric that
              applies to an application, and provides information about that query.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the metric applies to.

              - **EndTime** *(datetime) --*

                The last date and time of the date range that was used to filter the query results,
                in extended ISO 8601 format. The date range is inclusive.

              - **KpiName** *(string) --*

                The name of the metric, also referred to as a *key performance indicator (KPI)* ,
                that the data was retrieved for. This value describes the associated metric and
                consists of two or more terms, which are comprised of lowercase alphanumeric
                characters, separated by a hyphen. For a list of possible values, see the `Amazon
                Pinpoint Developer Guide
                <https://docs.aws.amazon.com/pinpoint/latest/developerguide/welcome.html>`__ .

              - **KpiResult** *(dict) --*

                An array of objects that contains the results of the query. Each object contains the
                value for the metric and metadata about that value.

                - **Rows** *(list) --*

                  An array of objects that provides the results of a query that retrieved the data
                  for a standard metric that applies to an application, campaign, or journey.

                  - *(dict) --*

                    Provides the results of a query that retrieved the data for a standard metric
                    that applies to an application, campaign, or journey.

                    - **GroupedBys** *(list) --*

                      An array of objects that defines the field and field values that were used to
                      group data in a result set that contains multiple results. This value is null
                      if the data in a result set isn’t grouped.

                      - *(dict) --*

                        Provides a single value and metadata about that value as part of an array of
                        query results for a standard metric that applies to an application,
                        campaign, or journey.

                        - **Key** *(string) --*

                          The friendly name of the metric whose value is specified by the Value
                          property.

                        - **Type** *(string) --*

                          The data type of the value specified by the Value property.

                        - **Value** *(string) --*

                          In a Values object, the value for the metric that the query retrieved data
                          for. In a GroupedBys object, the value for the field that was used to
                          group data in a result set that contains multiple results (Values
                          objects).

                    - **Values** *(list) --*

                      An array of objects that provides pre-aggregated values for a standard metric
                      that applies to an application, campaign, or journey.

                      - *(dict) --*

                        Provides a single value and metadata about that value as part of an array of
                        query results for a standard metric that applies to an application,
                        campaign, or journey.

                        - **Key** *(string) --*

                          The friendly name of the metric whose value is specified by the Value
                          property.

                        - **Type** *(string) --*

                          The data type of the value specified by the Value property.

                        - **Value** *(string) --*

                          In a Values object, the value for the metric that the query retrieved data
                          for. In a GroupedBys object, the value for the field that was used to
                          group data in a result set that contains multiple results (Values
                          objects).

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null for the Application Metrics resource because
                the resource returns all results in a single page.

              - **StartTime** *(datetime) --*

                The first date and time of the date range that was used to filter the query results,
                in extended ISO 8601 format. The date range is inclusive.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_application_settings(
        self, ApplicationId: str
    ) -> ClientGetApplicationSettingsResponseTypeDef:
        """
        Retrieves information about the settings for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetApplicationSettings>`_

        **Request Syntax**
        ::

          response = client.get_application_settings(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ApplicationSettingsResource': {
                    'ApplicationId': 'string',
                    'CampaignHook': {
                        'LambdaFunctionName': 'string',
                        'Mode': 'DELIVERY'|'FILTER',
                        'WebUrl': 'string'
                    },
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'Daily': 123,
                        'MaximumDuration': 123,
                        'MessagesPerSecond': 123,
                        'Total': 123
                    },
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ApplicationSettingsResource** *(dict) --*

              Provides information about an application, including the default settings for an
              application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application. This identifier is displayed as the
                **Project ID** on the Amazon Pinpoint console.

              - **CampaignHook** *(dict) --*

                The settings for the AWS Lambda function to use by default as a code hook for
                campaigns in the application.

                - **LambdaFunctionName** *(string) --*

                  The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon
                  Pinpoint invokes to send messages for a campaign.

                - **Mode** *(string) --*

                  Specifies which Lambda mode to use when invoking the AWS Lambda function.

                - **WebUrl** *(string) --*

                  The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over
                  HTTPS.

              - **LastModifiedDate** *(string) --*

                The date and time, in ISO 8601 format, when the application's settings were last
                modified.

              - **Limits** *(dict) --*

                The default sending limits for campaigns in the application.

                - **Daily** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during a 24-hour period. The maximum value is 100.

                - **MaximumDuration** *(integer) --*

                  The maximum amount of time, in seconds, that a campaign can attempt to deliver a
                  message after the scheduled start time for the campaign. The minimum value is 60
                  seconds.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that a campaign can send each second. The minimum
                  value is 50. The maximum value is 20,000.

                - **Total** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during the course of the campaign. The maximum value is 100.

              - **QuietTime** *(dict) --*

                The default quiet time for campaigns and journeys in the application. Quiet time is
                a specific time range when messages aren't sent to endpoints, if all the following
                conditions are met:

                * The EndpointDemographic.Timezone property of the endpoint is set to a valid value.

                * The current time in the endpoint's time zone is later than or equal to the time
                specified by the QuietTime.Start property for the application (or a campaign or
                journey that has custom quiet time settings).

                * The current time in the endpoint's time zone is earlier than or equal to the time
                specified by the QuietTime.End property for the application (or a campaign or
                journey that has custom quiet time settings).

                If any of the preceding conditions isn't met, the endpoint will receive messages
                from a campaign or journey, even if quiet time is enabled.

                - **End** *(string) --*

                  The specific time when quiet time ends. This value has to use 24-hour notation and
                  be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and
                  MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

                - **Start** *(string) --*

                  The specific time when quiet time begins. This value has to use 24-hour notation
                  and be in HH:MM format, where HH is the hour (with a leading zero, if applicable)
                  and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_apps(self, PageSize: str = None, Token: str = None) -> ClientGetAppsResponseTypeDef:
        """
        Retrieves information about all of your applications.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetApps>`_

        **Request Syntax**
        ::

          response = client.get_apps(
              PageSize='string',
              Token='string'
          )
        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type Token: string
        :param Token:

          The NextToken string that specifies which page of results to return in a paginated
          response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ApplicationsResponse': {
                    'Item': [
                        {
                            'Arn': 'string',
                            'Id': 'string',
                            'Name': 'string',
                            'tags': {
                                'string': 'string'
                            }
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ApplicationsResponse** *(dict) --*

              Provides information about all of your applications.

              - **Item** *(list) --*

                An array of responses, one for each application that was returned.

                - *(dict) --*

                  Provides information about an application.

                  - **Arn** *(string) --*

                    The Amazon Resource Name (ARN) of the application.

                  - **Id** *(string) --*

                    The unique identifier for the application. This identifier is displayed as the
                    **Project ID** on the Amazon Pinpoint console.

                  - **Name** *(string) --*

                    The display name of the application. This name is displayed as the **Project
                    name** on the Amazon Pinpoint console.

                  - **tags** *(dict) --*

                    A string-to-string map of key-value pairs that identifies the tags that are
                    associated with the application. Each tag consists of a required tag key and an
                    associated tag value.

                    - *(string) --*

                      - *(string) --*

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_baidu_channel(self, ApplicationId: str) -> ClientGetBaiduChannelResponseTypeDef:
        """
        Retrieves information about the status and settings of the Baidu channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetBaiduChannel>`_

        **Request Syntax**
        ::

          response = client.get_baidu_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'BaiduChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Credential': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **BaiduChannelResponse** *(dict) --*

              Provides information about the status and settings of the Baidu (Baidu Cloud Push)
              channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the Baidu channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the Baidu channel was enabled.

              - **Credential** *(string) --*

                The API key that you received from the Baidu Cloud Push service to communicate with
                the service.

              - **Enabled** *(boolean) --*

                Specifies whether the Baidu channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the Baidu channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the Baidu channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the Baidu channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the Baidu channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the Baidu
                channel, this value is BAIDU.

              - **Version** *(integer) --*

                The current version of the Baidu channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_campaign(self, ApplicationId: str, CampaignId: str) -> ClientGetCampaignResponseTypeDef:
        """
        Retrieves information about the status, configuration, and other settings for a campaign.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetCampaign>`_

        **Request Syntax**
        ::

          response = client.get_campaign(
              ApplicationId='string',
              CampaignId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type CampaignId: string
        :param CampaignId: **[REQUIRED]**

          The unique identifier for the campaign.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CampaignResponse': {
                    'AdditionalTreatments': [
                        {
                            'Id': 'string',
                            'MessageConfiguration': {
                                'ADMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'APNSMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'BaiduMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'DefaultMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'EmailMessage': {
                                    'Body': 'string',
                                    'FromAddress': 'string',
                                    'HtmlBody': 'string',
                                    'Title': 'string'
                                },
                                'GCMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'SMSMessage': {
                                    'Body': 'string',
                                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                    'SenderId': 'string'
                                }
                            },
                            'Schedule': {
                                'EndTime': 'string',
                                'EventFilter': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'FilterType': 'SYSTEM'|'ENDPOINT'
                                },
                                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                                'IsLocalTime': True|False,
                                'QuietTime': {
                                    'End': 'string',
                                    'Start': 'string'
                                },
                                'StartTime': 'string',
                                'Timezone': 'string'
                            },
                            'SizePercent': 123,
                            'State': {
                                'CampaignStatus':
                                'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'
                                |'COMPLETED'|'PAUSED'|'DELETED'
                            },
                            'TemplateConfiguration': {
                                'EmailTemplate': {
                                    'Name': 'string'
                                },
                                'PushTemplate': {
                                    'Name': 'string'
                                },
                                'SMSTemplate': {
                                    'Name': 'string'
                                },
                                'VoiceTemplate': {
                                    'Name': 'string'
                                }
                            },
                            'TreatmentDescription': 'string',
                            'TreatmentName': 'string'
                        },
                    ],
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'DefaultState': {
                        'CampaignStatus':
                        'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'
                        |'PAUSED'|'DELETED'
                    },
                    'Description': 'string',
                    'HoldoutPercent': 123,
                    'Hook': {
                        'LambdaFunctionName': 'string',
                        'Mode': 'DELIVERY'|'FILTER',
                        'WebUrl': 'string'
                    },
                    'Id': 'string',
                    'IsPaused': True|False,
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'Daily': 123,
                        'MaximumDuration': 123,
                        'MessagesPerSecond': 123,
                        'Total': 123
                    },
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Name': 'string',
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SegmentId': 'string',
                    'SegmentVersion': 123,
                    'State': {
                        'CampaignStatus':
                        'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'
                        |'PAUSED'|'DELETED'
                    },
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **CampaignResponse** *(dict) --*

              Provides information about the status, configuration, and other settings for a
              campaign.

              - **AdditionalTreatments** *(list) --*

                An array of responses, one for each treatment that you defined for the campaign, in
                addition to the default treatment.

                - *(dict) --*

                  Specifies the settings for a campaign treatment. A treatment is a variation of a
                  campaign that's used for A/B testing of a campaign.

                  - **Id** *(string) --*

                    The unique identifier for the treatment.

                  - **MessageConfiguration** *(dict) --*

                    The message configuration settings for the treatment.

                    - **ADMMessage** *(dict) --*

                      The message that the campaign sends through the ADM (Amazon Device Messaging)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **APNSMessage** *(dict) --*

                      The message that the campaign sends through the APNs (Apple Push Notification
                      service) channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **BaiduMessage** *(dict) --*

                      The message that the campaign sends through the Baidu (Baidu Cloud Push)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **DefaultMessage** *(dict) --*

                      The default message that the campaign sends through all the channels that are
                      configured for the campaign.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **EmailMessage** *(dict) --*

                      The message that the campaign sends through the email channel.

                      - **Body** *(string) --*

                        The body of the email for recipients whose email clients don't render HTML
                        content.

                      - **FromAddress** *(string) --*

                        The verified email address to send the email from. The default address is
                        the FromAddress specified for the email channel for the application.

                      - **HtmlBody** *(string) --*

                        The body of the email, in HTML format, for recipients whose email clients
                        render HTML content.

                      - **Title** *(string) --*

                        The subject line, or title, of the email.

                    - **GCMMessage** *(dict) --*

                      The message that the campaign sends through the GCM channel, which enables
                      Amazon Pinpoint to send push notifications through the Firebase Cloud
                      Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message
                      overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **SMSMessage** *(dict) --*

                      The message that the campaign sends through the SMS channel.

                      - **Body** *(string) --*

                        The body of the SMS message.

                      - **MessageType** *(string) --*

                        The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                        critical or time-sensitive, such as a one-time password that supports a
                        customer transaction; and, PROMOTIONAL, the message isn't critical or
                        time-sensitive, such as a marketing message.

                      - **SenderId** *(string) --*

                        The sender ID to display on recipients' devices when they receive the SMS
                        message.

                  - **Schedule** *(dict) --*

                    The schedule settings for the treatment.

                    - **EndTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                    - **EventFilter** *(dict) --*

                      The type of event that causes the campaign to be sent, if the value of the
                      Frequency property is EVENT.

                      - **Dimensions** *(dict) --*

                        The dimension settings of the event filter for the campaign.

                        - **Attributes** *(dict) --*

                          One or more custom attributes that your application reports to Amazon
                          Pinpoint. You can use these attributes as selection criteria when you
                          create an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **EventType** *(dict) --*

                          The name of the event that causes the campaign to be sent or the journey
                          activity to be performed. This can be a standard type of event that Amazon
                          Pinpoint generates, such as _email.delivered, or a custom event that's
                          specific to your application.

                          - **DimensionType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the DimensionType property, endpoints are included or excluded
                            from the segment if their values match the criteria values.

                            - *(string) --*

                        - **Metrics** *(dict) --*

                          One or more custom metrics that your application reports to Amazon
                          Pinpoint. You can use these metrics as selection criteria when you create
                          an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                      - **FilterType** *(string) --*

                        The type of event that causes the campaign to be sent. Valid values are:
                        SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends
                        the campaign when an endpoint event (Events resource) occurs.

                    - **Frequency** *(string) --*

                      Specifies how often the campaign is sent or whether the campaign is sent in
                      response to a specific event.

                    - **IsLocalTime** *(boolean) --*

                      Specifies whether the start and end times for the campaign schedule use each
                      recipient's local time. To base the schedule on each recipient's local time,
                      set this value to true.

                    - **QuietTime** *(dict) --*

                      The default quiet time for the campaign. Quiet time is a specific time range
                      when a campaign doesn't send messages to endpoints, if all the following
                      conditions are met:

                      * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                      value.

                      * The current time in the endpoint's time zone is later than or equal to the
                      time specified by the QuietTime.Start property for the campaign.

                      * The current time in the endpoint's time zone is earlier than or equal to the
                      time specified by the QuietTime.End property for the campaign.

                      If any of the preceding conditions isn't met, the endpoint will receive
                      messages from the campaign, even if quiet time is enabled.

                      - **End** *(string) --*

                        The specific time when quiet time ends. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                      - **Start** *(string) --*

                        The specific time when quiet time begins. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                    - **StartTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                    - **Timezone** *(string) --*

                      The starting UTC offset for the campaign schedule, if the value of the
                      IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                      UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                      UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13,
                      UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and
                      UTC-11.

                  - **SizePercent** *(integer) --*

                    The allocated percentage of users (segment members) that the treatment is sent
                    to.

                  - **State** *(dict) --*

                    The current status of the treatment.

                    - **CampaignStatus** *(string) --*

                      The current status of the campaign, or the current status of a treatment that
                      belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign
                      has a status of COMPLETED only if all campaign treatments have a status of
                      COMPLETED.

                  - **TemplateConfiguration** *(dict) --*

                    The message template to use for the treatment.

                    - **EmailTemplate** *(dict) --*

                      The email template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **PushTemplate** *(dict) --*

                      The push notification template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **SMSTemplate** *(dict) --*

                      The SMS template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **VoiceTemplate** *(dict) --*

                      The voice template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                  - **TreatmentDescription** *(string) --*

                    The custom description of the treatment.

                  - **TreatmentName** *(string) --*

                    The custom name of the treatment. A treatment is a variation of a campaign
                    that's used for A/B testing of a campaign.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the campaign applies to.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the campaign.

              - **CreationDate** *(string) --*

                The date, ISO 8601 format, when the campaign was created.

              - **DefaultState** *(dict) --*

                The current status of the campaign's default treatment. This value exists only for
                campaigns that have more than one treatment, to support A/B testing.

                - **CampaignStatus** *(string) --*

                  The current status of the campaign, or the current status of a treatment that
                  belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign has
                  a status of COMPLETED only if all campaign treatments have a status of COMPLETED.

              - **Description** *(string) --*

                The custom description of the campaign.

              - **HoldoutPercent** *(integer) --*

                The allocated percentage of users (segment members) who shouldn't receive messages
                from the campaign.

              - **Hook** *(dict) --*

                The settings for the AWS Lambda function to use as a code hook for the campaign.

                - **LambdaFunctionName** *(string) --*

                  The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon
                  Pinpoint invokes to send messages for a campaign.

                - **Mode** *(string) --*

                  Specifies which Lambda mode to use when invoking the AWS Lambda function.

                - **WebUrl** *(string) --*

                  The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over
                  HTTPS.

              - **Id** *(string) --*

                The unique identifier for the campaign.

              - **IsPaused** *(boolean) --*

                Specifies whether the campaign is paused. A paused campaign doesn't run unless you
                resume it by changing this value to false.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the campaign was last modified.

              - **Limits** *(dict) --*

                The messaging limits for the campaign.

                - **Daily** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during a 24-hour period. The maximum value is 100.

                - **MaximumDuration** *(integer) --*

                  The maximum amount of time, in seconds, that a campaign can attempt to deliver a
                  message after the scheduled start time for the campaign. The minimum value is 60
                  seconds.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that a campaign can send each second. The minimum
                  value is 50. The maximum value is 20,000.

                - **Total** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during the course of the campaign. The maximum value is 100.

              - **MessageConfiguration** *(dict) --*

                The message configuration settings for the campaign.

                - **ADMMessage** *(dict) --*

                  The message that the campaign sends through the ADM (Amazon Device Messaging)
                  channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **APNSMessage** *(dict) --*

                  The message that the campaign sends through the APNs (Apple Push Notification
                  service) channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **BaiduMessage** *(dict) --*

                  The message that the campaign sends through the Baidu (Baidu Cloud Push) channel.
                  This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **DefaultMessage** *(dict) --*

                  The default message that the campaign sends through all the channels that are
                  configured for the campaign.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **EmailMessage** *(dict) --*

                  The message that the campaign sends through the email channel.

                  - **Body** *(string) --*

                    The body of the email for recipients whose email clients don't render HTML
                    content.

                  - **FromAddress** *(string) --*

                    The verified email address to send the email from. The default address is the
                    FromAddress specified for the email channel for the application.

                  - **HtmlBody** *(string) --*

                    The body of the email, in HTML format, for recipients whose email clients render
                    HTML content.

                  - **Title** *(string) --*

                    The subject line, or title, of the email.

                - **GCMMessage** *(dict) --*

                  The message that the campaign sends through the GCM channel, which enables Amazon
                  Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM),
                  formerly Google Cloud Messaging (GCM), service. This message overrides the default
                  message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **SMSMessage** *(dict) --*

                  The message that the campaign sends through the SMS channel.

                  - **Body** *(string) --*

                    The body of the SMS message.

                  - **MessageType** *(string) --*

                    The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                    critical or time-sensitive, such as a one-time password that supports a customer
                    transaction; and, PROMOTIONAL, the message isn't critical or time-sensitive,
                    such as a marketing message.

                  - **SenderId** *(string) --*

                    The sender ID to display on recipients' devices when they receive the SMS
                    message.

              - **Name** *(string) --*

                The name of the campaign.

              - **Schedule** *(dict) --*

                The schedule settings for the campaign.

                - **EndTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                - **EventFilter** *(dict) --*

                  The type of event that causes the campaign to be sent, if the value of the
                  Frequency property is EVENT.

                  - **Dimensions** *(dict) --*

                    The dimension settings of the event filter for the campaign.

                    - **Attributes** *(dict) --*

                      One or more custom attributes that your application reports to Amazon
                      Pinpoint. You can use these attributes as selection criteria when you create
                      an event filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                    - **EventType** *(dict) --*

                      The name of the event that causes the campaign to be sent or the journey
                      activity to be performed. This can be a standard type of event that Amazon
                      Pinpoint generates, such as _email.delivered, or a custom event that's
                      specific to your application.

                      - **DimensionType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the DimensionType property, endpoints are included or excluded from the
                        segment if their values match the criteria values.

                        - *(string) --*

                    - **Metrics** *(dict) --*

                      One or more custom metrics that your application reports to Amazon Pinpoint.
                      You can use these metrics as selection criteria when you create an event
                      filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies metric-based criteria for including or excluding endpoints from
                          a segment. These criteria derive from custom metrics that you define for
                          endpoints.

                          - **ComparisonOperator** *(string) --*

                            The operator to use when comparing metric values. Valid values are:
                            GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                            EQUAL.

                          - **Value** *(float) --*

                            The value to compare.

                  - **FilterType** *(string) --*

                    The type of event that causes the campaign to be sent. Valid values are: SYSTEM,
                    sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign
                    when an endpoint event (Events resource) occurs.

                - **Frequency** *(string) --*

                  Specifies how often the campaign is sent or whether the campaign is sent in
                  response to a specific event.

                - **IsLocalTime** *(boolean) --*

                  Specifies whether the start and end times for the campaign schedule use each
                  recipient's local time. To base the schedule on each recipient's local time, set
                  this value to true.

                - **QuietTime** *(dict) --*

                  The default quiet time for the campaign. Quiet time is a specific time range when
                  a campaign doesn't send messages to endpoints, if all the following conditions are
                  met:

                  * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                  value.

                  * The current time in the endpoint's time zone is later than or equal to the time
                  specified by the QuietTime.Start property for the campaign.

                  * The current time in the endpoint's time zone is earlier than or equal to the
                  time specified by the QuietTime.End property for the campaign.

                  If any of the preceding conditions isn't met, the endpoint will receive messages
                  from the campaign, even if quiet time is enabled.

                  - **End** *(string) --*

                    The specific time when quiet time ends. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                  - **Start** *(string) --*

                    The specific time when quiet time begins. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                - **StartTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the campaign schedule, if the value of the IsLocalTime
                  property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30,
                  UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07,
                  UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02,
                  UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.

              - **SegmentId** *(string) --*

                The unique identifier for the segment that's associated with the campaign.

              - **SegmentVersion** *(integer) --*

                The version number of the segment that's associated with the campaign.

              - **State** *(dict) --*

                The current status of the campaign.

                - **CampaignStatus** *(string) --*

                  The current status of the campaign, or the current status of a treatment that
                  belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign has
                  a status of COMPLETED only if all campaign treatments have a status of COMPLETED.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the campaign. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **TemplateConfiguration** *(dict) --*

                The message template that’s used for the campaign.

                - **EmailTemplate** *(dict) --*

                  The email template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **PushTemplate** *(dict) --*

                  The push notification template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **SMSTemplate** *(dict) --*

                  The SMS template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **VoiceTemplate** *(dict) --*

                  The voice template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

              - **TreatmentDescription** *(string) --*

                The custom description of a variation of the campaign that's used for A/B testing.

              - **TreatmentName** *(string) --*

                The custom name of a variation of the campaign that's used for A/B testing.

              - **Version** *(integer) --*

                The version number of the campaign.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_campaign_activities(
        self, ApplicationId: str, CampaignId: str, PageSize: str = None, Token: str = None
    ) -> ClientGetCampaignActivitiesResponseTypeDef:
        """
        Retrieves information about all the activities for a campaign.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetCampaignActivities>`_

        **Request Syntax**
        ::

          response = client.get_campaign_activities(
              ApplicationId='string',
              CampaignId='string',
              PageSize='string',
              Token='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type CampaignId: string
        :param CampaignId: **[REQUIRED]**

          The unique identifier for the campaign.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type Token: string
        :param Token:

          The NextToken string that specifies which page of results to return in a paginated
          response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ActivitiesResponse': {
                    'Item': [
                        {
                            'ApplicationId': 'string',
                            'CampaignId': 'string',
                            'End': 'string',
                            'Id': 'string',
                            'Result': 'string',
                            'ScheduledStart': 'string',
                            'Start': 'string',
                            'State': 'string',
                            'SuccessfulEndpointCount': 123,
                            'TimezonesCompletedCount': 123,
                            'TimezonesTotalCount': 123,
                            'TotalEndpointCount': 123,
                            'TreatmentId': 'string'
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ActivitiesResponse** *(dict) --*

              Provides information about the activities that were performed by a campaign.

              - **Item** *(list) --*

                An array of responses, one for each activity that was performed by the campaign.

                - *(dict) --*

                  Provides information about an activity that was performed by a campaign.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that the campaign applies to.

                  - **CampaignId** *(string) --*

                    The unique identifier for the campaign that the activity applies to.

                  - **End** *(string) --*

                    The actual time, in ISO 8601 format, when the activity was marked CANCELLED or
                    COMPLETED.

                  - **Id** *(string) --*

                    The unique identifier for the activity.

                  - **Result** *(string) --*

                    Specifies whether the activity succeeded. Possible values are SUCCESS and FAIL.

                  - **ScheduledStart** *(string) --*

                    The scheduled start time, in ISO 8601 format, for the activity.

                  - **Start** *(string) --*

                    The actual start time, in ISO 8601 format, of the activity.

                  - **State** *(string) --*

                    The current status of the activity. Possible values are: PENDING, INITIALIZING,
                    RUNNING, PAUSED, CANCELLED, and COMPLETED.

                  - **SuccessfulEndpointCount** *(integer) --*

                    The total number of endpoints that the campaign successfully delivered messages
                    to.

                  - **TimezonesCompletedCount** *(integer) --*

                    The total number of time zones that were completed.

                  - **TimezonesTotalCount** *(integer) --*

                    The total number of unique time zones that are in the segment for the campaign.

                  - **TotalEndpointCount** *(integer) --*

                    The total number of endpoints that the campaign attempted to deliver messages
                    to.

                  - **TreatmentId** *(string) --*

                    The unique identifier for the campaign treatment that the activity applies to. A
                    treatment is a variation of a campaign that's used for A/B testing of a
                    campaign.

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_campaign_date_range_kpi(
        self,
        ApplicationId: str,
        CampaignId: str,
        KpiName: str,
        EndTime: datetime = None,
        NextToken: str = None,
        PageSize: str = None,
        StartTime: datetime = None,
    ) -> ClientGetCampaignDateRangeKpiResponseTypeDef:
        """
        Retrieves (queries) pre-aggregated data for a standard metric that applies to a campaign.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetCampaignDateRangeKpi>`_

        **Request Syntax**
        ::

          response = client.get_campaign_date_range_kpi(
              ApplicationId='string',
              CampaignId='string',
              EndTime=datetime(2015, 1, 1),
              KpiName='string',
              NextToken='string',
              PageSize='string',
              StartTime=datetime(2015, 1, 1)
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type CampaignId: string
        :param CampaignId: **[REQUIRED]**

          The unique identifier for the campaign.

        :type EndTime: datetime
        :param EndTime:

          The last date and time to retrieve data for, as part of an inclusive date range that
          filters the query results. This value should be in extended ISO 8601 format, for example:
          2019-07-19T00:00:00Z for July 19, 2019 and 2019-07-19T20:00:00Z for 8:00 PM July 19, 2019.

        :type KpiName: string
        :param KpiName: **[REQUIRED]**

          The name of the metric, also referred to as a *key performance indicator (KPI)* , to
          retrieve data for. This value describes the associated metric and consists of two or more
          terms, which are comprised of lowercase alphanumeric characters, separated by a hyphen.
          Examples are email-open-rate and successful-delivery-rate. For a list of valid values, see
          the `Amazon Pinpoint Developer Guide
          <https://docs.aws.amazon.com/pinpoint/latest/developerguide/welcome.html>`__ .

        :type NextToken: string
        :param NextToken:

          The string that specifies which page of results to return in a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type StartTime: datetime
        :param StartTime:

          The first date and time to retrieve data for, as part of an inclusive date range that
          filters the query results. This value should be in extended ISO 8601 format, for example:
          2019-07-15T00:00:00Z for July 15, 2019 and 2019-07-15T16:00:00Z for 4:00 PM July 15, 2019.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CampaignDateRangeKpiResponse': {
                    'ApplicationId': 'string',
                    'CampaignId': 'string',
                    'EndTime': datetime(2015, 1, 1),
                    'KpiName': 'string',
                    'KpiResult': {
                        'Rows': [
                            {
                                'GroupedBys': [
                                    {
                                        'Key': 'string',
                                        'Type': 'string',
                                        'Value': 'string'
                                    },
                                ],
                                'Values': [
                                    {
                                        'Key': 'string',
                                        'Type': 'string',
                                        'Value': 'string'
                                    },
                                ]
                            },
                        ]
                    },
                    'NextToken': 'string',
                    'StartTime': datetime(2015, 1, 1)
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **CampaignDateRangeKpiResponse** *(dict) --*

              Provides the results of a query that retrieved the data for a standard metric that
              applies to a campaign, and provides information about that query.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the metric applies to.

              - **CampaignId** *(string) --*

                The unique identifier for the campaign that the metric applies to.

              - **EndTime** *(datetime) --*

                The last date and time of the date range that was used to filter the query results,
                in extended ISO 8601 format. The date range is inclusive.

              - **KpiName** *(string) --*

                The name of the metric, also referred to as a *key performance indicator (KPI)* ,
                that the data was retrieved for. This value describes the associated metric and
                consists of two or more terms, which are comprised of lowercase alphanumeric
                characters, separated by a hyphen. For a list of possible values, see the `Amazon
                Pinpoint Developer Guide
                <https://docs.aws.amazon.com/pinpoint/latest/developerguide/welcome.html>`__ .

              - **KpiResult** *(dict) --*

                An array of objects that contains the results of the query. Each object contains the
                value for the metric and metadata about that value.

                - **Rows** *(list) --*

                  An array of objects that provides the results of a query that retrieved the data
                  for a standard metric that applies to an application, campaign, or journey.

                  - *(dict) --*

                    Provides the results of a query that retrieved the data for a standard metric
                    that applies to an application, campaign, or journey.

                    - **GroupedBys** *(list) --*

                      An array of objects that defines the field and field values that were used to
                      group data in a result set that contains multiple results. This value is null
                      if the data in a result set isn’t grouped.

                      - *(dict) --*

                        Provides a single value and metadata about that value as part of an array of
                        query results for a standard metric that applies to an application,
                        campaign, or journey.

                        - **Key** *(string) --*

                          The friendly name of the metric whose value is specified by the Value
                          property.

                        - **Type** *(string) --*

                          The data type of the value specified by the Value property.

                        - **Value** *(string) --*

                          In a Values object, the value for the metric that the query retrieved data
                          for. In a GroupedBys object, the value for the field that was used to
                          group data in a result set that contains multiple results (Values
                          objects).

                    - **Values** *(list) --*

                      An array of objects that provides pre-aggregated values for a standard metric
                      that applies to an application, campaign, or journey.

                      - *(dict) --*

                        Provides a single value and metadata about that value as part of an array of
                        query results for a standard metric that applies to an application,
                        campaign, or journey.

                        - **Key** *(string) --*

                          The friendly name of the metric whose value is specified by the Value
                          property.

                        - **Type** *(string) --*

                          The data type of the value specified by the Value property.

                        - **Value** *(string) --*

                          In a Values object, the value for the metric that the query retrieved data
                          for. In a GroupedBys object, the value for the field that was used to
                          group data in a result set that contains multiple results (Values
                          objects).

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null for the Campaign Metrics resource because the
                resource returns all results in a single page.

              - **StartTime** *(datetime) --*

                The first date and time of the date range that was used to filter the query results,
                in extended ISO 8601 format. The date range is inclusive.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_campaign_version(
        self, ApplicationId: str, CampaignId: str, Version: str
    ) -> ClientGetCampaignVersionResponseTypeDef:
        """
        Retrieves information about the status, configuration, and other settings for a specific
        version of a campaign.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetCampaignVersion>`_

        **Request Syntax**
        ::

          response = client.get_campaign_version(
              ApplicationId='string',
              CampaignId='string',
              Version='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type CampaignId: string
        :param CampaignId: **[REQUIRED]**

          The unique identifier for the campaign.

        :type Version: string
        :param Version: **[REQUIRED]**

          The unique version number (Version property) for the campaign version.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CampaignResponse': {
                    'AdditionalTreatments': [
                        {
                            'Id': 'string',
                            'MessageConfiguration': {
                                'ADMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'APNSMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'BaiduMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'DefaultMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'EmailMessage': {
                                    'Body': 'string',
                                    'FromAddress': 'string',
                                    'HtmlBody': 'string',
                                    'Title': 'string'
                                },
                                'GCMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'SMSMessage': {
                                    'Body': 'string',
                                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                    'SenderId': 'string'
                                }
                            },
                            'Schedule': {
                                'EndTime': 'string',
                                'EventFilter': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'FilterType': 'SYSTEM'|'ENDPOINT'
                                },
                                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                                'IsLocalTime': True|False,
                                'QuietTime': {
                                    'End': 'string',
                                    'Start': 'string'
                                },
                                'StartTime': 'string',
                                'Timezone': 'string'
                            },
                            'SizePercent': 123,
                            'State': {
                                'CampaignStatus':
                                'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'
                                |'COMPLETED'|'PAUSED'|'DELETED'
                            },
                            'TemplateConfiguration': {
                                'EmailTemplate': {
                                    'Name': 'string'
                                },
                                'PushTemplate': {
                                    'Name': 'string'
                                },
                                'SMSTemplate': {
                                    'Name': 'string'
                                },
                                'VoiceTemplate': {
                                    'Name': 'string'
                                }
                            },
                            'TreatmentDescription': 'string',
                            'TreatmentName': 'string'
                        },
                    ],
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'DefaultState': {
                        'CampaignStatus':
                        'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'
                        |'PAUSED'|'DELETED'
                    },
                    'Description': 'string',
                    'HoldoutPercent': 123,
                    'Hook': {
                        'LambdaFunctionName': 'string',
                        'Mode': 'DELIVERY'|'FILTER',
                        'WebUrl': 'string'
                    },
                    'Id': 'string',
                    'IsPaused': True|False,
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'Daily': 123,
                        'MaximumDuration': 123,
                        'MessagesPerSecond': 123,
                        'Total': 123
                    },
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Name': 'string',
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SegmentId': 'string',
                    'SegmentVersion': 123,
                    'State': {
                        'CampaignStatus':
                        'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'
                        |'PAUSED'|'DELETED'
                    },
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **CampaignResponse** *(dict) --*

              Provides information about the status, configuration, and other settings for a
              campaign.

              - **AdditionalTreatments** *(list) --*

                An array of responses, one for each treatment that you defined for the campaign, in
                addition to the default treatment.

                - *(dict) --*

                  Specifies the settings for a campaign treatment. A treatment is a variation of a
                  campaign that's used for A/B testing of a campaign.

                  - **Id** *(string) --*

                    The unique identifier for the treatment.

                  - **MessageConfiguration** *(dict) --*

                    The message configuration settings for the treatment.

                    - **ADMMessage** *(dict) --*

                      The message that the campaign sends through the ADM (Amazon Device Messaging)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **APNSMessage** *(dict) --*

                      The message that the campaign sends through the APNs (Apple Push Notification
                      service) channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **BaiduMessage** *(dict) --*

                      The message that the campaign sends through the Baidu (Baidu Cloud Push)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **DefaultMessage** *(dict) --*

                      The default message that the campaign sends through all the channels that are
                      configured for the campaign.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **EmailMessage** *(dict) --*

                      The message that the campaign sends through the email channel.

                      - **Body** *(string) --*

                        The body of the email for recipients whose email clients don't render HTML
                        content.

                      - **FromAddress** *(string) --*

                        The verified email address to send the email from. The default address is
                        the FromAddress specified for the email channel for the application.

                      - **HtmlBody** *(string) --*

                        The body of the email, in HTML format, for recipients whose email clients
                        render HTML content.

                      - **Title** *(string) --*

                        The subject line, or title, of the email.

                    - **GCMMessage** *(dict) --*

                      The message that the campaign sends through the GCM channel, which enables
                      Amazon Pinpoint to send push notifications through the Firebase Cloud
                      Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message
                      overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **SMSMessage** *(dict) --*

                      The message that the campaign sends through the SMS channel.

                      - **Body** *(string) --*

                        The body of the SMS message.

                      - **MessageType** *(string) --*

                        The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                        critical or time-sensitive, such as a one-time password that supports a
                        customer transaction; and, PROMOTIONAL, the message isn't critical or
                        time-sensitive, such as a marketing message.

                      - **SenderId** *(string) --*

                        The sender ID to display on recipients' devices when they receive the SMS
                        message.

                  - **Schedule** *(dict) --*

                    The schedule settings for the treatment.

                    - **EndTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                    - **EventFilter** *(dict) --*

                      The type of event that causes the campaign to be sent, if the value of the
                      Frequency property is EVENT.

                      - **Dimensions** *(dict) --*

                        The dimension settings of the event filter for the campaign.

                        - **Attributes** *(dict) --*

                          One or more custom attributes that your application reports to Amazon
                          Pinpoint. You can use these attributes as selection criteria when you
                          create an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **EventType** *(dict) --*

                          The name of the event that causes the campaign to be sent or the journey
                          activity to be performed. This can be a standard type of event that Amazon
                          Pinpoint generates, such as _email.delivered, or a custom event that's
                          specific to your application.

                          - **DimensionType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the DimensionType property, endpoints are included or excluded
                            from the segment if their values match the criteria values.

                            - *(string) --*

                        - **Metrics** *(dict) --*

                          One or more custom metrics that your application reports to Amazon
                          Pinpoint. You can use these metrics as selection criteria when you create
                          an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                      - **FilterType** *(string) --*

                        The type of event that causes the campaign to be sent. Valid values are:
                        SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends
                        the campaign when an endpoint event (Events resource) occurs.

                    - **Frequency** *(string) --*

                      Specifies how often the campaign is sent or whether the campaign is sent in
                      response to a specific event.

                    - **IsLocalTime** *(boolean) --*

                      Specifies whether the start and end times for the campaign schedule use each
                      recipient's local time. To base the schedule on each recipient's local time,
                      set this value to true.

                    - **QuietTime** *(dict) --*

                      The default quiet time for the campaign. Quiet time is a specific time range
                      when a campaign doesn't send messages to endpoints, if all the following
                      conditions are met:

                      * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                      value.

                      * The current time in the endpoint's time zone is later than or equal to the
                      time specified by the QuietTime.Start property for the campaign.

                      * The current time in the endpoint's time zone is earlier than or equal to the
                      time specified by the QuietTime.End property for the campaign.

                      If any of the preceding conditions isn't met, the endpoint will receive
                      messages from the campaign, even if quiet time is enabled.

                      - **End** *(string) --*

                        The specific time when quiet time ends. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                      - **Start** *(string) --*

                        The specific time when quiet time begins. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                    - **StartTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                    - **Timezone** *(string) --*

                      The starting UTC offset for the campaign schedule, if the value of the
                      IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                      UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                      UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13,
                      UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and
                      UTC-11.

                  - **SizePercent** *(integer) --*

                    The allocated percentage of users (segment members) that the treatment is sent
                    to.

                  - **State** *(dict) --*

                    The current status of the treatment.

                    - **CampaignStatus** *(string) --*

                      The current status of the campaign, or the current status of a treatment that
                      belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign
                      has a status of COMPLETED only if all campaign treatments have a status of
                      COMPLETED.

                  - **TemplateConfiguration** *(dict) --*

                    The message template to use for the treatment.

                    - **EmailTemplate** *(dict) --*

                      The email template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **PushTemplate** *(dict) --*

                      The push notification template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **SMSTemplate** *(dict) --*

                      The SMS template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **VoiceTemplate** *(dict) --*

                      The voice template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                  - **TreatmentDescription** *(string) --*

                    The custom description of the treatment.

                  - **TreatmentName** *(string) --*

                    The custom name of the treatment. A treatment is a variation of a campaign
                    that's used for A/B testing of a campaign.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the campaign applies to.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the campaign.

              - **CreationDate** *(string) --*

                The date, ISO 8601 format, when the campaign was created.

              - **DefaultState** *(dict) --*

                The current status of the campaign's default treatment. This value exists only for
                campaigns that have more than one treatment, to support A/B testing.

                - **CampaignStatus** *(string) --*

                  The current status of the campaign, or the current status of a treatment that
                  belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign has
                  a status of COMPLETED only if all campaign treatments have a status of COMPLETED.

              - **Description** *(string) --*

                The custom description of the campaign.

              - **HoldoutPercent** *(integer) --*

                The allocated percentage of users (segment members) who shouldn't receive messages
                from the campaign.

              - **Hook** *(dict) --*

                The settings for the AWS Lambda function to use as a code hook for the campaign.

                - **LambdaFunctionName** *(string) --*

                  The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon
                  Pinpoint invokes to send messages for a campaign.

                - **Mode** *(string) --*

                  Specifies which Lambda mode to use when invoking the AWS Lambda function.

                - **WebUrl** *(string) --*

                  The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over
                  HTTPS.

              - **Id** *(string) --*

                The unique identifier for the campaign.

              - **IsPaused** *(boolean) --*

                Specifies whether the campaign is paused. A paused campaign doesn't run unless you
                resume it by changing this value to false.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the campaign was last modified.

              - **Limits** *(dict) --*

                The messaging limits for the campaign.

                - **Daily** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during a 24-hour period. The maximum value is 100.

                - **MaximumDuration** *(integer) --*

                  The maximum amount of time, in seconds, that a campaign can attempt to deliver a
                  message after the scheduled start time for the campaign. The minimum value is 60
                  seconds.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that a campaign can send each second. The minimum
                  value is 50. The maximum value is 20,000.

                - **Total** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during the course of the campaign. The maximum value is 100.

              - **MessageConfiguration** *(dict) --*

                The message configuration settings for the campaign.

                - **ADMMessage** *(dict) --*

                  The message that the campaign sends through the ADM (Amazon Device Messaging)
                  channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **APNSMessage** *(dict) --*

                  The message that the campaign sends through the APNs (Apple Push Notification
                  service) channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **BaiduMessage** *(dict) --*

                  The message that the campaign sends through the Baidu (Baidu Cloud Push) channel.
                  This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **DefaultMessage** *(dict) --*

                  The default message that the campaign sends through all the channels that are
                  configured for the campaign.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **EmailMessage** *(dict) --*

                  The message that the campaign sends through the email channel.

                  - **Body** *(string) --*

                    The body of the email for recipients whose email clients don't render HTML
                    content.

                  - **FromAddress** *(string) --*

                    The verified email address to send the email from. The default address is the
                    FromAddress specified for the email channel for the application.

                  - **HtmlBody** *(string) --*

                    The body of the email, in HTML format, for recipients whose email clients render
                    HTML content.

                  - **Title** *(string) --*

                    The subject line, or title, of the email.

                - **GCMMessage** *(dict) --*

                  The message that the campaign sends through the GCM channel, which enables Amazon
                  Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM),
                  formerly Google Cloud Messaging (GCM), service. This message overrides the default
                  message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **SMSMessage** *(dict) --*

                  The message that the campaign sends through the SMS channel.

                  - **Body** *(string) --*

                    The body of the SMS message.

                  - **MessageType** *(string) --*

                    The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                    critical or time-sensitive, such as a one-time password that supports a customer
                    transaction; and, PROMOTIONAL, the message isn't critical or time-sensitive,
                    such as a marketing message.

                  - **SenderId** *(string) --*

                    The sender ID to display on recipients' devices when they receive the SMS
                    message.

              - **Name** *(string) --*

                The name of the campaign.

              - **Schedule** *(dict) --*

                The schedule settings for the campaign.

                - **EndTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                - **EventFilter** *(dict) --*

                  The type of event that causes the campaign to be sent, if the value of the
                  Frequency property is EVENT.

                  - **Dimensions** *(dict) --*

                    The dimension settings of the event filter for the campaign.

                    - **Attributes** *(dict) --*

                      One or more custom attributes that your application reports to Amazon
                      Pinpoint. You can use these attributes as selection criteria when you create
                      an event filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                    - **EventType** *(dict) --*

                      The name of the event that causes the campaign to be sent or the journey
                      activity to be performed. This can be a standard type of event that Amazon
                      Pinpoint generates, such as _email.delivered, or a custom event that's
                      specific to your application.

                      - **DimensionType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the DimensionType property, endpoints are included or excluded from the
                        segment if their values match the criteria values.

                        - *(string) --*

                    - **Metrics** *(dict) --*

                      One or more custom metrics that your application reports to Amazon Pinpoint.
                      You can use these metrics as selection criteria when you create an event
                      filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies metric-based criteria for including or excluding endpoints from
                          a segment. These criteria derive from custom metrics that you define for
                          endpoints.

                          - **ComparisonOperator** *(string) --*

                            The operator to use when comparing metric values. Valid values are:
                            GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                            EQUAL.

                          - **Value** *(float) --*

                            The value to compare.

                  - **FilterType** *(string) --*

                    The type of event that causes the campaign to be sent. Valid values are: SYSTEM,
                    sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign
                    when an endpoint event (Events resource) occurs.

                - **Frequency** *(string) --*

                  Specifies how often the campaign is sent or whether the campaign is sent in
                  response to a specific event.

                - **IsLocalTime** *(boolean) --*

                  Specifies whether the start and end times for the campaign schedule use each
                  recipient's local time. To base the schedule on each recipient's local time, set
                  this value to true.

                - **QuietTime** *(dict) --*

                  The default quiet time for the campaign. Quiet time is a specific time range when
                  a campaign doesn't send messages to endpoints, if all the following conditions are
                  met:

                  * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                  value.

                  * The current time in the endpoint's time zone is later than or equal to the time
                  specified by the QuietTime.Start property for the campaign.

                  * The current time in the endpoint's time zone is earlier than or equal to the
                  time specified by the QuietTime.End property for the campaign.

                  If any of the preceding conditions isn't met, the endpoint will receive messages
                  from the campaign, even if quiet time is enabled.

                  - **End** *(string) --*

                    The specific time when quiet time ends. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                  - **Start** *(string) --*

                    The specific time when quiet time begins. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                - **StartTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the campaign schedule, if the value of the IsLocalTime
                  property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30,
                  UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07,
                  UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02,
                  UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.

              - **SegmentId** *(string) --*

                The unique identifier for the segment that's associated with the campaign.

              - **SegmentVersion** *(integer) --*

                The version number of the segment that's associated with the campaign.

              - **State** *(dict) --*

                The current status of the campaign.

                - **CampaignStatus** *(string) --*

                  The current status of the campaign, or the current status of a treatment that
                  belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign has
                  a status of COMPLETED only if all campaign treatments have a status of COMPLETED.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the campaign. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **TemplateConfiguration** *(dict) --*

                The message template that’s used for the campaign.

                - **EmailTemplate** *(dict) --*

                  The email template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **PushTemplate** *(dict) --*

                  The push notification template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **SMSTemplate** *(dict) --*

                  The SMS template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **VoiceTemplate** *(dict) --*

                  The voice template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

              - **TreatmentDescription** *(string) --*

                The custom description of a variation of the campaign that's used for A/B testing.

              - **TreatmentName** *(string) --*

                The custom name of a variation of the campaign that's used for A/B testing.

              - **Version** *(integer) --*

                The version number of the campaign.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_campaign_versions(
        self, ApplicationId: str, CampaignId: str, PageSize: str = None, Token: str = None
    ) -> ClientGetCampaignVersionsResponseTypeDef:
        """
        Retrieves information about the status, configuration, and other settings for all versions
        of a campaign.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetCampaignVersions>`_

        **Request Syntax**
        ::

          response = client.get_campaign_versions(
              ApplicationId='string',
              CampaignId='string',
              PageSize='string',
              Token='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type CampaignId: string
        :param CampaignId: **[REQUIRED]**

          The unique identifier for the campaign.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type Token: string
        :param Token:

          The NextToken string that specifies which page of results to return in a paginated
          response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CampaignsResponse': {
                    'Item': [
                        {
                            'AdditionalTreatments': [
                                {
                                    'Id': 'string',
                                    'MessageConfiguration': {
                                        'ADMMessage': {
                                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                            'Body': 'string',
                                            'ImageIconUrl': 'string',
                                            'ImageSmallIconUrl': 'string',
                                            'ImageUrl': 'string',
                                            'JsonBody': 'string',
                                            'MediaUrl': 'string',
                                            'RawContent': 'string',
                                            'SilentPush': True|False,
                                            'TimeToLive': 123,
                                            'Title': 'string',
                                            'Url': 'string'
                                        },
                                        'APNSMessage': {
                                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                            'Body': 'string',
                                            'ImageIconUrl': 'string',
                                            'ImageSmallIconUrl': 'string',
                                            'ImageUrl': 'string',
                                            'JsonBody': 'string',
                                            'MediaUrl': 'string',
                                            'RawContent': 'string',
                                            'SilentPush': True|False,
                                            'TimeToLive': 123,
                                            'Title': 'string',
                                            'Url': 'string'
                                        },
                                        'BaiduMessage': {
                                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                            'Body': 'string',
                                            'ImageIconUrl': 'string',
                                            'ImageSmallIconUrl': 'string',
                                            'ImageUrl': 'string',
                                            'JsonBody': 'string',
                                            'MediaUrl': 'string',
                                            'RawContent': 'string',
                                            'SilentPush': True|False,
                                            'TimeToLive': 123,
                                            'Title': 'string',
                                            'Url': 'string'
                                        },
                                        'DefaultMessage': {
                                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                            'Body': 'string',
                                            'ImageIconUrl': 'string',
                                            'ImageSmallIconUrl': 'string',
                                            'ImageUrl': 'string',
                                            'JsonBody': 'string',
                                            'MediaUrl': 'string',
                                            'RawContent': 'string',
                                            'SilentPush': True|False,
                                            'TimeToLive': 123,
                                            'Title': 'string',
                                            'Url': 'string'
                                        },
                                        'EmailMessage': {
                                            'Body': 'string',
                                            'FromAddress': 'string',
                                            'HtmlBody': 'string',
                                            'Title': 'string'
                                        },
                                        'GCMMessage': {
                                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                            'Body': 'string',
                                            'ImageIconUrl': 'string',
                                            'ImageSmallIconUrl': 'string',
                                            'ImageUrl': 'string',
                                            'JsonBody': 'string',
                                            'MediaUrl': 'string',
                                            'RawContent': 'string',
                                            'SilentPush': True|False,
                                            'TimeToLive': 123,
                                            'Title': 'string',
                                            'Url': 'string'
                                        },
                                        'SMSMessage': {
                                            'Body': 'string',
                                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                            'SenderId': 'string'
                                        }
                                    },
                                    'Schedule': {
                                        'EndTime': 'string',
                                        'EventFilter': {
                                            'Dimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'EventType': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                }
                                            },
                                            'FilterType': 'SYSTEM'|'ENDPOINT'
                                        },
                                        'Frequency':
                                        'ONCE'|'HOURLY'|'DAILY'
                                        |'WEEKLY'|'MONTHLY'|'EVENT',
                                        'IsLocalTime': True|False,
                                        'QuietTime': {
                                            'End': 'string',
                                            'Start': 'string'
                                        },
                                        'StartTime': 'string',
                                        'Timezone': 'string'
                                    },
                                    'SizePercent': 123,
                                    'State': {
                                        'CampaignStatus':
                                        'SCHEDULED'|'EXECUTING'
                                        |'PENDING_NEXT_RUN'
                                        |'COMPLETED'|'PAUSED'
                                        |'DELETED'
                                    },
                                    'TemplateConfiguration': {
                                        'EmailTemplate': {
                                            'Name': 'string'
                                        },
                                        'PushTemplate': {
                                            'Name': 'string'
                                        },
                                        'SMSTemplate': {
                                            'Name': 'string'
                                        },
                                        'VoiceTemplate': {
                                            'Name': 'string'
                                        }
                                    },
                                    'TreatmentDescription': 'string',
                                    'TreatmentName': 'string'
                                },
                            ],
                            'ApplicationId': 'string',
                            'Arn': 'string',
                            'CreationDate': 'string',
                            'DefaultState': {
                                'CampaignStatus':
                                'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'
                                |'COMPLETED'|'PAUSED'|'DELETED'
                            },
                            'Description': 'string',
                            'HoldoutPercent': 123,
                            'Hook': {
                                'LambdaFunctionName': 'string',
                                'Mode': 'DELIVERY'|'FILTER',
                                'WebUrl': 'string'
                            },
                            'Id': 'string',
                            'IsPaused': True|False,
                            'LastModifiedDate': 'string',
                            'Limits': {
                                'Daily': 123,
                                'MaximumDuration': 123,
                                'MessagesPerSecond': 123,
                                'Total': 123
                            },
                            'MessageConfiguration': {
                                'ADMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'APNSMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'BaiduMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'DefaultMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'EmailMessage': {
                                    'Body': 'string',
                                    'FromAddress': 'string',
                                    'HtmlBody': 'string',
                                    'Title': 'string'
                                },
                                'GCMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'SMSMessage': {
                                    'Body': 'string',
                                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                    'SenderId': 'string'
                                }
                            },
                            'Name': 'string',
                            'Schedule': {
                                'EndTime': 'string',
                                'EventFilter': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'FilterType': 'SYSTEM'|'ENDPOINT'
                                },
                                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                                'IsLocalTime': True|False,
                                'QuietTime': {
                                    'End': 'string',
                                    'Start': 'string'
                                },
                                'StartTime': 'string',
                                'Timezone': 'string'
                            },
                            'SegmentId': 'string',
                            'SegmentVersion': 123,
                            'State': {
                                'CampaignStatus':
                                'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'
                                |'COMPLETED'|'PAUSED'|'DELETED'
                            },
                            'tags': {
                                'string': 'string'
                            },
                            'TemplateConfiguration': {
                                'EmailTemplate': {
                                    'Name': 'string'
                                },
                                'PushTemplate': {
                                    'Name': 'string'
                                },
                                'SMSTemplate': {
                                    'Name': 'string'
                                },
                                'VoiceTemplate': {
                                    'Name': 'string'
                                }
                            },
                            'TreatmentDescription': 'string',
                            'TreatmentName': 'string',
                            'Version': 123
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **CampaignsResponse** *(dict) --*

              Provides information about the configuration and other settings for all the campaigns
              that are associated with an application.

              - **Item** *(list) --*

                An array of responses, one for each campaign that's associated with the application.

                - *(dict) --*

                  Provides information about the status, configuration, and other settings for a
                  campaign.

                  - **AdditionalTreatments** *(list) --*

                    An array of responses, one for each treatment that you defined for the campaign,
                    in addition to the default treatment.

                    - *(dict) --*

                      Specifies the settings for a campaign treatment. A treatment is a variation of
                      a campaign that's used for A/B testing of a campaign.

                      - **Id** *(string) --*

                        The unique identifier for the treatment.

                      - **MessageConfiguration** *(dict) --*

                        The message configuration settings for the treatment.

                        - **ADMMessage** *(dict) --*

                          The message that the campaign sends through the ADM (Amazon Device
                          Messaging) channel. This message overrides the default message.

                          - **Action** *(string) --*

                            The action to occur if a recipient taps the push notification. Valid
                            values are:

                            * OPEN_APP - Your app opens or it becomes the foreground app if it was
                            sent to the background. This is the default action.

                            * DEEP_LINK - Your app opens and displays a designated user interface in
                            the app. This setting uses the deep-linking features of iOS and Android.

                            * URL - The default mobile browser on the recipient's device opens and
                            loads the web page at a URL that you specify.

                          - **Body** *(string) --*

                            The body of the notification message. The maximum number of characters
                            is 200.

                          - **ImageIconUrl** *(string) --*

                            The URL of the image to display as the push-notification icon, such as
                            the icon for the app.

                          - **ImageSmallIconUrl** *(string) --*

                            The URL of the image to display as the small, push-notification icon,
                            such as a small version of the icon for the app.

                          - **ImageUrl** *(string) --*

                            The URL of an image to display in the push notification.

                          - **JsonBody** *(string) --*

                            The JSON payload to use for a silent push notification.

                          - **MediaUrl** *(string) --*

                            The URL of the image or video to display in the push notification.

                          - **RawContent** *(string) --*

                            The raw, JSON-formatted string to use as the payload for the
                            notification message. If specified, this value overrides all other
                            content for the message.

                          - **SilentPush** *(boolean) --*

                            Specifies whether the notification is a silent push notification, which
                            is a push notification that doesn't display on a recipient's device.
                            Silent push notifications can be used for cases such as updating an
                            app's configuration, displaying messages in an in-app message center, or
                            supporting phone home functionality.

                          - **TimeToLive** *(integer) --*

                            The number of seconds that the push-notification service should keep the
                            message, if the service is unable to deliver the notification the first
                            time. This value is converted to an expiration value when it's sent to a
                            push-notification service. If this value is 0, the service treats the
                            notification as if it expires immediately and the service doesn't store
                            or try to deliver the notification again.

                            This value doesn't apply to messages that are sent through the Amazon
                            Device Messaging (ADM) service.

                          - **Title** *(string) --*

                            The title to display above the notification message on a recipient's
                            device.

                          - **Url** *(string) --*

                            The URL to open in a recipient's default mobile browser, if a recipient
                            taps the push notification and the value of the Action property is URL.

                        - **APNSMessage** *(dict) --*

                          The message that the campaign sends through the APNs (Apple Push
                          Notification service) channel. This message overrides the default message.

                          - **Action** *(string) --*

                            The action to occur if a recipient taps the push notification. Valid
                            values are:

                            * OPEN_APP - Your app opens or it becomes the foreground app if it was
                            sent to the background. This is the default action.

                            * DEEP_LINK - Your app opens and displays a designated user interface in
                            the app. This setting uses the deep-linking features of iOS and Android.

                            * URL - The default mobile browser on the recipient's device opens and
                            loads the web page at a URL that you specify.

                          - **Body** *(string) --*

                            The body of the notification message. The maximum number of characters
                            is 200.

                          - **ImageIconUrl** *(string) --*

                            The URL of the image to display as the push-notification icon, such as
                            the icon for the app.

                          - **ImageSmallIconUrl** *(string) --*

                            The URL of the image to display as the small, push-notification icon,
                            such as a small version of the icon for the app.

                          - **ImageUrl** *(string) --*

                            The URL of an image to display in the push notification.

                          - **JsonBody** *(string) --*

                            The JSON payload to use for a silent push notification.

                          - **MediaUrl** *(string) --*

                            The URL of the image or video to display in the push notification.

                          - **RawContent** *(string) --*

                            The raw, JSON-formatted string to use as the payload for the
                            notification message. If specified, this value overrides all other
                            content for the message.

                          - **SilentPush** *(boolean) --*

                            Specifies whether the notification is a silent push notification, which
                            is a push notification that doesn't display on a recipient's device.
                            Silent push notifications can be used for cases such as updating an
                            app's configuration, displaying messages in an in-app message center, or
                            supporting phone home functionality.

                          - **TimeToLive** *(integer) --*

                            The number of seconds that the push-notification service should keep the
                            message, if the service is unable to deliver the notification the first
                            time. This value is converted to an expiration value when it's sent to a
                            push-notification service. If this value is 0, the service treats the
                            notification as if it expires immediately and the service doesn't store
                            or try to deliver the notification again.

                            This value doesn't apply to messages that are sent through the Amazon
                            Device Messaging (ADM) service.

                          - **Title** *(string) --*

                            The title to display above the notification message on a recipient's
                            device.

                          - **Url** *(string) --*

                            The URL to open in a recipient's default mobile browser, if a recipient
                            taps the push notification and the value of the Action property is URL.

                        - **BaiduMessage** *(dict) --*

                          The message that the campaign sends through the Baidu (Baidu Cloud Push)
                          channel. This message overrides the default message.

                          - **Action** *(string) --*

                            The action to occur if a recipient taps the push notification. Valid
                            values are:

                            * OPEN_APP - Your app opens or it becomes the foreground app if it was
                            sent to the background. This is the default action.

                            * DEEP_LINK - Your app opens and displays a designated user interface in
                            the app. This setting uses the deep-linking features of iOS and Android.

                            * URL - The default mobile browser on the recipient's device opens and
                            loads the web page at a URL that you specify.

                          - **Body** *(string) --*

                            The body of the notification message. The maximum number of characters
                            is 200.

                          - **ImageIconUrl** *(string) --*

                            The URL of the image to display as the push-notification icon, such as
                            the icon for the app.

                          - **ImageSmallIconUrl** *(string) --*

                            The URL of the image to display as the small, push-notification icon,
                            such as a small version of the icon for the app.

                          - **ImageUrl** *(string) --*

                            The URL of an image to display in the push notification.

                          - **JsonBody** *(string) --*

                            The JSON payload to use for a silent push notification.

                          - **MediaUrl** *(string) --*

                            The URL of the image or video to display in the push notification.

                          - **RawContent** *(string) --*

                            The raw, JSON-formatted string to use as the payload for the
                            notification message. If specified, this value overrides all other
                            content for the message.

                          - **SilentPush** *(boolean) --*

                            Specifies whether the notification is a silent push notification, which
                            is a push notification that doesn't display on a recipient's device.
                            Silent push notifications can be used for cases such as updating an
                            app's configuration, displaying messages in an in-app message center, or
                            supporting phone home functionality.

                          - **TimeToLive** *(integer) --*

                            The number of seconds that the push-notification service should keep the
                            message, if the service is unable to deliver the notification the first
                            time. This value is converted to an expiration value when it's sent to a
                            push-notification service. If this value is 0, the service treats the
                            notification as if it expires immediately and the service doesn't store
                            or try to deliver the notification again.

                            This value doesn't apply to messages that are sent through the Amazon
                            Device Messaging (ADM) service.

                          - **Title** *(string) --*

                            The title to display above the notification message on a recipient's
                            device.

                          - **Url** *(string) --*

                            The URL to open in a recipient's default mobile browser, if a recipient
                            taps the push notification and the value of the Action property is URL.

                        - **DefaultMessage** *(dict) --*

                          The default message that the campaign sends through all the channels that
                          are configured for the campaign.

                          - **Action** *(string) --*

                            The action to occur if a recipient taps the push notification. Valid
                            values are:

                            * OPEN_APP - Your app opens or it becomes the foreground app if it was
                            sent to the background. This is the default action.

                            * DEEP_LINK - Your app opens and displays a designated user interface in
                            the app. This setting uses the deep-linking features of iOS and Android.

                            * URL - The default mobile browser on the recipient's device opens and
                            loads the web page at a URL that you specify.

                          - **Body** *(string) --*

                            The body of the notification message. The maximum number of characters
                            is 200.

                          - **ImageIconUrl** *(string) --*

                            The URL of the image to display as the push-notification icon, such as
                            the icon for the app.

                          - **ImageSmallIconUrl** *(string) --*

                            The URL of the image to display as the small, push-notification icon,
                            such as a small version of the icon for the app.

                          - **ImageUrl** *(string) --*

                            The URL of an image to display in the push notification.

                          - **JsonBody** *(string) --*

                            The JSON payload to use for a silent push notification.

                          - **MediaUrl** *(string) --*

                            The URL of the image or video to display in the push notification.

                          - **RawContent** *(string) --*

                            The raw, JSON-formatted string to use as the payload for the
                            notification message. If specified, this value overrides all other
                            content for the message.

                          - **SilentPush** *(boolean) --*

                            Specifies whether the notification is a silent push notification, which
                            is a push notification that doesn't display on a recipient's device.
                            Silent push notifications can be used for cases such as updating an
                            app's configuration, displaying messages in an in-app message center, or
                            supporting phone home functionality.

                          - **TimeToLive** *(integer) --*

                            The number of seconds that the push-notification service should keep the
                            message, if the service is unable to deliver the notification the first
                            time. This value is converted to an expiration value when it's sent to a
                            push-notification service. If this value is 0, the service treats the
                            notification as if it expires immediately and the service doesn't store
                            or try to deliver the notification again.

                            This value doesn't apply to messages that are sent through the Amazon
                            Device Messaging (ADM) service.

                          - **Title** *(string) --*

                            The title to display above the notification message on a recipient's
                            device.

                          - **Url** *(string) --*

                            The URL to open in a recipient's default mobile browser, if a recipient
                            taps the push notification and the value of the Action property is URL.

                        - **EmailMessage** *(dict) --*

                          The message that the campaign sends through the email channel.

                          - **Body** *(string) --*

                            The body of the email for recipients whose email clients don't render
                            HTML content.

                          - **FromAddress** *(string) --*

                            The verified email address to send the email from. The default address
                            is the FromAddress specified for the email channel for the application.

                          - **HtmlBody** *(string) --*

                            The body of the email, in HTML format, for recipients whose email
                            clients render HTML content.

                          - **Title** *(string) --*

                            The subject line, or title, of the email.

                        - **GCMMessage** *(dict) --*

                          The message that the campaign sends through the GCM channel, which enables
                          Amazon Pinpoint to send push notifications through the Firebase Cloud
                          Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This
                          message overrides the default message.

                          - **Action** *(string) --*

                            The action to occur if a recipient taps the push notification. Valid
                            values are:

                            * OPEN_APP - Your app opens or it becomes the foreground app if it was
                            sent to the background. This is the default action.

                            * DEEP_LINK - Your app opens and displays a designated user interface in
                            the app. This setting uses the deep-linking features of iOS and Android.

                            * URL - The default mobile browser on the recipient's device opens and
                            loads the web page at a URL that you specify.

                          - **Body** *(string) --*

                            The body of the notification message. The maximum number of characters
                            is 200.

                          - **ImageIconUrl** *(string) --*

                            The URL of the image to display as the push-notification icon, such as
                            the icon for the app.

                          - **ImageSmallIconUrl** *(string) --*

                            The URL of the image to display as the small, push-notification icon,
                            such as a small version of the icon for the app.

                          - **ImageUrl** *(string) --*

                            The URL of an image to display in the push notification.

                          - **JsonBody** *(string) --*

                            The JSON payload to use for a silent push notification.

                          - **MediaUrl** *(string) --*

                            The URL of the image or video to display in the push notification.

                          - **RawContent** *(string) --*

                            The raw, JSON-formatted string to use as the payload for the
                            notification message. If specified, this value overrides all other
                            content for the message.

                          - **SilentPush** *(boolean) --*

                            Specifies whether the notification is a silent push notification, which
                            is a push notification that doesn't display on a recipient's device.
                            Silent push notifications can be used for cases such as updating an
                            app's configuration, displaying messages in an in-app message center, or
                            supporting phone home functionality.

                          - **TimeToLive** *(integer) --*

                            The number of seconds that the push-notification service should keep the
                            message, if the service is unable to deliver the notification the first
                            time. This value is converted to an expiration value when it's sent to a
                            push-notification service. If this value is 0, the service treats the
                            notification as if it expires immediately and the service doesn't store
                            or try to deliver the notification again.

                            This value doesn't apply to messages that are sent through the Amazon
                            Device Messaging (ADM) service.

                          - **Title** *(string) --*

                            The title to display above the notification message on a recipient's
                            device.

                          - **Url** *(string) --*

                            The URL to open in a recipient's default mobile browser, if a recipient
                            taps the push notification and the value of the Action property is URL.

                        - **SMSMessage** *(dict) --*

                          The message that the campaign sends through the SMS channel.

                          - **Body** *(string) --*

                            The body of the SMS message.

                          - **MessageType** *(string) --*

                            The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                            critical or time-sensitive, such as a one-time password that supports a
                            customer transaction; and, PROMOTIONAL, the message isn't critical or
                            time-sensitive, such as a marketing message.

                          - **SenderId** *(string) --*

                            The sender ID to display on recipients' devices when they receive the
                            SMS message.

                      - **Schedule** *(dict) --*

                        The schedule settings for the treatment.

                        - **EndTime** *(string) --*

                          The scheduled time, in ISO 8601 format, when the campaign ended or will
                          end.

                        - **EventFilter** *(dict) --*

                          The type of event that causes the campaign to be sent, if the value of the
                          Frequency property is EVENT.

                          - **Dimensions** *(dict) --*

                            The dimension settings of the event filter for the campaign.

                            - **Attributes** *(dict) --*

                              One or more custom attributes that your application reports to Amazon
                              Pinpoint. You can use these attributes as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies attribute-based criteria for including or excluding
                                  endpoints from a segment.

                                  - **AttributeType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the AttributeType property, endpoints are
                                    included or excluded from the segment if their attribute values
                                    match the criteria values.

                                    - *(string) --*

                            - **EventType** *(dict) --*

                              The name of the event that causes the campaign to be sent or the
                              journey activity to be performed. This can be a standard type of event
                              that Amazon Pinpoint generates, such as _email.delivered, or a custom
                              event that's specific to your application.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Metrics** *(dict) --*

                              One or more custom metrics that your application reports to Amazon
                              Pinpoint. You can use these metrics as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies metric-based criteria for including or excluding
                                  endpoints from a segment. These criteria derive from custom
                                  metrics that you define for endpoints.

                                  - **ComparisonOperator** *(string) --*

                                    The operator to use when comparing metric values. Valid values
                                    are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                    LESS_THAN_OR_EQUAL, and EQUAL.

                                  - **Value** *(float) --*

                                    The value to compare.

                          - **FilterType** *(string) --*

                            The type of event that causes the campaign to be sent. Valid values are:
                            SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT,
                            sends the campaign when an endpoint event (Events resource) occurs.

                        - **Frequency** *(string) --*

                          Specifies how often the campaign is sent or whether the campaign is sent
                          in response to a specific event.

                        - **IsLocalTime** *(boolean) --*

                          Specifies whether the start and end times for the campaign schedule use
                          each recipient's local time. To base the schedule on each recipient's
                          local time, set this value to true.

                        - **QuietTime** *(dict) --*

                          The default quiet time for the campaign. Quiet time is a specific time
                          range when a campaign doesn't send messages to endpoints, if all the
                          following conditions are met:

                          * The EndpointDemographic.Timezone property of the endpoint is set to a
                          valid value.

                          * The current time in the endpoint's time zone is later than or equal to
                          the time specified by the QuietTime.Start property for the campaign.

                          * The current time in the endpoint's time zone is earlier than or equal to
                          the time specified by the QuietTime.End property for the campaign.

                          If any of the preceding conditions isn't met, the endpoint will receive
                          messages from the campaign, even if quiet time is enabled.

                          - **End** *(string) --*

                            The specific time when quiet time ends. This value has to use 24-hour
                            notation and be in HH:MM format, where HH is the hour (with a leading
                            zero, if applicable) and MM is the minutes. For example, use 02:30 to
                            represent 2:30 AM, or 14:30 to represent 2:30 PM.

                          - **Start** *(string) --*

                            The specific time when quiet time begins. This value has to use 24-hour
                            notation and be in HH:MM format, where HH is the hour (with a leading
                            zero, if applicable) and MM is the minutes. For example, use 02:30 to
                            represent 2:30 AM, or 14:30 to represent 2:30 PM.

                        - **StartTime** *(string) --*

                          The scheduled time, in ISO 8601 format, when the campaign began or will
                          begin.

                        - **Timezone** *(string) --*

                          The starting UTC offset for the campaign schedule, if the value of the
                          IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02,
                          UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45,
                          UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30,
                          UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07,
                          UTC-08, UTC-09, UTC-10, and UTC-11.

                      - **SizePercent** *(integer) --*

                        The allocated percentage of users (segment members) that the treatment is
                        sent to.

                      - **State** *(dict) --*

                        The current status of the treatment.

                        - **CampaignStatus** *(string) --*

                          The current status of the campaign, or the current status of a treatment
                          that belongs to an A/B test campaign. If a campaign uses A/B testing, the
                          campaign has a status of COMPLETED only if all campaign treatments have a
                          status of COMPLETED.

                      - **TemplateConfiguration** *(dict) --*

                        The message template to use for the treatment.

                        - **EmailTemplate** *(dict) --*

                          The email template to use for the message.

                          - **Name** *(string) --*

                            The name of the message template to use for the message. If specified,
                            this value must match the name of an existing message template.

                        - **PushTemplate** *(dict) --*

                          The push notification template to use for the message.

                          - **Name** *(string) --*

                            The name of the message template to use for the message. If specified,
                            this value must match the name of an existing message template.

                        - **SMSTemplate** *(dict) --*

                          The SMS template to use for the message.

                          - **Name** *(string) --*

                            The name of the message template to use for the message. If specified,
                            this value must match the name of an existing message template.

                        - **VoiceTemplate** *(dict) --*

                          The voice template to use for the message.

                          - **Name** *(string) --*

                            The name of the message template to use for the message. If specified,
                            this value must match the name of an existing message template.

                      - **TreatmentDescription** *(string) --*

                        The custom description of the treatment.

                      - **TreatmentName** *(string) --*

                        The custom name of the treatment. A treatment is a variation of a campaign
                        that's used for A/B testing of a campaign.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that the campaign applies to.

                  - **Arn** *(string) --*

                    The Amazon Resource Name (ARN) of the campaign.

                  - **CreationDate** *(string) --*

                    The date, ISO 8601 format, when the campaign was created.

                  - **DefaultState** *(dict) --*

                    The current status of the campaign's default treatment. This value exists only
                    for campaigns that have more than one treatment, to support A/B testing.

                    - **CampaignStatus** *(string) --*

                      The current status of the campaign, or the current status of a treatment that
                      belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign
                      has a status of COMPLETED only if all campaign treatments have a status of
                      COMPLETED.

                  - **Description** *(string) --*

                    The custom description of the campaign.

                  - **HoldoutPercent** *(integer) --*

                    The allocated percentage of users (segment members) who shouldn't receive
                    messages from the campaign.

                  - **Hook** *(dict) --*

                    The settings for the AWS Lambda function to use as a code hook for the campaign.

                    - **LambdaFunctionName** *(string) --*

                      The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon
                      Pinpoint invokes to send messages for a campaign.

                    - **Mode** *(string) --*

                      Specifies which Lambda mode to use when invoking the AWS Lambda function.

                    - **WebUrl** *(string) --*

                      The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over
                      HTTPS.

                  - **Id** *(string) --*

                    The unique identifier for the campaign.

                  - **IsPaused** *(boolean) --*

                    Specifies whether the campaign is paused. A paused campaign doesn't run unless
                    you resume it by changing this value to false.

                  - **LastModifiedDate** *(string) --*

                    The date, in ISO 8601 format, when the campaign was last modified.

                  - **Limits** *(dict) --*

                    The messaging limits for the campaign.

                    - **Daily** *(integer) --*

                      The maximum number of messages that a campaign can send to a single endpoint
                      during a 24-hour period. The maximum value is 100.

                    - **MaximumDuration** *(integer) --*

                      The maximum amount of time, in seconds, that a campaign can attempt to deliver
                      a message after the scheduled start time for the campaign. The minimum value
                      is 60 seconds.

                    - **MessagesPerSecond** *(integer) --*

                      The maximum number of messages that a campaign can send each second. The
                      minimum value is 50. The maximum value is 20,000.

                    - **Total** *(integer) --*

                      The maximum number of messages that a campaign can send to a single endpoint
                      during the course of the campaign. The maximum value is 100.

                  - **MessageConfiguration** *(dict) --*

                    The message configuration settings for the campaign.

                    - **ADMMessage** *(dict) --*

                      The message that the campaign sends through the ADM (Amazon Device Messaging)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **APNSMessage** *(dict) --*

                      The message that the campaign sends through the APNs (Apple Push Notification
                      service) channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **BaiduMessage** *(dict) --*

                      The message that the campaign sends through the Baidu (Baidu Cloud Push)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **DefaultMessage** *(dict) --*

                      The default message that the campaign sends through all the channels that are
                      configured for the campaign.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **EmailMessage** *(dict) --*

                      The message that the campaign sends through the email channel.

                      - **Body** *(string) --*

                        The body of the email for recipients whose email clients don't render HTML
                        content.

                      - **FromAddress** *(string) --*

                        The verified email address to send the email from. The default address is
                        the FromAddress specified for the email channel for the application.

                      - **HtmlBody** *(string) --*

                        The body of the email, in HTML format, for recipients whose email clients
                        render HTML content.

                      - **Title** *(string) --*

                        The subject line, or title, of the email.

                    - **GCMMessage** *(dict) --*

                      The message that the campaign sends through the GCM channel, which enables
                      Amazon Pinpoint to send push notifications through the Firebase Cloud
                      Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message
                      overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **SMSMessage** *(dict) --*

                      The message that the campaign sends through the SMS channel.

                      - **Body** *(string) --*

                        The body of the SMS message.

                      - **MessageType** *(string) --*

                        The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                        critical or time-sensitive, such as a one-time password that supports a
                        customer transaction; and, PROMOTIONAL, the message isn't critical or
                        time-sensitive, such as a marketing message.

                      - **SenderId** *(string) --*

                        The sender ID to display on recipients' devices when they receive the SMS
                        message.

                  - **Name** *(string) --*

                    The name of the campaign.

                  - **Schedule** *(dict) --*

                    The schedule settings for the campaign.

                    - **EndTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                    - **EventFilter** *(dict) --*

                      The type of event that causes the campaign to be sent, if the value of the
                      Frequency property is EVENT.

                      - **Dimensions** *(dict) --*

                        The dimension settings of the event filter for the campaign.

                        - **Attributes** *(dict) --*

                          One or more custom attributes that your application reports to Amazon
                          Pinpoint. You can use these attributes as selection criteria when you
                          create an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **EventType** *(dict) --*

                          The name of the event that causes the campaign to be sent or the journey
                          activity to be performed. This can be a standard type of event that Amazon
                          Pinpoint generates, such as _email.delivered, or a custom event that's
                          specific to your application.

                          - **DimensionType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the DimensionType property, endpoints are included or excluded
                            from the segment if their values match the criteria values.

                            - *(string) --*

                        - **Metrics** *(dict) --*

                          One or more custom metrics that your application reports to Amazon
                          Pinpoint. You can use these metrics as selection criteria when you create
                          an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                      - **FilterType** *(string) --*

                        The type of event that causes the campaign to be sent. Valid values are:
                        SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends
                        the campaign when an endpoint event (Events resource) occurs.

                    - **Frequency** *(string) --*

                      Specifies how often the campaign is sent or whether the campaign is sent in
                      response to a specific event.

                    - **IsLocalTime** *(boolean) --*

                      Specifies whether the start and end times for the campaign schedule use each
                      recipient's local time. To base the schedule on each recipient's local time,
                      set this value to true.

                    - **QuietTime** *(dict) --*

                      The default quiet time for the campaign. Quiet time is a specific time range
                      when a campaign doesn't send messages to endpoints, if all the following
                      conditions are met:

                      * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                      value.

                      * The current time in the endpoint's time zone is later than or equal to the
                      time specified by the QuietTime.Start property for the campaign.

                      * The current time in the endpoint's time zone is earlier than or equal to the
                      time specified by the QuietTime.End property for the campaign.

                      If any of the preceding conditions isn't met, the endpoint will receive
                      messages from the campaign, even if quiet time is enabled.

                      - **End** *(string) --*

                        The specific time when quiet time ends. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                      - **Start** *(string) --*

                        The specific time when quiet time begins. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                    - **StartTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                    - **Timezone** *(string) --*

                      The starting UTC offset for the campaign schedule, if the value of the
                      IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                      UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                      UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13,
                      UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and
                      UTC-11.

                  - **SegmentId** *(string) --*

                    The unique identifier for the segment that's associated with the campaign.

                  - **SegmentVersion** *(integer) --*

                    The version number of the segment that's associated with the campaign.

                  - **State** *(dict) --*

                    The current status of the campaign.

                    - **CampaignStatus** *(string) --*

                      The current status of the campaign, or the current status of a treatment that
                      belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign
                      has a status of COMPLETED only if all campaign treatments have a status of
                      COMPLETED.

                  - **tags** *(dict) --*

                    A string-to-string map of key-value pairs that identifies the tags that are
                    associated with the campaign. Each tag consists of a required tag key and an
                    associated tag value.

                    - *(string) --*

                      - *(string) --*

                  - **TemplateConfiguration** *(dict) --*

                    The message template that’s used for the campaign.

                    - **EmailTemplate** *(dict) --*

                      The email template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **PushTemplate** *(dict) --*

                      The push notification template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **SMSTemplate** *(dict) --*

                      The SMS template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **VoiceTemplate** *(dict) --*

                      The voice template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                  - **TreatmentDescription** *(string) --*

                    The custom description of a variation of the campaign that's used for A/B
                    testing.

                  - **TreatmentName** *(string) --*

                    The custom name of a variation of the campaign that's used for A/B testing.

                  - **Version** *(integer) --*

                    The version number of the campaign.

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_campaigns(
        self, ApplicationId: str, PageSize: str = None, Token: str = None
    ) -> ClientGetCampaignsResponseTypeDef:
        """
        Retrieves information about the status, configuration, and other settings for all the
        campaigns that are associated with an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetCampaigns>`_

        **Request Syntax**
        ::

          response = client.get_campaigns(
              ApplicationId='string',
              PageSize='string',
              Token='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type Token: string
        :param Token:

          The NextToken string that specifies which page of results to return in a paginated
          response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CampaignsResponse': {
                    'Item': [
                        {
                            'AdditionalTreatments': [
                                {
                                    'Id': 'string',
                                    'MessageConfiguration': {
                                        'ADMMessage': {
                                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                            'Body': 'string',
                                            'ImageIconUrl': 'string',
                                            'ImageSmallIconUrl': 'string',
                                            'ImageUrl': 'string',
                                            'JsonBody': 'string',
                                            'MediaUrl': 'string',
                                            'RawContent': 'string',
                                            'SilentPush': True|False,
                                            'TimeToLive': 123,
                                            'Title': 'string',
                                            'Url': 'string'
                                        },
                                        'APNSMessage': {
                                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                            'Body': 'string',
                                            'ImageIconUrl': 'string',
                                            'ImageSmallIconUrl': 'string',
                                            'ImageUrl': 'string',
                                            'JsonBody': 'string',
                                            'MediaUrl': 'string',
                                            'RawContent': 'string',
                                            'SilentPush': True|False,
                                            'TimeToLive': 123,
                                            'Title': 'string',
                                            'Url': 'string'
                                        },
                                        'BaiduMessage': {
                                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                            'Body': 'string',
                                            'ImageIconUrl': 'string',
                                            'ImageSmallIconUrl': 'string',
                                            'ImageUrl': 'string',
                                            'JsonBody': 'string',
                                            'MediaUrl': 'string',
                                            'RawContent': 'string',
                                            'SilentPush': True|False,
                                            'TimeToLive': 123,
                                            'Title': 'string',
                                            'Url': 'string'
                                        },
                                        'DefaultMessage': {
                                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                            'Body': 'string',
                                            'ImageIconUrl': 'string',
                                            'ImageSmallIconUrl': 'string',
                                            'ImageUrl': 'string',
                                            'JsonBody': 'string',
                                            'MediaUrl': 'string',
                                            'RawContent': 'string',
                                            'SilentPush': True|False,
                                            'TimeToLive': 123,
                                            'Title': 'string',
                                            'Url': 'string'
                                        },
                                        'EmailMessage': {
                                            'Body': 'string',
                                            'FromAddress': 'string',
                                            'HtmlBody': 'string',
                                            'Title': 'string'
                                        },
                                        'GCMMessage': {
                                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                            'Body': 'string',
                                            'ImageIconUrl': 'string',
                                            'ImageSmallIconUrl': 'string',
                                            'ImageUrl': 'string',
                                            'JsonBody': 'string',
                                            'MediaUrl': 'string',
                                            'RawContent': 'string',
                                            'SilentPush': True|False,
                                            'TimeToLive': 123,
                                            'Title': 'string',
                                            'Url': 'string'
                                        },
                                        'SMSMessage': {
                                            'Body': 'string',
                                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                            'SenderId': 'string'
                                        }
                                    },
                                    'Schedule': {
                                        'EndTime': 'string',
                                        'EventFilter': {
                                            'Dimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'EventType': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                }
                                            },
                                            'FilterType': 'SYSTEM'|'ENDPOINT'
                                        },
                                        'Frequency':
                                        'ONCE'|'HOURLY'|'DAILY'
                                        |'WEEKLY'|'MONTHLY'|'EVENT',
                                        'IsLocalTime': True|False,
                                        'QuietTime': {
                                            'End': 'string',
                                            'Start': 'string'
                                        },
                                        'StartTime': 'string',
                                        'Timezone': 'string'
                                    },
                                    'SizePercent': 123,
                                    'State': {
                                        'CampaignStatus':
                                        'SCHEDULED'|'EXECUTING'
                                        |'PENDING_NEXT_RUN'
                                        |'COMPLETED'|'PAUSED'
                                        |'DELETED'
                                    },
                                    'TemplateConfiguration': {
                                        'EmailTemplate': {
                                            'Name': 'string'
                                        },
                                        'PushTemplate': {
                                            'Name': 'string'
                                        },
                                        'SMSTemplate': {
                                            'Name': 'string'
                                        },
                                        'VoiceTemplate': {
                                            'Name': 'string'
                                        }
                                    },
                                    'TreatmentDescription': 'string',
                                    'TreatmentName': 'string'
                                },
                            ],
                            'ApplicationId': 'string',
                            'Arn': 'string',
                            'CreationDate': 'string',
                            'DefaultState': {
                                'CampaignStatus':
                                'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'
                                |'COMPLETED'|'PAUSED'|'DELETED'
                            },
                            'Description': 'string',
                            'HoldoutPercent': 123,
                            'Hook': {
                                'LambdaFunctionName': 'string',
                                'Mode': 'DELIVERY'|'FILTER',
                                'WebUrl': 'string'
                            },
                            'Id': 'string',
                            'IsPaused': True|False,
                            'LastModifiedDate': 'string',
                            'Limits': {
                                'Daily': 123,
                                'MaximumDuration': 123,
                                'MessagesPerSecond': 123,
                                'Total': 123
                            },
                            'MessageConfiguration': {
                                'ADMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'APNSMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'BaiduMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'DefaultMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'EmailMessage': {
                                    'Body': 'string',
                                    'FromAddress': 'string',
                                    'HtmlBody': 'string',
                                    'Title': 'string'
                                },
                                'GCMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'SMSMessage': {
                                    'Body': 'string',
                                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                    'SenderId': 'string'
                                }
                            },
                            'Name': 'string',
                            'Schedule': {
                                'EndTime': 'string',
                                'EventFilter': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'FilterType': 'SYSTEM'|'ENDPOINT'
                                },
                                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                                'IsLocalTime': True|False,
                                'QuietTime': {
                                    'End': 'string',
                                    'Start': 'string'
                                },
                                'StartTime': 'string',
                                'Timezone': 'string'
                            },
                            'SegmentId': 'string',
                            'SegmentVersion': 123,
                            'State': {
                                'CampaignStatus':
                                'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'
                                |'COMPLETED'|'PAUSED'|'DELETED'
                            },
                            'tags': {
                                'string': 'string'
                            },
                            'TemplateConfiguration': {
                                'EmailTemplate': {
                                    'Name': 'string'
                                },
                                'PushTemplate': {
                                    'Name': 'string'
                                },
                                'SMSTemplate': {
                                    'Name': 'string'
                                },
                                'VoiceTemplate': {
                                    'Name': 'string'
                                }
                            },
                            'TreatmentDescription': 'string',
                            'TreatmentName': 'string',
                            'Version': 123
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **CampaignsResponse** *(dict) --*

              Provides information about the configuration and other settings for all the campaigns
              that are associated with an application.

              - **Item** *(list) --*

                An array of responses, one for each campaign that's associated with the application.

                - *(dict) --*

                  Provides information about the status, configuration, and other settings for a
                  campaign.

                  - **AdditionalTreatments** *(list) --*

                    An array of responses, one for each treatment that you defined for the campaign,
                    in addition to the default treatment.

                    - *(dict) --*

                      Specifies the settings for a campaign treatment. A treatment is a variation of
                      a campaign that's used for A/B testing of a campaign.

                      - **Id** *(string) --*

                        The unique identifier for the treatment.

                      - **MessageConfiguration** *(dict) --*

                        The message configuration settings for the treatment.

                        - **ADMMessage** *(dict) --*

                          The message that the campaign sends through the ADM (Amazon Device
                          Messaging) channel. This message overrides the default message.

                          - **Action** *(string) --*

                            The action to occur if a recipient taps the push notification. Valid
                            values are:

                            * OPEN_APP - Your app opens or it becomes the foreground app if it was
                            sent to the background. This is the default action.

                            * DEEP_LINK - Your app opens and displays a designated user interface in
                            the app. This setting uses the deep-linking features of iOS and Android.

                            * URL - The default mobile browser on the recipient's device opens and
                            loads the web page at a URL that you specify.

                          - **Body** *(string) --*

                            The body of the notification message. The maximum number of characters
                            is 200.

                          - **ImageIconUrl** *(string) --*

                            The URL of the image to display as the push-notification icon, such as
                            the icon for the app.

                          - **ImageSmallIconUrl** *(string) --*

                            The URL of the image to display as the small, push-notification icon,
                            such as a small version of the icon for the app.

                          - **ImageUrl** *(string) --*

                            The URL of an image to display in the push notification.

                          - **JsonBody** *(string) --*

                            The JSON payload to use for a silent push notification.

                          - **MediaUrl** *(string) --*

                            The URL of the image or video to display in the push notification.

                          - **RawContent** *(string) --*

                            The raw, JSON-formatted string to use as the payload for the
                            notification message. If specified, this value overrides all other
                            content for the message.

                          - **SilentPush** *(boolean) --*

                            Specifies whether the notification is a silent push notification, which
                            is a push notification that doesn't display on a recipient's device.
                            Silent push notifications can be used for cases such as updating an
                            app's configuration, displaying messages in an in-app message center, or
                            supporting phone home functionality.

                          - **TimeToLive** *(integer) --*

                            The number of seconds that the push-notification service should keep the
                            message, if the service is unable to deliver the notification the first
                            time. This value is converted to an expiration value when it's sent to a
                            push-notification service. If this value is 0, the service treats the
                            notification as if it expires immediately and the service doesn't store
                            or try to deliver the notification again.

                            This value doesn't apply to messages that are sent through the Amazon
                            Device Messaging (ADM) service.

                          - **Title** *(string) --*

                            The title to display above the notification message on a recipient's
                            device.

                          - **Url** *(string) --*

                            The URL to open in a recipient's default mobile browser, if a recipient
                            taps the push notification and the value of the Action property is URL.

                        - **APNSMessage** *(dict) --*

                          The message that the campaign sends through the APNs (Apple Push
                          Notification service) channel. This message overrides the default message.

                          - **Action** *(string) --*

                            The action to occur if a recipient taps the push notification. Valid
                            values are:

                            * OPEN_APP - Your app opens or it becomes the foreground app if it was
                            sent to the background. This is the default action.

                            * DEEP_LINK - Your app opens and displays a designated user interface in
                            the app. This setting uses the deep-linking features of iOS and Android.

                            * URL - The default mobile browser on the recipient's device opens and
                            loads the web page at a URL that you specify.

                          - **Body** *(string) --*

                            The body of the notification message. The maximum number of characters
                            is 200.

                          - **ImageIconUrl** *(string) --*

                            The URL of the image to display as the push-notification icon, such as
                            the icon for the app.

                          - **ImageSmallIconUrl** *(string) --*

                            The URL of the image to display as the small, push-notification icon,
                            such as a small version of the icon for the app.

                          - **ImageUrl** *(string) --*

                            The URL of an image to display in the push notification.

                          - **JsonBody** *(string) --*

                            The JSON payload to use for a silent push notification.

                          - **MediaUrl** *(string) --*

                            The URL of the image or video to display in the push notification.

                          - **RawContent** *(string) --*

                            The raw, JSON-formatted string to use as the payload for the
                            notification message. If specified, this value overrides all other
                            content for the message.

                          - **SilentPush** *(boolean) --*

                            Specifies whether the notification is a silent push notification, which
                            is a push notification that doesn't display on a recipient's device.
                            Silent push notifications can be used for cases such as updating an
                            app's configuration, displaying messages in an in-app message center, or
                            supporting phone home functionality.

                          - **TimeToLive** *(integer) --*

                            The number of seconds that the push-notification service should keep the
                            message, if the service is unable to deliver the notification the first
                            time. This value is converted to an expiration value when it's sent to a
                            push-notification service. If this value is 0, the service treats the
                            notification as if it expires immediately and the service doesn't store
                            or try to deliver the notification again.

                            This value doesn't apply to messages that are sent through the Amazon
                            Device Messaging (ADM) service.

                          - **Title** *(string) --*

                            The title to display above the notification message on a recipient's
                            device.

                          - **Url** *(string) --*

                            The URL to open in a recipient's default mobile browser, if a recipient
                            taps the push notification and the value of the Action property is URL.

                        - **BaiduMessage** *(dict) --*

                          The message that the campaign sends through the Baidu (Baidu Cloud Push)
                          channel. This message overrides the default message.

                          - **Action** *(string) --*

                            The action to occur if a recipient taps the push notification. Valid
                            values are:

                            * OPEN_APP - Your app opens or it becomes the foreground app if it was
                            sent to the background. This is the default action.

                            * DEEP_LINK - Your app opens and displays a designated user interface in
                            the app. This setting uses the deep-linking features of iOS and Android.

                            * URL - The default mobile browser on the recipient's device opens and
                            loads the web page at a URL that you specify.

                          - **Body** *(string) --*

                            The body of the notification message. The maximum number of characters
                            is 200.

                          - **ImageIconUrl** *(string) --*

                            The URL of the image to display as the push-notification icon, such as
                            the icon for the app.

                          - **ImageSmallIconUrl** *(string) --*

                            The URL of the image to display as the small, push-notification icon,
                            such as a small version of the icon for the app.

                          - **ImageUrl** *(string) --*

                            The URL of an image to display in the push notification.

                          - **JsonBody** *(string) --*

                            The JSON payload to use for a silent push notification.

                          - **MediaUrl** *(string) --*

                            The URL of the image or video to display in the push notification.

                          - **RawContent** *(string) --*

                            The raw, JSON-formatted string to use as the payload for the
                            notification message. If specified, this value overrides all other
                            content for the message.

                          - **SilentPush** *(boolean) --*

                            Specifies whether the notification is a silent push notification, which
                            is a push notification that doesn't display on a recipient's device.
                            Silent push notifications can be used for cases such as updating an
                            app's configuration, displaying messages in an in-app message center, or
                            supporting phone home functionality.

                          - **TimeToLive** *(integer) --*

                            The number of seconds that the push-notification service should keep the
                            message, if the service is unable to deliver the notification the first
                            time. This value is converted to an expiration value when it's sent to a
                            push-notification service. If this value is 0, the service treats the
                            notification as if it expires immediately and the service doesn't store
                            or try to deliver the notification again.

                            This value doesn't apply to messages that are sent through the Amazon
                            Device Messaging (ADM) service.

                          - **Title** *(string) --*

                            The title to display above the notification message on a recipient's
                            device.

                          - **Url** *(string) --*

                            The URL to open in a recipient's default mobile browser, if a recipient
                            taps the push notification and the value of the Action property is URL.

                        - **DefaultMessage** *(dict) --*

                          The default message that the campaign sends through all the channels that
                          are configured for the campaign.

                          - **Action** *(string) --*

                            The action to occur if a recipient taps the push notification. Valid
                            values are:

                            * OPEN_APP - Your app opens or it becomes the foreground app if it was
                            sent to the background. This is the default action.

                            * DEEP_LINK - Your app opens and displays a designated user interface in
                            the app. This setting uses the deep-linking features of iOS and Android.

                            * URL - The default mobile browser on the recipient's device opens and
                            loads the web page at a URL that you specify.

                          - **Body** *(string) --*

                            The body of the notification message. The maximum number of characters
                            is 200.

                          - **ImageIconUrl** *(string) --*

                            The URL of the image to display as the push-notification icon, such as
                            the icon for the app.

                          - **ImageSmallIconUrl** *(string) --*

                            The URL of the image to display as the small, push-notification icon,
                            such as a small version of the icon for the app.

                          - **ImageUrl** *(string) --*

                            The URL of an image to display in the push notification.

                          - **JsonBody** *(string) --*

                            The JSON payload to use for a silent push notification.

                          - **MediaUrl** *(string) --*

                            The URL of the image or video to display in the push notification.

                          - **RawContent** *(string) --*

                            The raw, JSON-formatted string to use as the payload for the
                            notification message. If specified, this value overrides all other
                            content for the message.

                          - **SilentPush** *(boolean) --*

                            Specifies whether the notification is a silent push notification, which
                            is a push notification that doesn't display on a recipient's device.
                            Silent push notifications can be used for cases such as updating an
                            app's configuration, displaying messages in an in-app message center, or
                            supporting phone home functionality.

                          - **TimeToLive** *(integer) --*

                            The number of seconds that the push-notification service should keep the
                            message, if the service is unable to deliver the notification the first
                            time. This value is converted to an expiration value when it's sent to a
                            push-notification service. If this value is 0, the service treats the
                            notification as if it expires immediately and the service doesn't store
                            or try to deliver the notification again.

                            This value doesn't apply to messages that are sent through the Amazon
                            Device Messaging (ADM) service.

                          - **Title** *(string) --*

                            The title to display above the notification message on a recipient's
                            device.

                          - **Url** *(string) --*

                            The URL to open in a recipient's default mobile browser, if a recipient
                            taps the push notification and the value of the Action property is URL.

                        - **EmailMessage** *(dict) --*

                          The message that the campaign sends through the email channel.

                          - **Body** *(string) --*

                            The body of the email for recipients whose email clients don't render
                            HTML content.

                          - **FromAddress** *(string) --*

                            The verified email address to send the email from. The default address
                            is the FromAddress specified for the email channel for the application.

                          - **HtmlBody** *(string) --*

                            The body of the email, in HTML format, for recipients whose email
                            clients render HTML content.

                          - **Title** *(string) --*

                            The subject line, or title, of the email.

                        - **GCMMessage** *(dict) --*

                          The message that the campaign sends through the GCM channel, which enables
                          Amazon Pinpoint to send push notifications through the Firebase Cloud
                          Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This
                          message overrides the default message.

                          - **Action** *(string) --*

                            The action to occur if a recipient taps the push notification. Valid
                            values are:

                            * OPEN_APP - Your app opens or it becomes the foreground app if it was
                            sent to the background. This is the default action.

                            * DEEP_LINK - Your app opens and displays a designated user interface in
                            the app. This setting uses the deep-linking features of iOS and Android.

                            * URL - The default mobile browser on the recipient's device opens and
                            loads the web page at a URL that you specify.

                          - **Body** *(string) --*

                            The body of the notification message. The maximum number of characters
                            is 200.

                          - **ImageIconUrl** *(string) --*

                            The URL of the image to display as the push-notification icon, such as
                            the icon for the app.

                          - **ImageSmallIconUrl** *(string) --*

                            The URL of the image to display as the small, push-notification icon,
                            such as a small version of the icon for the app.

                          - **ImageUrl** *(string) --*

                            The URL of an image to display in the push notification.

                          - **JsonBody** *(string) --*

                            The JSON payload to use for a silent push notification.

                          - **MediaUrl** *(string) --*

                            The URL of the image or video to display in the push notification.

                          - **RawContent** *(string) --*

                            The raw, JSON-formatted string to use as the payload for the
                            notification message. If specified, this value overrides all other
                            content for the message.

                          - **SilentPush** *(boolean) --*

                            Specifies whether the notification is a silent push notification, which
                            is a push notification that doesn't display on a recipient's device.
                            Silent push notifications can be used for cases such as updating an
                            app's configuration, displaying messages in an in-app message center, or
                            supporting phone home functionality.

                          - **TimeToLive** *(integer) --*

                            The number of seconds that the push-notification service should keep the
                            message, if the service is unable to deliver the notification the first
                            time. This value is converted to an expiration value when it's sent to a
                            push-notification service. If this value is 0, the service treats the
                            notification as if it expires immediately and the service doesn't store
                            or try to deliver the notification again.

                            This value doesn't apply to messages that are sent through the Amazon
                            Device Messaging (ADM) service.

                          - **Title** *(string) --*

                            The title to display above the notification message on a recipient's
                            device.

                          - **Url** *(string) --*

                            The URL to open in a recipient's default mobile browser, if a recipient
                            taps the push notification and the value of the Action property is URL.

                        - **SMSMessage** *(dict) --*

                          The message that the campaign sends through the SMS channel.

                          - **Body** *(string) --*

                            The body of the SMS message.

                          - **MessageType** *(string) --*

                            The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                            critical or time-sensitive, such as a one-time password that supports a
                            customer transaction; and, PROMOTIONAL, the message isn't critical or
                            time-sensitive, such as a marketing message.

                          - **SenderId** *(string) --*

                            The sender ID to display on recipients' devices when they receive the
                            SMS message.

                      - **Schedule** *(dict) --*

                        The schedule settings for the treatment.

                        - **EndTime** *(string) --*

                          The scheduled time, in ISO 8601 format, when the campaign ended or will
                          end.

                        - **EventFilter** *(dict) --*

                          The type of event that causes the campaign to be sent, if the value of the
                          Frequency property is EVENT.

                          - **Dimensions** *(dict) --*

                            The dimension settings of the event filter for the campaign.

                            - **Attributes** *(dict) --*

                              One or more custom attributes that your application reports to Amazon
                              Pinpoint. You can use these attributes as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies attribute-based criteria for including or excluding
                                  endpoints from a segment.

                                  - **AttributeType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the AttributeType property, endpoints are
                                    included or excluded from the segment if their attribute values
                                    match the criteria values.

                                    - *(string) --*

                            - **EventType** *(dict) --*

                              The name of the event that causes the campaign to be sent or the
                              journey activity to be performed. This can be a standard type of event
                              that Amazon Pinpoint generates, such as _email.delivered, or a custom
                              event that's specific to your application.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Metrics** *(dict) --*

                              One or more custom metrics that your application reports to Amazon
                              Pinpoint. You can use these metrics as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies metric-based criteria for including or excluding
                                  endpoints from a segment. These criteria derive from custom
                                  metrics that you define for endpoints.

                                  - **ComparisonOperator** *(string) --*

                                    The operator to use when comparing metric values. Valid values
                                    are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                    LESS_THAN_OR_EQUAL, and EQUAL.

                                  - **Value** *(float) --*

                                    The value to compare.

                          - **FilterType** *(string) --*

                            The type of event that causes the campaign to be sent. Valid values are:
                            SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT,
                            sends the campaign when an endpoint event (Events resource) occurs.

                        - **Frequency** *(string) --*

                          Specifies how often the campaign is sent or whether the campaign is sent
                          in response to a specific event.

                        - **IsLocalTime** *(boolean) --*

                          Specifies whether the start and end times for the campaign schedule use
                          each recipient's local time. To base the schedule on each recipient's
                          local time, set this value to true.

                        - **QuietTime** *(dict) --*

                          The default quiet time for the campaign. Quiet time is a specific time
                          range when a campaign doesn't send messages to endpoints, if all the
                          following conditions are met:

                          * The EndpointDemographic.Timezone property of the endpoint is set to a
                          valid value.

                          * The current time in the endpoint's time zone is later than or equal to
                          the time specified by the QuietTime.Start property for the campaign.

                          * The current time in the endpoint's time zone is earlier than or equal to
                          the time specified by the QuietTime.End property for the campaign.

                          If any of the preceding conditions isn't met, the endpoint will receive
                          messages from the campaign, even if quiet time is enabled.

                          - **End** *(string) --*

                            The specific time when quiet time ends. This value has to use 24-hour
                            notation and be in HH:MM format, where HH is the hour (with a leading
                            zero, if applicable) and MM is the minutes. For example, use 02:30 to
                            represent 2:30 AM, or 14:30 to represent 2:30 PM.

                          - **Start** *(string) --*

                            The specific time when quiet time begins. This value has to use 24-hour
                            notation and be in HH:MM format, where HH is the hour (with a leading
                            zero, if applicable) and MM is the minutes. For example, use 02:30 to
                            represent 2:30 AM, or 14:30 to represent 2:30 PM.

                        - **StartTime** *(string) --*

                          The scheduled time, in ISO 8601 format, when the campaign began or will
                          begin.

                        - **Timezone** *(string) --*

                          The starting UTC offset for the campaign schedule, if the value of the
                          IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02,
                          UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45,
                          UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30,
                          UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07,
                          UTC-08, UTC-09, UTC-10, and UTC-11.

                      - **SizePercent** *(integer) --*

                        The allocated percentage of users (segment members) that the treatment is
                        sent to.

                      - **State** *(dict) --*

                        The current status of the treatment.

                        - **CampaignStatus** *(string) --*

                          The current status of the campaign, or the current status of a treatment
                          that belongs to an A/B test campaign. If a campaign uses A/B testing, the
                          campaign has a status of COMPLETED only if all campaign treatments have a
                          status of COMPLETED.

                      - **TemplateConfiguration** *(dict) --*

                        The message template to use for the treatment.

                        - **EmailTemplate** *(dict) --*

                          The email template to use for the message.

                          - **Name** *(string) --*

                            The name of the message template to use for the message. If specified,
                            this value must match the name of an existing message template.

                        - **PushTemplate** *(dict) --*

                          The push notification template to use for the message.

                          - **Name** *(string) --*

                            The name of the message template to use for the message. If specified,
                            this value must match the name of an existing message template.

                        - **SMSTemplate** *(dict) --*

                          The SMS template to use for the message.

                          - **Name** *(string) --*

                            The name of the message template to use for the message. If specified,
                            this value must match the name of an existing message template.

                        - **VoiceTemplate** *(dict) --*

                          The voice template to use for the message.

                          - **Name** *(string) --*

                            The name of the message template to use for the message. If specified,
                            this value must match the name of an existing message template.

                      - **TreatmentDescription** *(string) --*

                        The custom description of the treatment.

                      - **TreatmentName** *(string) --*

                        The custom name of the treatment. A treatment is a variation of a campaign
                        that's used for A/B testing of a campaign.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that the campaign applies to.

                  - **Arn** *(string) --*

                    The Amazon Resource Name (ARN) of the campaign.

                  - **CreationDate** *(string) --*

                    The date, ISO 8601 format, when the campaign was created.

                  - **DefaultState** *(dict) --*

                    The current status of the campaign's default treatment. This value exists only
                    for campaigns that have more than one treatment, to support A/B testing.

                    - **CampaignStatus** *(string) --*

                      The current status of the campaign, or the current status of a treatment that
                      belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign
                      has a status of COMPLETED only if all campaign treatments have a status of
                      COMPLETED.

                  - **Description** *(string) --*

                    The custom description of the campaign.

                  - **HoldoutPercent** *(integer) --*

                    The allocated percentage of users (segment members) who shouldn't receive
                    messages from the campaign.

                  - **Hook** *(dict) --*

                    The settings for the AWS Lambda function to use as a code hook for the campaign.

                    - **LambdaFunctionName** *(string) --*

                      The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon
                      Pinpoint invokes to send messages for a campaign.

                    - **Mode** *(string) --*

                      Specifies which Lambda mode to use when invoking the AWS Lambda function.

                    - **WebUrl** *(string) --*

                      The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over
                      HTTPS.

                  - **Id** *(string) --*

                    The unique identifier for the campaign.

                  - **IsPaused** *(boolean) --*

                    Specifies whether the campaign is paused. A paused campaign doesn't run unless
                    you resume it by changing this value to false.

                  - **LastModifiedDate** *(string) --*

                    The date, in ISO 8601 format, when the campaign was last modified.

                  - **Limits** *(dict) --*

                    The messaging limits for the campaign.

                    - **Daily** *(integer) --*

                      The maximum number of messages that a campaign can send to a single endpoint
                      during a 24-hour period. The maximum value is 100.

                    - **MaximumDuration** *(integer) --*

                      The maximum amount of time, in seconds, that a campaign can attempt to deliver
                      a message after the scheduled start time for the campaign. The minimum value
                      is 60 seconds.

                    - **MessagesPerSecond** *(integer) --*

                      The maximum number of messages that a campaign can send each second. The
                      minimum value is 50. The maximum value is 20,000.

                    - **Total** *(integer) --*

                      The maximum number of messages that a campaign can send to a single endpoint
                      during the course of the campaign. The maximum value is 100.

                  - **MessageConfiguration** *(dict) --*

                    The message configuration settings for the campaign.

                    - **ADMMessage** *(dict) --*

                      The message that the campaign sends through the ADM (Amazon Device Messaging)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **APNSMessage** *(dict) --*

                      The message that the campaign sends through the APNs (Apple Push Notification
                      service) channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **BaiduMessage** *(dict) --*

                      The message that the campaign sends through the Baidu (Baidu Cloud Push)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **DefaultMessage** *(dict) --*

                      The default message that the campaign sends through all the channels that are
                      configured for the campaign.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **EmailMessage** *(dict) --*

                      The message that the campaign sends through the email channel.

                      - **Body** *(string) --*

                        The body of the email for recipients whose email clients don't render HTML
                        content.

                      - **FromAddress** *(string) --*

                        The verified email address to send the email from. The default address is
                        the FromAddress specified for the email channel for the application.

                      - **HtmlBody** *(string) --*

                        The body of the email, in HTML format, for recipients whose email clients
                        render HTML content.

                      - **Title** *(string) --*

                        The subject line, or title, of the email.

                    - **GCMMessage** *(dict) --*

                      The message that the campaign sends through the GCM channel, which enables
                      Amazon Pinpoint to send push notifications through the Firebase Cloud
                      Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message
                      overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **SMSMessage** *(dict) --*

                      The message that the campaign sends through the SMS channel.

                      - **Body** *(string) --*

                        The body of the SMS message.

                      - **MessageType** *(string) --*

                        The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                        critical or time-sensitive, such as a one-time password that supports a
                        customer transaction; and, PROMOTIONAL, the message isn't critical or
                        time-sensitive, such as a marketing message.

                      - **SenderId** *(string) --*

                        The sender ID to display on recipients' devices when they receive the SMS
                        message.

                  - **Name** *(string) --*

                    The name of the campaign.

                  - **Schedule** *(dict) --*

                    The schedule settings for the campaign.

                    - **EndTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                    - **EventFilter** *(dict) --*

                      The type of event that causes the campaign to be sent, if the value of the
                      Frequency property is EVENT.

                      - **Dimensions** *(dict) --*

                        The dimension settings of the event filter for the campaign.

                        - **Attributes** *(dict) --*

                          One or more custom attributes that your application reports to Amazon
                          Pinpoint. You can use these attributes as selection criteria when you
                          create an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **EventType** *(dict) --*

                          The name of the event that causes the campaign to be sent or the journey
                          activity to be performed. This can be a standard type of event that Amazon
                          Pinpoint generates, such as _email.delivered, or a custom event that's
                          specific to your application.

                          - **DimensionType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the DimensionType property, endpoints are included or excluded
                            from the segment if their values match the criteria values.

                            - *(string) --*

                        - **Metrics** *(dict) --*

                          One or more custom metrics that your application reports to Amazon
                          Pinpoint. You can use these metrics as selection criteria when you create
                          an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                      - **FilterType** *(string) --*

                        The type of event that causes the campaign to be sent. Valid values are:
                        SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends
                        the campaign when an endpoint event (Events resource) occurs.

                    - **Frequency** *(string) --*

                      Specifies how often the campaign is sent or whether the campaign is sent in
                      response to a specific event.

                    - **IsLocalTime** *(boolean) --*

                      Specifies whether the start and end times for the campaign schedule use each
                      recipient's local time. To base the schedule on each recipient's local time,
                      set this value to true.

                    - **QuietTime** *(dict) --*

                      The default quiet time for the campaign. Quiet time is a specific time range
                      when a campaign doesn't send messages to endpoints, if all the following
                      conditions are met:

                      * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                      value.

                      * The current time in the endpoint's time zone is later than or equal to the
                      time specified by the QuietTime.Start property for the campaign.

                      * The current time in the endpoint's time zone is earlier than or equal to the
                      time specified by the QuietTime.End property for the campaign.

                      If any of the preceding conditions isn't met, the endpoint will receive
                      messages from the campaign, even if quiet time is enabled.

                      - **End** *(string) --*

                        The specific time when quiet time ends. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                      - **Start** *(string) --*

                        The specific time when quiet time begins. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                    - **StartTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                    - **Timezone** *(string) --*

                      The starting UTC offset for the campaign schedule, if the value of the
                      IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                      UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                      UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13,
                      UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and
                      UTC-11.

                  - **SegmentId** *(string) --*

                    The unique identifier for the segment that's associated with the campaign.

                  - **SegmentVersion** *(integer) --*

                    The version number of the segment that's associated with the campaign.

                  - **State** *(dict) --*

                    The current status of the campaign.

                    - **CampaignStatus** *(string) --*

                      The current status of the campaign, or the current status of a treatment that
                      belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign
                      has a status of COMPLETED only if all campaign treatments have a status of
                      COMPLETED.

                  - **tags** *(dict) --*

                    A string-to-string map of key-value pairs that identifies the tags that are
                    associated with the campaign. Each tag consists of a required tag key and an
                    associated tag value.

                    - *(string) --*

                      - *(string) --*

                  - **TemplateConfiguration** *(dict) --*

                    The message template that’s used for the campaign.

                    - **EmailTemplate** *(dict) --*

                      The email template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **PushTemplate** *(dict) --*

                      The push notification template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **SMSTemplate** *(dict) --*

                      The SMS template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **VoiceTemplate** *(dict) --*

                      The voice template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                  - **TreatmentDescription** *(string) --*

                    The custom description of a variation of the campaign that's used for A/B
                    testing.

                  - **TreatmentName** *(string) --*

                    The custom name of a variation of the campaign that's used for A/B testing.

                  - **Version** *(integer) --*

                    The version number of the campaign.

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_channels(self, ApplicationId: str) -> ClientGetChannelsResponseTypeDef:
        """
        Retrieves information about the history and status of each channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetChannels>`_

        **Request Syntax**
        ::

          response = client.get_channels(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ChannelsResponse': {
                    'Channels': {
                        'string': {
                            'ApplicationId': 'string',
                            'CreationDate': 'string',
                            'Enabled': True|False,
                            'HasCredential': True|False,
                            'Id': 'string',
                            'IsArchived': True|False,
                            'LastModifiedBy': 'string',
                            'LastModifiedDate': 'string',
                            'Version': 123
                        }
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ChannelsResponse** *(dict) --*

              Provides information about the general settings and status of all channels for an
              application, including channels that aren't enabled for the application.

              - **Channels** *(dict) --*

                A map that contains a multipart response for each channel. For each item in this
                object, the ChannelType is the key and the Channel is the value.

                - *(string) --*

                  - *(dict) --*

                    Provides information about the general settings and status of a channel for an
                    application.

                    - **ApplicationId** *(string) --*

                      The unique identifier for the application.

                    - **CreationDate** *(string) --*

                      The date and time, in ISO 8601 format, when the channel was enabled.

                    - **Enabled** *(boolean) --*

                      Specifies whether the channel is enabled for the application.

                    - **HasCredential** *(boolean) --*

                      (Not used) This property is retained only for backward compatibility.

                    - **Id** *(string) --*

                      (Deprecated) An identifier for the channel. This property is retained only for
                      backward compatibility.

                    - **IsArchived** *(boolean) --*

                      Specifies whether the channel is archived.

                    - **LastModifiedBy** *(string) --*

                      The user who last modified the channel.

                    - **LastModifiedDate** *(string) --*

                      The date and time, in ISO 8601 format, when the channel was last modified.

                    - **Version** *(integer) --*

                      The current version of the channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_email_channel(self, ApplicationId: str) -> ClientGetEmailChannelResponseTypeDef:
        """
        Retrieves information about the status and settings of the email channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetEmailChannel>`_

        **Request Syntax**
        ::

          response = client.get_email_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EmailChannelResponse': {
                    'ApplicationId': 'string',
                    'ConfigurationSet': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'FromAddress': 'string',
                    'HasCredential': True|False,
                    'Id': 'string',
                    'Identity': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'MessagesPerSecond': 123,
                    'Platform': 'string',
                    'RoleArn': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **EmailChannelResponse** *(dict) --*

              Provides information about the status and settings of the email channel for an
              application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the email channel applies to.

              - **ConfigurationSet** *(string) --*

                The configuration set that's applied to email that's sent through the channel by
                using the `Amazon Pinpoint Email API <emailAPIreference.html>`__ .

              - **CreationDate** *(string) --*

                The date and time, in ISO 8601 format, when the email channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the email channel is enabled for the application.

              - **FromAddress** *(string) --*

                The verified email address that you send email from when you send email through the
                channel.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the email channel. This property is retained only for
                backward compatibility.

              - **Identity** *(string) --*

                The Amazon Resource Name (ARN) of the identity, verified with Amazon Simple Email
                Service (Amazon SES), that you use when you send email through the channel.

              - **IsArchived** *(boolean) --*

                Specifies whether the email channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the email channel.

              - **LastModifiedDate** *(string) --*

                The date and time, in ISO 8601 format, when the email channel was last modified.

              - **MessagesPerSecond** *(integer) --*

                The maximum number of emails that you can send through the channel each second.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the email
                channel, this value is EMAIL.

              - **RoleArn** *(string) --*

                The ARN of the AWS Identity and Access Management (IAM) role that Amazon Pinpoint
                uses to submit email-related event data for the channel.

              - **Version** *(integer) --*

                The current version of the email channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_email_template(self, TemplateName: str) -> ClientGetEmailTemplateResponseTypeDef:
        """
        Retrieves the content and settings for a message template that you can use in messages that
        are sent through the email channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetEmailTemplate>`_

        **Request Syntax**
        ::

          response = client.get_email_template(
              TemplateName='string'
          )
        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EmailTemplateResponse': {
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'DefaultSubstitutions': 'string',
                    'HtmlPart': 'string',
                    'LastModifiedDate': 'string',
                    'Subject': 'string',
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateDescription': 'string',
                    'TemplateName': 'string',
                    'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
                    'TextPart': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **EmailTemplateResponse** *(dict) --*

              Provides information about the content and settings for a message template that can be
              used in messages that are sent through the email channel.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the message template.

              - **CreationDate** *(string) --*

                The date when the message template was created.

              - **DefaultSubstitutions** *(string) --*

                The JSON object that specifies the default values that are used for message
                variables in the message template. This object is a set of key-value pairs. Each key
                defines a message variable in the template. The corresponding value defines the
                default value for that variable.

              - **HtmlPart** *(string) --*

                The message body, in HTML format, that's used in email messages that are based on
                the message template.

              - **LastModifiedDate** *(string) --*

                The date when the message template was last modified.

              - **Subject** *(string) --*

                The subject line, or title, that's used in email messages that are based on the
                message template.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the message template. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **TemplateDescription** *(string) --*

                The custom description of the message template.

              - **TemplateName** *(string) --*

                The name of the message template.

              - **TemplateType** *(string) --*

                The type of channel that the message template is designed for. For an email
                template, this value is EMAIL.

              - **TextPart** *(string) --*

                The message body, in plain text format, that's used in email messages that are based
                on the message template.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_endpoint(self, ApplicationId: str, EndpointId: str) -> ClientGetEndpointResponseTypeDef:
        """
        Retrieves information about the settings and attributes of a specific endpoint for an
        application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetEndpoint>`_

        **Request Syntax**
        ::

          response = client.get_endpoint(
              ApplicationId='string',
              EndpointId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type EndpointId: string
        :param EndpointId: **[REQUIRED]**

          The unique identifier for the endpoint.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EndpointResponse': {
                    'Address': 'string',
                    'ApplicationId': 'string',
                    'Attributes': {
                        'string': [
                            'string',
                        ]
                    },
                    'ChannelType':
                    'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'
                    |'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    'CohortId': 'string',
                    'CreationDate': 'string',
                    'Demographic': {
                        'AppVersion': 'string',
                        'Locale': 'string',
                        'Make': 'string',
                        'Model': 'string',
                        'ModelVersion': 'string',
                        'Platform': 'string',
                        'PlatformVersion': 'string',
                        'Timezone': 'string'
                    },
                    'EffectiveDate': 'string',
                    'EndpointStatus': 'string',
                    'Id': 'string',
                    'Location': {
                        'City': 'string',
                        'Country': 'string',
                        'Latitude': 123.0,
                        'Longitude': 123.0,
                        'PostalCode': 'string',
                        'Region': 'string'
                    },
                    'Metrics': {
                        'string': 123.0
                    },
                    'OptOut': 'string',
                    'RequestId': 'string',
                    'User': {
                        'UserAttributes': {
                            'string': [
                                'string',
                            ]
                        },
                        'UserId': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **EndpointResponse** *(dict) --*

              Provides information about the channel type and other settings for an endpoint.

              - **Address** *(string) --*

                The destination address for messages or push notifications that you send to the
                endpoint. The address varies by channel. For example, the address for a
                push-notification channel is typically the token provided by a push notification
                service, such as an Apple Push Notification service (APNs) device token or a
                Firebase Cloud Messaging (FCM) registration token. The address for the SMS channel
                is a phone number in E.164 format, such as +12065550100. The address for the email
                channel is an email address.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that's associated with the endpoint.

              - **Attributes** *(dict) --*

                One or more custom attributes that describe the endpoint by associating a name with
                an array of values. For example, the value of a custom attribute named Interests
                might be: ["science", "music", "travel"]. You can use these attributes as filter
                criteria when you create segments.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **ChannelType** *(string) --*

                The channel that's used when sending messages or push notifications to the endpoint.

              - **CohortId** *(string) --*

                A number from 0-99 that represents the cohort that the endpoint is assigned to.
                Endpoints are grouped into cohorts randomly, and each cohort contains approximately
                1 percent of the endpoints for an application. Amazon Pinpoint assigns cohorts to
                the holdout or treatment allocations for campaigns.

              - **CreationDate** *(string) --*

                The date and time, in ISO 8601 format, when the endpoint was created.

              - **Demographic** *(dict) --*

                The demographic information for the endpoint, such as the time zone and platform.

                - **AppVersion** *(string) --*

                  The version of the app that's associated with the endpoint.

                - **Locale** *(string) --*

                  The locale of the endpoint, in the following format: the ISO 639-1 alpha-2 code,
                  followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.

                - **Make** *(string) --*

                  The manufacturer of the endpoint device, such as Apple or Samsung.

                - **Model** *(string) --*

                  The model name or number of the endpoint device, such as iPhone.

                - **ModelVersion** *(string) --*

                  The model version of the endpoint device.

                - **Platform** *(string) --*

                  The platform of the endpoint device, such as iOS or Android.

                - **PlatformVersion** *(string) --*

                  The platform version of the endpoint device.

                - **Timezone** *(string) --*

                  The time zone of the endpoint, specified as a tz database name value, such as
                  America/Los_Angeles.

              - **EffectiveDate** *(string) --*

                The date and time, in ISO 8601 format, when the endpoint was last updated.

              - **EndpointStatus** *(string) --*

                Specifies whether messages or push notifications are sent to the endpoint. Possible
                values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages
                aren’t sent to the endpoint.

                Amazon Pinpoint automatically sets this value to ACTIVE when you create an endpoint
                or update an existing endpoint. Amazon Pinpoint automatically sets this value to
                INACTIVE if you update another endpoint that has the same address specified by the
                Address property.

              - **Id** *(string) --*

                The unique identifier that you assigned to the endpoint. The identifier should be a
                globally unique identifier (GUID) to ensure that it doesn't conflict with other
                endpoint identifiers that are associated with the application.

              - **Location** *(dict) --*

                The geographic information for the endpoint.

                - **City** *(string) --*

                  The name of the city where the endpoint is located.

                - **Country** *(string) --*

                  The two-character code, in ISO 3166-1 alpha-2 format, for the country or region
                  where the endpoint is located. For example, US for the United States.

                - **Latitude** *(float) --*

                  The latitude coordinate of the endpoint location, rounded to one decimal place.

                - **Longitude** *(float) --*

                  The longitude coordinate of the endpoint location, rounded to one decimal place.

                - **PostalCode** *(string) --*

                  The postal or ZIP code for the area where the endpoint is located.

                - **Region** *(string) --*

                  The name of the region where the endpoint is located. For locations in the United
                  States, this value is the name of a state.

              - **Metrics** *(dict) --*

                One or more custom metrics that your app reports to Amazon Pinpoint for the
                endpoint.

                - *(string) --*

                  - *(float) --*

              - **OptOut** *(string) --*

                Specifies whether the user who's associated with the endpoint has opted out of
                receiving messages and push notifications from you. Possible values are: ALL, the
                user has opted out and doesn't want to receive any messages or push notifications;
                and, NONE, the user hasn't opted out and wants to receive all messages and push
                notifications.

              - **RequestId** *(string) --*

                The unique identifier for the most recent request to update the endpoint.

              - **User** *(dict) --*

                One or more custom user attributes that your app reports to Amazon Pinpoint for the
                user who's associated with the endpoint.

                - **UserAttributes** *(dict) --*

                  One or more custom attributes that describe the user by associating a name with an
                  array of values. For example, the value of an attribute named Interests might be:
                  ["science", "music", "travel"]. You can use these attributes as filter criteria
                  when you create segments.

                  When you define the name of a custom attribute, avoid using the following
                  characters: number sign (#), colon (:), question mark (?), backslash (\\), and
                  slash (/). The Amazon Pinpoint console can't display attribute names that contain
                  these characters. This limitation doesn't apply to attribute values.

                  - *(string) --*

                    - *(list) --*

                      - *(string) --*

                - **UserId** *(string) --*

                  The unique identifier for the user.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_event_stream(self, ApplicationId: str) -> ClientGetEventStreamResponseTypeDef:
        """
        Retrieves information about the event stream settings for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetEventStream>`_

        **Request Syntax**
        ::

          response = client.get_event_stream(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EventStream': {
                    'ApplicationId': 'string',
                    'DestinationStreamArn': 'string',
                    'ExternalId': 'string',
                    'LastModifiedDate': 'string',
                    'LastUpdatedBy': 'string',
                    'RoleArn': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **EventStream** *(dict) --*

              Specifies settings for publishing event data to an Amazon Kinesis data stream or an
              Amazon Kinesis Data Firehose delivery stream.

              - **ApplicationId** *(string) --*

                The unique identifier for the application to publish event data for.

              - **DestinationStreamArn** *(string) --*

                The Amazon Resource Name (ARN) of the Amazon Kinesis data stream or Amazon Kinesis
                Data Firehose delivery stream to publish event data to.

                For a Kinesis data stream, the ARN format is:
                arn:aws:kinesis:region:account-id:stream/stream_name

                For a Kinesis Data Firehose delivery stream, the ARN format is:
                arn:aws:firehose:region:account-id:deliverystream/stream_name

              - **ExternalId** *(string) --*

                (Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM
                trust policy. Amazon Pinpoint previously used this value to assume an IAM role when
                publishing event data, but we removed this requirement. We don't recommend use of
                external IDs for IAM roles that are assumed by Amazon Pinpoint.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the event stream was last modified.

              - **LastUpdatedBy** *(string) --*

                The IAM user who last modified the event stream.

              - **RoleArn** *(string) --*

                The AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to
                publish event data to the stream in your AWS account.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_export_job(self, ApplicationId: str, JobId: str) -> ClientGetExportJobResponseTypeDef:
        """
        Retrieves information about the status and settings of a specific export job for an
        application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetExportJob>`_

        **Request Syntax**
        ::

          response = client.get_export_job(
              ApplicationId='string',
              JobId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type JobId: string
        :param JobId: **[REQUIRED]**

          The unique identifier for the job.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ExportJobResponse': {
                    'ApplicationId': 'string',
                    'CompletedPieces': 123,
                    'CompletionDate': 'string',
                    'CreationDate': 'string',
                    'Definition': {
                        'RoleArn': 'string',
                        'S3UrlPrefix': 'string',
                        'SegmentId': 'string',
                        'SegmentVersion': 123
                    },
                    'FailedPieces': 123,
                    'Failures': [
                        'string',
                    ],
                    'Id': 'string',
                    'JobStatus':
                    'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'
                    |'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                    'TotalFailures': 123,
                    'TotalPieces': 123,
                    'TotalProcessed': 123,
                    'Type': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ExportJobResponse** *(dict) --*

              Provides information about the status and settings of a job that exports endpoint
              definitions to a file. The file can be added directly to an Amazon Simple Storage
              Service (Amazon S3) bucket by using the Amazon Pinpoint API or downloaded directly to
              a computer by using the Amazon Pinpoint console.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that's associated with the export job.

              - **CompletedPieces** *(integer) --*

                The number of pieces that were processed successfully (completed) by the export job,
                as of the time of the request.

              - **CompletionDate** *(string) --*

                The date, in ISO 8601 format, when the export job was completed.

              - **CreationDate** *(string) --*

                The date, in ISO 8601 format, when the export job was created.

              - **Definition** *(dict) --*

                The resource settings that apply to the export job.

                - **RoleArn** *(string) --*

                  The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                  role that authorized Amazon Pinpoint to access the Amazon S3 location where the
                  endpoint definitions were exported to.

                - **S3UrlPrefix** *(string) --*

                  The URL of the location in an Amazon Simple Storage Service (Amazon S3) bucket
                  where the endpoint definitions were exported to. This location is typically a
                  folder that contains multiple files. The URL should be in the following format:
                  s3://bucket-name/folder-name/.

                - **SegmentId** *(string) --*

                  The identifier for the segment that the endpoint definitions were exported from.
                  If this value isn't present, Amazon Pinpoint exported definitions for all the
                  endpoints that are associated with the application.

                - **SegmentVersion** *(integer) --*

                  The version of the segment that the endpoint definitions were exported from.

              - **FailedPieces** *(integer) --*

                The number of pieces that weren't processed successfully (failed) by the export job,
                as of the time of the request.

              - **Failures** *(list) --*

                An array of entries, one for each of the first 100 entries that weren't processed
                successfully (failed) by the export job, if any.

                - *(string) --*

              - **Id** *(string) --*

                The unique identifier for the export job.

              - **JobStatus** *(string) --*

                The status of the export job. The job status is FAILED if Amazon Pinpoint wasn't
                able to process one or more pieces in the job.

              - **TotalFailures** *(integer) --*

                The total number of endpoint definitions that weren't processed successfully
                (failed) by the export job, typically because an error, such as a syntax error,
                occurred.

              - **TotalPieces** *(integer) --*

                The total number of pieces that must be processed to complete the export job. Each
                piece consists of an approximately equal portion of the endpoint definitions that
                are part of the export job.

              - **TotalProcessed** *(integer) --*

                The total number of endpoint definitions that were processed by the export job.

              - **Type** *(string) --*

                The job type. This value is EXPORT for export jobs.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_export_jobs(
        self, ApplicationId: str, PageSize: str = None, Token: str = None
    ) -> ClientGetExportJobsResponseTypeDef:
        """
        Retrieves information about the status and settings of all the export jobs for an
        application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetExportJobs>`_

        **Request Syntax**
        ::

          response = client.get_export_jobs(
              ApplicationId='string',
              PageSize='string',
              Token='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type Token: string
        :param Token:

          The NextToken string that specifies which page of results to return in a paginated
          response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ExportJobsResponse': {
                    'Item': [
                        {
                            'ApplicationId': 'string',
                            'CompletedPieces': 123,
                            'CompletionDate': 'string',
                            'CreationDate': 'string',
                            'Definition': {
                                'RoleArn': 'string',
                                'S3UrlPrefix': 'string',
                                'SegmentId': 'string',
                                'SegmentVersion': 123
                            },
                            'FailedPieces': 123,
                            'Failures': [
                                'string',
                            ],
                            'Id': 'string',
                            'JobStatus':
                            'CREATED'|'PREPARING_FOR_INITIALIZATION'
                            |'INITIALIZING'|'PROCESSING'|'PENDING_JOB'
                            |'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                            'TotalFailures': 123,
                            'TotalPieces': 123,
                            'TotalProcessed': 123,
                            'Type': 'string'
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ExportJobsResponse** *(dict) --*

              Provides information about all the export jobs that are associated with an application
              or segment. An export job is a job that exports endpoint definitions to a file.

              - **Item** *(list) --*

                An array of responses, one for each export job that's associated with the
                application (Export Jobs resource) or segment (Segment Export Jobs resource).

                - *(dict) --*

                  Provides information about the status and settings of a job that exports endpoint
                  definitions to a file. The file can be added directly to an Amazon Simple Storage
                  Service (Amazon S3) bucket by using the Amazon Pinpoint API or downloaded directly
                  to a computer by using the Amazon Pinpoint console.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that's associated with the export job.

                  - **CompletedPieces** *(integer) --*

                    The number of pieces that were processed successfully (completed) by the export
                    job, as of the time of the request.

                  - **CompletionDate** *(string) --*

                    The date, in ISO 8601 format, when the export job was completed.

                  - **CreationDate** *(string) --*

                    The date, in ISO 8601 format, when the export job was created.

                  - **Definition** *(dict) --*

                    The resource settings that apply to the export job.

                    - **RoleArn** *(string) --*

                      The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                      role that authorized Amazon Pinpoint to access the Amazon S3 location where
                      the endpoint definitions were exported to.

                    - **S3UrlPrefix** *(string) --*

                      The URL of the location in an Amazon Simple Storage Service (Amazon S3) bucket
                      where the endpoint definitions were exported to. This location is typically a
                      folder that contains multiple files. The URL should be in the following
                      format: s3://bucket-name/folder-name/.

                    - **SegmentId** *(string) --*

                      The identifier for the segment that the endpoint definitions were exported
                      from. If this value isn't present, Amazon Pinpoint exported definitions for
                      all the endpoints that are associated with the application.

                    - **SegmentVersion** *(integer) --*

                      The version of the segment that the endpoint definitions were exported from.

                  - **FailedPieces** *(integer) --*

                    The number of pieces that weren't processed successfully (failed) by the export
                    job, as of the time of the request.

                  - **Failures** *(list) --*

                    An array of entries, one for each of the first 100 entries that weren't
                    processed successfully (failed) by the export job, if any.

                    - *(string) --*

                  - **Id** *(string) --*

                    The unique identifier for the export job.

                  - **JobStatus** *(string) --*

                    The status of the export job. The job status is FAILED if Amazon Pinpoint wasn't
                    able to process one or more pieces in the job.

                  - **TotalFailures** *(integer) --*

                    The total number of endpoint definitions that weren't processed successfully
                    (failed) by the export job, typically because an error, such as a syntax error,
                    occurred.

                  - **TotalPieces** *(integer) --*

                    The total number of pieces that must be processed to complete the export job.
                    Each piece consists of an approximately equal portion of the endpoint
                    definitions that are part of the export job.

                  - **TotalProcessed** *(integer) --*

                    The total number of endpoint definitions that were processed by the export job.

                  - **Type** *(string) --*

                    The job type. This value is EXPORT for export jobs.

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_gcm_channel(self, ApplicationId: str) -> ClientGetGcmChannelResponseTypeDef:
        """
        Retrieves information about the status and settings of the GCM channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetGcmChannel>`_

        **Request Syntax**
        ::

          response = client.get_gcm_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'GCMChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Credential': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **GCMChannelResponse** *(dict) --*

              Provides information about the status and settings of the GCM channel for an
              application. The GCM channel enables Amazon Pinpoint to send push notifications
              through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM),
              service.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the GCM channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the GCM channel was enabled.

              - **Credential** *(string) --*

                The Web API Key, also referred to as an *API_KEY* or *server key* , that you
                received from Google to communicate with Google services.

              - **Enabled** *(boolean) --*

                Specifies whether the GCM channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the GCM channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the GCM channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the GCM channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the GCM channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the GCM channel,
                this value is GCM.

              - **Version** *(integer) --*

                The current version of the GCM channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_import_job(self, ApplicationId: str, JobId: str) -> ClientGetImportJobResponseTypeDef:
        """
        Retrieves information about the status and settings of a specific import job for an
        application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetImportJob>`_

        **Request Syntax**
        ::

          response = client.get_import_job(
              ApplicationId='string',
              JobId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type JobId: string
        :param JobId: **[REQUIRED]**

          The unique identifier for the job.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ImportJobResponse': {
                    'ApplicationId': 'string',
                    'CompletedPieces': 123,
                    'CompletionDate': 'string',
                    'CreationDate': 'string',
                    'Definition': {
                        'DefineSegment': True|False,
                        'ExternalId': 'string',
                        'Format': 'CSV'|'JSON',
                        'RegisterEndpoints': True|False,
                        'RoleArn': 'string',
                        'S3Url': 'string',
                        'SegmentId': 'string',
                        'SegmentName': 'string'
                    },
                    'FailedPieces': 123,
                    'Failures': [
                        'string',
                    ],
                    'Id': 'string',
                    'JobStatus':
                    'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'
                    |'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                    'TotalFailures': 123,
                    'TotalPieces': 123,
                    'TotalProcessed': 123,
                    'Type': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ImportJobResponse** *(dict) --*

              Provides information about the status and settings of a job that imports endpoint
              definitions from one or more files. The files can be stored in an Amazon Simple
              Storage Service (Amazon S3) bucket or uploaded directly from a computer by using the
              Amazon Pinpoint console.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that's associated with the import job.

              - **CompletedPieces** *(integer) --*

                The number of pieces that were processed successfully (completed) by the import job,
                as of the time of the request.

              - **CompletionDate** *(string) --*

                The date, in ISO 8601 format, when the import job was completed.

              - **CreationDate** *(string) --*

                The date, in ISO 8601 format, when the import job was created.

              - **Definition** *(dict) --*

                The resource settings that apply to the import job.

                - **DefineSegment** *(boolean) --*

                  Specifies whether the import job creates a segment that contains the endpoints,
                  when the endpoint definitions are imported.

                - **ExternalId** *(string) --*

                  (Deprecated) Your AWS account ID, which you assigned to an external ID key in an
                  IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role
                  when importing endpoint definitions, but we removed this requirement. We don't
                  recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

                - **Format** *(string) --*

                  The format of the files that contain the endpoint definitions to import. Valid
                  values are: CSV, for comma-separated values format; and, JSON, for
                  newline-delimited JSON format.

                  If the files are stored in an Amazon S3 location and that location contains
                  multiple files that use different formats, Amazon Pinpoint imports data only from
                  the files that use the specified format.

                - **RegisterEndpoints** *(boolean) --*

                  Specifies whether the import job registers the endpoints with Amazon Pinpoint,
                  when the endpoint definitions are imported.

                - **RoleArn** *(string) --*

                  The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                  role that authorizes Amazon Pinpoint to access the Amazon S3 location to import
                  endpoint definitions from.

                - **S3Url** *(string) --*

                  The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains the
                  endpoint definitions to import. This location can be a folder or a single file. If
                  the location is a folder, Amazon Pinpoint imports endpoint definitions from the
                  files in this location, including any subfolders that the folder contains.

                  The URL should be in the following format: s3://bucket-name/folder-name/file-name.
                  The location can end with the key for an individual object or a prefix that
                  qualifies multiple objects.

                - **SegmentId** *(string) --*

                  The identifier for the segment that the import job updates or adds endpoint
                  definitions to, if the import job updates an existing segment.

                - **SegmentName** *(string) --*

                  The custom name for the segment that's created by the import job, if the value of
                  the DefineSegment property is true.

              - **FailedPieces** *(integer) --*

                The number of pieces that weren't processed successfully (failed) by the import job,
                as of the time of the request.

              - **Failures** *(list) --*

                An array of entries, one for each of the first 100 entries that weren't processed
                successfully (failed) by the import job, if any.

                - *(string) --*

              - **Id** *(string) --*

                The unique identifier for the import job.

              - **JobStatus** *(string) --*

                The status of the import job. The job status is FAILED if Amazon Pinpoint wasn't
                able to process one or more pieces in the job.

              - **TotalFailures** *(integer) --*

                The total number of endpoint definitions that weren't processed successfully
                (failed) by the import job, typically because an error, such as a syntax error,
                occurred.

              - **TotalPieces** *(integer) --*

                The total number of pieces that must be processed to complete the import job. Each
                piece consists of an approximately equal portion of the endpoint definitions that
                are part of the import job.

              - **TotalProcessed** *(integer) --*

                The total number of endpoint definitions that were processed by the import job.

              - **Type** *(string) --*

                The job type. This value is IMPORT for import jobs.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_import_jobs(
        self, ApplicationId: str, PageSize: str = None, Token: str = None
    ) -> ClientGetImportJobsResponseTypeDef:
        """
        Retrieves information about the status and settings of all the import jobs for an
        application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetImportJobs>`_

        **Request Syntax**
        ::

          response = client.get_import_jobs(
              ApplicationId='string',
              PageSize='string',
              Token='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type Token: string
        :param Token:

          The NextToken string that specifies which page of results to return in a paginated
          response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ImportJobsResponse': {
                    'Item': [
                        {
                            'ApplicationId': 'string',
                            'CompletedPieces': 123,
                            'CompletionDate': 'string',
                            'CreationDate': 'string',
                            'Definition': {
                                'DefineSegment': True|False,
                                'ExternalId': 'string',
                                'Format': 'CSV'|'JSON',
                                'RegisterEndpoints': True|False,
                                'RoleArn': 'string',
                                'S3Url': 'string',
                                'SegmentId': 'string',
                                'SegmentName': 'string'
                            },
                            'FailedPieces': 123,
                            'Failures': [
                                'string',
                            ],
                            'Id': 'string',
                            'JobStatus':
                            'CREATED'|'PREPARING_FOR_INITIALIZATION'
                            |'INITIALIZING'|'PROCESSING'|'PENDING_JOB'
                            |'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                            'TotalFailures': 123,
                            'TotalPieces': 123,
                            'TotalProcessed': 123,
                            'Type': 'string'
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ImportJobsResponse** *(dict) --*

              Provides information about the status and settings of all the import jobs that are
              associated with an application or segment. An import job is a job that imports
              endpoint definitions from one or more files.

              - **Item** *(list) --*

                An array of responses, one for each import job that's associated with the
                application (Import Jobs resource) or segment (Segment Import Jobs resource).

                - *(dict) --*

                  Provides information about the status and settings of a job that imports endpoint
                  definitions from one or more files. The files can be stored in an Amazon Simple
                  Storage Service (Amazon S3) bucket or uploaded directly from a computer by using
                  the Amazon Pinpoint console.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that's associated with the import job.

                  - **CompletedPieces** *(integer) --*

                    The number of pieces that were processed successfully (completed) by the import
                    job, as of the time of the request.

                  - **CompletionDate** *(string) --*

                    The date, in ISO 8601 format, when the import job was completed.

                  - **CreationDate** *(string) --*

                    The date, in ISO 8601 format, when the import job was created.

                  - **Definition** *(dict) --*

                    The resource settings that apply to the import job.

                    - **DefineSegment** *(boolean) --*

                      Specifies whether the import job creates a segment that contains the
                      endpoints, when the endpoint definitions are imported.

                    - **ExternalId** *(string) --*

                      (Deprecated) Your AWS account ID, which you assigned to an external ID key in
                      an IAM trust policy. Amazon Pinpoint previously used this value to assume an
                      IAM role when importing endpoint definitions, but we removed this requirement.
                      We don't recommend use of external IDs for IAM roles that are assumed by
                      Amazon Pinpoint.

                    - **Format** *(string) --*

                      The format of the files that contain the endpoint definitions to import. Valid
                      values are: CSV, for comma-separated values format; and, JSON, for
                      newline-delimited JSON format.

                      If the files are stored in an Amazon S3 location and that location contains
                      multiple files that use different formats, Amazon Pinpoint imports data only
                      from the files that use the specified format.

                    - **RegisterEndpoints** *(boolean) --*

                      Specifies whether the import job registers the endpoints with Amazon Pinpoint,
                      when the endpoint definitions are imported.

                    - **RoleArn** *(string) --*

                      The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                      role that authorizes Amazon Pinpoint to access the Amazon S3 location to
                      import endpoint definitions from.

                    - **S3Url** *(string) --*

                      The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains
                      the endpoint definitions to import. This location can be a folder or a single
                      file. If the location is a folder, Amazon Pinpoint imports endpoint
                      definitions from the files in this location, including any subfolders that the
                      folder contains.

                      The URL should be in the following format:
                      s3://bucket-name/folder-name/file-name. The location can end with the key for
                      an individual object or a prefix that qualifies multiple objects.

                    - **SegmentId** *(string) --*

                      The identifier for the segment that the import job updates or adds endpoint
                      definitions to, if the import job updates an existing segment.

                    - **SegmentName** *(string) --*

                      The custom name for the segment that's created by the import job, if the value
                      of the DefineSegment property is true.

                  - **FailedPieces** *(integer) --*

                    The number of pieces that weren't processed successfully (failed) by the import
                    job, as of the time of the request.

                  - **Failures** *(list) --*

                    An array of entries, one for each of the first 100 entries that weren't
                    processed successfully (failed) by the import job, if any.

                    - *(string) --*

                  - **Id** *(string) --*

                    The unique identifier for the import job.

                  - **JobStatus** *(string) --*

                    The status of the import job. The job status is FAILED if Amazon Pinpoint wasn't
                    able to process one or more pieces in the job.

                  - **TotalFailures** *(integer) --*

                    The total number of endpoint definitions that weren't processed successfully
                    (failed) by the import job, typically because an error, such as a syntax error,
                    occurred.

                  - **TotalPieces** *(integer) --*

                    The total number of pieces that must be processed to complete the import job.
                    Each piece consists of an approximately equal portion of the endpoint
                    definitions that are part of the import job.

                  - **TotalProcessed** *(integer) --*

                    The total number of endpoint definitions that were processed by the import job.

                  - **Type** *(string) --*

                    The job type. This value is IMPORT for import jobs.

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_journey(self, ApplicationId: str, JourneyId: str) -> ClientGetJourneyResponseTypeDef:
        """
        Retrieves information about the status, configuration, and other settings for a journey.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetJourney>`_

        **Request Syntax**
        ::

          response = client.get_journey(
              ApplicationId='string',
              JourneyId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type JourneyId: string
        :param JourneyId: **[REQUIRED]**

          The unique identifier for the journey.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'JourneyResponse': {
                    'Activities': {
                        'string': {
                            'ConditionalSplit': {
                                'Condition': {
                                    'Conditions': [
                                        {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType':
                                                            'INCLUSIVE'
                                                            |'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                    ],
                                    'Operator': 'ALL'|'ANY'
                                },
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                },
                                'FalseActivity': 'string',
                                'TrueActivity': 'string'
                            },
                            'Description': 'string',
                            'EMAIL': {
                                'MessageConfig': {
                                    'FromAddress': 'string'
                                },
                                'NextActivity': 'string',
                                'TemplateName': 'string'
                            },
                            'Holdout': {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                            'MultiCondition': {
                                'Branches': [
                                    {
                                        'Condition': {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType':
                                                            'INCLUSIVE'
                                                            |'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                        'NextActivity': 'string'
                                    },
                                ],
                                'DefaultActivity': 'string',
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            },
                            'RandomSplit': {
                                'Branches': [
                                    {
                                        'NextActivity': 'string',
                                        'Percentage': 123
                                    },
                                ]
                            },
                            'Wait': {
                                'NextActivity': 'string',
                                'WaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            }
                        }
                    },
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Id': 'string',
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'DailyCap': 123,
                        'EndpointReentryCap': 123,
                        'MessagesPerSecond': 123
                    },
                    'LocalTime': True|False,
                    'Name': 'string',
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'RefreshFrequency': 'string',
                    'Schedule': {
                        'EndTime': datetime(2015, 1, 1),
                        'StartTime': datetime(2015, 1, 1),
                        'Timezone': 'string'
                    },
                    'StartActivity': 'string',
                    'StartCondition': {
                        'Description': 'string',
                        'SegmentStartCondition': {
                            'SegmentId': 'string'
                        }
                    },
                    'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
                    'tags': {
                        'string': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **JourneyResponse** *(dict) --*

              Provides information about the status, configuration, and other settings for a
              journey.

              - **Activities** *(dict) --*

                The configuration and other settings for the activities that comprise the journey.

                - *(string) --*

                  - *(dict) --*

                    Specifies the configuration and other settings for an activity in a journey.

                    - **ConditionalSplit** *(dict) --*

                      The settings for a yes/no split activity. This type of activity sends
                      participants down one of two paths in a journey, based on conditions that you
                      specify.

                      - **Condition** *(dict) --*

                        The conditions that define the paths for the activity, and the relationship
                        between the conditions.

                        - **Conditions** *(list) --*

                          The conditions to evaluate for the activity.

                          - *(dict) --*

                            Specifies a condition to evaluate for an activity in a journey.

                            - **EventCondition** *(dict) --*

                              The dimension settings for the event that's associated with the
                              activity.

                              - **Dimensions** *(dict) --*

                                The dimensions for the event filter to use for the activity.

                                - **Attributes** *(dict) --*

                                  One or more custom attributes that your application reports to
                                  Amazon Pinpoint. You can use these attributes as selection
                                  criteria when you create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies attribute-based criteria for including or excluding
                                      endpoints from a segment.

                                      - **AttributeType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the AttributeType property,
                                        endpoints are included or excluded from the segment if their
                                        attribute values match the criteria values.

                                        - *(string) --*

                                - **EventType** *(dict) --*

                                  The name of the event that causes the campaign to be sent or the
                                  journey activity to be performed. This can be a standard type of
                                  event that Amazon Pinpoint generates, such as _email.delivered, or
                                  a custom event that's specific to your application.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Metrics** *(dict) --*

                                  One or more custom metrics that your application reports to Amazon
                                  Pinpoint. You can use these metrics as selection criteria when you
                                  create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies metric-based criteria for including or excluding
                                      endpoints from a segment. These criteria derive from custom
                                      metrics that you define for endpoints.

                                      - **ComparisonOperator** *(string) --*

                                        The operator to use when comparing metric values. Valid
                                        values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                        LESS_THAN_OR_EQUAL, and EQUAL.

                                      - **Value** *(float) --*

                                        The value to compare.

                              - **MessageActivity** *(string) --*

                                The message identifier (message_id) for the message to use when
                                determining whether message events meet the condition.

                            - **SegmentCondition** *(dict) --*

                              The segment that's associated with the activity.

                              - **SegmentId** *(string) --*

                                The unique identifier for the segment to associate with the
                                activity.

                            - **SegmentDimensions** *(dict) --*

                              The dimension settings for the segment that's associated with the
                              activity.

                              - **Attributes** *(dict) --*

                                One or more custom attributes to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                              - **Behavior** *(dict) --*

                                The behavior-based criteria, such as how recently users have used
                                your app, for the segment.

                                - **Recency** *(dict) --*

                                  The dimension settings that are based on how recently an endpoint
                                  was active.

                                  - **Duration** *(string) --*

                                    The duration to use when determining whether an endpoint is
                                    active or inactive.

                                  - **RecencyType** *(string) --*

                                    The type of recency dimension to use for the segment. Valid
                                    values are: ACTIVE, endpoints that were active within the
                                    specified duration are included in the segment; and, INACTIVE,
                                    endpoints that weren't active within the specified duration are
                                    included in the segment.

                              - **Demographic** *(dict) --*

                                The demographic-based criteria, such as device platform, for the
                                segment.

                                - **AppVersion** *(dict) --*

                                  The app version criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Channel** *(dict) --*

                                  The channel criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **DeviceType** *(dict) --*

                                  The device type criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Make** *(dict) --*

                                  The device make criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Model** *(dict) --*

                                  The device model criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Platform** *(dict) --*

                                  The device platform criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                              - **Location** *(dict) --*

                                The location-based criteria, such as region or GPS coordinates, for
                                the segment.

                                - **Country** *(dict) --*

                                  The country or region code, in ISO 3166-1 alpha-2 format, for the
                                  segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **GPSPoint** *(dict) --*

                                  The GPS location and range for the segment.

                                  - **Coordinates** *(dict) --*

                                    The GPS coordinates to measure distance from.

                                    - **Latitude** *(float) --*

                                      The latitude coordinate of the location.

                                    - **Longitude** *(float) --*

                                      The longitude coordinate of the location.

                                  - **RangeInKilometers** *(float) --*

                                    The range, in kilometers, from the GPS coordinates.

                              - **Metrics** *(dict) --*

                                One or more custom metrics to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies metric-based criteria for including or excluding
                                    endpoints from a segment. These criteria derive from custom
                                    metrics that you define for endpoints.

                                    - **ComparisonOperator** *(string) --*

                                      The operator to use when comparing metric values. Valid values
                                      are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                      LESS_THAN_OR_EQUAL, and EQUAL.

                                    - **Value** *(float) --*

                                      The value to compare.

                              - **UserAttributes** *(dict) --*

                                One or more custom user attributes to use as criteria for the
                                segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                        - **Operator** *(string) --*

                          Specifies how to handle multiple conditions for the activity. For example,
                          if you specify two conditions for an activity, whether both or only one of
                          the conditions must be met for the activity to be performed.

                      - **EvaluationWaitTime** *(dict) --*

                        The amount of time to wait before determining whether the conditions are
                        met, or the date and time when Amazon Pinpoint determines whether the
                        conditions are met.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

                      - **FalseActivity** *(string) --*

                        The unique identifier for the activity to perform if the condition isn't
                        met.

                      - **TrueActivity** *(string) --*

                        The unique identifier for the activity to perform if the condition is met.

                    - **Description** *(string) --*

                      The custom description of the activity.

                    - **EMAIL** *(dict) --*

                      The settings for an email activity. This type of activity sends an email
                      message to participants.

                      - **MessageConfig** *(dict) --*

                        The "From" address to use for the message.

                        - **FromAddress** *(string) --*

                          The verified email address to send the email message from. The default
                          address is the FromAddress specified for the email channel for the
                          application.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after the message is
                        sent.

                      - **TemplateName** *(string) --*

                        The name of the email template to use for the message.

                    - **Holdout** *(dict) --*

                      The settings for a holdout activity. This type of activity stops a journey for
                      a specified percentage of participants.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after performing the
                        holdout activity.

                      - **Percentage** *(integer) --*

                        The percentage of participants who shouldn't continue the journey.

                    - **MultiCondition** *(dict) --*

                      The settings for a multivariate split activity. This type of activity sends
                      participants down one of as many as five paths in a journey, based on
                      conditions that you specify.

                      - **Branches** *(list) --*

                        The paths for the activity, including the conditions for entering each path
                        and the activity to perform for each path.

                        - *(dict) --*

                          Specifies a condition to evaluate for an activity path in a journey.

                          - **Condition** *(dict) --*

                            The condition to evaluate for the activity path.

                            - **EventCondition** *(dict) --*

                              The dimension settings for the event that's associated with the
                              activity.

                              - **Dimensions** *(dict) --*

                                The dimensions for the event filter to use for the activity.

                                - **Attributes** *(dict) --*

                                  One or more custom attributes that your application reports to
                                  Amazon Pinpoint. You can use these attributes as selection
                                  criteria when you create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies attribute-based criteria for including or excluding
                                      endpoints from a segment.

                                      - **AttributeType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the AttributeType property,
                                        endpoints are included or excluded from the segment if their
                                        attribute values match the criteria values.

                                        - *(string) --*

                                - **EventType** *(dict) --*

                                  The name of the event that causes the campaign to be sent or the
                                  journey activity to be performed. This can be a standard type of
                                  event that Amazon Pinpoint generates, such as _email.delivered, or
                                  a custom event that's specific to your application.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Metrics** *(dict) --*

                                  One or more custom metrics that your application reports to Amazon
                                  Pinpoint. You can use these metrics as selection criteria when you
                                  create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies metric-based criteria for including or excluding
                                      endpoints from a segment. These criteria derive from custom
                                      metrics that you define for endpoints.

                                      - **ComparisonOperator** *(string) --*

                                        The operator to use when comparing metric values. Valid
                                        values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                        LESS_THAN_OR_EQUAL, and EQUAL.

                                      - **Value** *(float) --*

                                        The value to compare.

                              - **MessageActivity** *(string) --*

                                The message identifier (message_id) for the message to use when
                                determining whether message events meet the condition.

                            - **SegmentCondition** *(dict) --*

                              The segment that's associated with the activity.

                              - **SegmentId** *(string) --*

                                The unique identifier for the segment to associate with the
                                activity.

                            - **SegmentDimensions** *(dict) --*

                              The dimension settings for the segment that's associated with the
                              activity.

                              - **Attributes** *(dict) --*

                                One or more custom attributes to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                              - **Behavior** *(dict) --*

                                The behavior-based criteria, such as how recently users have used
                                your app, for the segment.

                                - **Recency** *(dict) --*

                                  The dimension settings that are based on how recently an endpoint
                                  was active.

                                  - **Duration** *(string) --*

                                    The duration to use when determining whether an endpoint is
                                    active or inactive.

                                  - **RecencyType** *(string) --*

                                    The type of recency dimension to use for the segment. Valid
                                    values are: ACTIVE, endpoints that were active within the
                                    specified duration are included in the segment; and, INACTIVE,
                                    endpoints that weren't active within the specified duration are
                                    included in the segment.

                              - **Demographic** *(dict) --*

                                The demographic-based criteria, such as device platform, for the
                                segment.

                                - **AppVersion** *(dict) --*

                                  The app version criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Channel** *(dict) --*

                                  The channel criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **DeviceType** *(dict) --*

                                  The device type criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Make** *(dict) --*

                                  The device make criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Model** *(dict) --*

                                  The device model criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Platform** *(dict) --*

                                  The device platform criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                              - **Location** *(dict) --*

                                The location-based criteria, such as region or GPS coordinates, for
                                the segment.

                                - **Country** *(dict) --*

                                  The country or region code, in ISO 3166-1 alpha-2 format, for the
                                  segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **GPSPoint** *(dict) --*

                                  The GPS location and range for the segment.

                                  - **Coordinates** *(dict) --*

                                    The GPS coordinates to measure distance from.

                                    - **Latitude** *(float) --*

                                      The latitude coordinate of the location.

                                    - **Longitude** *(float) --*

                                      The longitude coordinate of the location.

                                  - **RangeInKilometers** *(float) --*

                                    The range, in kilometers, from the GPS coordinates.

                              - **Metrics** *(dict) --*

                                One or more custom metrics to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies metric-based criteria for including or excluding
                                    endpoints from a segment. These criteria derive from custom
                                    metrics that you define for endpoints.

                                    - **ComparisonOperator** *(string) --*

                                      The operator to use when comparing metric values. Valid values
                                      are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                      LESS_THAN_OR_EQUAL, and EQUAL.

                                    - **Value** *(float) --*

                                      The value to compare.

                              - **UserAttributes** *(dict) --*

                                One or more custom user attributes to use as criteria for the
                                segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after completing
                            the activity for the path.

                      - **DefaultActivity** *(string) --*

                        The activity to perform by default for any path in the activity.

                      - **EvaluationWaitTime** *(dict) --*

                        The amount of time to wait or the date and time when Amazon Pinpoint
                        determines whether the conditions are met.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

                    - **RandomSplit** *(dict) --*

                      The settings for a random split activity. This type of activity randomly sends
                      specified percentages of participants down one of as many as five paths in a
                      journey, based on conditions that you specify.

                      - **Branches** *(list) --*

                        The paths for the activity, including the percentage of participants to
                        enter each path and the activity to perform for each path.

                        - *(dict) --*

                          Specifies the settings for a path in a random split activity in a journey.

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after completing
                            the activity for the path.

                          - **Percentage** *(integer) --*

                            The percentage of participants to send down the activity path.

                    - **Wait** *(dict) --*

                      The settings for a wait activity. This type of activity waits for a certain
                      amount of time or until a specific date and time before moving participants to
                      the next activity in a journey.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after performing the
                        wait activity.

                      - **WaitTime** *(dict) --*

                        The amount of time to wait or the date and time when the activity moves
                        participants to the next activity in the journey.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the journey applies to.

              - **CreationDate** *(string) --*

                The date, in ISO 8601 format, when the journey was created.

              - **Id** *(string) --*

                The unique identifier for the journey.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the journey was last modified.

              - **Limits** *(dict) --*

                The messaging and entry limits for the journey.

                - **DailyCap** *(integer) --*

                  The maximum number of messages that the journey can send to a single participant
                  during a 24-hour period. The maximum value is 100.

                - **EndpointReentryCap** *(integer) --*

                  The maximum number of times that a participant can enter the journey. The maximum
                  value is 100. To allow participants to enter the journey an unlimited number of
                  times, set this value to 0.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that the journey can send each second.

              - **LocalTime** *(boolean) --*

                Specifies whether the journey's scheduled start and end times use each participant's
                local time. If this value is true, the schedule uses each participant's local time.

              - **Name** *(string) --*

                The name of the journey.

              - **QuietTime** *(dict) --*

                The quiet time settings for the journey. Quiet time is a specific time range when a
                journey doesn't send messages to participants, if all the following conditions are
                met:

                * The EndpointDemographic.Timezone property of the endpoint for the participant is
                set to a valid value.

                * The current time in the participant's time zone is later than or equal to the time
                specified by the QuietTime.Start property for the journey.

                * The current time in the participant's time zone is earlier than or equal to the
                time specified by the QuietTime.End property for the journey.

                If any of the preceding conditions isn't met, the participant will receive messages
                from the journey, even if quiet time is enabled.

                - **End** *(string) --*

                  The specific time when quiet time ends. This value has to use 24-hour notation and
                  be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and
                  MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

                - **Start** *(string) --*

                  The specific time when quiet time begins. This value has to use 24-hour notation
                  and be in HH:MM format, where HH is the hour (with a leading zero, if applicable)
                  and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

              - **RefreshFrequency** *(string) --*

                The frequency with which Amazon Pinpoint evaluates segment and event data for the
                journey, as a duration in ISO 8601 format.

              - **Schedule** *(dict) --*

                The schedule settings for the journey.

                - **EndTime** *(datetime) --*

                  The scheduled time, in ISO 8601 format, when the journey ended or will end.

                - **StartTime** *(datetime) --*

                  The scheduled time, in ISO 8601 format, when the journey began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the journey schedule, if the value of the journey's
                  LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                  UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                  UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12,
                  UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04,
                  UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.

              - **StartActivity** *(string) --*

                The unique identifier for the first activity in the journey.

              - **StartCondition** *(dict) --*

                The segment that defines which users are participants in the journey.

                - **Description** *(string) --*

                  The custom description of the condition.

                - **SegmentStartCondition** *(dict) --*

                  The segment that's associated with the first activity in the journey. This segment
                  determines which users are participants in the journey.

                  - **SegmentId** *(string) --*

                    The unique identifier for the segment to associate with the activity.

              - **State** *(string) --*

                The current status of the journey. Possible values are:

                * DRAFT - The journey is being developed and hasn't been published yet.

                * ACTIVE - The journey has been developed and published. Depending on the journey's
                schedule, the journey may currently be running or scheduled to start running at a
                later time. If a journey's status is ACTIVE, you can't add, change, or remove
                activities from it.

                * COMPLETED - The journey has been published and has finished running. All
                participants have entered the journey and no participants are waiting to complete
                the journey or any activities in the journey.

                * CANCELLED - The journey has been stopped. If a journey's status is CANCELLED, you
                can't add, change, or remove activities or segment settings from the journey.

                * CLOSED - The journey has been published and has started running. It may have also
                passed its scheduled end time, or passed its scheduled start time and a refresh
                frequency hasn't been specified for it. If a journey's status is CLOSED, you can't
                add participants to it, and no existing participants can enter the journey for the
                first time. However, any existing participants who are currently waiting to start an
                activity may resume the journey.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the journey. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_journey_date_range_kpi(
        self,
        ApplicationId: str,
        JourneyId: str,
        KpiName: str,
        EndTime: datetime = None,
        NextToken: str = None,
        PageSize: str = None,
        StartTime: datetime = None,
    ) -> ClientGetJourneyDateRangeKpiResponseTypeDef:
        """
        Retrieves (queries) pre-aggregated data for a standard engagement metric that applies to a
        journey.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetJourneyDateRangeKpi>`_

        **Request Syntax**
        ::

          response = client.get_journey_date_range_kpi(
              ApplicationId='string',
              EndTime=datetime(2015, 1, 1),
              JourneyId='string',
              KpiName='string',
              NextToken='string',
              PageSize='string',
              StartTime=datetime(2015, 1, 1)
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type EndTime: datetime
        :param EndTime:

          The last date and time to retrieve data for, as part of an inclusive date range that
          filters the query results. This value should be in extended ISO 8601 format, for example:
          2019-07-19T00:00:00Z for July 19, 2019 and 2019-07-19T20:00:00Z for 8:00 PM July 19, 2019.

        :type JourneyId: string
        :param JourneyId: **[REQUIRED]**

          The unique identifier for the journey.

        :type KpiName: string
        :param KpiName: **[REQUIRED]**

          The name of the metric, also referred to as a *key performance indicator (KPI)* , to
          retrieve data for. This value describes the associated metric and consists of two or more
          terms, which are comprised of lowercase alphanumeric characters, separated by a hyphen.
          Examples are email-open-rate and successful-delivery-rate. For a list of valid values, see
          the `Amazon Pinpoint Developer Guide
          <https://docs.aws.amazon.com/pinpoint/latest/developerguide/welcome.html>`__ .

        :type NextToken: string
        :param NextToken:

          The string that specifies which page of results to return in a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type StartTime: datetime
        :param StartTime:

          The first date and time to retrieve data for, as part of an inclusive date range that
          filters the query results. This value should be in extended ISO 8601 format, for example:
          2019-07-15T00:00:00Z for July 15, 2019 and 2019-07-15T16:00:00Z for 4:00 PM July 15, 2019.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'JourneyDateRangeKpiResponse': {
                    'ApplicationId': 'string',
                    'EndTime': datetime(2015, 1, 1),
                    'JourneyId': 'string',
                    'KpiName': 'string',
                    'KpiResult': {
                        'Rows': [
                            {
                                'GroupedBys': [
                                    {
                                        'Key': 'string',
                                        'Type': 'string',
                                        'Value': 'string'
                                    },
                                ],
                                'Values': [
                                    {
                                        'Key': 'string',
                                        'Type': 'string',
                                        'Value': 'string'
                                    },
                                ]
                            },
                        ]
                    },
                    'NextToken': 'string',
                    'StartTime': datetime(2015, 1, 1)
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **JourneyDateRangeKpiResponse** *(dict) --*

              Provides the results of a query that retrieved the data for a standard engagement
              metric that applies to a journey, and provides information about that query.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the metric applies to.

              - **EndTime** *(datetime) --*

                The last date and time of the date range that was used to filter the query results,
                in extended ISO 8601 format. The date range is inclusive.

              - **JourneyId** *(string) --*

                The unique identifier for the journey that the metric applies to.

              - **KpiName** *(string) --*

                The name of the metric, also referred to as a *key performance indicator (KPI)* ,
                that the data was retrieved for. This value describes the associated metric and
                consists of two or more terms, which are comprised of lowercase alphanumeric
                characters, separated by a hyphen. For a list of possible values, see the `Amazon
                Pinpoint Developer Guide
                <https://docs.aws.amazon.com/pinpoint/latest/developerguide/welcome.html>`__ .

              - **KpiResult** *(dict) --*

                An array of objects that contains the results of the query. Each object contains the
                value for the metric and metadata about that value.

                - **Rows** *(list) --*

                  An array of objects that provides the results of a query that retrieved the data
                  for a standard metric that applies to an application, campaign, or journey.

                  - *(dict) --*

                    Provides the results of a query that retrieved the data for a standard metric
                    that applies to an application, campaign, or journey.

                    - **GroupedBys** *(list) --*

                      An array of objects that defines the field and field values that were used to
                      group data in a result set that contains multiple results. This value is null
                      if the data in a result set isn’t grouped.

                      - *(dict) --*

                        Provides a single value and metadata about that value as part of an array of
                        query results for a standard metric that applies to an application,
                        campaign, or journey.

                        - **Key** *(string) --*

                          The friendly name of the metric whose value is specified by the Value
                          property.

                        - **Type** *(string) --*

                          The data type of the value specified by the Value property.

                        - **Value** *(string) --*

                          In a Values object, the value for the metric that the query retrieved data
                          for. In a GroupedBys object, the value for the field that was used to
                          group data in a result set that contains multiple results (Values
                          objects).

                    - **Values** *(list) --*

                      An array of objects that provides pre-aggregated values for a standard metric
                      that applies to an application, campaign, or journey.

                      - *(dict) --*

                        Provides a single value and metadata about that value as part of an array of
                        query results for a standard metric that applies to an application,
                        campaign, or journey.

                        - **Key** *(string) --*

                          The friendly name of the metric whose value is specified by the Value
                          property.

                        - **Type** *(string) --*

                          The data type of the value specified by the Value property.

                        - **Value** *(string) --*

                          In a Values object, the value for the metric that the query retrieved data
                          for. In a GroupedBys object, the value for the field that was used to
                          group data in a result set that contains multiple results (Values
                          objects).

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null for the Journey Engagement Metrics resource
                because the resource returns all results in a single page.

              - **StartTime** *(datetime) --*

                The first date and time of the date range that was used to filter the query results,
                in extended ISO 8601 format. The date range is inclusive.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_journey_execution_activity_metrics(
        self,
        ApplicationId: str,
        JourneyActivityId: str,
        JourneyId: str,
        NextToken: str = None,
        PageSize: str = None,
    ) -> ClientGetJourneyExecutionActivityMetricsResponseTypeDef:
        """
        Retrieves (queries) pre-aggregated data for a standard execution metric that applies to a
        journey activity.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetJourneyExecutionActivityMetrics>`_

        **Request Syntax**
        ::

          response = client.get_journey_execution_activity_metrics(
              ApplicationId='string',
              JourneyActivityId='string',
              JourneyId='string',
              NextToken='string',
              PageSize='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type JourneyActivityId: string
        :param JourneyActivityId: **[REQUIRED]**

          The unique identifier for the journey activity.

        :type JourneyId: string
        :param JourneyId: **[REQUIRED]**

          The unique identifier for the journey.

        :type NextToken: string
        :param NextToken:

          The string that specifies which page of results to return in a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'JourneyExecutionActivityMetricsResponse': {
                    'ActivityType': 'string',
                    'ApplicationId': 'string',
                    'JourneyActivityId': 'string',
                    'JourneyId': 'string',
                    'LastEvaluatedTime': 'string',
                    'Metrics': {
                        'string': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **JourneyExecutionActivityMetricsResponse** *(dict) --*

              Provides the results of a query that retrieved the data for a standard execution
              metric that applies to a journey activity, and provides information about that query.

              - **ActivityType** *(string) --*

                The type of activity that the metric applies to. Possible values are:

                * CONDITIONAL_SPLIT - For a yes/no split activity, which is an activity that sends
                participants down one of two paths in a journey.

                * HOLDOUT - For a holdout activity, which is an activity that stops a journey for a
                specified percentage of participants.

                * MESSAGE - For an email activity, which is an activity that sends an email message
                to participants.

                * MULTI_CONDITIONAL_SPLIT - For a multivariate split activity, which is an activity
                that sends participants down one of as many as five paths in a journey.

                * RANDOM_SPLIT - For a random split activity, which is an activity that sends
                specified percentages of participants down one of as many as five paths in a
                journey.

                * WAIT - For a wait activity, which is an activity that waits for a certain amount
                of time or until a specific date and time before moving participants to the next
                activity in a journey.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the metric applies to.

              - **JourneyActivityId** *(string) --*

                The unique identifier for the activity that the metric applies to.

              - **JourneyId** *(string) --*

                The unique identifier for the journey that the metric applies to.

              - **LastEvaluatedTime** *(string) --*

                The date and time, in ISO 8601 format, when Amazon Pinpoint last evaluated the
                execution status of the activity and updated the data for the metric.

              - **Metrics** *(dict) --*

                A JSON object that contains the results of the query. The results vary depending on
                the type of activity (ActivityType). For information about the structure and
                contents of the results, see the `Amazon Pinpoint Developer Guide
                <https://docs.aws.amazon.com/pinpoint/latest/developerguide/welcome.html>`__ .

                - *(string) --*

                  - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_journey_execution_metrics(
        self, ApplicationId: str, JourneyId: str, NextToken: str = None, PageSize: str = None
    ) -> ClientGetJourneyExecutionMetricsResponseTypeDef:
        """
        Retrieves (queries) pre-aggregated data for a standard execution metric that applies to a
        journey.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetJourneyExecutionMetrics>`_

        **Request Syntax**
        ::

          response = client.get_journey_execution_metrics(
              ApplicationId='string',
              JourneyId='string',
              NextToken='string',
              PageSize='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type JourneyId: string
        :param JourneyId: **[REQUIRED]**

          The unique identifier for the journey.

        :type NextToken: string
        :param NextToken:

          The string that specifies which page of results to return in a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'JourneyExecutionMetricsResponse': {
                    'ApplicationId': 'string',
                    'JourneyId': 'string',
                    'LastEvaluatedTime': 'string',
                    'Metrics': {
                        'string': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **JourneyExecutionMetricsResponse** *(dict) --*

              Provides the results of a query that retrieved the data for a standard execution
              metric that applies to a journey, and provides information about that query.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the metric applies to.

              - **JourneyId** *(string) --*

                The unique identifier for the journey that the metric applies to.

              - **LastEvaluatedTime** *(string) --*

                The date and time, in ISO 8601 format, when Amazon Pinpoint last evaluated the
                journey and updated the data for the metric.

              - **Metrics** *(dict) --*

                A JSON object that contains the results of the query. For information about the
                structure and contents of the results, see the `Amazon Pinpoint Developer Guide
                <https://docs.aws.amazon.com/pinpoint/latest/developerguide/welcome.html>`__ .

                - *(string) --*

                  - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_push_template(self, TemplateName: str) -> ClientGetPushTemplateResponseTypeDef:
        """
        Retrieves the content and settings for a message template that you can use in messages that
        are sent through a push notification channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetPushTemplate>`_

        **Request Syntax**
        ::

          response = client.get_push_template(
              TemplateName='string'
          )
        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'PushNotificationTemplateResponse': {
                    'ADM': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageUrl': 'string',
                        'RawContent': 'string',
                        'SmallImageIconUrl': 'string',
                        'Sound': 'string',
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'APNS': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'Sound': 'string',
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'Arn': 'string',
                    'Baidu': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageUrl': 'string',
                        'RawContent': 'string',
                        'SmallImageIconUrl': 'string',
                        'Sound': 'string',
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'CreationDate': 'string',
                    'Default': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'Sound': 'string',
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'DefaultSubstitutions': 'string',
                    'GCM': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageUrl': 'string',
                        'RawContent': 'string',
                        'SmallImageIconUrl': 'string',
                        'Sound': 'string',
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'LastModifiedDate': 'string',
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateDescription': 'string',
                    'TemplateName': 'string',
                    'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **PushNotificationTemplateResponse** *(dict) --*

              Provides information about the content and settings for a message template that can be
              used in messages that are sent through a push notification channel.

              - **ADM** *(dict) --*

                The message template that's used for the ADM (Amazon Device Messaging) channel. This
                message template overrides the default template for push notification channels
                (DefaultPushNotificationTemplate).

                - **Action** *(string) --*

                  The action to occur if a recipient taps a push notification that's based on the
                  message template. Valid values are:

                  * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                  background. This is the default action.

                  * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                  This action uses the deep-linking features of the Android platform.

                  * URL - The default mobile browser on the recipient's device opens and loads the
                  web page at a URL that you specify.

                - **Body** *(string) --*

                  The message body to use in a push notification that's based on the message
                  template.

                - **ImageIconUrl** *(string) --*

                  The URL of the large icon image to display in the content view of a push
                  notification that's based on the message template.

                - **ImageUrl** *(string) --*

                  The URL of an image to display in a push notification that's based on the message
                  template.

                - **RawContent** *(string) --*

                  The raw, JSON-formatted string to use as the payload for a push notification
                  that's based on the message template. If specified, this value overrides all other
                  content for the message template.

                - **SmallImageIconUrl** *(string) --*

                  The URL of the small icon image to display in the status bar and the content view
                  of a push notification that's based on the message template.

                - **Sound** *(string) --*

                  The sound to play when a recipient receives a push notification that's based on
                  the message template. You can use the default stream or specify the file name of a
                  sound resource that's bundled in your app. On an Android platform, the sound file
                  must reside in /res/raw/.

                - **Title** *(string) --*

                  The title to use in a push notification that's based on the message template. This
                  title appears above the notification message on a recipient's device.

                - **Url** *(string) --*

                  The URL to open in a recipient's default mobile browser, if a recipient taps a a
                  push notification that's based on the message template and the value of the Action
                  property is URL.

              - **APNS** *(dict) --*

                The message template that's used for the APNs (Apple Push Notification service)
                channel. This message template overrides the default template for push notification
                channels (DefaultPushNotificationTemplate).

                - **Action** *(string) --*

                  The action to occur if a recipient taps a push notification that's based on the
                  message template. Valid values are:

                  * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                  background. This is the default action.

                  * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                  This setting uses the deep-linking features of the iOS platform.

                  * URL - The default mobile browser on the recipient's device opens and loads the
                  web page at a URL that you specify.

                - **Body** *(string) --*

                  The message body to use in push notifications that are based on the message
                  template.

                - **MediaUrl** *(string) --*

                  The URL of an image or video to display in push notifications that are based on
                  the message template.

                - **RawContent** *(string) --*

                  The raw, JSON-formatted string to use as the payload for push notifications that
                  are based on the message template. If specified, this value overrides all other
                  content for the message template.

                - **Sound** *(string) --*

                  The key for the sound to play when the recipient receives a push notification
                  that's based on the message template. The value for this key is the name of a
                  sound file in your app's main bundle or the Library/Sounds folder in your app's
                  data container. If the sound file can't be found or you specify default for the
                  value, the system plays the default alert sound.

                - **Title** *(string) --*

                  The title to use in push notifications that are based on the message template.
                  This title appears above the notification message on a recipient's device.

                - **Url** *(string) --*

                  The URL to open in the recipient's default mobile browser, if a recipient taps a
                  push notification that's based on the message template and the value of the Action
                  property is URL.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the message template.

              - **Baidu** *(dict) --*

                The message template that's used for the Baidu (Baidu Cloud Push) channel. This
                message template overrides the default template for push notification channels
                (DefaultPushNotificationTemplate).

                - **Action** *(string) --*

                  The action to occur if a recipient taps a push notification that's based on the
                  message template. Valid values are:

                  * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                  background. This is the default action.

                  * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                  This action uses the deep-linking features of the Android platform.

                  * URL - The default mobile browser on the recipient's device opens and loads the
                  web page at a URL that you specify.

                - **Body** *(string) --*

                  The message body to use in a push notification that's based on the message
                  template.

                - **ImageIconUrl** *(string) --*

                  The URL of the large icon image to display in the content view of a push
                  notification that's based on the message template.

                - **ImageUrl** *(string) --*

                  The URL of an image to display in a push notification that's based on the message
                  template.

                - **RawContent** *(string) --*

                  The raw, JSON-formatted string to use as the payload for a push notification
                  that's based on the message template. If specified, this value overrides all other
                  content for the message template.

                - **SmallImageIconUrl** *(string) --*

                  The URL of the small icon image to display in the status bar and the content view
                  of a push notification that's based on the message template.

                - **Sound** *(string) --*

                  The sound to play when a recipient receives a push notification that's based on
                  the message template. You can use the default stream or specify the file name of a
                  sound resource that's bundled in your app. On an Android platform, the sound file
                  must reside in /res/raw/.

                - **Title** *(string) --*

                  The title to use in a push notification that's based on the message template. This
                  title appears above the notification message on a recipient's device.

                - **Url** *(string) --*

                  The URL to open in a recipient's default mobile browser, if a recipient taps a a
                  push notification that's based on the message template and the value of the Action
                  property is URL.

              - **CreationDate** *(string) --*

                The date when the message template was created.

              - **Default** *(dict) --*

                The default message template that's used for push notification channels.

                - **Action** *(string) --*

                  The action to occur if a recipient taps a push notification that's based on the
                  message template. Valid values are:

                  * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                  background. This is the default action.

                  * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                  This setting uses the deep-linking features of the iOS and Android platforms.

                  * URL - The default mobile browser on the recipient's device opens and loads the
                  web page at a URL that you specify.

                - **Body** *(string) --*

                  The message body to use in push notifications that are based on the message
                  template.

                - **Sound** *(string) --*

                  The sound to play when a recipient receives a push notification that's based on
                  the message template. You can use the default stream or specify the file name of a
                  sound resource that's bundled in your app. On an Android platform, the sound file
                  must reside in /res/raw/.

                  For an iOS platform, this value is the key for the name of a sound file in your
                  app's main bundle or the Library/Sounds folder in your app's data container. If
                  the sound file can't be found or you specify default for the value, the system
                  plays the default alert sound.

                - **Title** *(string) --*

                  The title to use in push notifications that are based on the message template.
                  This title appears above the notification message on a recipient's device.

                - **Url** *(string) --*

                  The URL to open in a recipient's default mobile browser, if a recipient taps a
                  push notification that's based on the message template and the value of the Action
                  property is URL.

              - **DefaultSubstitutions** *(string) --*

                The JSON object that specifies the default values that are used for message
                variables in the message template. This object is a set of key-value pairs. Each key
                defines a message variable in the template. The corresponding value defines the
                default value for that variable.

              - **GCM** *(dict) --*

                The message template that's used for the GCM channel, which is used to send
                notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud
                Messaging (GCM), service. This message template overrides the default template for
                push notification channels (DefaultPushNotificationTemplate).

                - **Action** *(string) --*

                  The action to occur if a recipient taps a push notification that's based on the
                  message template. Valid values are:

                  * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                  background. This is the default action.

                  * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                  This action uses the deep-linking features of the Android platform.

                  * URL - The default mobile browser on the recipient's device opens and loads the
                  web page at a URL that you specify.

                - **Body** *(string) --*

                  The message body to use in a push notification that's based on the message
                  template.

                - **ImageIconUrl** *(string) --*

                  The URL of the large icon image to display in the content view of a push
                  notification that's based on the message template.

                - **ImageUrl** *(string) --*

                  The URL of an image to display in a push notification that's based on the message
                  template.

                - **RawContent** *(string) --*

                  The raw, JSON-formatted string to use as the payload for a push notification
                  that's based on the message template. If specified, this value overrides all other
                  content for the message template.

                - **SmallImageIconUrl** *(string) --*

                  The URL of the small icon image to display in the status bar and the content view
                  of a push notification that's based on the message template.

                - **Sound** *(string) --*

                  The sound to play when a recipient receives a push notification that's based on
                  the message template. You can use the default stream or specify the file name of a
                  sound resource that's bundled in your app. On an Android platform, the sound file
                  must reside in /res/raw/.

                - **Title** *(string) --*

                  The title to use in a push notification that's based on the message template. This
                  title appears above the notification message on a recipient's device.

                - **Url** *(string) --*

                  The URL to open in a recipient's default mobile browser, if a recipient taps a a
                  push notification that's based on the message template and the value of the Action
                  property is URL.

              - **LastModifiedDate** *(string) --*

                The date when the message template was last modified.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the message template. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **TemplateDescription** *(string) --*

                The custom description of the message template.

              - **TemplateName** *(string) --*

                The name of the message template.

              - **TemplateType** *(string) --*

                The type of channel that the message template is designed for. For a push
                notification template, this value is PUSH.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_segment(self, ApplicationId: str, SegmentId: str) -> ClientGetSegmentResponseTypeDef:
        """
        Retrieves information about the configuration, dimension, and other settings for a specific
        segment that's associated with an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetSegment>`_

        **Request Syntax**
        ::

          response = client.get_segment(
              ApplicationId='string',
              SegmentId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type SegmentId: string
        :param SegmentId: **[REQUIRED]**

          The unique identifier for the segment.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SegmentResponse': {
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Behavior': {
                            'Recency': {
                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                'RecencyType': 'ACTIVE'|'INACTIVE'
                            }
                        },
                        'Demographic': {
                            'AppVersion': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Channel': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'DeviceType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Make': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Model': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Platform': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Location': {
                            'Country': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'GPSPoint': {
                                'Coordinates': {
                                    'Latitude': 123.0,
                                    'Longitude': 123.0
                                },
                                'RangeInKilometers': 123.0
                            }
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        },
                        'UserAttributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        }
                    },
                    'Id': 'string',
                    'ImportDefinition': {
                        'ChannelCounts': {
                            'string': 123
                        },
                        'ExternalId': 'string',
                        'Format': 'CSV'|'JSON',
                        'RoleArn': 'string',
                        'S3Url': 'string',
                        'Size': 123
                    },
                    'LastModifiedDate': 'string',
                    'Name': 'string',
                    'SegmentGroups': {
                        'Groups': [
                            {
                                'Dimensions': [
                                    {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    },
                                ],
                                'SourceSegments': [
                                    {
                                        'Id': 'string',
                                        'Version': 123
                                    },
                                ],
                                'SourceType': 'ALL'|'ANY'|'NONE',
                                'Type': 'ALL'|'ANY'|'NONE'
                            },
                        ],
                        'Include': 'ALL'|'ANY'|'NONE'
                    },
                    'SegmentType': 'DIMENSIONAL'|'IMPORT',
                    'tags': {
                        'string': 'string'
                    },
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **SegmentResponse** *(dict) --*

              Provides information about the configuration, dimension, and other settings for a
              segment.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the segment is associated with.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the segment.

              - **CreationDate** *(string) --*

                The date and time when the segment was created.

              - **Dimensions** *(dict) --*

                The dimension settings for the segment.

                - **Attributes** *(dict) --*

                  One or more custom attributes to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

                - **Behavior** *(dict) --*

                  The behavior-based criteria, such as how recently users have used your app, for
                  the segment.

                  - **Recency** *(dict) --*

                    The dimension settings that are based on how recently an endpoint was active.

                    - **Duration** *(string) --*

                      The duration to use when determining whether an endpoint is active or
                      inactive.

                    - **RecencyType** *(string) --*

                      The type of recency dimension to use for the segment. Valid values are:
                      ACTIVE, endpoints that were active within the specified duration are included
                      in the segment; and, INACTIVE, endpoints that weren't active within the
                      specified duration are included in the segment.

                - **Demographic** *(dict) --*

                  The demographic-based criteria, such as device platform, for the segment.

                  - **AppVersion** *(dict) --*

                    The app version criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Channel** *(dict) --*

                    The channel criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **DeviceType** *(dict) --*

                    The device type criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Make** *(dict) --*

                    The device make criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Model** *(dict) --*

                    The device model criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Platform** *(dict) --*

                    The device platform criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                - **Location** *(dict) --*

                  The location-based criteria, such as region or GPS coordinates, for the segment.

                  - **Country** *(dict) --*

                    The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **GPSPoint** *(dict) --*

                    The GPS location and range for the segment.

                    - **Coordinates** *(dict) --*

                      The GPS coordinates to measure distance from.

                      - **Latitude** *(float) --*

                        The latitude coordinate of the location.

                      - **Longitude** *(float) --*

                        The longitude coordinate of the location.

                    - **RangeInKilometers** *(float) --*

                      The range, in kilometers, from the GPS coordinates.

                - **Metrics** *(dict) --*

                  One or more custom metrics to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies metric-based criteria for including or excluding endpoints from a
                      segment. These criteria derive from custom metrics that you define for
                      endpoints.

                      - **ComparisonOperator** *(string) --*

                        The operator to use when comparing metric values. Valid values are:
                        GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                        EQUAL.

                      - **Value** *(float) --*

                        The value to compare.

                - **UserAttributes** *(dict) --*

                  One or more custom user attributes to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

              - **Id** *(string) --*

                The unique identifier for the segment.

              - **ImportDefinition** *(dict) --*

                The settings for the import job that's associated with the segment.

                - **ChannelCounts** *(dict) --*

                  The number of channel types in the endpoint definitions that were imported to
                  create the segment.

                  - *(string) --*

                    - *(integer) --*

                - **ExternalId** *(string) --*

                  (Deprecated) Your AWS account ID, which you assigned to an external ID key in an
                  IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role
                  when importing endpoint definitions, but we removed this requirement. We don't
                  recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

                - **Format** *(string) --*

                  The format of the files that were imported to create the segment. Valid values
                  are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON
                  format.

                - **RoleArn** *(string) --*

                  The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                  role that authorized Amazon Pinpoint to access the Amazon S3 location to import
                  endpoint definitions from.

                - **S3Url** *(string) --*

                  The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint
                  definitions were imported from to create the segment.

                - **Size** *(integer) --*

                  The number of endpoint definitions that were imported successfully to create the
                  segment.

              - **LastModifiedDate** *(string) --*

                The date and time when the segment was last modified.

              - **Name** *(string) --*

                The name of the segment.

              - **SegmentGroups** *(dict) --*

                A list of one or more segment groups that apply to the segment. Each segment group
                consists of zero or more base segments and the dimensions that are applied to those
                base segments.

                - **Groups** *(list) --*

                  An array that defines the set of segment criteria to evaluate when handling
                  segment groups for the segment.

                  - *(dict) --*

                    Specifies the base segments and dimensions for a segment, and the relationships
                    between these base segments and dimensions.

                    - **Dimensions** *(list) --*

                      An array that defines the dimensions for the segment.

                      - *(dict) --*

                        Specifies the dimension settings for a segment.

                        - **Attributes** *(dict) --*

                          One or more custom attributes to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **Behavior** *(dict) --*

                          The behavior-based criteria, such as how recently users have used your
                          app, for the segment.

                          - **Recency** *(dict) --*

                            The dimension settings that are based on how recently an endpoint was
                            active.

                            - **Duration** *(string) --*

                              The duration to use when determining whether an endpoint is active or
                              inactive.

                            - **RecencyType** *(string) --*

                              The type of recency dimension to use for the segment. Valid values
                              are: ACTIVE, endpoints that were active within the specified duration
                              are included in the segment; and, INACTIVE, endpoints that weren't
                              active within the specified duration are included in the segment.

                        - **Demographic** *(dict) --*

                          The demographic-based criteria, such as device platform, for the segment.

                          - **AppVersion** *(dict) --*

                            The app version criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Channel** *(dict) --*

                            The channel criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **DeviceType** *(dict) --*

                            The device type criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Make** *(dict) --*

                            The device make criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Model** *(dict) --*

                            The device model criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Platform** *(dict) --*

                            The device platform criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                        - **Location** *(dict) --*

                          The location-based criteria, such as region or GPS coordinates, for the
                          segment.

                          - **Country** *(dict) --*

                            The country or region code, in ISO 3166-1 alpha-2 format, for the
                            segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **GPSPoint** *(dict) --*

                            The GPS location and range for the segment.

                            - **Coordinates** *(dict) --*

                              The GPS coordinates to measure distance from.

                              - **Latitude** *(float) --*

                                The latitude coordinate of the location.

                              - **Longitude** *(float) --*

                                The longitude coordinate of the location.

                            - **RangeInKilometers** *(float) --*

                              The range, in kilometers, from the GPS coordinates.

                        - **Metrics** *(dict) --*

                          One or more custom metrics to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                        - **UserAttributes** *(dict) --*

                          One or more custom user attributes to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                    - **SourceSegments** *(list) --*

                      The base segment to build the segment on. A base segment, also referred to as
                      a *source segment* , defines the initial population of endpoints for a
                      segment. When you add dimensions to a segment, Amazon Pinpoint filters the
                      base segment by using the dimensions that you specify.

                      You can specify more than one dimensional segment or only one imported
                      segment. If you specify an imported segment, the Amazon Pinpoint console
                      displays a segment size estimate that indicates the size of the imported
                      segment without any filters applied to it.

                      - *(dict) --*

                        Specifies the segment identifier and version of a segment.

                        - **Id** *(string) --*

                          The unique identifier for the segment.

                        - **Version** *(integer) --*

                          The version number of the segment.

                    - **SourceType** *(string) --*

                      Specifies how to handle multiple base segments for the segment. For example,
                      if you specify three base segments for the segment, whether the resulting
                      segment is based on all, any, or none of the base segments.

                    - **Type** *(string) --*

                      Specifies how to handle multiple dimensions for the segment. For example, if
                      you specify three dimensions for the segment, whether the resulting segment
                      includes endpoints that match all, any, or none of the dimensions.

                - **Include** *(string) --*

                  Specifies how to handle multiple segment groups for the segment. For example, if
                  the segment includes three segment groups, whether the resulting segment includes
                  endpoints that match all, any, or none of the segment groups.

              - **SegmentType** *(string) --*

                The segment type. Valid values are:

                * DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria
                that you specify and is based on endpoint data that's reported by your app. Dynamic
                segments can change over time.

                * IMPORT - A static segment, which is a segment that uses selection criteria that
                you specify and is based on endpoint definitions that you import from a file.
                Imported segments are static; they don't change over time.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the segment. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **Version** *(integer) --*

                The version number of the segment.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_segment_export_jobs(
        self, ApplicationId: str, SegmentId: str, PageSize: str = None, Token: str = None
    ) -> ClientGetSegmentExportJobsResponseTypeDef:
        """
        Retrieves information about the status and settings of the export jobs for a segment.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetSegmentExportJobs>`_

        **Request Syntax**
        ::

          response = client.get_segment_export_jobs(
              ApplicationId='string',
              PageSize='string',
              SegmentId='string',
              Token='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type SegmentId: string
        :param SegmentId: **[REQUIRED]**

          The unique identifier for the segment.

        :type Token: string
        :param Token:

          The NextToken string that specifies which page of results to return in a paginated
          response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ExportJobsResponse': {
                    'Item': [
                        {
                            'ApplicationId': 'string',
                            'CompletedPieces': 123,
                            'CompletionDate': 'string',
                            'CreationDate': 'string',
                            'Definition': {
                                'RoleArn': 'string',
                                'S3UrlPrefix': 'string',
                                'SegmentId': 'string',
                                'SegmentVersion': 123
                            },
                            'FailedPieces': 123,
                            'Failures': [
                                'string',
                            ],
                            'Id': 'string',
                            'JobStatus':
                            'CREATED'|'PREPARING_FOR_INITIALIZATION'
                            |'INITIALIZING'|'PROCESSING'|'PENDING_JOB'
                            |'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                            'TotalFailures': 123,
                            'TotalPieces': 123,
                            'TotalProcessed': 123,
                            'Type': 'string'
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ExportJobsResponse** *(dict) --*

              Provides information about all the export jobs that are associated with an application
              or segment. An export job is a job that exports endpoint definitions to a file.

              - **Item** *(list) --*

                An array of responses, one for each export job that's associated with the
                application (Export Jobs resource) or segment (Segment Export Jobs resource).

                - *(dict) --*

                  Provides information about the status and settings of a job that exports endpoint
                  definitions to a file. The file can be added directly to an Amazon Simple Storage
                  Service (Amazon S3) bucket by using the Amazon Pinpoint API or downloaded directly
                  to a computer by using the Amazon Pinpoint console.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that's associated with the export job.

                  - **CompletedPieces** *(integer) --*

                    The number of pieces that were processed successfully (completed) by the export
                    job, as of the time of the request.

                  - **CompletionDate** *(string) --*

                    The date, in ISO 8601 format, when the export job was completed.

                  - **CreationDate** *(string) --*

                    The date, in ISO 8601 format, when the export job was created.

                  - **Definition** *(dict) --*

                    The resource settings that apply to the export job.

                    - **RoleArn** *(string) --*

                      The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                      role that authorized Amazon Pinpoint to access the Amazon S3 location where
                      the endpoint definitions were exported to.

                    - **S3UrlPrefix** *(string) --*

                      The URL of the location in an Amazon Simple Storage Service (Amazon S3) bucket
                      where the endpoint definitions were exported to. This location is typically a
                      folder that contains multiple files. The URL should be in the following
                      format: s3://bucket-name/folder-name/.

                    - **SegmentId** *(string) --*

                      The identifier for the segment that the endpoint definitions were exported
                      from. If this value isn't present, Amazon Pinpoint exported definitions for
                      all the endpoints that are associated with the application.

                    - **SegmentVersion** *(integer) --*

                      The version of the segment that the endpoint definitions were exported from.

                  - **FailedPieces** *(integer) --*

                    The number of pieces that weren't processed successfully (failed) by the export
                    job, as of the time of the request.

                  - **Failures** *(list) --*

                    An array of entries, one for each of the first 100 entries that weren't
                    processed successfully (failed) by the export job, if any.

                    - *(string) --*

                  - **Id** *(string) --*

                    The unique identifier for the export job.

                  - **JobStatus** *(string) --*

                    The status of the export job. The job status is FAILED if Amazon Pinpoint wasn't
                    able to process one or more pieces in the job.

                  - **TotalFailures** *(integer) --*

                    The total number of endpoint definitions that weren't processed successfully
                    (failed) by the export job, typically because an error, such as a syntax error,
                    occurred.

                  - **TotalPieces** *(integer) --*

                    The total number of pieces that must be processed to complete the export job.
                    Each piece consists of an approximately equal portion of the endpoint
                    definitions that are part of the export job.

                  - **TotalProcessed** *(integer) --*

                    The total number of endpoint definitions that were processed by the export job.

                  - **Type** *(string) --*

                    The job type. This value is EXPORT for export jobs.

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_segment_import_jobs(
        self, ApplicationId: str, SegmentId: str, PageSize: str = None, Token: str = None
    ) -> ClientGetSegmentImportJobsResponseTypeDef:
        """
        Retrieves information about the status and settings of the import jobs for a segment.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetSegmentImportJobs>`_

        **Request Syntax**
        ::

          response = client.get_segment_import_jobs(
              ApplicationId='string',
              PageSize='string',
              SegmentId='string',
              Token='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type SegmentId: string
        :param SegmentId: **[REQUIRED]**

          The unique identifier for the segment.

        :type Token: string
        :param Token:

          The NextToken string that specifies which page of results to return in a paginated
          response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ImportJobsResponse': {
                    'Item': [
                        {
                            'ApplicationId': 'string',
                            'CompletedPieces': 123,
                            'CompletionDate': 'string',
                            'CreationDate': 'string',
                            'Definition': {
                                'DefineSegment': True|False,
                                'ExternalId': 'string',
                                'Format': 'CSV'|'JSON',
                                'RegisterEndpoints': True|False,
                                'RoleArn': 'string',
                                'S3Url': 'string',
                                'SegmentId': 'string',
                                'SegmentName': 'string'
                            },
                            'FailedPieces': 123,
                            'Failures': [
                                'string',
                            ],
                            'Id': 'string',
                            'JobStatus':
                            'CREATED'|'PREPARING_FOR_INITIALIZATION'
                            |'INITIALIZING'|'PROCESSING'|'PENDING_JOB'
                            |'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                            'TotalFailures': 123,
                            'TotalPieces': 123,
                            'TotalProcessed': 123,
                            'Type': 'string'
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ImportJobsResponse** *(dict) --*

              Provides information about the status and settings of all the import jobs that are
              associated with an application or segment. An import job is a job that imports
              endpoint definitions from one or more files.

              - **Item** *(list) --*

                An array of responses, one for each import job that's associated with the
                application (Import Jobs resource) or segment (Segment Import Jobs resource).

                - *(dict) --*

                  Provides information about the status and settings of a job that imports endpoint
                  definitions from one or more files. The files can be stored in an Amazon Simple
                  Storage Service (Amazon S3) bucket or uploaded directly from a computer by using
                  the Amazon Pinpoint console.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that's associated with the import job.

                  - **CompletedPieces** *(integer) --*

                    The number of pieces that were processed successfully (completed) by the import
                    job, as of the time of the request.

                  - **CompletionDate** *(string) --*

                    The date, in ISO 8601 format, when the import job was completed.

                  - **CreationDate** *(string) --*

                    The date, in ISO 8601 format, when the import job was created.

                  - **Definition** *(dict) --*

                    The resource settings that apply to the import job.

                    - **DefineSegment** *(boolean) --*

                      Specifies whether the import job creates a segment that contains the
                      endpoints, when the endpoint definitions are imported.

                    - **ExternalId** *(string) --*

                      (Deprecated) Your AWS account ID, which you assigned to an external ID key in
                      an IAM trust policy. Amazon Pinpoint previously used this value to assume an
                      IAM role when importing endpoint definitions, but we removed this requirement.
                      We don't recommend use of external IDs for IAM roles that are assumed by
                      Amazon Pinpoint.

                    - **Format** *(string) --*

                      The format of the files that contain the endpoint definitions to import. Valid
                      values are: CSV, for comma-separated values format; and, JSON, for
                      newline-delimited JSON format.

                      If the files are stored in an Amazon S3 location and that location contains
                      multiple files that use different formats, Amazon Pinpoint imports data only
                      from the files that use the specified format.

                    - **RegisterEndpoints** *(boolean) --*

                      Specifies whether the import job registers the endpoints with Amazon Pinpoint,
                      when the endpoint definitions are imported.

                    - **RoleArn** *(string) --*

                      The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                      role that authorizes Amazon Pinpoint to access the Amazon S3 location to
                      import endpoint definitions from.

                    - **S3Url** *(string) --*

                      The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains
                      the endpoint definitions to import. This location can be a folder or a single
                      file. If the location is a folder, Amazon Pinpoint imports endpoint
                      definitions from the files in this location, including any subfolders that the
                      folder contains.

                      The URL should be in the following format:
                      s3://bucket-name/folder-name/file-name. The location can end with the key for
                      an individual object or a prefix that qualifies multiple objects.

                    - **SegmentId** *(string) --*

                      The identifier for the segment that the import job updates or adds endpoint
                      definitions to, if the import job updates an existing segment.

                    - **SegmentName** *(string) --*

                      The custom name for the segment that's created by the import job, if the value
                      of the DefineSegment property is true.

                  - **FailedPieces** *(integer) --*

                    The number of pieces that weren't processed successfully (failed) by the import
                    job, as of the time of the request.

                  - **Failures** *(list) --*

                    An array of entries, one for each of the first 100 entries that weren't
                    processed successfully (failed) by the import job, if any.

                    - *(string) --*

                  - **Id** *(string) --*

                    The unique identifier for the import job.

                  - **JobStatus** *(string) --*

                    The status of the import job. The job status is FAILED if Amazon Pinpoint wasn't
                    able to process one or more pieces in the job.

                  - **TotalFailures** *(integer) --*

                    The total number of endpoint definitions that weren't processed successfully
                    (failed) by the import job, typically because an error, such as a syntax error,
                    occurred.

                  - **TotalPieces** *(integer) --*

                    The total number of pieces that must be processed to complete the import job.
                    Each piece consists of an approximately equal portion of the endpoint
                    definitions that are part of the import job.

                  - **TotalProcessed** *(integer) --*

                    The total number of endpoint definitions that were processed by the import job.

                  - **Type** *(string) --*

                    The job type. This value is IMPORT for import jobs.

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_segment_version(
        self, ApplicationId: str, SegmentId: str, Version: str
    ) -> ClientGetSegmentVersionResponseTypeDef:
        """
        Retrieves information about the configuration, dimension, and other settings for a specific
        version of a segment that's associated with an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetSegmentVersion>`_

        **Request Syntax**
        ::

          response = client.get_segment_version(
              ApplicationId='string',
              SegmentId='string',
              Version='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type SegmentId: string
        :param SegmentId: **[REQUIRED]**

          The unique identifier for the segment.

        :type Version: string
        :param Version: **[REQUIRED]**

          The unique version number (Version property) for the campaign version.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SegmentResponse': {
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Behavior': {
                            'Recency': {
                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                'RecencyType': 'ACTIVE'|'INACTIVE'
                            }
                        },
                        'Demographic': {
                            'AppVersion': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Channel': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'DeviceType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Make': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Model': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Platform': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Location': {
                            'Country': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'GPSPoint': {
                                'Coordinates': {
                                    'Latitude': 123.0,
                                    'Longitude': 123.0
                                },
                                'RangeInKilometers': 123.0
                            }
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        },
                        'UserAttributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        }
                    },
                    'Id': 'string',
                    'ImportDefinition': {
                        'ChannelCounts': {
                            'string': 123
                        },
                        'ExternalId': 'string',
                        'Format': 'CSV'|'JSON',
                        'RoleArn': 'string',
                        'S3Url': 'string',
                        'Size': 123
                    },
                    'LastModifiedDate': 'string',
                    'Name': 'string',
                    'SegmentGroups': {
                        'Groups': [
                            {
                                'Dimensions': [
                                    {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    },
                                ],
                                'SourceSegments': [
                                    {
                                        'Id': 'string',
                                        'Version': 123
                                    },
                                ],
                                'SourceType': 'ALL'|'ANY'|'NONE',
                                'Type': 'ALL'|'ANY'|'NONE'
                            },
                        ],
                        'Include': 'ALL'|'ANY'|'NONE'
                    },
                    'SegmentType': 'DIMENSIONAL'|'IMPORT',
                    'tags': {
                        'string': 'string'
                    },
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **SegmentResponse** *(dict) --*

              Provides information about the configuration, dimension, and other settings for a
              segment.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the segment is associated with.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the segment.

              - **CreationDate** *(string) --*

                The date and time when the segment was created.

              - **Dimensions** *(dict) --*

                The dimension settings for the segment.

                - **Attributes** *(dict) --*

                  One or more custom attributes to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

                - **Behavior** *(dict) --*

                  The behavior-based criteria, such as how recently users have used your app, for
                  the segment.

                  - **Recency** *(dict) --*

                    The dimension settings that are based on how recently an endpoint was active.

                    - **Duration** *(string) --*

                      The duration to use when determining whether an endpoint is active or
                      inactive.

                    - **RecencyType** *(string) --*

                      The type of recency dimension to use for the segment. Valid values are:
                      ACTIVE, endpoints that were active within the specified duration are included
                      in the segment; and, INACTIVE, endpoints that weren't active within the
                      specified duration are included in the segment.

                - **Demographic** *(dict) --*

                  The demographic-based criteria, such as device platform, for the segment.

                  - **AppVersion** *(dict) --*

                    The app version criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Channel** *(dict) --*

                    The channel criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **DeviceType** *(dict) --*

                    The device type criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Make** *(dict) --*

                    The device make criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Model** *(dict) --*

                    The device model criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Platform** *(dict) --*

                    The device platform criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                - **Location** *(dict) --*

                  The location-based criteria, such as region or GPS coordinates, for the segment.

                  - **Country** *(dict) --*

                    The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **GPSPoint** *(dict) --*

                    The GPS location and range for the segment.

                    - **Coordinates** *(dict) --*

                      The GPS coordinates to measure distance from.

                      - **Latitude** *(float) --*

                        The latitude coordinate of the location.

                      - **Longitude** *(float) --*

                        The longitude coordinate of the location.

                    - **RangeInKilometers** *(float) --*

                      The range, in kilometers, from the GPS coordinates.

                - **Metrics** *(dict) --*

                  One or more custom metrics to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies metric-based criteria for including or excluding endpoints from a
                      segment. These criteria derive from custom metrics that you define for
                      endpoints.

                      - **ComparisonOperator** *(string) --*

                        The operator to use when comparing metric values. Valid values are:
                        GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                        EQUAL.

                      - **Value** *(float) --*

                        The value to compare.

                - **UserAttributes** *(dict) --*

                  One or more custom user attributes to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

              - **Id** *(string) --*

                The unique identifier for the segment.

              - **ImportDefinition** *(dict) --*

                The settings for the import job that's associated with the segment.

                - **ChannelCounts** *(dict) --*

                  The number of channel types in the endpoint definitions that were imported to
                  create the segment.

                  - *(string) --*

                    - *(integer) --*

                - **ExternalId** *(string) --*

                  (Deprecated) Your AWS account ID, which you assigned to an external ID key in an
                  IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role
                  when importing endpoint definitions, but we removed this requirement. We don't
                  recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

                - **Format** *(string) --*

                  The format of the files that were imported to create the segment. Valid values
                  are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON
                  format.

                - **RoleArn** *(string) --*

                  The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                  role that authorized Amazon Pinpoint to access the Amazon S3 location to import
                  endpoint definitions from.

                - **S3Url** *(string) --*

                  The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint
                  definitions were imported from to create the segment.

                - **Size** *(integer) --*

                  The number of endpoint definitions that were imported successfully to create the
                  segment.

              - **LastModifiedDate** *(string) --*

                The date and time when the segment was last modified.

              - **Name** *(string) --*

                The name of the segment.

              - **SegmentGroups** *(dict) --*

                A list of one or more segment groups that apply to the segment. Each segment group
                consists of zero or more base segments and the dimensions that are applied to those
                base segments.

                - **Groups** *(list) --*

                  An array that defines the set of segment criteria to evaluate when handling
                  segment groups for the segment.

                  - *(dict) --*

                    Specifies the base segments and dimensions for a segment, and the relationships
                    between these base segments and dimensions.

                    - **Dimensions** *(list) --*

                      An array that defines the dimensions for the segment.

                      - *(dict) --*

                        Specifies the dimension settings for a segment.

                        - **Attributes** *(dict) --*

                          One or more custom attributes to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **Behavior** *(dict) --*

                          The behavior-based criteria, such as how recently users have used your
                          app, for the segment.

                          - **Recency** *(dict) --*

                            The dimension settings that are based on how recently an endpoint was
                            active.

                            - **Duration** *(string) --*

                              The duration to use when determining whether an endpoint is active or
                              inactive.

                            - **RecencyType** *(string) --*

                              The type of recency dimension to use for the segment. Valid values
                              are: ACTIVE, endpoints that were active within the specified duration
                              are included in the segment; and, INACTIVE, endpoints that weren't
                              active within the specified duration are included in the segment.

                        - **Demographic** *(dict) --*

                          The demographic-based criteria, such as device platform, for the segment.

                          - **AppVersion** *(dict) --*

                            The app version criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Channel** *(dict) --*

                            The channel criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **DeviceType** *(dict) --*

                            The device type criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Make** *(dict) --*

                            The device make criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Model** *(dict) --*

                            The device model criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Platform** *(dict) --*

                            The device platform criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                        - **Location** *(dict) --*

                          The location-based criteria, such as region or GPS coordinates, for the
                          segment.

                          - **Country** *(dict) --*

                            The country or region code, in ISO 3166-1 alpha-2 format, for the
                            segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **GPSPoint** *(dict) --*

                            The GPS location and range for the segment.

                            - **Coordinates** *(dict) --*

                              The GPS coordinates to measure distance from.

                              - **Latitude** *(float) --*

                                The latitude coordinate of the location.

                              - **Longitude** *(float) --*

                                The longitude coordinate of the location.

                            - **RangeInKilometers** *(float) --*

                              The range, in kilometers, from the GPS coordinates.

                        - **Metrics** *(dict) --*

                          One or more custom metrics to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                        - **UserAttributes** *(dict) --*

                          One or more custom user attributes to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                    - **SourceSegments** *(list) --*

                      The base segment to build the segment on. A base segment, also referred to as
                      a *source segment* , defines the initial population of endpoints for a
                      segment. When you add dimensions to a segment, Amazon Pinpoint filters the
                      base segment by using the dimensions that you specify.

                      You can specify more than one dimensional segment or only one imported
                      segment. If you specify an imported segment, the Amazon Pinpoint console
                      displays a segment size estimate that indicates the size of the imported
                      segment without any filters applied to it.

                      - *(dict) --*

                        Specifies the segment identifier and version of a segment.

                        - **Id** *(string) --*

                          The unique identifier for the segment.

                        - **Version** *(integer) --*

                          The version number of the segment.

                    - **SourceType** *(string) --*

                      Specifies how to handle multiple base segments for the segment. For example,
                      if you specify three base segments for the segment, whether the resulting
                      segment is based on all, any, or none of the base segments.

                    - **Type** *(string) --*

                      Specifies how to handle multiple dimensions for the segment. For example, if
                      you specify three dimensions for the segment, whether the resulting segment
                      includes endpoints that match all, any, or none of the dimensions.

                - **Include** *(string) --*

                  Specifies how to handle multiple segment groups for the segment. For example, if
                  the segment includes three segment groups, whether the resulting segment includes
                  endpoints that match all, any, or none of the segment groups.

              - **SegmentType** *(string) --*

                The segment type. Valid values are:

                * DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria
                that you specify and is based on endpoint data that's reported by your app. Dynamic
                segments can change over time.

                * IMPORT - A static segment, which is a segment that uses selection criteria that
                you specify and is based on endpoint definitions that you import from a file.
                Imported segments are static; they don't change over time.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the segment. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **Version** *(integer) --*

                The version number of the segment.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_segment_versions(
        self, ApplicationId: str, SegmentId: str, PageSize: str = None, Token: str = None
    ) -> ClientGetSegmentVersionsResponseTypeDef:
        """
        Retrieves information about the configuration, dimension, and other settings for all
        versions of a specific segment that's associated with an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetSegmentVersions>`_

        **Request Syntax**
        ::

          response = client.get_segment_versions(
              ApplicationId='string',
              PageSize='string',
              SegmentId='string',
              Token='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type SegmentId: string
        :param SegmentId: **[REQUIRED]**

          The unique identifier for the segment.

        :type Token: string
        :param Token:

          The NextToken string that specifies which page of results to return in a paginated
          response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SegmentsResponse': {
                    'Item': [
                        {
                            'ApplicationId': 'string',
                            'Arn': 'string',
                            'CreationDate': 'string',
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Behavior': {
                                    'Recency': {
                                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                    }
                                },
                                'Demographic': {
                                    'AppVersion': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Channel': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'DeviceType': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Make': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Model': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Platform': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Location': {
                                    'Country': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'GPSPoint': {
                                        'Coordinates': {
                                            'Latitude': 123.0,
                                            'Longitude': 123.0
                                        },
                                        'RangeInKilometers': 123.0
                                    }
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                },
                                'UserAttributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                }
                            },
                            'Id': 'string',
                            'ImportDefinition': {
                                'ChannelCounts': {
                                    'string': 123
                                },
                                'ExternalId': 'string',
                                'Format': 'CSV'|'JSON',
                                'RoleArn': 'string',
                                'S3Url': 'string',
                                'Size': 123
                            },
                            'LastModifiedDate': 'string',
                            'Name': 'string',
                            'SegmentGroups': {
                                'Groups': [
                                    {
                                        'Dimensions': [
                                            {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            },
                                        ],
                                        'SourceSegments': [
                                            {
                                                'Id': 'string',
                                                'Version': 123
                                            },
                                        ],
                                        'SourceType': 'ALL'|'ANY'|'NONE',
                                        'Type': 'ALL'|'ANY'|'NONE'
                                    },
                                ],
                                'Include': 'ALL'|'ANY'|'NONE'
                            },
                            'SegmentType': 'DIMENSIONAL'|'IMPORT',
                            'tags': {
                                'string': 'string'
                            },
                            'Version': 123
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **SegmentsResponse** *(dict) --*

              Provides information about all the segments that are associated with an application.

              - **Item** *(list) --*

                An array of responses, one for each segment that's associated with the application
                (Segments resource) or each version of a segment that's associated with the
                application (Segment Versions resource).

                - *(dict) --*

                  Provides information about the configuration, dimension, and other settings for a
                  segment.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that the segment is associated with.

                  - **Arn** *(string) --*

                    The Amazon Resource Name (ARN) of the segment.

                  - **CreationDate** *(string) --*

                    The date and time when the segment was created.

                  - **Dimensions** *(dict) --*

                    The dimension settings for the segment.

                    - **Attributes** *(dict) --*

                      One or more custom attributes to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                    - **Behavior** *(dict) --*

                      The behavior-based criteria, such as how recently users have used your app,
                      for the segment.

                      - **Recency** *(dict) --*

                        The dimension settings that are based on how recently an endpoint was
                        active.

                        - **Duration** *(string) --*

                          The duration to use when determining whether an endpoint is active or
                          inactive.

                        - **RecencyType** *(string) --*

                          The type of recency dimension to use for the segment. Valid values are:
                          ACTIVE, endpoints that were active within the specified duration are
                          included in the segment; and, INACTIVE, endpoints that weren't active
                          within the specified duration are included in the segment.

                    - **Demographic** *(dict) --*

                      The demographic-based criteria, such as device platform, for the segment.

                      - **AppVersion** *(dict) --*

                        The app version criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Channel** *(dict) --*

                        The channel criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **DeviceType** *(dict) --*

                        The device type criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Make** *(dict) --*

                        The device make criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Model** *(dict) --*

                        The device model criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Platform** *(dict) --*

                        The device platform criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                    - **Location** *(dict) --*

                      The location-based criteria, such as region or GPS coordinates, for the
                      segment.

                      - **Country** *(dict) --*

                        The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **GPSPoint** *(dict) --*

                        The GPS location and range for the segment.

                        - **Coordinates** *(dict) --*

                          The GPS coordinates to measure distance from.

                          - **Latitude** *(float) --*

                            The latitude coordinate of the location.

                          - **Longitude** *(float) --*

                            The longitude coordinate of the location.

                        - **RangeInKilometers** *(float) --*

                          The range, in kilometers, from the GPS coordinates.

                    - **Metrics** *(dict) --*

                      One or more custom metrics to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies metric-based criteria for including or excluding endpoints from
                          a segment. These criteria derive from custom metrics that you define for
                          endpoints.

                          - **ComparisonOperator** *(string) --*

                            The operator to use when comparing metric values. Valid values are:
                            GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                            EQUAL.

                          - **Value** *(float) --*

                            The value to compare.

                    - **UserAttributes** *(dict) --*

                      One or more custom user attributes to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                  - **Id** *(string) --*

                    The unique identifier for the segment.

                  - **ImportDefinition** *(dict) --*

                    The settings for the import job that's associated with the segment.

                    - **ChannelCounts** *(dict) --*

                      The number of channel types in the endpoint definitions that were imported to
                      create the segment.

                      - *(string) --*

                        - *(integer) --*

                    - **ExternalId** *(string) --*

                      (Deprecated) Your AWS account ID, which you assigned to an external ID key in
                      an IAM trust policy. Amazon Pinpoint previously used this value to assume an
                      IAM role when importing endpoint definitions, but we removed this requirement.
                      We don't recommend use of external IDs for IAM roles that are assumed by
                      Amazon Pinpoint.

                    - **Format** *(string) --*

                      The format of the files that were imported to create the segment. Valid values
                      are: CSV, for comma-separated values format; and, JSON, for newline-delimited
                      JSON format.

                    - **RoleArn** *(string) --*

                      The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                      role that authorized Amazon Pinpoint to access the Amazon S3 location to
                      import endpoint definitions from.

                    - **S3Url** *(string) --*

                      The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the
                      endpoint definitions were imported from to create the segment.

                    - **Size** *(integer) --*

                      The number of endpoint definitions that were imported successfully to create
                      the segment.

                  - **LastModifiedDate** *(string) --*

                    The date and time when the segment was last modified.

                  - **Name** *(string) --*

                    The name of the segment.

                  - **SegmentGroups** *(dict) --*

                    A list of one or more segment groups that apply to the segment. Each segment
                    group consists of zero or more base segments and the dimensions that are applied
                    to those base segments.

                    - **Groups** *(list) --*

                      An array that defines the set of segment criteria to evaluate when handling
                      segment groups for the segment.

                      - *(dict) --*

                        Specifies the base segments and dimensions for a segment, and the
                        relationships between these base segments and dimensions.

                        - **Dimensions** *(list) --*

                          An array that defines the dimensions for the segment.

                          - *(dict) --*

                            Specifies the dimension settings for a segment.

                            - **Attributes** *(dict) --*

                              One or more custom attributes to use as criteria for the segment.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies attribute-based criteria for including or excluding
                                  endpoints from a segment.

                                  - **AttributeType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the AttributeType property, endpoints are
                                    included or excluded from the segment if their attribute values
                                    match the criteria values.

                                    - *(string) --*

                            - **Behavior** *(dict) --*

                              The behavior-based criteria, such as how recently users have used your
                              app, for the segment.

                              - **Recency** *(dict) --*

                                The dimension settings that are based on how recently an endpoint
                                was active.

                                - **Duration** *(string) --*

                                  The duration to use when determining whether an endpoint is active
                                  or inactive.

                                - **RecencyType** *(string) --*

                                  The type of recency dimension to use for the segment. Valid values
                                  are: ACTIVE, endpoints that were active within the specified
                                  duration are included in the segment; and, INACTIVE, endpoints
                                  that weren't active within the specified duration are included in
                                  the segment.

                            - **Demographic** *(dict) --*

                              The demographic-based criteria, such as device platform, for the
                              segment.

                              - **AppVersion** *(dict) --*

                                The app version criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **Channel** *(dict) --*

                                The channel criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **DeviceType** *(dict) --*

                                The device type criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **Make** *(dict) --*

                                The device make criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **Model** *(dict) --*

                                The device model criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **Platform** *(dict) --*

                                The device platform criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                            - **Location** *(dict) --*

                              The location-based criteria, such as region or GPS coordinates, for
                              the segment.

                              - **Country** *(dict) --*

                                The country or region code, in ISO 3166-1 alpha-2 format, for the
                                segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **GPSPoint** *(dict) --*

                                The GPS location and range for the segment.

                                - **Coordinates** *(dict) --*

                                  The GPS coordinates to measure distance from.

                                  - **Latitude** *(float) --*

                                    The latitude coordinate of the location.

                                  - **Longitude** *(float) --*

                                    The longitude coordinate of the location.

                                - **RangeInKilometers** *(float) --*

                                  The range, in kilometers, from the GPS coordinates.

                            - **Metrics** *(dict) --*

                              One or more custom metrics to use as criteria for the segment.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies metric-based criteria for including or excluding
                                  endpoints from a segment. These criteria derive from custom
                                  metrics that you define for endpoints.

                                  - **ComparisonOperator** *(string) --*

                                    The operator to use when comparing metric values. Valid values
                                    are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                    LESS_THAN_OR_EQUAL, and EQUAL.

                                  - **Value** *(float) --*

                                    The value to compare.

                            - **UserAttributes** *(dict) --*

                              One or more custom user attributes to use as criteria for the segment.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies attribute-based criteria for including or excluding
                                  endpoints from a segment.

                                  - **AttributeType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the AttributeType property, endpoints are
                                    included or excluded from the segment if their attribute values
                                    match the criteria values.

                                    - *(string) --*

                        - **SourceSegments** *(list) --*

                          The base segment to build the segment on. A base segment, also referred to
                          as a *source segment* , defines the initial population of endpoints for a
                          segment. When you add dimensions to a segment, Amazon Pinpoint filters the
                          base segment by using the dimensions that you specify.

                          You can specify more than one dimensional segment or only one imported
                          segment. If you specify an imported segment, the Amazon Pinpoint console
                          displays a segment size estimate that indicates the size of the imported
                          segment without any filters applied to it.

                          - *(dict) --*

                            Specifies the segment identifier and version of a segment.

                            - **Id** *(string) --*

                              The unique identifier for the segment.

                            - **Version** *(integer) --*

                              The version number of the segment.

                        - **SourceType** *(string) --*

                          Specifies how to handle multiple base segments for the segment. For
                          example, if you specify three base segments for the segment, whether the
                          resulting segment is based on all, any, or none of the base segments.

                        - **Type** *(string) --*

                          Specifies how to handle multiple dimensions for the segment. For example,
                          if you specify three dimensions for the segment, whether the resulting
                          segment includes endpoints that match all, any, or none of the dimensions.

                    - **Include** *(string) --*

                      Specifies how to handle multiple segment groups for the segment. For example,
                      if the segment includes three segment groups, whether the resulting segment
                      includes endpoints that match all, any, or none of the segment groups.

                  - **SegmentType** *(string) --*

                    The segment type. Valid values are:

                    * DIMENSIONAL - A dynamic segment, which is a segment that uses selection
                    criteria that you specify and is based on endpoint data that's reported by your
                    app. Dynamic segments can change over time.

                    * IMPORT - A static segment, which is a segment that uses selection criteria
                    that you specify and is based on endpoint definitions that you import from a
                    file. Imported segments are static; they don't change over time.

                  - **tags** *(dict) --*

                    A string-to-string map of key-value pairs that identifies the tags that are
                    associated with the segment. Each tag consists of a required tag key and an
                    associated tag value.

                    - *(string) --*

                      - *(string) --*

                  - **Version** *(integer) --*

                    The version number of the segment.

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_segments(
        self, ApplicationId: str, PageSize: str = None, Token: str = None
    ) -> ClientGetSegmentsResponseTypeDef:
        """
        Retrieves information about the configuration, dimension, and other settings for all the
        segments that are associated with an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetSegments>`_

        **Request Syntax**
        ::

          response = client.get_segments(
              ApplicationId='string',
              PageSize='string',
              Token='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type Token: string
        :param Token:

          The NextToken string that specifies which page of results to return in a paginated
          response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SegmentsResponse': {
                    'Item': [
                        {
                            'ApplicationId': 'string',
                            'Arn': 'string',
                            'CreationDate': 'string',
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Behavior': {
                                    'Recency': {
                                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                    }
                                },
                                'Demographic': {
                                    'AppVersion': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Channel': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'DeviceType': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Make': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Model': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Platform': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Location': {
                                    'Country': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'GPSPoint': {
                                        'Coordinates': {
                                            'Latitude': 123.0,
                                            'Longitude': 123.0
                                        },
                                        'RangeInKilometers': 123.0
                                    }
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                },
                                'UserAttributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                }
                            },
                            'Id': 'string',
                            'ImportDefinition': {
                                'ChannelCounts': {
                                    'string': 123
                                },
                                'ExternalId': 'string',
                                'Format': 'CSV'|'JSON',
                                'RoleArn': 'string',
                                'S3Url': 'string',
                                'Size': 123
                            },
                            'LastModifiedDate': 'string',
                            'Name': 'string',
                            'SegmentGroups': {
                                'Groups': [
                                    {
                                        'Dimensions': [
                                            {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            },
                                        ],
                                        'SourceSegments': [
                                            {
                                                'Id': 'string',
                                                'Version': 123
                                            },
                                        ],
                                        'SourceType': 'ALL'|'ANY'|'NONE',
                                        'Type': 'ALL'|'ANY'|'NONE'
                                    },
                                ],
                                'Include': 'ALL'|'ANY'|'NONE'
                            },
                            'SegmentType': 'DIMENSIONAL'|'IMPORT',
                            'tags': {
                                'string': 'string'
                            },
                            'Version': 123
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **SegmentsResponse** *(dict) --*

              Provides information about all the segments that are associated with an application.

              - **Item** *(list) --*

                An array of responses, one for each segment that's associated with the application
                (Segments resource) or each version of a segment that's associated with the
                application (Segment Versions resource).

                - *(dict) --*

                  Provides information about the configuration, dimension, and other settings for a
                  segment.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that the segment is associated with.

                  - **Arn** *(string) --*

                    The Amazon Resource Name (ARN) of the segment.

                  - **CreationDate** *(string) --*

                    The date and time when the segment was created.

                  - **Dimensions** *(dict) --*

                    The dimension settings for the segment.

                    - **Attributes** *(dict) --*

                      One or more custom attributes to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                    - **Behavior** *(dict) --*

                      The behavior-based criteria, such as how recently users have used your app,
                      for the segment.

                      - **Recency** *(dict) --*

                        The dimension settings that are based on how recently an endpoint was
                        active.

                        - **Duration** *(string) --*

                          The duration to use when determining whether an endpoint is active or
                          inactive.

                        - **RecencyType** *(string) --*

                          The type of recency dimension to use for the segment. Valid values are:
                          ACTIVE, endpoints that were active within the specified duration are
                          included in the segment; and, INACTIVE, endpoints that weren't active
                          within the specified duration are included in the segment.

                    - **Demographic** *(dict) --*

                      The demographic-based criteria, such as device platform, for the segment.

                      - **AppVersion** *(dict) --*

                        The app version criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Channel** *(dict) --*

                        The channel criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **DeviceType** *(dict) --*

                        The device type criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Make** *(dict) --*

                        The device make criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Model** *(dict) --*

                        The device model criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Platform** *(dict) --*

                        The device platform criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                    - **Location** *(dict) --*

                      The location-based criteria, such as region or GPS coordinates, for the
                      segment.

                      - **Country** *(dict) --*

                        The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --*

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **GPSPoint** *(dict) --*

                        The GPS location and range for the segment.

                        - **Coordinates** *(dict) --*

                          The GPS coordinates to measure distance from.

                          - **Latitude** *(float) --*

                            The latitude coordinate of the location.

                          - **Longitude** *(float) --*

                            The longitude coordinate of the location.

                        - **RangeInKilometers** *(float) --*

                          The range, in kilometers, from the GPS coordinates.

                    - **Metrics** *(dict) --*

                      One or more custom metrics to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies metric-based criteria for including or excluding endpoints from
                          a segment. These criteria derive from custom metrics that you define for
                          endpoints.

                          - **ComparisonOperator** *(string) --*

                            The operator to use when comparing metric values. Valid values are:
                            GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                            EQUAL.

                          - **Value** *(float) --*

                            The value to compare.

                    - **UserAttributes** *(dict) --*

                      One or more custom user attributes to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                  - **Id** *(string) --*

                    The unique identifier for the segment.

                  - **ImportDefinition** *(dict) --*

                    The settings for the import job that's associated with the segment.

                    - **ChannelCounts** *(dict) --*

                      The number of channel types in the endpoint definitions that were imported to
                      create the segment.

                      - *(string) --*

                        - *(integer) --*

                    - **ExternalId** *(string) --*

                      (Deprecated) Your AWS account ID, which you assigned to an external ID key in
                      an IAM trust policy. Amazon Pinpoint previously used this value to assume an
                      IAM role when importing endpoint definitions, but we removed this requirement.
                      We don't recommend use of external IDs for IAM roles that are assumed by
                      Amazon Pinpoint.

                    - **Format** *(string) --*

                      The format of the files that were imported to create the segment. Valid values
                      are: CSV, for comma-separated values format; and, JSON, for newline-delimited
                      JSON format.

                    - **RoleArn** *(string) --*

                      The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                      role that authorized Amazon Pinpoint to access the Amazon S3 location to
                      import endpoint definitions from.

                    - **S3Url** *(string) --*

                      The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the
                      endpoint definitions were imported from to create the segment.

                    - **Size** *(integer) --*

                      The number of endpoint definitions that were imported successfully to create
                      the segment.

                  - **LastModifiedDate** *(string) --*

                    The date and time when the segment was last modified.

                  - **Name** *(string) --*

                    The name of the segment.

                  - **SegmentGroups** *(dict) --*

                    A list of one or more segment groups that apply to the segment. Each segment
                    group consists of zero or more base segments and the dimensions that are applied
                    to those base segments.

                    - **Groups** *(list) --*

                      An array that defines the set of segment criteria to evaluate when handling
                      segment groups for the segment.

                      - *(dict) --*

                        Specifies the base segments and dimensions for a segment, and the
                        relationships between these base segments and dimensions.

                        - **Dimensions** *(list) --*

                          An array that defines the dimensions for the segment.

                          - *(dict) --*

                            Specifies the dimension settings for a segment.

                            - **Attributes** *(dict) --*

                              One or more custom attributes to use as criteria for the segment.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies attribute-based criteria for including or excluding
                                  endpoints from a segment.

                                  - **AttributeType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the AttributeType property, endpoints are
                                    included or excluded from the segment if their attribute values
                                    match the criteria values.

                                    - *(string) --*

                            - **Behavior** *(dict) --*

                              The behavior-based criteria, such as how recently users have used your
                              app, for the segment.

                              - **Recency** *(dict) --*

                                The dimension settings that are based on how recently an endpoint
                                was active.

                                - **Duration** *(string) --*

                                  The duration to use when determining whether an endpoint is active
                                  or inactive.

                                - **RecencyType** *(string) --*

                                  The type of recency dimension to use for the segment. Valid values
                                  are: ACTIVE, endpoints that were active within the specified
                                  duration are included in the segment; and, INACTIVE, endpoints
                                  that weren't active within the specified duration are included in
                                  the segment.

                            - **Demographic** *(dict) --*

                              The demographic-based criteria, such as device platform, for the
                              segment.

                              - **AppVersion** *(dict) --*

                                The app version criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **Channel** *(dict) --*

                                The channel criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **DeviceType** *(dict) --*

                                The device type criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **Make** *(dict) --*

                                The device make criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **Model** *(dict) --*

                                The device model criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **Platform** *(dict) --*

                                The device platform criteria for the segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                            - **Location** *(dict) --*

                              The location-based criteria, such as region or GPS coordinates, for
                              the segment.

                              - **Country** *(dict) --*

                                The country or region code, in ISO 3166-1 alpha-2 format, for the
                                segment.

                                - **DimensionType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --*

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the DimensionType property, endpoints are included or
                                  excluded from the segment if their values match the criteria
                                  values.

                                  - *(string) --*

                              - **GPSPoint** *(dict) --*

                                The GPS location and range for the segment.

                                - **Coordinates** *(dict) --*

                                  The GPS coordinates to measure distance from.

                                  - **Latitude** *(float) --*

                                    The latitude coordinate of the location.

                                  - **Longitude** *(float) --*

                                    The longitude coordinate of the location.

                                - **RangeInKilometers** *(float) --*

                                  The range, in kilometers, from the GPS coordinates.

                            - **Metrics** *(dict) --*

                              One or more custom metrics to use as criteria for the segment.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies metric-based criteria for including or excluding
                                  endpoints from a segment. These criteria derive from custom
                                  metrics that you define for endpoints.

                                  - **ComparisonOperator** *(string) --*

                                    The operator to use when comparing metric values. Valid values
                                    are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                    LESS_THAN_OR_EQUAL, and EQUAL.

                                  - **Value** *(float) --*

                                    The value to compare.

                            - **UserAttributes** *(dict) --*

                              One or more custom user attributes to use as criteria for the segment.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies attribute-based criteria for including or excluding
                                  endpoints from a segment.

                                  - **AttributeType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the AttributeType property, endpoints are
                                    included or excluded from the segment if their attribute values
                                    match the criteria values.

                                    - *(string) --*

                        - **SourceSegments** *(list) --*

                          The base segment to build the segment on. A base segment, also referred to
                          as a *source segment* , defines the initial population of endpoints for a
                          segment. When you add dimensions to a segment, Amazon Pinpoint filters the
                          base segment by using the dimensions that you specify.

                          You can specify more than one dimensional segment or only one imported
                          segment. If you specify an imported segment, the Amazon Pinpoint console
                          displays a segment size estimate that indicates the size of the imported
                          segment without any filters applied to it.

                          - *(dict) --*

                            Specifies the segment identifier and version of a segment.

                            - **Id** *(string) --*

                              The unique identifier for the segment.

                            - **Version** *(integer) --*

                              The version number of the segment.

                        - **SourceType** *(string) --*

                          Specifies how to handle multiple base segments for the segment. For
                          example, if you specify three base segments for the segment, whether the
                          resulting segment is based on all, any, or none of the base segments.

                        - **Type** *(string) --*

                          Specifies how to handle multiple dimensions for the segment. For example,
                          if you specify three dimensions for the segment, whether the resulting
                          segment includes endpoints that match all, any, or none of the dimensions.

                    - **Include** *(string) --*

                      Specifies how to handle multiple segment groups for the segment. For example,
                      if the segment includes three segment groups, whether the resulting segment
                      includes endpoints that match all, any, or none of the segment groups.

                  - **SegmentType** *(string) --*

                    The segment type. Valid values are:

                    * DIMENSIONAL - A dynamic segment, which is a segment that uses selection
                    criteria that you specify and is based on endpoint data that's reported by your
                    app. Dynamic segments can change over time.

                    * IMPORT - A static segment, which is a segment that uses selection criteria
                    that you specify and is based on endpoint definitions that you import from a
                    file. Imported segments are static; they don't change over time.

                  - **tags** *(dict) --*

                    A string-to-string map of key-value pairs that identifies the tags that are
                    associated with the segment. Each tag consists of a required tag key and an
                    associated tag value.

                    - *(string) --*

                      - *(string) --*

                  - **Version** *(integer) --*

                    The version number of the segment.

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_sms_channel(self, ApplicationId: str) -> ClientGetSmsChannelResponseTypeDef:
        """
        Retrieves information about the status and settings of the SMS channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetSmsChannel>`_

        **Request Syntax**
        ::

          response = client.get_sms_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SMSChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'PromotionalMessagesPerSecond': 123,
                    'SenderId': 'string',
                    'ShortCode': 'string',
                    'TransactionalMessagesPerSecond': 123,
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **SMSChannelResponse** *(dict) --*

              Provides information about the status and settings of the SMS channel for an
              application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the SMS channel applies to.

              - **CreationDate** *(string) --*

                The date and time, in ISO 8601 format, when the SMS channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the SMS channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the SMS channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the SMS channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the SMS channel.

              - **LastModifiedDate** *(string) --*

                The date and time, in ISO 8601 format, when the SMS channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the SMS channel,
                this value is SMS.

              - **PromotionalMessagesPerSecond** *(integer) --*

                The maximum number of promotional messages that you can send through the SMS channel
                each second.

              - **SenderId** *(string) --*

                The identity that displays on recipients' devices when they receive messages from
                the SMS channel.

              - **ShortCode** *(string) --*

                The registered short code to use when you send messages through the SMS channel.

              - **TransactionalMessagesPerSecond** *(integer) --*

                The maximum number of transactional messages that you can send through the SMS
                channel each second.

              - **Version** *(integer) --*

                The current version of the SMS channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_sms_template(self, TemplateName: str) -> ClientGetSmsTemplateResponseTypeDef:
        """
        Retrieves the content and settings for a message template that you can use in messages that
        are sent through the SMS channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetSmsTemplate>`_

        **Request Syntax**
        ::

          response = client.get_sms_template(
              TemplateName='string'
          )
        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SMSTemplateResponse': {
                    'Arn': 'string',
                    'Body': 'string',
                    'CreationDate': 'string',
                    'DefaultSubstitutions': 'string',
                    'LastModifiedDate': 'string',
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateDescription': 'string',
                    'TemplateName': 'string',
                    'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **SMSTemplateResponse** *(dict) --*

              Provides information about the content and settings for a message template that can be
              used in text messages that are sent through the SMS channel.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the message template.

              - **Body** *(string) --*

                The message body that's used in text messages that are based on the message
                template.

              - **CreationDate** *(string) --*

                The date when the message template was created.

              - **DefaultSubstitutions** *(string) --*

                The JSON object that specifies the default values that are used for message
                variables in the message template. This object is a set of key-value pairs. Each key
                defines a message variable in the template. The corresponding value defines the
                default value for that variable.

              - **LastModifiedDate** *(string) --*

                The date when the message template was last modified.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the message template. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **TemplateDescription** *(string) --*

                The custom description of the message template.

              - **TemplateName** *(string) --*

                The name of the message template.

              - **TemplateType** *(string) --*

                The type of channel that the message template is designed for. For an SMS template,
                this value is SMS.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_user_endpoints(
        self, ApplicationId: str, UserId: str
    ) -> ClientGetUserEndpointsResponseTypeDef:
        """
        Retrieves information about all the endpoints that are associated with a specific user ID.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetUserEndpoints>`_

        **Request Syntax**
        ::

          response = client.get_user_endpoints(
              ApplicationId='string',
              UserId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type UserId: string
        :param UserId: **[REQUIRED]**

          The unique identifier for the user.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EndpointsResponse': {
                    'Item': [
                        {
                            'Address': 'string',
                            'ApplicationId': 'string',
                            'Attributes': {
                                'string': [
                                    'string',
                                ]
                            },
                            'ChannelType':
                            'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'
                            |'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'
                            |'BAIDU'|'CUSTOM',
                            'CohortId': 'string',
                            'CreationDate': 'string',
                            'Demographic': {
                                'AppVersion': 'string',
                                'Locale': 'string',
                                'Make': 'string',
                                'Model': 'string',
                                'ModelVersion': 'string',
                                'Platform': 'string',
                                'PlatformVersion': 'string',
                                'Timezone': 'string'
                            },
                            'EffectiveDate': 'string',
                            'EndpointStatus': 'string',
                            'Id': 'string',
                            'Location': {
                                'City': 'string',
                                'Country': 'string',
                                'Latitude': 123.0,
                                'Longitude': 123.0,
                                'PostalCode': 'string',
                                'Region': 'string'
                            },
                            'Metrics': {
                                'string': 123.0
                            },
                            'OptOut': 'string',
                            'RequestId': 'string',
                            'User': {
                                'UserAttributes': {
                                    'string': [
                                        'string',
                                    ]
                                },
                                'UserId': 'string'
                            }
                        },
                    ]
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **EndpointsResponse** *(dict) --*

              Provides information about all the endpoints that are associated with a user ID.

              - **Item** *(list) --*

                An array of responses, one for each endpoint that's associated with the user ID.

                - *(dict) --*

                  Provides information about the channel type and other settings for an endpoint.

                  - **Address** *(string) --*

                    The destination address for messages or push notifications that you send to the
                    endpoint. The address varies by channel. For example, the address for a
                    push-notification channel is typically the token provided by a push notification
                    service, such as an Apple Push Notification service (APNs) device token or a
                    Firebase Cloud Messaging (FCM) registration token. The address for the SMS
                    channel is a phone number in E.164 format, such as +12065550100. The address for
                    the email channel is an email address.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that's associated with the endpoint.

                  - **Attributes** *(dict) --*

                    One or more custom attributes that describe the endpoint by associating a name
                    with an array of values. For example, the value of a custom attribute named
                    Interests might be: ["science", "music", "travel"]. You can use these attributes
                    as filter criteria when you create segments.

                    - *(string) --*

                      - *(list) --*

                        - *(string) --*

                  - **ChannelType** *(string) --*

                    The channel that's used when sending messages or push notifications to the
                    endpoint.

                  - **CohortId** *(string) --*

                    A number from 0-99 that represents the cohort that the endpoint is assigned to.
                    Endpoints are grouped into cohorts randomly, and each cohort contains
                    approximately 1 percent of the endpoints for an application. Amazon Pinpoint
                    assigns cohorts to the holdout or treatment allocations for campaigns.

                  - **CreationDate** *(string) --*

                    The date and time, in ISO 8601 format, when the endpoint was created.

                  - **Demographic** *(dict) --*

                    The demographic information for the endpoint, such as the time zone and
                    platform.

                    - **AppVersion** *(string) --*

                      The version of the app that's associated with the endpoint.

                    - **Locale** *(string) --*

                      The locale of the endpoint, in the following format: the ISO 639-1 alpha-2
                      code, followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.

                    - **Make** *(string) --*

                      The manufacturer of the endpoint device, such as Apple or Samsung.

                    - **Model** *(string) --*

                      The model name or number of the endpoint device, such as iPhone.

                    - **ModelVersion** *(string) --*

                      The model version of the endpoint device.

                    - **Platform** *(string) --*

                      The platform of the endpoint device, such as iOS or Android.

                    - **PlatformVersion** *(string) --*

                      The platform version of the endpoint device.

                    - **Timezone** *(string) --*

                      The time zone of the endpoint, specified as a tz database name value, such as
                      America/Los_Angeles.

                  - **EffectiveDate** *(string) --*

                    The date and time, in ISO 8601 format, when the endpoint was last updated.

                  - **EndpointStatus** *(string) --*

                    Specifies whether messages or push notifications are sent to the endpoint.
                    Possible values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE,
                    messages aren’t sent to the endpoint.

                    Amazon Pinpoint automatically sets this value to ACTIVE when you create an
                    endpoint or update an existing endpoint. Amazon Pinpoint automatically sets this
                    value to INACTIVE if you update another endpoint that has the same address
                    specified by the Address property.

                  - **Id** *(string) --*

                    The unique identifier that you assigned to the endpoint. The identifier should
                    be a globally unique identifier (GUID) to ensure that it doesn't conflict with
                    other endpoint identifiers that are associated with the application.

                  - **Location** *(dict) --*

                    The geographic information for the endpoint.

                    - **City** *(string) --*

                      The name of the city where the endpoint is located.

                    - **Country** *(string) --*

                      The two-character code, in ISO 3166-1 alpha-2 format, for the country or
                      region where the endpoint is located. For example, US for the United States.

                    - **Latitude** *(float) --*

                      The latitude coordinate of the endpoint location, rounded to one decimal
                      place.

                    - **Longitude** *(float) --*

                      The longitude coordinate of the endpoint location, rounded to one decimal
                      place.

                    - **PostalCode** *(string) --*

                      The postal or ZIP code for the area where the endpoint is located.

                    - **Region** *(string) --*

                      The name of the region where the endpoint is located. For locations in the
                      United States, this value is the name of a state.

                  - **Metrics** *(dict) --*

                    One or more custom metrics that your app reports to Amazon Pinpoint for the
                    endpoint.

                    - *(string) --*

                      - *(float) --*

                  - **OptOut** *(string) --*

                    Specifies whether the user who's associated with the endpoint has opted out of
                    receiving messages and push notifications from you. Possible values are: ALL,
                    the user has opted out and doesn't want to receive any messages or push
                    notifications; and, NONE, the user hasn't opted out and wants to receive all
                    messages and push notifications.

                  - **RequestId** *(string) --*

                    The unique identifier for the most recent request to update the endpoint.

                  - **User** *(dict) --*

                    One or more custom user attributes that your app reports to Amazon Pinpoint for
                    the user who's associated with the endpoint.

                    - **UserAttributes** *(dict) --*

                      One or more custom attributes that describe the user by associating a name
                      with an array of values. For example, the value of an attribute named
                      Interests might be: ["science", "music", "travel"]. You can use these
                      attributes as filter criteria when you create segments.

                      When you define the name of a custom attribute, avoid using the following
                      characters: number sign (#), colon (:), question mark (?), backslash (\\), and
                      slash (/). The Amazon Pinpoint console can't display attribute names that
                      contain these characters. This limitation doesn't apply to attribute values.

                      - *(string) --*

                        - *(list) --*

                          - *(string) --*

                    - **UserId** *(string) --*

                      The unique identifier for the user.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_voice_channel(self, ApplicationId: str) -> ClientGetVoiceChannelResponseTypeDef:
        """
        Retrieves information about the status and settings of the voice channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetVoiceChannel>`_

        **Request Syntax**
        ::

          response = client.get_voice_channel(
              ApplicationId='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'VoiceChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **VoiceChannelResponse** *(dict) --*

              Provides information about the status and settings of the voice channel for an
              application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the voice channel applies to.

              - **CreationDate** *(string) --*

                The date and time, in ISO 8601 format, when the voice channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the voice channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the voice channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the voice channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the voice channel.

              - **LastModifiedDate** *(string) --*

                The date and time, in ISO 8601 format, when the voice channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the voice
                channel, this value is VOICE.

              - **Version** *(integer) --*

                The current version of the voice channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_voice_template(self, TemplateName: str) -> ClientGetVoiceTemplateResponseTypeDef:
        """
        Retrieves the content and settings for a message template that you can use in messages that
        are sent through the voice channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/GetVoiceTemplate>`_

        **Request Syntax**
        ::

          response = client.get_voice_template(
              TemplateName='string'
          )
        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'VoiceTemplateResponse': {
                    'Arn': 'string',
                    'Body': 'string',
                    'CreationDate': 'string',
                    'DefaultSubstitutions': 'string',
                    'LanguageCode': 'string',
                    'LastModifiedDate': 'string',
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateDescription': 'string',
                    'TemplateName': 'string',
                    'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
                    'VoiceId': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **VoiceTemplateResponse** *(dict) --*

              Provides information about the content and settings for a message template that can be
              used in messages that are sent through the voice channel.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the message template.

              - **Body** *(string) --*

                The text of the script that's used in messages that are based on the message
                template, in plain text format.

              - **CreationDate** *(string) --*

                The date when the message template was created.

              - **DefaultSubstitutions** *(string) --*

                The JSON object that specifies the default values that are used for message
                variables in the message template. This object is a set of key-value pairs. Each key
                defines a message variable in the template. The corresponding value defines the
                default value for that variable.

              - **LanguageCode** *(string) --*

                The code for the language that's used when synthesizing the text of the script in
                messages that are based on the message template. For a list of supported languages
                and the code for each one, see the `Amazon Polly Developer Guide
                <https://docs.aws.amazon.com/polly/latest/dg/what-is.html>`__ .

              - **LastModifiedDate** *(string) --*

                The date when the message template was last modified.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the message template. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **TemplateDescription** *(string) --*

                The custom description of the message template.

              - **TemplateName** *(string) --*

                The name of the message template.

              - **TemplateType** *(string) --*

                The type of channel that the message template is designed for. For a voice template,
                this value is VOICE.

              - **VoiceId** *(string) --*

                The name of the voice that's used when delivering messages that are based on the
                message template. For a list of supported voices, see the `Amazon Polly Developer
                Guide <https://docs.aws.amazon.com/polly/latest/dg/what-is.html>`__ .

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_journeys(
        self, ApplicationId: str, PageSize: str = None, Token: str = None
    ) -> ClientListJourneysResponseTypeDef:
        """
        Retrieves information about the status, configuration, and other settings for all the
        journeys that are associated with an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/ListJourneys>`_

        **Request Syntax**
        ::

          response = client.list_journeys(
              ApplicationId='string',
              PageSize='string',
              Token='string'
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type Token: string
        :param Token:

          The NextToken string that specifies which page of results to return in a paginated
          response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'JourneysResponse': {
                    'Item': [
                        {
                            'Activities': {
                                'string': {
                                    'ConditionalSplit': {
                                        'Condition': {
                                            'Conditions': [
                                                {
                                                    'EventCondition': {
                                                        'Dimensions': {
                                                            'Attributes': {
                                                                'string': {
                                                                    'AttributeType':
                                                                    'INCLUSIVE'
                                                                    |'EXCLUSIVE',
                                                                    'Values': [
                                                                        'string',
                                                                    ]
                                                                }
                                                            },
                                                            'EventType': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'Metrics': {
                                                                'string': {
                                                                    'ComparisonOperator': 'string',
                                                                    'Value': 123.0
                                                                }
                                                            }
                                                        },
                                                        'MessageActivity': 'string'
                                                    },
                                                    'SegmentCondition': {
                                                        'SegmentId': 'string'
                                                    },
                                                    'SegmentDimensions': {
                                                        'Attributes': {
                                                            'string': {
                                                                'AttributeType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            }
                                                        },
                                                        'Behavior': {
                                                            'Recency': {
                                                                'Duration':
                                                                'HR_24'|'DAY_7'|'DAY_14'
                                                                |'DAY_30',
                                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                                            }
                                                        },
                                                        'Demographic': {
                                                            'AppVersion': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'Channel': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'DeviceType': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'Make': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'Model': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'Platform': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            }
                                                        },
                                                        'Location': {
                                                            'Country': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'GPSPoint': {
                                                                'Coordinates': {
                                                                    'Latitude': 123.0,
                                                                    'Longitude': 123.0
                                                                },
                                                                'RangeInKilometers': 123.0
                                                            }
                                                        },
                                                        'Metrics': {
                                                            'string': {
                                                                'ComparisonOperator': 'string',
                                                                'Value': 123.0
                                                            }
                                                        },
                                                        'UserAttributes': {
                                                            'string': {
                                                                'AttributeType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            }
                                                        }
                                                    }
                                                },
                                            ],
                                            'Operator': 'ALL'|'ANY'
                                        },
                                        'EvaluationWaitTime': {
                                            'WaitFor': 'string',
                                            'WaitUntil': 'string'
                                        },
                                        'FalseActivity': 'string',
                                        'TrueActivity': 'string'
                                    },
                                    'Description': 'string',
                                    'EMAIL': {
                                        'MessageConfig': {
                                            'FromAddress': 'string'
                                        },
                                        'NextActivity': 'string',
                                        'TemplateName': 'string'
                                    },
                                    'Holdout': {
                                        'NextActivity': 'string',
                                        'Percentage': 123
                                    },
                                    'MultiCondition': {
                                        'Branches': [
                                            {
                                                'Condition': {
                                                    'EventCondition': {
                                                        'Dimensions': {
                                                            'Attributes': {
                                                                'string': {
                                                                    'AttributeType':
                                                                    'INCLUSIVE'
                                                                    |'EXCLUSIVE',
                                                                    'Values': [
                                                                        'string',
                                                                    ]
                                                                }
                                                            },
                                                            'EventType': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'Metrics': {
                                                                'string': {
                                                                    'ComparisonOperator': 'string',
                                                                    'Value': 123.0
                                                                }
                                                            }
                                                        },
                                                        'MessageActivity': 'string'
                                                    },
                                                    'SegmentCondition': {
                                                        'SegmentId': 'string'
                                                    },
                                                    'SegmentDimensions': {
                                                        'Attributes': {
                                                            'string': {
                                                                'AttributeType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            }
                                                        },
                                                        'Behavior': {
                                                            'Recency': {
                                                                'Duration':
                                                                'HR_24'|'DAY_7'|'DAY_14'
                                                                |'DAY_30',
                                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                                            }
                                                        },
                                                        'Demographic': {
                                                            'AppVersion': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'Channel': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'DeviceType': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'Make': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'Model': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'Platform': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            }
                                                        },
                                                        'Location': {
                                                            'Country': {
                                                                'DimensionType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            },
                                                            'GPSPoint': {
                                                                'Coordinates': {
                                                                    'Latitude': 123.0,
                                                                    'Longitude': 123.0
                                                                },
                                                                'RangeInKilometers': 123.0
                                                            }
                                                        },
                                                        'Metrics': {
                                                            'string': {
                                                                'ComparisonOperator': 'string',
                                                                'Value': 123.0
                                                            }
                                                        },
                                                        'UserAttributes': {
                                                            'string': {
                                                                'AttributeType':
                                                                'INCLUSIVE'
                                                                |'EXCLUSIVE',
                                                                'Values': [
                                                                    'string',
                                                                ]
                                                            }
                                                        }
                                                    }
                                                },
                                                'NextActivity': 'string'
                                            },
                                        ],
                                        'DefaultActivity': 'string',
                                        'EvaluationWaitTime': {
                                            'WaitFor': 'string',
                                            'WaitUntil': 'string'
                                        }
                                    },
                                    'RandomSplit': {
                                        'Branches': [
                                            {
                                                'NextActivity': 'string',
                                                'Percentage': 123
                                            },
                                        ]
                                    },
                                    'Wait': {
                                        'NextActivity': 'string',
                                        'WaitTime': {
                                            'WaitFor': 'string',
                                            'WaitUntil': 'string'
                                        }
                                    }
                                }
                            },
                            'ApplicationId': 'string',
                            'CreationDate': 'string',
                            'Id': 'string',
                            'LastModifiedDate': 'string',
                            'Limits': {
                                'DailyCap': 123,
                                'EndpointReentryCap': 123,
                                'MessagesPerSecond': 123
                            },
                            'LocalTime': True|False,
                            'Name': 'string',
                            'QuietTime': {
                                'End': 'string',
                                'Start': 'string'
                            },
                            'RefreshFrequency': 'string',
                            'Schedule': {
                                'EndTime': datetime(2015, 1, 1),
                                'StartTime': datetime(2015, 1, 1),
                                'Timezone': 'string'
                            },
                            'StartActivity': 'string',
                            'StartCondition': {
                                'Description': 'string',
                                'SegmentStartCondition': {
                                    'SegmentId': 'string'
                                }
                            },
                            'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
                            'tags': {
                                'string': 'string'
                            }
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **JourneysResponse** *(dict) --*

              Provides information about the status, configuration, and other settings for all the
              journeys that are associated with an application.

              - **Item** *(list) --*

                An array of responses, one for each journey that's associated with the application.

                - *(dict) --*

                  Provides information about the status, configuration, and other settings for a
                  journey.

                  - **Activities** *(dict) --*

                    The configuration and other settings for the activities that comprise the
                    journey.

                    - *(string) --*

                      - *(dict) --*

                        Specifies the configuration and other settings for an activity in a journey.

                        - **ConditionalSplit** *(dict) --*

                          The settings for a yes/no split activity. This type of activity sends
                          participants down one of two paths in a journey, based on conditions that
                          you specify.

                          - **Condition** *(dict) --*

                            The conditions that define the paths for the activity, and the
                            relationship between the conditions.

                            - **Conditions** *(list) --*

                              The conditions to evaluate for the activity.

                              - *(dict) --*

                                Specifies a condition to evaluate for an activity in a journey.

                                - **EventCondition** *(dict) --*

                                  The dimension settings for the event that's associated with the
                                  activity.

                                  - **Dimensions** *(dict) --*

                                    The dimensions for the event filter to use for the activity.

                                    - **Attributes** *(dict) --*

                                      One or more custom attributes that your application reports to
                                      Amazon Pinpoint. You can use these attributes as selection
                                      criteria when you create an event filter.

                                      - *(string) --*

                                        - *(dict) --*

                                          Specifies attribute-based criteria for including or
                                          excluding endpoints from a segment.

                                          - **AttributeType** *(string) --*

                                            The type of segment dimension to use. Valid values are:
                                            INCLUSIVE, endpoints that match the criteria are
                                            included in the segment; and, EXCLUSIVE, endpoints that
                                            match the criteria are excluded from the segment.

                                          - **Values** *(list) --*

                                            The criteria values to use for the segment dimension.
                                            Depending on the value of the AttributeType property,
                                            endpoints are included or excluded from the segment if
                                            their attribute values match the criteria values.

                                            - *(string) --*

                                    - **EventType** *(dict) --*

                                      The name of the event that causes the campaign to be sent or
                                      the journey activity to be performed. This can be a standard
                                      type of event that Amazon Pinpoint generates, such as
                                      _email.delivered, or a custom event that's specific to your
                                      application.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **Metrics** *(dict) --*

                                      One or more custom metrics that your application reports to
                                      Amazon Pinpoint. You can use these metrics as selection
                                      criteria when you create an event filter.

                                      - *(string) --*

                                        - *(dict) --*

                                          Specifies metric-based criteria for including or excluding
                                          endpoints from a segment. These criteria derive from
                                          custom metrics that you define for endpoints.

                                          - **ComparisonOperator** *(string) --*

                                            The operator to use when comparing metric values. Valid
                                            values are: GREATER_THAN, LESS_THAN,
                                            GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

                                          - **Value** *(float) --*

                                            The value to compare.

                                  - **MessageActivity** *(string) --*

                                    The message identifier (message_id) for the message to use when
                                    determining whether message events meet the condition.

                                - **SegmentCondition** *(dict) --*

                                  The segment that's associated with the activity.

                                  - **SegmentId** *(string) --*

                                    The unique identifier for the segment to associate with the
                                    activity.

                                - **SegmentDimensions** *(dict) --*

                                  The dimension settings for the segment that's associated with the
                                  activity.

                                  - **Attributes** *(dict) --*

                                    One or more custom attributes to use as criteria for the
                                    segment.

                                    - *(string) --*

                                      - *(dict) --*

                                        Specifies attribute-based criteria for including or
                                        excluding endpoints from a segment.

                                        - **AttributeType** *(string) --*

                                          The type of segment dimension to use. Valid values are:
                                          INCLUSIVE, endpoints that match the criteria are included
                                          in the segment; and, EXCLUSIVE, endpoints that match the
                                          criteria are excluded from the segment.

                                        - **Values** *(list) --*

                                          The criteria values to use for the segment dimension.
                                          Depending on the value of the AttributeType property,
                                          endpoints are included or excluded from the segment if
                                          their attribute values match the criteria values.

                                          - *(string) --*

                                  - **Behavior** *(dict) --*

                                    The behavior-based criteria, such as how recently users have
                                    used your app, for the segment.

                                    - **Recency** *(dict) --*

                                      The dimension settings that are based on how recently an
                                      endpoint was active.

                                      - **Duration** *(string) --*

                                        The duration to use when determining whether an endpoint is
                                        active or inactive.

                                      - **RecencyType** *(string) --*

                                        The type of recency dimension to use for the segment. Valid
                                        values are: ACTIVE, endpoints that were active within the
                                        specified duration are included in the segment; and,
                                        INACTIVE, endpoints that weren't active within the specified
                                        duration are included in the segment.

                                  - **Demographic** *(dict) --*

                                    The demographic-based criteria, such as device platform, for the
                                    segment.

                                    - **AppVersion** *(dict) --*

                                      The app version criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **Channel** *(dict) --*

                                      The channel criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **DeviceType** *(dict) --*

                                      The device type criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **Make** *(dict) --*

                                      The device make criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **Model** *(dict) --*

                                      The device model criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **Platform** *(dict) --*

                                      The device platform criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                  - **Location** *(dict) --*

                                    The location-based criteria, such as region or GPS coordinates,
                                    for the segment.

                                    - **Country** *(dict) --*

                                      The country or region code, in ISO 3166-1 alpha-2 format, for
                                      the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **GPSPoint** *(dict) --*

                                      The GPS location and range for the segment.

                                      - **Coordinates** *(dict) --*

                                        The GPS coordinates to measure distance from.

                                        - **Latitude** *(float) --*

                                          The latitude coordinate of the location.

                                        - **Longitude** *(float) --*

                                          The longitude coordinate of the location.

                                      - **RangeInKilometers** *(float) --*

                                        The range, in kilometers, from the GPS coordinates.

                                  - **Metrics** *(dict) --*

                                    One or more custom metrics to use as criteria for the segment.

                                    - *(string) --*

                                      - *(dict) --*

                                        Specifies metric-based criteria for including or excluding
                                        endpoints from a segment. These criteria derive from custom
                                        metrics that you define for endpoints.

                                        - **ComparisonOperator** *(string) --*

                                          The operator to use when comparing metric values. Valid
                                          values are: GREATER_THAN, LESS_THAN,
                                          GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

                                        - **Value** *(float) --*

                                          The value to compare.

                                  - **UserAttributes** *(dict) --*

                                    One or more custom user attributes to use as criteria for the
                                    segment.

                                    - *(string) --*

                                      - *(dict) --*

                                        Specifies attribute-based criteria for including or
                                        excluding endpoints from a segment.

                                        - **AttributeType** *(string) --*

                                          The type of segment dimension to use. Valid values are:
                                          INCLUSIVE, endpoints that match the criteria are included
                                          in the segment; and, EXCLUSIVE, endpoints that match the
                                          criteria are excluded from the segment.

                                        - **Values** *(list) --*

                                          The criteria values to use for the segment dimension.
                                          Depending on the value of the AttributeType property,
                                          endpoints are included or excluded from the segment if
                                          their attribute values match the criteria values.

                                          - *(string) --*

                            - **Operator** *(string) --*

                              Specifies how to handle multiple conditions for the activity. For
                              example, if you specify two conditions for an activity, whether both
                              or only one of the conditions must be met for the activity to be
                              performed.

                          - **EvaluationWaitTime** *(dict) --*

                            The amount of time to wait before determining whether the conditions are
                            met, or the date and time when Amazon Pinpoint determines whether the
                            conditions are met.

                            - **WaitFor** *(string) --*

                              The amount of time to wait, as a duration in ISO 8601 format, before
                              determining whether the activity's conditions have been met or moving
                              participants to the next activity in the journey.

                            - **WaitUntil** *(string) --*

                              The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                              whether the activity's conditions have been met or the activity moves
                              participants to the next activity in the journey.

                          - **FalseActivity** *(string) --*

                            The unique identifier for the activity to perform if the condition isn't
                            met.

                          - **TrueActivity** *(string) --*

                            The unique identifier for the activity to perform if the condition is
                            met.

                        - **Description** *(string) --*

                          The custom description of the activity.

                        - **EMAIL** *(dict) --*

                          The settings for an email activity. This type of activity sends an email
                          message to participants.

                          - **MessageConfig** *(dict) --*

                            The "From" address to use for the message.

                            - **FromAddress** *(string) --*

                              The verified email address to send the email message from. The default
                              address is the FromAddress specified for the email channel for the
                              application.

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after the
                            message is sent.

                          - **TemplateName** *(string) --*

                            The name of the email template to use for the message.

                        - **Holdout** *(dict) --*

                          The settings for a holdout activity. This type of activity stops a journey
                          for a specified percentage of participants.

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after performing
                            the holdout activity.

                          - **Percentage** *(integer) --*

                            The percentage of participants who shouldn't continue the journey.

                        - **MultiCondition** *(dict) --*

                          The settings for a multivariate split activity. This type of activity
                          sends participants down one of as many as five paths in a journey, based
                          on conditions that you specify.

                          - **Branches** *(list) --*

                            The paths for the activity, including the conditions for entering each
                            path and the activity to perform for each path.

                            - *(dict) --*

                              Specifies a condition to evaluate for an activity path in a journey.

                              - **Condition** *(dict) --*

                                The condition to evaluate for the activity path.

                                - **EventCondition** *(dict) --*

                                  The dimension settings for the event that's associated with the
                                  activity.

                                  - **Dimensions** *(dict) --*

                                    The dimensions for the event filter to use for the activity.

                                    - **Attributes** *(dict) --*

                                      One or more custom attributes that your application reports to
                                      Amazon Pinpoint. You can use these attributes as selection
                                      criteria when you create an event filter.

                                      - *(string) --*

                                        - *(dict) --*

                                          Specifies attribute-based criteria for including or
                                          excluding endpoints from a segment.

                                          - **AttributeType** *(string) --*

                                            The type of segment dimension to use. Valid values are:
                                            INCLUSIVE, endpoints that match the criteria are
                                            included in the segment; and, EXCLUSIVE, endpoints that
                                            match the criteria are excluded from the segment.

                                          - **Values** *(list) --*

                                            The criteria values to use for the segment dimension.
                                            Depending on the value of the AttributeType property,
                                            endpoints are included or excluded from the segment if
                                            their attribute values match the criteria values.

                                            - *(string) --*

                                    - **EventType** *(dict) --*

                                      The name of the event that causes the campaign to be sent or
                                      the journey activity to be performed. This can be a standard
                                      type of event that Amazon Pinpoint generates, such as
                                      _email.delivered, or a custom event that's specific to your
                                      application.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **Metrics** *(dict) --*

                                      One or more custom metrics that your application reports to
                                      Amazon Pinpoint. You can use these metrics as selection
                                      criteria when you create an event filter.

                                      - *(string) --*

                                        - *(dict) --*

                                          Specifies metric-based criteria for including or excluding
                                          endpoints from a segment. These criteria derive from
                                          custom metrics that you define for endpoints.

                                          - **ComparisonOperator** *(string) --*

                                            The operator to use when comparing metric values. Valid
                                            values are: GREATER_THAN, LESS_THAN,
                                            GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

                                          - **Value** *(float) --*

                                            The value to compare.

                                  - **MessageActivity** *(string) --*

                                    The message identifier (message_id) for the message to use when
                                    determining whether message events meet the condition.

                                - **SegmentCondition** *(dict) --*

                                  The segment that's associated with the activity.

                                  - **SegmentId** *(string) --*

                                    The unique identifier for the segment to associate with the
                                    activity.

                                - **SegmentDimensions** *(dict) --*

                                  The dimension settings for the segment that's associated with the
                                  activity.

                                  - **Attributes** *(dict) --*

                                    One or more custom attributes to use as criteria for the
                                    segment.

                                    - *(string) --*

                                      - *(dict) --*

                                        Specifies attribute-based criteria for including or
                                        excluding endpoints from a segment.

                                        - **AttributeType** *(string) --*

                                          The type of segment dimension to use. Valid values are:
                                          INCLUSIVE, endpoints that match the criteria are included
                                          in the segment; and, EXCLUSIVE, endpoints that match the
                                          criteria are excluded from the segment.

                                        - **Values** *(list) --*

                                          The criteria values to use for the segment dimension.
                                          Depending on the value of the AttributeType property,
                                          endpoints are included or excluded from the segment if
                                          their attribute values match the criteria values.

                                          - *(string) --*

                                  - **Behavior** *(dict) --*

                                    The behavior-based criteria, such as how recently users have
                                    used your app, for the segment.

                                    - **Recency** *(dict) --*

                                      The dimension settings that are based on how recently an
                                      endpoint was active.

                                      - **Duration** *(string) --*

                                        The duration to use when determining whether an endpoint is
                                        active or inactive.

                                      - **RecencyType** *(string) --*

                                        The type of recency dimension to use for the segment. Valid
                                        values are: ACTIVE, endpoints that were active within the
                                        specified duration are included in the segment; and,
                                        INACTIVE, endpoints that weren't active within the specified
                                        duration are included in the segment.

                                  - **Demographic** *(dict) --*

                                    The demographic-based criteria, such as device platform, for the
                                    segment.

                                    - **AppVersion** *(dict) --*

                                      The app version criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **Channel** *(dict) --*

                                      The channel criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **DeviceType** *(dict) --*

                                      The device type criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **Make** *(dict) --*

                                      The device make criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **Model** *(dict) --*

                                      The device model criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **Platform** *(dict) --*

                                      The device platform criteria for the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                  - **Location** *(dict) --*

                                    The location-based criteria, such as region or GPS coordinates,
                                    for the segment.

                                    - **Country** *(dict) --*

                                      The country or region code, in ISO 3166-1 alpha-2 format, for
                                      the segment.

                                      - **DimensionType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the DimensionType property,
                                        endpoints are included or excluded from the segment if their
                                        values match the criteria values.

                                        - *(string) --*

                                    - **GPSPoint** *(dict) --*

                                      The GPS location and range for the segment.

                                      - **Coordinates** *(dict) --*

                                        The GPS coordinates to measure distance from.

                                        - **Latitude** *(float) --*

                                          The latitude coordinate of the location.

                                        - **Longitude** *(float) --*

                                          The longitude coordinate of the location.

                                      - **RangeInKilometers** *(float) --*

                                        The range, in kilometers, from the GPS coordinates.

                                  - **Metrics** *(dict) --*

                                    One or more custom metrics to use as criteria for the segment.

                                    - *(string) --*

                                      - *(dict) --*

                                        Specifies metric-based criteria for including or excluding
                                        endpoints from a segment. These criteria derive from custom
                                        metrics that you define for endpoints.

                                        - **ComparisonOperator** *(string) --*

                                          The operator to use when comparing metric values. Valid
                                          values are: GREATER_THAN, LESS_THAN,
                                          GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

                                        - **Value** *(float) --*

                                          The value to compare.

                                  - **UserAttributes** *(dict) --*

                                    One or more custom user attributes to use as criteria for the
                                    segment.

                                    - *(string) --*

                                      - *(dict) --*

                                        Specifies attribute-based criteria for including or
                                        excluding endpoints from a segment.

                                        - **AttributeType** *(string) --*

                                          The type of segment dimension to use. Valid values are:
                                          INCLUSIVE, endpoints that match the criteria are included
                                          in the segment; and, EXCLUSIVE, endpoints that match the
                                          criteria are excluded from the segment.

                                        - **Values** *(list) --*

                                          The criteria values to use for the segment dimension.
                                          Depending on the value of the AttributeType property,
                                          endpoints are included or excluded from the segment if
                                          their attribute values match the criteria values.

                                          - *(string) --*

                              - **NextActivity** *(string) --*

                                The unique identifier for the next activity to perform, after
                                completing the activity for the path.

                          - **DefaultActivity** *(string) --*

                            The activity to perform by default for any path in the activity.

                          - **EvaluationWaitTime** *(dict) --*

                            The amount of time to wait or the date and time when Amazon Pinpoint
                            determines whether the conditions are met.

                            - **WaitFor** *(string) --*

                              The amount of time to wait, as a duration in ISO 8601 format, before
                              determining whether the activity's conditions have been met or moving
                              participants to the next activity in the journey.

                            - **WaitUntil** *(string) --*

                              The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                              whether the activity's conditions have been met or the activity moves
                              participants to the next activity in the journey.

                        - **RandomSplit** *(dict) --*

                          The settings for a random split activity. This type of activity randomly
                          sends specified percentages of participants down one of as many as five
                          paths in a journey, based on conditions that you specify.

                          - **Branches** *(list) --*

                            The paths for the activity, including the percentage of participants to
                            enter each path and the activity to perform for each path.

                            - *(dict) --*

                              Specifies the settings for a path in a random split activity in a
                              journey.

                              - **NextActivity** *(string) --*

                                The unique identifier for the next activity to perform, after
                                completing the activity for the path.

                              - **Percentage** *(integer) --*

                                The percentage of participants to send down the activity path.

                        - **Wait** *(dict) --*

                          The settings for a wait activity. This type of activity waits for a
                          certain amount of time or until a specific date and time before moving
                          participants to the next activity in a journey.

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after performing
                            the wait activity.

                          - **WaitTime** *(dict) --*

                            The amount of time to wait or the date and time when the activity moves
                            participants to the next activity in the journey.

                            - **WaitFor** *(string) --*

                              The amount of time to wait, as a duration in ISO 8601 format, before
                              determining whether the activity's conditions have been met or moving
                              participants to the next activity in the journey.

                            - **WaitUntil** *(string) --*

                              The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                              whether the activity's conditions have been met or the activity moves
                              participants to the next activity in the journey.

                  - **ApplicationId** *(string) --*

                    The unique identifier for the application that the journey applies to.

                  - **CreationDate** *(string) --*

                    The date, in ISO 8601 format, when the journey was created.

                  - **Id** *(string) --*

                    The unique identifier for the journey.

                  - **LastModifiedDate** *(string) --*

                    The date, in ISO 8601 format, when the journey was last modified.

                  - **Limits** *(dict) --*

                    The messaging and entry limits for the journey.

                    - **DailyCap** *(integer) --*

                      The maximum number of messages that the journey can send to a single
                      participant during a 24-hour period. The maximum value is 100.

                    - **EndpointReentryCap** *(integer) --*

                      The maximum number of times that a participant can enter the journey. The
                      maximum value is 100. To allow participants to enter the journey an unlimited
                      number of times, set this value to 0.

                    - **MessagesPerSecond** *(integer) --*

                      The maximum number of messages that the journey can send each second.

                  - **LocalTime** *(boolean) --*

                    Specifies whether the journey's scheduled start and end times use each
                    participant's local time. If this value is true, the schedule uses each
                    participant's local time.

                  - **Name** *(string) --*

                    The name of the journey.

                  - **QuietTime** *(dict) --*

                    The quiet time settings for the journey. Quiet time is a specific time range
                    when a journey doesn't send messages to participants, if all the following
                    conditions are met:

                    * The EndpointDemographic.Timezone property of the endpoint for the participant
                    is set to a valid value.

                    * The current time in the participant's time zone is later than or equal to the
                    time specified by the QuietTime.Start property for the journey.

                    * The current time in the participant's time zone is earlier than or equal to
                    the time specified by the QuietTime.End property for the journey.

                    If any of the preceding conditions isn't met, the participant will receive
                    messages from the journey, even if quiet time is enabled.

                    - **End** *(string) --*

                      The specific time when quiet time ends. This value has to use 24-hour notation
                      and be in HH:MM format, where HH is the hour (with a leading zero, if
                      applicable) and MM is the minutes. For example, use 02:30 to represent 2:30
                      AM, or 14:30 to represent 2:30 PM.

                    - **Start** *(string) --*

                      The specific time when quiet time begins. This value has to use 24-hour
                      notation and be in HH:MM format, where HH is the hour (with a leading zero, if
                      applicable) and MM is the minutes. For example, use 02:30 to represent 2:30
                      AM, or 14:30 to represent 2:30 PM.

                  - **RefreshFrequency** *(string) --*

                    The frequency with which Amazon Pinpoint evaluates segment and event data for
                    the journey, as a duration in ISO 8601 format.

                  - **Schedule** *(dict) --*

                    The schedule settings for the journey.

                    - **EndTime** *(datetime) --*

                      The scheduled time, in ISO 8601 format, when the journey ended or will end.

                    - **StartTime** *(datetime) --*

                      The scheduled time, in ISO 8601 format, when the journey began or will begin.

                    - **Timezone** *(string) --*

                      The starting UTC offset for the journey schedule, if the value of the
                      journey's LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02,
                      UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06,
                      UTC+06:30, UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30,
                      UTC+11, UTC+12, UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03,
                      UTC-03:30, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10,
                      and UTC-11.

                  - **StartActivity** *(string) --*

                    The unique identifier for the first activity in the journey.

                  - **StartCondition** *(dict) --*

                    The segment that defines which users are participants in the journey.

                    - **Description** *(string) --*

                      The custom description of the condition.

                    - **SegmentStartCondition** *(dict) --*

                      The segment that's associated with the first activity in the journey. This
                      segment determines which users are participants in the journey.

                      - **SegmentId** *(string) --*

                        The unique identifier for the segment to associate with the activity.

                  - **State** *(string) --*

                    The current status of the journey. Possible values are:

                    * DRAFT - The journey is being developed and hasn't been published yet.

                    * ACTIVE - The journey has been developed and published. Depending on the
                    journey's schedule, the journey may currently be running or scheduled to start
                    running at a later time. If a journey's status is ACTIVE, you can't add, change,
                    or remove activities from it.

                    * COMPLETED - The journey has been published and has finished running. All
                    participants have entered the journey and no participants are waiting to
                    complete the journey or any activities in the journey.

                    * CANCELLED - The journey has been stopped. If a journey's status is CANCELLED,
                    you can't add, change, or remove activities or segment settings from the
                    journey.

                    * CLOSED - The journey has been published and has started running. It may have
                    also passed its scheduled end time, or passed its scheduled start time and a
                    refresh frequency hasn't been specified for it. If a journey's status is CLOSED,
                    you can't add participants to it, and no existing participants can enter the
                    journey for the first time. However, any existing participants who are currently
                    waiting to start an activity may resume the journey.

                  - **tags** *(dict) --*

                    A string-to-string map of key-value pairs that identifies the tags that are
                    associated with the journey. Each tag consists of a required tag key and an
                    associated tag value.

                    - *(string) --*

                      - *(string) --*

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_tags_for_resource(self, ResourceArn: str) -> ClientListTagsForResourceResponseTypeDef:
        """
        Retrieves all the tags (keys and values) that are associated with an application, campaign,
        journey, message template, or segment.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/ListTagsForResource>`_

        **Request Syntax**
        ::

          response = client.list_tags_for_resource(
              ResourceArn='string'
          )
        :type ResourceArn: string
        :param ResourceArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the resource.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TagsModel': {
                    'tags': {
                        'string': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **TagsModel** *(dict) --*

              Specifies the tags (keys and values) for an application, campaign, journey, message
              template, or segment.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that defines the tags for an application,
                campaign, journey, message template, or segment. Each of these resources can have a
                maximum of 50 tags.

                Each tag consists of a required tag key and an associated tag value. The maximum
                length of a tag key is 128 characters. The maximum length of a tag value is 256
                characters.

                - *(string) --*

                  - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_templates(
        self,
        NextToken: str = None,
        PageSize: str = None,
        Prefix: str = None,
        TemplateType: str = None,
    ) -> ClientListTemplatesResponseTypeDef:
        """
        Retrieves information about all the message templates that are associated with your Amazon
        Pinpoint account.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/ListTemplates>`_

        **Request Syntax**
        ::

          response = client.list_templates(
              NextToken='string',
              PageSize='string',
              Prefix='string',
              TemplateType='string'
          )
        :type NextToken: string
        :param NextToken:

          The string that specifies which page of results to return in a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type PageSize: string
        :param PageSize:

          The maximum number of items to include in each page of a paginated response. This
          parameter is currently not supported for application, campaign, and journey metrics.

        :type Prefix: string
        :param Prefix:

          The substring to match in the names of the message templates to include in the results. If
          you specify this value, Amazon Pinpoint returns only those templates whose names begin
          with the value that you specify.

        :type TemplateType: string
        :param TemplateType:

          The type of message template to include in the results. Valid values are: EMAIL, SMS,
          PUSH, and VOICE. To include all types of templates in the results, don't include this
          parameter in your request.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'TemplatesResponse': {
                    'Item': [
                        {
                            'Arn': 'string',
                            'CreationDate': 'string',
                            'DefaultSubstitutions': 'string',
                            'LastModifiedDate': 'string',
                            'tags': {
                                'string': 'string'
                            },
                            'TemplateDescription': 'string',
                            'TemplateName': 'string',
                            'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH'
                        },
                    ],
                    'NextToken': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **TemplatesResponse** *(dict) --*

              Provides information about all the message templates that are associated with your
              Amazon Pinpoint account.

              - **Item** *(list) --*

                An array of responses, one for each message template that's associated with your
                Amazon Pinpoint account and meets any filter criteria that you specified in the
                request.

                - *(dict) --*

                  Provides information about a message template that's associated with your Amazon
                  Pinpoint account.

                  - **Arn** *(string) --*

                    The Amazon Resource Name (ARN) of the message template.

                  - **CreationDate** *(string) --*

                    The date when the message template was created.

                  - **DefaultSubstitutions** *(string) --*

                    The JSON object that specifies the default values that are used for message
                    variables in the message template. This object is a set of key-value pairs. Each
                    key defines a message variable in the template. The corresponding value defines
                    the default value for that variable.

                  - **LastModifiedDate** *(string) --*

                    The date when the message template was last modified.

                  - **tags** *(dict) --*

                    A string-to-string map of key-value pairs that identifies the tags that are
                    associated with the message template. Each tag consists of a required tag key
                    and an associated tag value.

                    - *(string) --*

                      - *(string) --*

                  - **TemplateDescription** *(string) --*

                    The custom description of the message template.

                  - **TemplateName** *(string) --*

                    The name of the message template.

                  - **TemplateType** *(string) --*

                    The type of channel that the message template is designed for.

              - **NextToken** *(string) --*

                The string to use in a subsequent request to get the next page of results in a
                paginated response. This value is null if there are no additional pages.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def phone_number_validate(
        self, NumberValidateRequest: ClientPhoneNumberValidateNumberValidateRequestTypeDef
    ) -> ClientPhoneNumberValidateResponseTypeDef:
        """
        Retrieves information about a phone number.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/PhoneNumberValidate>`_

        **Request Syntax**
        ::

          response = client.phone_number_validate(
              NumberValidateRequest={
                  'IsoCountryCode': 'string',
                  'PhoneNumber': 'string'
              }
          )
        :type NumberValidateRequest: dict
        :param NumberValidateRequest: **[REQUIRED]**

          Specifies a phone number to validate and retrieve information about.

          - **IsoCountryCode** *(string) --*

            The two-character code, in ISO 3166-1 alpha-2 format, for the country or region where
            the phone number was originally registered.

          - **PhoneNumber** *(string) --*

            The phone number to retrieve information about. The phone number that you provide should
            include a valid numeric country code. Otherwise, the operation might result in an error.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'NumberValidateResponse': {
                    'Carrier': 'string',
                    'City': 'string',
                    'CleansedPhoneNumberE164': 'string',
                    'CleansedPhoneNumberNational': 'string',
                    'Country': 'string',
                    'CountryCodeIso2': 'string',
                    'CountryCodeNumeric': 'string',
                    'County': 'string',
                    'OriginalCountryCodeIso2': 'string',
                    'OriginalPhoneNumber': 'string',
                    'PhoneType': 'string',
                    'PhoneTypeCode': 123,
                    'Timezone': 'string',
                    'ZipCode': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **NumberValidateResponse** *(dict) --*

              Provides information about a phone number.

              - **Carrier** *(string) --*

                The carrier or service provider that the phone number is currently registered with.
                In some countries and regions, this value may be the carrier or service provider
                that the phone number was originally registered with.

              - **City** *(string) --*

                The name of the city where the phone number was originally registered.

              - **CleansedPhoneNumberE164** *(string) --*

                The cleansed phone number, in E.164 format, for the location where the phone number
                was originally registered.

              - **CleansedPhoneNumberNational** *(string) --*

                The cleansed phone number, in the format for the location where the phone number was
                originally registered.

              - **Country** *(string) --*

                The name of the country or region where the phone number was originally registered.

              - **CountryCodeIso2** *(string) --*

                The two-character code, in ISO 3166-1 alpha-2 format, for the country or region
                where the phone number was originally registered.

              - **CountryCodeNumeric** *(string) --*

                The numeric code for the country or region where the phone number was originally
                registered.

              - **County** *(string) --*

                The name of the county where the phone number was originally registered.

              - **OriginalCountryCodeIso2** *(string) --*

                The two-character code, in ISO 3166-1 alpha-2 format, that was sent in the request
                body.

              - **OriginalPhoneNumber** *(string) --*

                The phone number that was sent in the request body.

              - **PhoneType** *(string) --*

                The description of the phone type. Valid values are: MOBILE, LANDLINE, VOIP,
                INVALID, PREPAID, and OTHER.

              - **PhoneTypeCode** *(integer) --*

                The phone type, represented by an integer. Valid values are: 0 (mobile), 1
                (landline), 2 (VoIP), 3 (invalid), 4 (other), and 5 (prepaid).

              - **Timezone** *(string) --*

                The time zone for the location where the phone number was originally registered.

              - **ZipCode** *(string) --*

                The postal or ZIP code for the location where the phone number was originally
                registered.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def put_event_stream(
        self, ApplicationId: str, WriteEventStream: ClientPutEventStreamWriteEventStreamTypeDef
    ) -> ClientPutEventStreamResponseTypeDef:
        """
        Creates a new event stream for an application or updates the settings of an existing event
        stream for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/PutEventStream>`_

        **Request Syntax**
        ::

          response = client.put_event_stream(
              ApplicationId='string',
              WriteEventStream={
                  'DestinationStreamArn': 'string',
                  'RoleArn': 'string'
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type WriteEventStream: dict
        :param WriteEventStream: **[REQUIRED]**

          Specifies the Amazon Resource Name (ARN) of an event stream to publish events to and the
          AWS Identity and Access Management (IAM) role to use when publishing those events.

          - **DestinationStreamArn** *(string) --* **[REQUIRED]**

            The Amazon Resource Name (ARN) of the Amazon Kinesis data stream or Amazon Kinesis Data
            Firehose delivery stream that you want to publish event data to.

            For a Kinesis data stream, the ARN format is:
            arn:aws:kinesis:region:account-id:stream/stream_name

            For a Kinesis Data Firehose delivery stream, the ARN format is:
            arn:aws:firehose:region:account-id:deliverystream/stream_name

          - **RoleArn** *(string) --* **[REQUIRED]**

            The AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to
            publish event data to the stream in your AWS account.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EventStream': {
                    'ApplicationId': 'string',
                    'DestinationStreamArn': 'string',
                    'ExternalId': 'string',
                    'LastModifiedDate': 'string',
                    'LastUpdatedBy': 'string',
                    'RoleArn': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **EventStream** *(dict) --*

              Specifies settings for publishing event data to an Amazon Kinesis data stream or an
              Amazon Kinesis Data Firehose delivery stream.

              - **ApplicationId** *(string) --*

                The unique identifier for the application to publish event data for.

              - **DestinationStreamArn** *(string) --*

                The Amazon Resource Name (ARN) of the Amazon Kinesis data stream or Amazon Kinesis
                Data Firehose delivery stream to publish event data to.

                For a Kinesis data stream, the ARN format is:
                arn:aws:kinesis:region:account-id:stream/stream_name

                For a Kinesis Data Firehose delivery stream, the ARN format is:
                arn:aws:firehose:region:account-id:deliverystream/stream_name

              - **ExternalId** *(string) --*

                (Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM
                trust policy. Amazon Pinpoint previously used this value to assume an IAM role when
                publishing event data, but we removed this requirement. We don't recommend use of
                external IDs for IAM roles that are assumed by Amazon Pinpoint.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the event stream was last modified.

              - **LastUpdatedBy** *(string) --*

                The IAM user who last modified the event stream.

              - **RoleArn** *(string) --*

                The AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to
                publish event data to the stream in your AWS account.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def put_events(
        self, ApplicationId: str, EventsRequest: ClientPutEventsEventsRequestTypeDef
    ) -> ClientPutEventsResponseTypeDef:
        """
        Creates a new event to record for endpoints, or creates or updates endpoint data that
        existing events are associated with.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/PutEvents>`_

        **Request Syntax**
        ::

          response = client.put_events(
              ApplicationId='string',
              EventsRequest={
                  'BatchItem': {
                      'string': {
                          'Endpoint': {
                              'Address': 'string',
                              'Attributes': {
                                  'string': [
                                      'string',
                                  ]
                              },
                              'ChannelType':
                              'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'
                              |'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'
                              |'BAIDU'|'CUSTOM',
                              'Demographic': {
                                  'AppVersion': 'string',
                                  'Locale': 'string',
                                  'Make': 'string',
                                  'Model': 'string',
                                  'ModelVersion': 'string',
                                  'Platform': 'string',
                                  'PlatformVersion': 'string',
                                  'Timezone': 'string'
                              },
                              'EffectiveDate': 'string',
                              'EndpointStatus': 'string',
                              'Location': {
                                  'City': 'string',
                                  'Country': 'string',
                                  'Latitude': 123.0,
                                  'Longitude': 123.0,
                                  'PostalCode': 'string',
                                  'Region': 'string'
                              },
                              'Metrics': {
                                  'string': 123.0
                              },
                              'OptOut': 'string',
                              'RequestId': 'string',
                              'User': {
                                  'UserAttributes': {
                                      'string': [
                                          'string',
                                      ]
                                  },
                                  'UserId': 'string'
                              }
                          },
                          'Events': {
                              'string': {
                                  'AppPackageName': 'string',
                                  'AppTitle': 'string',
                                  'AppVersionCode': 'string',
                                  'Attributes': {
                                      'string': 'string'
                                  },
                                  'ClientSdkVersion': 'string',
                                  'EventType': 'string',
                                  'Metrics': {
                                      'string': 123.0
                                  },
                                  'SdkName': 'string',
                                  'Session': {
                                      'Duration': 123,
                                      'Id': 'string',
                                      'StartTimestamp': 'string',
                                      'StopTimestamp': 'string'
                                  },
                                  'Timestamp': 'string'
                              }
                          }
                      }
                  }
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type EventsRequest: dict
        :param EventsRequest: **[REQUIRED]**

          Specifies a batch of events to process.

          - **BatchItem** *(dict) --* **[REQUIRED]**

            The batch of events to process. For each item in a batch, the endpoint ID acts as a key
            that has an EventsBatch object as its value.

            - *(string) --*

              - *(dict) --*

                Specifies a batch of endpoints and events to process.

                - **Endpoint** *(dict) --* **[REQUIRED]**

                  A set of properties and attributes that are associated with the endpoint.

                  - **Address** *(string) --*

                    The unique identifier for the recipient, such as a device token, email address,
                    or mobile phone number.

                  - **Attributes** *(dict) --*

                    One or more custom attributes that describe the endpoint by associating a name
                    with an array of values. You can use these attributes as filter criteria when
                    you create segments.

                    - *(string) --*

                      - *(list) --*

                        - *(string) --*

                  - **ChannelType** *(string) --*

                    The channel that's used when sending messages or push notifications to the
                    endpoint.

                  - **Demographic** *(dict) --*

                    The demographic information for the endpoint, such as the time zone and
                    platform.

                    - **AppVersion** *(string) --*

                      The version of the app that's associated with the endpoint.

                    - **Locale** *(string) --*

                      The locale of the endpoint, in the following format: the ISO 639-1 alpha-2
                      code, followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.

                    - **Make** *(string) --*

                      The manufacturer of the endpoint device, such as Apple or Samsung.

                    - **Model** *(string) --*

                      The model name or number of the endpoint device, such as iPhone.

                    - **ModelVersion** *(string) --*

                      The model version of the endpoint device.

                    - **Platform** *(string) --*

                      The platform of the endpoint device, such as iOS or Android.

                    - **PlatformVersion** *(string) --*

                      The platform version of the endpoint device.

                    - **Timezone** *(string) --*

                      The time zone of the endpoint, specified as a tz database name value, such as
                      America/Los_Angeles.

                  - **EffectiveDate** *(string) --*

                    The date and time, in ISO 8601 format, when the endpoint was last updated.

                  - **EndpointStatus** *(string) --*

                    Specifies whether to send messages or push notifications to the endpoint. Valid
                    values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages
                    aren’t sent to the endpoint.

                    Amazon Pinpoint automatically sets this value to ACTIVE when you create an
                    endpoint or update an existing endpoint. Amazon Pinpoint automatically sets this
                    value to INACTIVE if you update another endpoint that has the same address
                    specified by the Address property.

                  - **Location** *(dict) --*

                    The geographic information for the endpoint.

                    - **City** *(string) --*

                      The name of the city where the endpoint is located.

                    - **Country** *(string) --*

                      The two-character code, in ISO 3166-1 alpha-2 format, for the country or
                      region where the endpoint is located. For example, US for the United States.

                    - **Latitude** *(float) --*

                      The latitude coordinate of the endpoint location, rounded to one decimal
                      place.

                    - **Longitude** *(float) --*

                      The longitude coordinate of the endpoint location, rounded to one decimal
                      place.

                    - **PostalCode** *(string) --*

                      The postal or ZIP code for the area where the endpoint is located.

                    - **Region** *(string) --*

                      The name of the region where the endpoint is located. For locations in the
                      United States, this value is the name of a state.

                  - **Metrics** *(dict) --*

                    One or more custom metrics that your app reports to Amazon Pinpoint for the
                    endpoint.

                    - *(string) --*

                      - *(float) --*

                  - **OptOut** *(string) --*

                    Specifies whether the user who's associated with the endpoint has opted out of
                    receiving messages and push notifications from you. Possible values are: ALL,
                    the user has opted out and doesn't want to receive any messages or push
                    notifications; and, NONE, the user hasn't opted out and wants to receive all
                    messages and push notifications.

                  - **RequestId** *(string) --*

                    A unique identifier that's generated each time the endpoint is updated.

                  - **User** *(dict) --*

                    One or more custom user attributes that your app reports to Amazon Pinpoint for
                    the user who's associated with the endpoint.

                    - **UserAttributes** *(dict) --*

                      One or more custom attributes that describe the user by associating a name
                      with an array of values. For example, the value of an attribute named
                      Interests might be: ["science", "music", "travel"]. You can use these
                      attributes as filter criteria when you create segments.

                      When you define the name of a custom attribute, avoid using the following
                      characters: number sign (#), colon (:), question mark (?), backslash (\\), and
                      slash (/). The Amazon Pinpoint console can't display attribute names that
                      contain these characters. This limitation doesn't apply to attribute values.

                      - *(string) --*

                        - *(list) --*

                          - *(string) --*

                    - **UserId** *(string) --*

                      The unique identifier for the user.

                - **Events** *(dict) --* **[REQUIRED]**

                  A set of properties that are associated with the event.

                  - *(string) --*

                    - *(dict) --*

                      Specifies information about an event that reports data to Amazon Pinpoint.

                      - **AppPackageName** *(string) --*

                        The package name of the app that's recording the event.

                      - **AppTitle** *(string) --*

                        The title of the app that's recording the event.

                      - **AppVersionCode** *(string) --*

                        The version number of the app that's recording the event.

                      - **Attributes** *(dict) --*

                        One or more custom attributes that are associated with the event.

                        - *(string) --*

                          - *(string) --*

                      - **ClientSdkVersion** *(string) --*

                        The version of the SDK that's running on the client device.

                      - **EventType** *(string) --* **[REQUIRED]**

                        The name of the event.

                      - **Metrics** *(dict) --*

                        One or more custom metrics that are associated with the event.

                        - *(string) --*

                          - *(float) --*

                      - **SdkName** *(string) --*

                        The name of the SDK that's being used to record the event.

                      - **Session** *(dict) --*

                        Information about the session in which the event occurred.

                        - **Duration** *(integer) --*

                          The duration of the session, in milliseconds.

                        - **Id** *(string) --* **[REQUIRED]**

                          The unique identifier for the session.

                        - **StartTimestamp** *(string) --* **[REQUIRED]**

                          The date and time when the session began.

                        - **StopTimestamp** *(string) --*

                          The date and time when the session ended.

                      - **Timestamp** *(string) --* **[REQUIRED]**

                        The date and time, in ISO 8601 format, when the event occurred.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EventsResponse': {
                    'Results': {
                        'string': {
                            'EndpointItemResponse': {
                                'Message': 'string',
                                'StatusCode': 123
                            },
                            'EventsItemResponse': {
                                'string': {
                                    'Message': 'string',
                                    'StatusCode': 123
                                }
                            }
                        }
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **EventsResponse** *(dict) --*

              Provides information about endpoints and the events that they're associated with.

              - **Results** *(dict) --*

                A map that contains a multipart response for each endpoint. For each item in this
                object, the endpoint ID is the key and the item response is the value. If no item
                response exists, the value can also be one of the following: 202, the request was
                processed successfully; or 400, the payload wasn't valid or required fields were
                missing.

                - *(string) --*

                  - *(dict) --*

                    Provides information about the results of a request to create or update an
                    endpoint that's associated with an event.

                    - **EndpointItemResponse** *(dict) --*

                      The response that was received after the endpoint data was accepted.

                      - **Message** *(string) --*

                        The custom message that's returned in the response as a result of processing
                        the endpoint data.

                      - **StatusCode** *(integer) --*

                        The status code that's returned in the response as a result of processing
                        the endpoint data.

                    - **EventsItemResponse** *(dict) --*

                      A multipart response object that contains a key and a value for each event in
                      the request. In each object, the event ID is the key and an EventItemResponse
                      object is the value.

                      - *(string) --*

                        - *(dict) --*

                          Provides the status code and message that result from processing an event.

                          - **Message** *(string) --*

                            A custom message that's returned in the response as a result of
                            processing the event.

                          - **StatusCode** *(integer) --*

                            The status code that's returned in the response as a result of
                            processing the event. Possible values are: 202, for events that were
                            accepted; and, 400, for events that weren't valid.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def remove_attributes(
        self,
        ApplicationId: str,
        AttributeType: str,
        UpdateAttributesRequest: ClientRemoveAttributesUpdateAttributesRequestTypeDef,
    ) -> ClientRemoveAttributesResponseTypeDef:
        """
        Removes one or more attributes, of the same attribute type, from all the endpoints that are
        associated with an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/RemoveAttributes>`_

        **Request Syntax**
        ::

          response = client.remove_attributes(
              ApplicationId='string',
              AttributeType='string',
              UpdateAttributesRequest={
                  'Blacklist': [
                      'string',
                  ]
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type AttributeType: string
        :param AttributeType: **[REQUIRED]**

          The type of attribute or attributes to remove. Valid values are:

          * endpoint-custom-attributes - Custom attributes that describe endpoints, such as the date
          when an associated user opted in or out of receiving communications from you through a
          specific type of channel.

          * endpoint-metric-attributes - Custom metrics that your app reports to Amazon Pinpoint for
          endpoints, such as the number of app sessions or the number of items left in a cart.

          * endpoint-user-attributes - Custom attributes that describe users, such as first name,
          last name, and age.

        :type UpdateAttributesRequest: dict
        :param UpdateAttributesRequest: **[REQUIRED]**

          Specifies one or more attributes to remove from all the endpoints that are associated with
          an application.

          - **Blacklist** *(list) --*

            An array of the attributes to remove from all the endpoints that are associated with the
            application. The array can specify the complete, exact name of each attribute to remove
            or it can specify a glob pattern that an attribute name must match in order for the
            attribute to be removed.

            - *(string) --*

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'AttributesResource': {
                    'ApplicationId': 'string',
                    'AttributeType': 'string',
                    'Attributes': [
                        'string',
                    ]
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **AttributesResource** *(dict) --*

              Provides information about the type and the names of attributes that were removed from
              all the endpoints that are associated with an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application.

              - **AttributeType** *(string) --*

                The type of attribute or attributes that were removed from the endpoints. Valid
                values are:

                * endpoint-custom-attributes - Custom attributes that describe endpoints.

                * endpoint-metric-attributes - Custom metrics that your app reports to Amazon
                Pinpoint for endpoints.

                * endpoint-user-attributes - Custom attributes that describe users.

              - **Attributes** *(list) --*

                An array that specifies the names of the attributes that were removed from the
                endpoints.

                - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def send_messages(
        self, ApplicationId: str, MessageRequest: ClientSendMessagesMessageRequestTypeDef
    ) -> ClientSendMessagesResponseTypeDef:
        """
        Creates and sends a direct message.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/SendMessages>`_

        **Request Syntax**
        ::

          response = client.send_messages(
              ApplicationId='string',
              MessageRequest={
                  'Addresses': {
                      'string': {
                          'BodyOverride': 'string',
                          'ChannelType':
                          'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'
                          |'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'
                          |'CUSTOM',
                          'Context': {
                              'string': 'string'
                          },
                          'RawContent': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'TitleOverride': 'string'
                      }
                  },
                  'Context': {
                      'string': 'string'
                  },
                  'Endpoints': {
                      'string': {
                          'BodyOverride': 'string',
                          'Context': {
                              'string': 'string'
                          },
                          'RawContent': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'TitleOverride': 'string'
                      }
                  },
                  'MessageConfiguration': {
                      'ADMMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ConsolidationKey': 'string',
                          'Data': {
                              'string': 'string'
                          },
                          'ExpiresAfter': 'string',
                          'IconReference': 'string',
                          'ImageIconUrl': 'string',
                          'ImageUrl': 'string',
                          'MD5': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'SmallImageIconUrl': 'string',
                          'Sound': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'APNSMessage': {
                          'APNSPushType': 'string',
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Badge': 123,
                          'Body': 'string',
                          'Category': 'string',
                          'CollapseId': 'string',
                          'Data': {
                              'string': 'string'
                          },
                          'MediaUrl': 'string',
                          'PreferredAuthenticationMethod': 'string',
                          'Priority': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'Sound': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'ThreadId': 'string',
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'BaiduMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'Data': {
                              'string': 'string'
                          },
                          'IconReference': 'string',
                          'ImageIconUrl': 'string',
                          'ImageUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'SmallImageIconUrl': 'string',
                          'Sound': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'DefaultMessage': {
                          'Body': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          }
                      },
                      'DefaultPushNotificationMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'Data': {
                              'string': 'string'
                          },
                          'SilentPush': True|False,
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'EmailMessage': {
                          'Body': 'string',
                          'FeedbackForwardingAddress': 'string',
                          'FromAddress': 'string',
                          'RawEmail': {
                              'Data': b'bytes'
                          },
                          'ReplyToAddresses': [
                              'string',
                          ],
                          'SimpleEmail': {
                              'HtmlPart': {
                                  'Charset': 'string',
                                  'Data': 'string'
                              },
                              'Subject': {
                                  'Charset': 'string',
                                  'Data': 'string'
                              },
                              'TextPart': {
                                  'Charset': 'string',
                                  'Data': 'string'
                              }
                          },
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          }
                      },
                      'GCMMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'CollapseKey': 'string',
                          'Data': {
                              'string': 'string'
                          },
                          'IconReference': 'string',
                          'ImageIconUrl': 'string',
                          'ImageUrl': 'string',
                          'Priority': 'string',
                          'RawContent': 'string',
                          'RestrictedPackageName': 'string',
                          'SilentPush': True|False,
                          'SmallImageIconUrl': 'string',
                          'Sound': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'SMSMessage': {
                          'Body': 'string',
                          'Keyword': 'string',
                          'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                          'OriginationNumber': 'string',
                          'SenderId': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          }
                      },
                      'VoiceMessage': {
                          'Body': 'string',
                          'LanguageCode': 'string',
                          'OriginationNumber': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'VoiceId': 'string'
                      }
                  },
                  'TemplateConfiguration': {
                      'EmailTemplate': {
                          'Name': 'string'
                      },
                      'PushTemplate': {
                          'Name': 'string'
                      },
                      'SMSTemplate': {
                          'Name': 'string'
                      },
                      'VoiceTemplate': {
                          'Name': 'string'
                      }
                  },
                  'TraceId': 'string'
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type MessageRequest: dict
        :param MessageRequest: **[REQUIRED]**

          Specifies the configuration and other settings for a message.

          - **Addresses** *(dict) --*

            A map of key-value pairs, where each key is an address and each value is an
            AddressConfiguration object. An address can be a push notification token, a phone
            number, or an email address. You can use an AddressConfiguration object to tailor the
            message for an address by specifying settings such as content overrides and message
            variables.

            - *(string) --*

              - *(dict) --*

                Specifies address-based configuration settings for a message that's sent directly to
                an endpoint.

                - **BodyOverride** *(string) --*

                  The message body to use instead of the default message body. This value overrides
                  the default message body.

                - **ChannelType** *(string) --*

                  The channel to use when sending the message.

                - **Context** *(dict) --*

                  An object that maps custom attributes to attributes for the address and is
                  attached to the message. For a push notification, this payload is added to the
                  data.pinpoint object. For an email or text message, this payload is added to
                  email/SMS delivery receipt event attributes.

                  - *(string) --*

                    - *(string) --*

                - **RawContent** *(string) --*

                  The raw, JSON-formatted string to use as the payload for the message. If
                  specified, this value overrides all other values for the message.

                - **Substitutions** *(dict) --*

                  A map of the message variables to merge with the variables specified by properties
                  of the DefaultMessage object. The variables specified in this map take precedence
                  over all other variables.

                  - *(string) --*

                    - *(list) --*

                      - *(string) --*

                - **TitleOverride** *(string) --*

                  The message title to use instead of the default message title. This value
                  overrides the default message title.

          - **Context** *(dict) --*

            A map of custom attributes to attach to the message. For a push notification, this
            payload is added to the data.pinpoint object. For an email or text message, this payload
            is added to email/SMS delivery receipt event attributes.

            - *(string) --*

              - *(string) --*

          - **Endpoints** *(dict) --*

            A map of key-value pairs, where each key is an endpoint ID and each value is an
            EndpointSendConfiguration object. You can use an EndpointSendConfiguration object to
            tailor the message for an endpoint by specifying settings such as content overrides and
            message variables.

            - *(string) --*

              - *(dict) --*

                Specifies the content, including message variables and attributes, to use in a
                message that's sent directly to an endpoint.

                - **BodyOverride** *(string) --*

                  The body of the message. If specified, this value overrides the default message
                  body.

                - **Context** *(dict) --*

                  A map of custom attributes to attach to the message for the address. For a push
                  notification, this payload is added to the data.pinpoint object. For an email or
                  text message, this payload is added to email/SMS delivery receipt event
                  attributes.

                  - *(string) --*

                    - *(string) --*

                - **RawContent** *(string) --*

                  The raw, JSON-formatted string to use as the payload for the message. If
                  specified, this value overrides all other values for the message.

                - **Substitutions** *(dict) --*

                  A map of the message variables to merge with the variables specified for the
                  default message (DefaultMessage.Substitutions). The variables specified in this
                  map take precedence over all other variables.

                  - *(string) --*

                    - *(list) --*

                      - *(string) --*

                - **TitleOverride** *(string) --*

                  The title or subject line of the message. If specified, this value overrides the
                  default message title or subject line.

          - **MessageConfiguration** *(dict) --* **[REQUIRED]**

            The settings and content for the default message and any default messages that you
            defined for specific channels.

            - **ADMMessage** *(dict) --*

              The default push notification message for the ADM (Amazon Device Messaging) channel.
              This message overrides the default push notification message
              (DefaultPushNotificationMessage).

              - **Action** *(string) --*

                The action to occur if the recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This action uses the deep-linking features of the Android platform.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message.

              - **ConsolidationKey** *(string) --*

                An arbitrary string that indicates that multiple messages are logically the same and
                that Amazon Device Messaging (ADM) can drop previously enqueued messages in favor of
                this message.

              - **Data** *(dict) --*

                The JSON data payload to use for the push notification, if the notification is a
                silent push notification. This payload is added to the data.pinpoint.jsonBody object
                of the notification.

                - *(string) --*

                  - *(string) --*

              - **ExpiresAfter** *(string) --*

                The amount of time, in seconds, that ADM should store the message if the recipient's
                device is offline. Amazon Pinpoint specifies this value in the expiresAfter
                parameter when it sends the notification message to ADM.

              - **IconReference** *(string) --*

                The icon image name of the asset saved in your app.

              - **ImageIconUrl** *(string) --*

                The URL of the large icon image to display in the content view of the push
                notification.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **MD5** *(string) --*

                The base64-encoded, MD5 checksum of the value specified by the Data property. ADM
                uses the MD5 value to verify the integrity of the data.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration or supporting phone
                home functionality.

              - **SmallImageIconUrl** *(string) --*

                The URL of the small icon image to display in the status bar and the content view of
                the push notification.

              - **Sound** *(string) --*

                The sound to play when the recipient receives the push notification. You can use the
                default stream or specify the file name of a sound resource that's bundled in your
                app. On an Android platform, the sound file must reside in /res/raw/.

              - **Substitutions** *(dict) --*

                The default message variables to use in the notification message. You can override
                the default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **Title** *(string) --*

                The title to display above the notification message on the recipient's device.

              - **Url** *(string) --*

                The URL to open in the recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **APNSMessage** *(dict) --*

              The default push notification message for the APNs (Apple Push Notification service)
              channel. This message overrides the default push notification message
              (DefaultPushNotificationMessage).

              - **APNSPushType** *(string) --*

                The type of push notification to send. Valid values are:

                * alert - For a standard notification that's displayed on recipients' devices and
                prompts a recipient to interact with the notification.

                * background - For a silent notification that delivers content in the background and
                isn't displayed on recipients' devices.

                * complication - For a notification that contains update information for an app’s
                complication timeline.

                * fileprovider - For a notification that signals changes to a File Provider
                extension.

                * mdm - For a notification that tells managed devices to contact the MDM server.

                * voip - For a notification that provides information about an incoming VoIP call.

                Amazon Pinpoint specifies this value in the apns-push-type request header when it
                sends the notification message to APNs. If you don't specify a value for this
                property, Amazon Pinpoint sets the value to alert or background automatically, based
                on the value that you specify for the SilentPush or RawContent property of the
                message.

                For more information about the apns-push-type request header, see `Sending
                Notification Requests to APNs
                <https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/sending_notification_requests_to_apns>`__
                on the Apple Developer website.

              - **Action** *(string) --*

                The action to occur if the recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of the iOS platform.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Badge** *(integer) --*

                The key that indicates whether and how to modify the badge of your app's icon when
                the recipient receives the push notification. If this key isn't included in the
                dictionary, the badge doesn't change. To remove the badge, set this value to 0.

              - **Body** *(string) --*

                The body of the notification message.

              - **Category** *(string) --*

                The key that indicates the notification type for the push notification. This key is
                a value that's defined by the identifier property of one of your app's registered
                categories.

              - **CollapseId** *(string) --*

                An arbitrary identifier that, if assigned to multiple messages, APNs uses to
                coalesce the messages into a single push notification instead of delivering each
                message individually. This value can't exceed 64 bytes.

                Amazon Pinpoint specifies this value in the apns-collapse-id request header when it
                sends the notification message to APNs.

              - **Data** *(dict) --*

                The JSON payload to use for a silent push notification. This payload is added to the
                data.pinpoint.jsonBody object of the notification.

                - *(string) --*

                  - *(string) --*

              - **MediaUrl** *(string) --*

                The URL of an image or video to display in the push notification.

              - **PreferredAuthenticationMethod** *(string) --*

                The authentication method that you want Amazon Pinpoint to use when authenticating
                with APNs, CERTIFICATE or TOKEN.

              - **Priority** *(string) --*

                para>5 - Low priority, the notification might be delayed, delivered as part of a
                group, or throttled.

                /listitem>
                * 10 - High priority, the notification is sent immediately. This is the default
                value. A high priority notification should trigger an alert, play a sound, or badge
                your app's icon on the recipient's device.
                /para>

                Amazon Pinpoint specifies this value in the apns-priority request header when it
                sends the notification message to APNs.

                The equivalent values for Firebase Cloud Messaging (FCM), formerly Google Cloud
                Messaging (GCM), are normal, for 5, and high, for 10. If you specify an FCM value
                for this property, Amazon Pinpoint accepts and converts the value to the
                corresponding APNs value.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

                .. note::

                  If you specify the raw content of an APNs push notification, the message payload
                  has to include the content-available key. The value of the content-available key
                  has to be an integer, and can only be 0 or 1. If you're sending a standard
                  notification, set the value of content-available to 0. If you're sending a silent
                  (background) notification, set the value of content-available to 1. Additionally,
                  silent notification payloads can't include the alert, badge, or sound keys. For
                  more information, see `Generating a Remote Notification
                  <https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/generating_a_remote_notification>`__
                  and `Pushing Background Updates to Your App
                  <https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/pushing_background_updates_to_your_app>`__
                  on the Apple Developer website.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification. A silent (or
                background) push notification isn't displayed on recipients' devices. You can use
                silent push notifications to make small updates to your app, or to display messages
                in an in-app message center.

                Amazon Pinpoint uses this property to determine the correct value for the
                apns-push-type request header when it sends the notification message to APNs. If you
                specify a value of true for this property, Amazon Pinpoint sets the value for the
                apns-push-type header field to background.

                .. note::

                  If you specify the raw content of an APNs push notification, the message payload
                  has to include the content-available key. For silent (background) notifications,
                  set the value of content-available to 1. Additionally, the message payload for a
                  silent notification can't include the alert, badge, or sound keys. For more
                  information, see `Generating a Remote Notification
                  <https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/generating_a_remote_notification>`__
                  and `Pushing Background Updates to Your App
                  <https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/pushing_background_updates_to_your_app>`__
                  on the Apple Developer website.

                  Apple has indicated that they will throttle "excessive" background notifications
                  based on current traffic volumes. To prevent your notifications being throttled,
                  Apple recommends that you send no more than 3 silent push notifications to each
                  recipient per hour.

              - **Sound** *(string) --*

                The key for the sound to play when the recipient receives the push notification. The
                value for this key is the name of a sound file in your app's main bundle or the
                Library/Sounds folder in your app's data container. If the sound file can't be found
                or you specify default for the value, the system plays the default alert sound.

              - **Substitutions** *(dict) --*

                The default message variables to use in the notification message. You can override
                these default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **ThreadId** *(string) --*

                The key that represents your app-specific identifier for grouping notifications. If
                you provide a Notification Content app extension, you can use this value to group
                your notifications together.

              - **TimeToLive** *(integer) --*

                The amount of time, in seconds, that APNs should store and attempt to deliver the
                push notification, if the service is unable to deliver the notification the first
                time. If this value is 0, APNs treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                Amazon Pinpoint specifies this value in the apns-expiration request header when it
                sends the notification message to APNs.

              - **Title** *(string) --*

                The title to display above the notification message on the recipient's device.

              - **Url** *(string) --*

                The URL to open in the recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **BaiduMessage** *(dict) --*

              The default push notification message for the Baidu (Baidu Cloud Push) channel. This
              message overrides the default push notification message
              (DefaultPushNotificationMessage).

              - **Action** *(string) --*

                The action to occur if the recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This action uses the deep-linking features of the Android platform.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message.

              - **Data** *(dict) --*

                The JSON data payload to use for the push notification, if the notification is a
                silent push notification. This payload is added to the data.pinpoint.jsonBody object
                of the notification.

                - *(string) --*

                  - *(string) --*

              - **IconReference** *(string) --*

                The icon image name of the asset saved in your app.

              - **ImageIconUrl** *(string) --*

                The URL of the large icon image to display in the content view of the push
                notification.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration or supporting phone
                home functionality.

              - **SmallImageIconUrl** *(string) --*

                The URL of the small icon image to display in the status bar and the content view of
                the push notification.

              - **Sound** *(string) --*

                The sound to play when the recipient receives the push notification. You can use the
                default stream or specify the file name of a sound resource that's bundled in your
                app. On an Android platform, the sound file must reside in /res/raw/.

              - **Substitutions** *(dict) --*

                The default message variables to use in the notification message. You can override
                the default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **TimeToLive** *(integer) --*

                The amount of time, in seconds, that the Baidu Cloud Push service should store the
                message if the recipient's device is offline. The default value and maximum
                supported time is 604,800 seconds (7 days).

              - **Title** *(string) --*

                The title to display above the notification message on the recipient's device.

              - **Url** *(string) --*

                The URL to open in the recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **DefaultMessage** *(dict) --*

              The default message for all channels.

              - **Body** *(string) --*

                The default body of the message.

              - **Substitutions** *(dict) --*

                The default message variables to use in the message. You can override these default
                variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

            - **DefaultPushNotificationMessage** *(dict) --*

              The default push notification message for all push notification channels.

              - **Action** *(string) --*

                The default action to occur if a recipient taps the push notification. Valid values
                are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of the iOS and Android platforms.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The default body of the notification message.

              - **Data** *(dict) --*

                The JSON data payload to use for the default push notification, if the notification
                is a silent push notification. This payload is added to the data.pinpoint.jsonBody
                object of the notification.

                - *(string) --*

                  - *(string) --*

              - **SilentPush** *(boolean) --*

                Specifies whether the default notification is a silent push notification, which is a
                push notification that doesn't display on a recipient's device. Silent push
                notifications can be used for cases such as updating an app's configuration or
                delivering messages to an in-app notification center.

              - **Substitutions** *(dict) --*

                The default message variables to use in the notification message. You can override
                the default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **Title** *(string) --*

                The default title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The default URL to open in a recipient's default mobile browser, if a recipient taps
                the push notification and the value of the Action property is URL.

            - **EmailMessage** *(dict) --*

              The default message for the email channel. This message overrides the default message
              (DefaultMessage).

              - **Body** *(string) --*

                The body of the email message.

              - **FeedbackForwardingAddress** *(string) --*

                The email address to forward bounces and complaints to, if feedback forwarding is
                enabled.

              - **FromAddress** *(string) --*

                The verified email address to send the email message from. The default value is the
                FromAddress specified for the email channel.

              - **RawEmail** *(dict) --*

                The email message, represented as a raw MIME message.

                - **Data** *(bytes) --*

                  The email message, represented as a raw MIME message. The entire message must be
                  base64 encoded.

              - **ReplyToAddresses** *(list) --*

                The reply-to email address(es) for the email message. If a recipient replies to the
                email, each reply-to address receives the reply.

                - *(string) --*

              - **SimpleEmail** *(dict) --*

                The email message, composed of a subject, a text part, and an HTML part.

                - **HtmlPart** *(dict) --*

                  The body of the email message, in HTML format. We recommend using HTML format for
                  email clients that render HTML content. You can include links, formatted text, and
                  more in an HTML message.

                  - **Charset** *(string) --*

                    The applicable character set for the message content.

                  - **Data** *(string) --*

                    The textual data of the message content.

                - **Subject** *(dict) --*

                  The subject line, or title, of the email.

                  - **Charset** *(string) --*

                    The applicable character set for the message content.

                  - **Data** *(string) --*

                    The textual data of the message content.

                - **TextPart** *(dict) --*

                  The body of the email message, in plain text format. We recommend using plain text
                  format for email clients that don't render HTML content and clients that are
                  connected to high-latency networks, such as mobile devices.

                  - **Charset** *(string) --*

                    The applicable character set for the message content.

                  - **Data** *(string) --*

                    The textual data of the message content.

              - **Substitutions** *(dict) --*

                The default message variables to use in the email message. You can override the
                default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

            - **GCMMessage** *(dict) --*

              The default push notification message for the GCM channel, which is used to send
              notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud
              Messaging (GCM), service. This message overrides the default push notification message
              (DefaultPushNotificationMessage).

              - **Action** *(string) --*

                The action to occur if the recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This action uses the deep-linking features of the Android platform.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message.

              - **CollapseKey** *(string) --*

                An arbitrary string that identifies a group of messages that can be collapsed to
                ensure that only the last message is sent when delivery can resume. This helps avoid
                sending too many instances of the same messages when the recipient's device comes
                online again or becomes active.

                Amazon Pinpoint specifies this value in the Firebase Cloud Messaging (FCM)
                collapse_key parameter when it sends the notification message to FCM.

              - **Data** *(dict) --*

                The JSON data payload to use for the push notification, if the notification is a
                silent push notification. This payload is added to the data.pinpoint.jsonBody object
                of the notification.

                - *(string) --*

                  - *(string) --*

              - **IconReference** *(string) --*

                The icon image name of the asset saved in your app.

              - **ImageIconUrl** *(string) --*

                The URL of the large icon image to display in the content view of the push
                notification.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **Priority** *(string) --*

                para>normal - The notification might be delayed. Delivery is optimized for battery
                usage on the recipient's device. Use this value unless immediate delivery is
                required.

                /listitem>
                * high - The notification is sent immediately and might wake a sleeping device.
                /para>

                Amazon Pinpoint specifies this value in the FCM priority parameter when it sends the
                notification message to FCM.

                The equivalent values for Apple Push Notification service (APNs) are 5, for normal,
                and 10, for high. If you specify an APNs value for this property, Amazon Pinpoint
                accepts and converts the value to the corresponding FCM value.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **RestrictedPackageName** *(string) --*

                The package name of the application where registration tokens must match in order
                for the recipient to receive the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration or supporting phone
                home functionality.

              - **SmallImageIconUrl** *(string) --*

                The URL of the small icon image to display in the status bar and the content view of
                the push notification.

              - **Sound** *(string) --*

                The sound to play when the recipient receives the push notification. You can use the
                default stream or specify the file name of a sound resource that's bundled in your
                app. On an Android platform, the sound file must reside in /res/raw/.

              - **Substitutions** *(dict) --*

                The default message variables to use in the notification message. You can override
                the default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **TimeToLive** *(integer) --*

                The amount of time, in seconds, that FCM should store and attempt to deliver the
                push notification, if the service is unable to deliver the notification the first
                time. If you don't specify this value, FCM defaults to the maximum value, which is
                2,419,200 seconds (28 days).

                Amazon Pinpoint specifies this value in the FCM time_to_live parameter when it sends
                the notification message to FCM.

              - **Title** *(string) --*

                The title to display above the notification message on the recipient's device.

              - **Url** *(string) --*

                The URL to open in the recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **SMSMessage** *(dict) --*

              The default message for the SMS channel. This message overrides the default message
              (DefaultMessage).

              - **Body** *(string) --*

                The body of the SMS message.

              - **Keyword** *(string) --*

                The SMS program name that you provided to AWS Support when you requested your
                dedicated number.

              - **MessageType** *(string) --*

                The SMS message type. Valid values are: TRANSACTIONAL, the message is critical or
                time-sensitive, such as a one-time password that supports a customer transaction;
                and, PROMOTIONAL, the message is not critical or time-sensitive, such as a marketing
                message.

              - **OriginationNumber** *(string) --*

                The number to send the SMS message from. This value should be one of the dedicated
                long or short codes that's assigned to your AWS account. If you don't specify a long
                or short code, Amazon Pinpoint assigns a random long code to the SMS message and
                sends the message from that code.

              - **SenderId** *(string) --*

                The sender ID to display as the sender of the message on a recipient's device.
                Support for sender IDs varies by country or region.

              - **Substitutions** *(dict) --*

                The message variables to use in the SMS message. You can override the default
                variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

            - **VoiceMessage** *(dict) --*

              The default message for the voice channel. This message overrides the default message
              (DefaultMessage).

              - **Body** *(string) --*

                The text of the script to use for the voice message.

              - **LanguageCode** *(string) --*

                The code for the language to use when synthesizing the text of the message script.
                For a list of supported languages and the code for each one, see the `Amazon Polly
                Developer Guide <https://docs.aws.amazon.com/polly/latest/dg/what-is.html>`__ .

              - **OriginationNumber** *(string) --*

                The long code to send the voice message from. This value should be one of the
                dedicated long codes that's assigned to your AWS account. Although it isn't
                required, we recommend that you specify the long code in E.164 format, for example
                +12065550100, to ensure prompt and accurate delivery of the message.

              - **Substitutions** *(dict) --*

                The default message variables to use in the voice message. You can override the
                default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **VoiceId** *(string) --*

                The name of the voice to use when delivering the message. For a list of supported
                voices, see the `Amazon Polly Developer Guide
                <https://docs.aws.amazon.com/polly/latest/dg/what-is.html>`__ .

          - **TemplateConfiguration** *(dict) --*

            The message template to use for the message.

            - **EmailTemplate** *(dict) --*

              The email template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **PushTemplate** *(dict) --*

              The push notification template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **SMSTemplate** *(dict) --*

              The SMS template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **VoiceTemplate** *(dict) --*

              The voice template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

          - **TraceId** *(string) --*

            The unique identifier for tracing the message. This identifier is visible to message
            recipients.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MessageResponse': {
                    'ApplicationId': 'string',
                    'EndpointResult': {
                        'string': {
                            'Address': 'string',
                            'DeliveryStatus':
                            'SUCCESSFUL'|'THROTTLED'|'TEMPORARY_FAILURE'
                            |'PERMANENT_FAILURE'|'UNKNOWN_FAILURE'|'OPT_OUT'
                            |'DUPLICATE',
                            'MessageId': 'string',
                            'StatusCode': 123,
                            'StatusMessage': 'string',
                            'UpdatedToken': 'string'
                        }
                    },
                    'RequestId': 'string',
                    'Result': {
                        'string': {
                            'DeliveryStatus':
                            'SUCCESSFUL'|'THROTTLED'|'TEMPORARY_FAILURE'
                            |'PERMANENT_FAILURE'|'UNKNOWN_FAILURE'|'OPT_OUT'
                            |'DUPLICATE',
                            'MessageId': 'string',
                            'StatusCode': 123,
                            'StatusMessage': 'string',
                            'UpdatedToken': 'string'
                        }
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **MessageResponse** *(dict) --*

              Provides information about the results of a request to send a message to an endpoint
              address.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that was used to send the message.

              - **EndpointResult** *(dict) --*

                A map that contains a multipart response for each address that the message was sent
                to. In the map, the endpoint ID is the key and the result is the value.

                - *(string) --*

                  - *(dict) --*

                    Provides information about the delivery status and results of sending a message
                    directly to an endpoint.

                    - **Address** *(string) --*

                      The endpoint address that the message was delivered to.

                    - **DeliveryStatus** *(string) --*

                      The delivery status of the message. Possible values are:

                      * DUPLICATE - The endpoint address is a duplicate of another endpoint address.
                      Amazon Pinpoint won't attempt to send the message again.

                      * OPT_OUT - The user who's associated with the endpoint has opted out of
                      receiving messages from you. Amazon Pinpoint won't attempt to send the message
                      again.

                      * PERMANENT_FAILURE - An error occurred when delivering the message to the
                      endpoint. Amazon Pinpoint won't attempt to send the message again.

                      * SUCCESSFUL - The message was successfully delivered to the endpoint.

                      * TEMPORARY_FAILURE - A temporary error occurred. Amazon Pinpoint will attempt
                      to deliver the message again later.

                      * THROTTLED - Amazon Pinpoint throttled the operation to send the message to
                      the endpoint.

                      * TIMEOUT - The message couldn't be sent within the timeout period.

                      * UNKNOWN_FAILURE - An unknown error occurred.

                    - **MessageId** *(string) --*

                      The unique identifier for the message that was sent.

                    - **StatusCode** *(integer) --*

                      The downstream service status code for delivering the message.

                    - **StatusMessage** *(string) --*

                      The status message for delivering the message.

                    - **UpdatedToken** *(string) --*

                      For push notifications that are sent through the GCM channel, specifies
                      whether the endpoint's device registration token was updated as part of
                      delivering the message.

              - **RequestId** *(string) --*

                The identifier for the original request that the message was delivered for.

              - **Result** *(dict) --*

                A map that contains a multipart response for each address (email address, phone
                number, or push notification token) that the message was sent to. In the map, the
                address is the key and the result is the value.

                - *(string) --*

                  - *(dict) --*

                    Provides information about the results of sending a message directly to an
                    endpoint address.

                    - **DeliveryStatus** *(string) --*

                      The delivery status of the message. Possible values are:

                      * DUPLICATE - The endpoint address is a duplicate of another endpoint address.
                      Amazon Pinpoint won't attempt to send the message again.

                      * OPT_OUT - The user who's associated with the endpoint address has opted out
                      of receiving messages from you. Amazon Pinpoint won't attempt to send the
                      message again.

                      * PERMANENT_FAILURE - An error occurred when delivering the message to the
                      endpoint address. Amazon Pinpoint won't attempt to send the message again.

                      * SUCCESSFUL - The message was successfully delivered to the endpoint address.

                      * TEMPORARY_FAILURE - A temporary error occurred. Amazon Pinpoint will attempt
                      to deliver the message again later.

                      * THROTTLED - Amazon Pinpoint throttled the operation to send the message to
                      the endpoint address.

                      * TIMEOUT - The message couldn't be sent within the timeout period.

                      * UNKNOWN_FAILURE - An unknown error occurred.

                    - **MessageId** *(string) --*

                      The unique identifier for the message that was sent.

                    - **StatusCode** *(integer) --*

                      The downstream service status code for delivering the message.

                    - **StatusMessage** *(string) --*

                      The status message for delivering the message.

                    - **UpdatedToken** *(string) --*

                      For push notifications that are sent through the GCM channel, specifies
                      whether the endpoint's device registration token was updated as part of
                      delivering the message.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def send_users_messages(
        self,
        ApplicationId: str,
        SendUsersMessageRequest: ClientSendUsersMessagesSendUsersMessageRequestTypeDef,
    ) -> ClientSendUsersMessagesResponseTypeDef:
        """
        Creates and sends a message to a list of users.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/SendUsersMessages>`_

        **Request Syntax**
        ::

          response = client.send_users_messages(
              ApplicationId='string',
              SendUsersMessageRequest={
                  'Context': {
                      'string': 'string'
                  },
                  'MessageConfiguration': {
                      'ADMMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ConsolidationKey': 'string',
                          'Data': {
                              'string': 'string'
                          },
                          'ExpiresAfter': 'string',
                          'IconReference': 'string',
                          'ImageIconUrl': 'string',
                          'ImageUrl': 'string',
                          'MD5': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'SmallImageIconUrl': 'string',
                          'Sound': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'APNSMessage': {
                          'APNSPushType': 'string',
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Badge': 123,
                          'Body': 'string',
                          'Category': 'string',
                          'CollapseId': 'string',
                          'Data': {
                              'string': 'string'
                          },
                          'MediaUrl': 'string',
                          'PreferredAuthenticationMethod': 'string',
                          'Priority': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'Sound': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'ThreadId': 'string',
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'BaiduMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'Data': {
                              'string': 'string'
                          },
                          'IconReference': 'string',
                          'ImageIconUrl': 'string',
                          'ImageUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'SmallImageIconUrl': 'string',
                          'Sound': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'DefaultMessage': {
                          'Body': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          }
                      },
                      'DefaultPushNotificationMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'Data': {
                              'string': 'string'
                          },
                          'SilentPush': True|False,
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'EmailMessage': {
                          'Body': 'string',
                          'FeedbackForwardingAddress': 'string',
                          'FromAddress': 'string',
                          'RawEmail': {
                              'Data': b'bytes'
                          },
                          'ReplyToAddresses': [
                              'string',
                          ],
                          'SimpleEmail': {
                              'HtmlPart': {
                                  'Charset': 'string',
                                  'Data': 'string'
                              },
                              'Subject': {
                                  'Charset': 'string',
                                  'Data': 'string'
                              },
                              'TextPart': {
                                  'Charset': 'string',
                                  'Data': 'string'
                              }
                          },
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          }
                      },
                      'GCMMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'CollapseKey': 'string',
                          'Data': {
                              'string': 'string'
                          },
                          'IconReference': 'string',
                          'ImageIconUrl': 'string',
                          'ImageUrl': 'string',
                          'Priority': 'string',
                          'RawContent': 'string',
                          'RestrictedPackageName': 'string',
                          'SilentPush': True|False,
                          'SmallImageIconUrl': 'string',
                          'Sound': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'SMSMessage': {
                          'Body': 'string',
                          'Keyword': 'string',
                          'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                          'OriginationNumber': 'string',
                          'SenderId': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          }
                      },
                      'VoiceMessage': {
                          'Body': 'string',
                          'LanguageCode': 'string',
                          'OriginationNumber': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'VoiceId': 'string'
                      }
                  },
                  'TemplateConfiguration': {
                      'EmailTemplate': {
                          'Name': 'string'
                      },
                      'PushTemplate': {
                          'Name': 'string'
                      },
                      'SMSTemplate': {
                          'Name': 'string'
                      },
                      'VoiceTemplate': {
                          'Name': 'string'
                      }
                  },
                  'TraceId': 'string',
                  'Users': {
                      'string': {
                          'BodyOverride': 'string',
                          'Context': {
                              'string': 'string'
                          },
                          'RawContent': 'string',
                          'Substitutions': {
                              'string': [
                                  'string',
                              ]
                          },
                          'TitleOverride': 'string'
                      }
                  }
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type SendUsersMessageRequest: dict
        :param SendUsersMessageRequest: **[REQUIRED]**

          Specifies the configuration and other settings for a message to send to all the endpoints
          that are associated with a list of users.

          - **Context** *(dict) --*

            A map of custom attribute-value pairs. For a push notification, Amazon Pinpoint adds
            these attributes to the data.pinpoint object in the body of the notification payload.
            Amazon Pinpoint also provides these attributes in the events that it generates for
            users-messages deliveries.

            - *(string) --*

              - *(string) --*

          - **MessageConfiguration** *(dict) --* **[REQUIRED]**

            The settings and content for the default message and any default messages that you
            defined for specific channels.

            - **ADMMessage** *(dict) --*

              The default push notification message for the ADM (Amazon Device Messaging) channel.
              This message overrides the default push notification message
              (DefaultPushNotificationMessage).

              - **Action** *(string) --*

                The action to occur if the recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This action uses the deep-linking features of the Android platform.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message.

              - **ConsolidationKey** *(string) --*

                An arbitrary string that indicates that multiple messages are logically the same and
                that Amazon Device Messaging (ADM) can drop previously enqueued messages in favor of
                this message.

              - **Data** *(dict) --*

                The JSON data payload to use for the push notification, if the notification is a
                silent push notification. This payload is added to the data.pinpoint.jsonBody object
                of the notification.

                - *(string) --*

                  - *(string) --*

              - **ExpiresAfter** *(string) --*

                The amount of time, in seconds, that ADM should store the message if the recipient's
                device is offline. Amazon Pinpoint specifies this value in the expiresAfter
                parameter when it sends the notification message to ADM.

              - **IconReference** *(string) --*

                The icon image name of the asset saved in your app.

              - **ImageIconUrl** *(string) --*

                The URL of the large icon image to display in the content view of the push
                notification.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **MD5** *(string) --*

                The base64-encoded, MD5 checksum of the value specified by the Data property. ADM
                uses the MD5 value to verify the integrity of the data.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration or supporting phone
                home functionality.

              - **SmallImageIconUrl** *(string) --*

                The URL of the small icon image to display in the status bar and the content view of
                the push notification.

              - **Sound** *(string) --*

                The sound to play when the recipient receives the push notification. You can use the
                default stream or specify the file name of a sound resource that's bundled in your
                app. On an Android platform, the sound file must reside in /res/raw/.

              - **Substitutions** *(dict) --*

                The default message variables to use in the notification message. You can override
                the default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **Title** *(string) --*

                The title to display above the notification message on the recipient's device.

              - **Url** *(string) --*

                The URL to open in the recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **APNSMessage** *(dict) --*

              The default push notification message for the APNs (Apple Push Notification service)
              channel. This message overrides the default push notification message
              (DefaultPushNotificationMessage).

              - **APNSPushType** *(string) --*

                The type of push notification to send. Valid values are:

                * alert - For a standard notification that's displayed on recipients' devices and
                prompts a recipient to interact with the notification.

                * background - For a silent notification that delivers content in the background and
                isn't displayed on recipients' devices.

                * complication - For a notification that contains update information for an app’s
                complication timeline.

                * fileprovider - For a notification that signals changes to a File Provider
                extension.

                * mdm - For a notification that tells managed devices to contact the MDM server.

                * voip - For a notification that provides information about an incoming VoIP call.

                Amazon Pinpoint specifies this value in the apns-push-type request header when it
                sends the notification message to APNs. If you don't specify a value for this
                property, Amazon Pinpoint sets the value to alert or background automatically, based
                on the value that you specify for the SilentPush or RawContent property of the
                message.

                For more information about the apns-push-type request header, see `Sending
                Notification Requests to APNs
                <https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/sending_notification_requests_to_apns>`__
                on the Apple Developer website.

              - **Action** *(string) --*

                The action to occur if the recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of the iOS platform.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Badge** *(integer) --*

                The key that indicates whether and how to modify the badge of your app's icon when
                the recipient receives the push notification. If this key isn't included in the
                dictionary, the badge doesn't change. To remove the badge, set this value to 0.

              - **Body** *(string) --*

                The body of the notification message.

              - **Category** *(string) --*

                The key that indicates the notification type for the push notification. This key is
                a value that's defined by the identifier property of one of your app's registered
                categories.

              - **CollapseId** *(string) --*

                An arbitrary identifier that, if assigned to multiple messages, APNs uses to
                coalesce the messages into a single push notification instead of delivering each
                message individually. This value can't exceed 64 bytes.

                Amazon Pinpoint specifies this value in the apns-collapse-id request header when it
                sends the notification message to APNs.

              - **Data** *(dict) --*

                The JSON payload to use for a silent push notification. This payload is added to the
                data.pinpoint.jsonBody object of the notification.

                - *(string) --*

                  - *(string) --*

              - **MediaUrl** *(string) --*

                The URL of an image or video to display in the push notification.

              - **PreferredAuthenticationMethod** *(string) --*

                The authentication method that you want Amazon Pinpoint to use when authenticating
                with APNs, CERTIFICATE or TOKEN.

              - **Priority** *(string) --*

                para>5 - Low priority, the notification might be delayed, delivered as part of a
                group, or throttled.

                /listitem>
                * 10 - High priority, the notification is sent immediately. This is the default
                value. A high priority notification should trigger an alert, play a sound, or badge
                your app's icon on the recipient's device.
                /para>

                Amazon Pinpoint specifies this value in the apns-priority request header when it
                sends the notification message to APNs.

                The equivalent values for Firebase Cloud Messaging (FCM), formerly Google Cloud
                Messaging (GCM), are normal, for 5, and high, for 10. If you specify an FCM value
                for this property, Amazon Pinpoint accepts and converts the value to the
                corresponding APNs value.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

                .. note::

                  If you specify the raw content of an APNs push notification, the message payload
                  has to include the content-available key. The value of the content-available key
                  has to be an integer, and can only be 0 or 1. If you're sending a standard
                  notification, set the value of content-available to 0. If you're sending a silent
                  (background) notification, set the value of content-available to 1. Additionally,
                  silent notification payloads can't include the alert, badge, or sound keys. For
                  more information, see `Generating a Remote Notification
                  <https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/generating_a_remote_notification>`__
                  and `Pushing Background Updates to Your App
                  <https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/pushing_background_updates_to_your_app>`__
                  on the Apple Developer website.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification. A silent (or
                background) push notification isn't displayed on recipients' devices. You can use
                silent push notifications to make small updates to your app, or to display messages
                in an in-app message center.

                Amazon Pinpoint uses this property to determine the correct value for the
                apns-push-type request header when it sends the notification message to APNs. If you
                specify a value of true for this property, Amazon Pinpoint sets the value for the
                apns-push-type header field to background.

                .. note::

                  If you specify the raw content of an APNs push notification, the message payload
                  has to include the content-available key. For silent (background) notifications,
                  set the value of content-available to 1. Additionally, the message payload for a
                  silent notification can't include the alert, badge, or sound keys. For more
                  information, see `Generating a Remote Notification
                  <https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/generating_a_remote_notification>`__
                  and `Pushing Background Updates to Your App
                  <https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/pushing_background_updates_to_your_app>`__
                  on the Apple Developer website.

                  Apple has indicated that they will throttle "excessive" background notifications
                  based on current traffic volumes. To prevent your notifications being throttled,
                  Apple recommends that you send no more than 3 silent push notifications to each
                  recipient per hour.

              - **Sound** *(string) --*

                The key for the sound to play when the recipient receives the push notification. The
                value for this key is the name of a sound file in your app's main bundle or the
                Library/Sounds folder in your app's data container. If the sound file can't be found
                or you specify default for the value, the system plays the default alert sound.

              - **Substitutions** *(dict) --*

                The default message variables to use in the notification message. You can override
                these default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **ThreadId** *(string) --*

                The key that represents your app-specific identifier for grouping notifications. If
                you provide a Notification Content app extension, you can use this value to group
                your notifications together.

              - **TimeToLive** *(integer) --*

                The amount of time, in seconds, that APNs should store and attempt to deliver the
                push notification, if the service is unable to deliver the notification the first
                time. If this value is 0, APNs treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                Amazon Pinpoint specifies this value in the apns-expiration request header when it
                sends the notification message to APNs.

              - **Title** *(string) --*

                The title to display above the notification message on the recipient's device.

              - **Url** *(string) --*

                The URL to open in the recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **BaiduMessage** *(dict) --*

              The default push notification message for the Baidu (Baidu Cloud Push) channel. This
              message overrides the default push notification message
              (DefaultPushNotificationMessage).

              - **Action** *(string) --*

                The action to occur if the recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This action uses the deep-linking features of the Android platform.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message.

              - **Data** *(dict) --*

                The JSON data payload to use for the push notification, if the notification is a
                silent push notification. This payload is added to the data.pinpoint.jsonBody object
                of the notification.

                - *(string) --*

                  - *(string) --*

              - **IconReference** *(string) --*

                The icon image name of the asset saved in your app.

              - **ImageIconUrl** *(string) --*

                The URL of the large icon image to display in the content view of the push
                notification.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration or supporting phone
                home functionality.

              - **SmallImageIconUrl** *(string) --*

                The URL of the small icon image to display in the status bar and the content view of
                the push notification.

              - **Sound** *(string) --*

                The sound to play when the recipient receives the push notification. You can use the
                default stream or specify the file name of a sound resource that's bundled in your
                app. On an Android platform, the sound file must reside in /res/raw/.

              - **Substitutions** *(dict) --*

                The default message variables to use in the notification message. You can override
                the default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **TimeToLive** *(integer) --*

                The amount of time, in seconds, that the Baidu Cloud Push service should store the
                message if the recipient's device is offline. The default value and maximum
                supported time is 604,800 seconds (7 days).

              - **Title** *(string) --*

                The title to display above the notification message on the recipient's device.

              - **Url** *(string) --*

                The URL to open in the recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **DefaultMessage** *(dict) --*

              The default message for all channels.

              - **Body** *(string) --*

                The default body of the message.

              - **Substitutions** *(dict) --*

                The default message variables to use in the message. You can override these default
                variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

            - **DefaultPushNotificationMessage** *(dict) --*

              The default push notification message for all push notification channels.

              - **Action** *(string) --*

                The default action to occur if a recipient taps the push notification. Valid values
                are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of the iOS and Android platforms.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The default body of the notification message.

              - **Data** *(dict) --*

                The JSON data payload to use for the default push notification, if the notification
                is a silent push notification. This payload is added to the data.pinpoint.jsonBody
                object of the notification.

                - *(string) --*

                  - *(string) --*

              - **SilentPush** *(boolean) --*

                Specifies whether the default notification is a silent push notification, which is a
                push notification that doesn't display on a recipient's device. Silent push
                notifications can be used for cases such as updating an app's configuration or
                delivering messages to an in-app notification center.

              - **Substitutions** *(dict) --*

                The default message variables to use in the notification message. You can override
                the default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **Title** *(string) --*

                The default title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The default URL to open in a recipient's default mobile browser, if a recipient taps
                the push notification and the value of the Action property is URL.

            - **EmailMessage** *(dict) --*

              The default message for the email channel. This message overrides the default message
              (DefaultMessage).

              - **Body** *(string) --*

                The body of the email message.

              - **FeedbackForwardingAddress** *(string) --*

                The email address to forward bounces and complaints to, if feedback forwarding is
                enabled.

              - **FromAddress** *(string) --*

                The verified email address to send the email message from. The default value is the
                FromAddress specified for the email channel.

              - **RawEmail** *(dict) --*

                The email message, represented as a raw MIME message.

                - **Data** *(bytes) --*

                  The email message, represented as a raw MIME message. The entire message must be
                  base64 encoded.

              - **ReplyToAddresses** *(list) --*

                The reply-to email address(es) for the email message. If a recipient replies to the
                email, each reply-to address receives the reply.

                - *(string) --*

              - **SimpleEmail** *(dict) --*

                The email message, composed of a subject, a text part, and an HTML part.

                - **HtmlPart** *(dict) --*

                  The body of the email message, in HTML format. We recommend using HTML format for
                  email clients that render HTML content. You can include links, formatted text, and
                  more in an HTML message.

                  - **Charset** *(string) --*

                    The applicable character set for the message content.

                  - **Data** *(string) --*

                    The textual data of the message content.

                - **Subject** *(dict) --*

                  The subject line, or title, of the email.

                  - **Charset** *(string) --*

                    The applicable character set for the message content.

                  - **Data** *(string) --*

                    The textual data of the message content.

                - **TextPart** *(dict) --*

                  The body of the email message, in plain text format. We recommend using plain text
                  format for email clients that don't render HTML content and clients that are
                  connected to high-latency networks, such as mobile devices.

                  - **Charset** *(string) --*

                    The applicable character set for the message content.

                  - **Data** *(string) --*

                    The textual data of the message content.

              - **Substitutions** *(dict) --*

                The default message variables to use in the email message. You can override the
                default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

            - **GCMMessage** *(dict) --*

              The default push notification message for the GCM channel, which is used to send
              notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud
              Messaging (GCM), service. This message overrides the default push notification message
              (DefaultPushNotificationMessage).

              - **Action** *(string) --*

                The action to occur if the recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This action uses the deep-linking features of the Android platform.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message.

              - **CollapseKey** *(string) --*

                An arbitrary string that identifies a group of messages that can be collapsed to
                ensure that only the last message is sent when delivery can resume. This helps avoid
                sending too many instances of the same messages when the recipient's device comes
                online again or becomes active.

                Amazon Pinpoint specifies this value in the Firebase Cloud Messaging (FCM)
                collapse_key parameter when it sends the notification message to FCM.

              - **Data** *(dict) --*

                The JSON data payload to use for the push notification, if the notification is a
                silent push notification. This payload is added to the data.pinpoint.jsonBody object
                of the notification.

                - *(string) --*

                  - *(string) --*

              - **IconReference** *(string) --*

                The icon image name of the asset saved in your app.

              - **ImageIconUrl** *(string) --*

                The URL of the large icon image to display in the content view of the push
                notification.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **Priority** *(string) --*

                para>normal - The notification might be delayed. Delivery is optimized for battery
                usage on the recipient's device. Use this value unless immediate delivery is
                required.

                /listitem>
                * high - The notification is sent immediately and might wake a sleeping device.
                /para>

                Amazon Pinpoint specifies this value in the FCM priority parameter when it sends the
                notification message to FCM.

                The equivalent values for Apple Push Notification service (APNs) are 5, for normal,
                and 10, for high. If you specify an APNs value for this property, Amazon Pinpoint
                accepts and converts the value to the corresponding FCM value.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **RestrictedPackageName** *(string) --*

                The package name of the application where registration tokens must match in order
                for the recipient to receive the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration or supporting phone
                home functionality.

              - **SmallImageIconUrl** *(string) --*

                The URL of the small icon image to display in the status bar and the content view of
                the push notification.

              - **Sound** *(string) --*

                The sound to play when the recipient receives the push notification. You can use the
                default stream or specify the file name of a sound resource that's bundled in your
                app. On an Android platform, the sound file must reside in /res/raw/.

              - **Substitutions** *(dict) --*

                The default message variables to use in the notification message. You can override
                the default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **TimeToLive** *(integer) --*

                The amount of time, in seconds, that FCM should store and attempt to deliver the
                push notification, if the service is unable to deliver the notification the first
                time. If you don't specify this value, FCM defaults to the maximum value, which is
                2,419,200 seconds (28 days).

                Amazon Pinpoint specifies this value in the FCM time_to_live parameter when it sends
                the notification message to FCM.

              - **Title** *(string) --*

                The title to display above the notification message on the recipient's device.

              - **Url** *(string) --*

                The URL to open in the recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **SMSMessage** *(dict) --*

              The default message for the SMS channel. This message overrides the default message
              (DefaultMessage).

              - **Body** *(string) --*

                The body of the SMS message.

              - **Keyword** *(string) --*

                The SMS program name that you provided to AWS Support when you requested your
                dedicated number.

              - **MessageType** *(string) --*

                The SMS message type. Valid values are: TRANSACTIONAL, the message is critical or
                time-sensitive, such as a one-time password that supports a customer transaction;
                and, PROMOTIONAL, the message is not critical or time-sensitive, such as a marketing
                message.

              - **OriginationNumber** *(string) --*

                The number to send the SMS message from. This value should be one of the dedicated
                long or short codes that's assigned to your AWS account. If you don't specify a long
                or short code, Amazon Pinpoint assigns a random long code to the SMS message and
                sends the message from that code.

              - **SenderId** *(string) --*

                The sender ID to display as the sender of the message on a recipient's device.
                Support for sender IDs varies by country or region.

              - **Substitutions** *(dict) --*

                The message variables to use in the SMS message. You can override the default
                variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

            - **VoiceMessage** *(dict) --*

              The default message for the voice channel. This message overrides the default message
              (DefaultMessage).

              - **Body** *(string) --*

                The text of the script to use for the voice message.

              - **LanguageCode** *(string) --*

                The code for the language to use when synthesizing the text of the message script.
                For a list of supported languages and the code for each one, see the `Amazon Polly
                Developer Guide <https://docs.aws.amazon.com/polly/latest/dg/what-is.html>`__ .

              - **OriginationNumber** *(string) --*

                The long code to send the voice message from. This value should be one of the
                dedicated long codes that's assigned to your AWS account. Although it isn't
                required, we recommend that you specify the long code in E.164 format, for example
                +12065550100, to ensure prompt and accurate delivery of the message.

              - **Substitutions** *(dict) --*

                The default message variables to use in the voice message. You can override the
                default variables with individual address variables.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **VoiceId** *(string) --*

                The name of the voice to use when delivering the message. For a list of supported
                voices, see the `Amazon Polly Developer Guide
                <https://docs.aws.amazon.com/polly/latest/dg/what-is.html>`__ .

          - **TemplateConfiguration** *(dict) --*

            The message template to use for the message.

            - **EmailTemplate** *(dict) --*

              The email template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **PushTemplate** *(dict) --*

              The push notification template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **SMSTemplate** *(dict) --*

              The SMS template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **VoiceTemplate** *(dict) --*

              The voice template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

          - **TraceId** *(string) --*

            The unique identifier for tracing the message. This identifier is visible to message
            recipients.

          - **Users** *(dict) --* **[REQUIRED]**

            A map that associates user IDs with EndpointSendConfiguration objects. You can use an
            EndpointSendConfiguration object to tailor the message for a user by specifying settings
            such as content overrides and message variables.

            - *(string) --*

              - *(dict) --*

                Specifies the content, including message variables and attributes, to use in a
                message that's sent directly to an endpoint.

                - **BodyOverride** *(string) --*

                  The body of the message. If specified, this value overrides the default message
                  body.

                - **Context** *(dict) --*

                  A map of custom attributes to attach to the message for the address. For a push
                  notification, this payload is added to the data.pinpoint object. For an email or
                  text message, this payload is added to email/SMS delivery receipt event
                  attributes.

                  - *(string) --*

                    - *(string) --*

                - **RawContent** *(string) --*

                  The raw, JSON-formatted string to use as the payload for the message. If
                  specified, this value overrides all other values for the message.

                - **Substitutions** *(dict) --*

                  A map of the message variables to merge with the variables specified for the
                  default message (DefaultMessage.Substitutions). The variables specified in this
                  map take precedence over all other variables.

                  - *(string) --*

                    - *(list) --*

                      - *(string) --*

                - **TitleOverride** *(string) --*

                  The title or subject line of the message. If specified, this value overrides the
                  default message title or subject line.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SendUsersMessageResponse': {
                    'ApplicationId': 'string',
                    'RequestId': 'string',
                    'Result': {
                        'string': {
                            'string': {
                                'Address': 'string',
                                'DeliveryStatus':
                                'SUCCESSFUL'|'THROTTLED'|'TEMPORARY_FAILURE'
                                |'PERMANENT_FAILURE'|'UNKNOWN_FAILURE'
                                |'OPT_OUT'|'DUPLICATE',
                                'MessageId': 'string',
                                'StatusCode': 123,
                                'StatusMessage': 'string',
                                'UpdatedToken': 'string'
                            }
                        }
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **SendUsersMessageResponse** *(dict) --*

              Provides information about which users and endpoints a message was sent to.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that was used to send the message.

              - **RequestId** *(string) --*

                The unique identifier that was assigned to the message request.

              - **Result** *(dict) --*

                An object that indicates which endpoints the message was sent to, for each user. The
                object lists user IDs and, for each user ID, provides the endpoint IDs that the
                message was sent to. For each endpoint ID, it provides an EndpointMessageResult
                object.

                - *(string) --*

                  - *(dict) --*

                    - *(string) --*

                      - *(dict) --*

                        Provides information about the delivery status and results of sending a
                        message directly to an endpoint.

                        - **Address** *(string) --*

                          The endpoint address that the message was delivered to.

                        - **DeliveryStatus** *(string) --*

                          The delivery status of the message. Possible values are:

                          * DUPLICATE - The endpoint address is a duplicate of another endpoint
                          address. Amazon Pinpoint won't attempt to send the message again.

                          * OPT_OUT - The user who's associated with the endpoint has opted out of
                          receiving messages from you. Amazon Pinpoint won't attempt to send the
                          message again.

                          * PERMANENT_FAILURE - An error occurred when delivering the message to the
                          endpoint. Amazon Pinpoint won't attempt to send the message again.

                          * SUCCESSFUL - The message was successfully delivered to the endpoint.

                          * TEMPORARY_FAILURE - A temporary error occurred. Amazon Pinpoint will
                          attempt to deliver the message again later.

                          * THROTTLED - Amazon Pinpoint throttled the operation to send the message
                          to the endpoint.

                          * TIMEOUT - The message couldn't be sent within the timeout period.

                          * UNKNOWN_FAILURE - An unknown error occurred.

                        - **MessageId** *(string) --*

                          The unique identifier for the message that was sent.

                        - **StatusCode** *(integer) --*

                          The downstream service status code for delivering the message.

                        - **StatusMessage** *(string) --*

                          The status message for delivering the message.

                        - **UpdatedToken** *(string) --*

                          For push notifications that are sent through the GCM channel, specifies
                          whether the endpoint's device registration token was updated as part of
                          delivering the message.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def tag_resource(self, ResourceArn: str, TagsModel: ClientTagResourceTagsModelTypeDef) -> None:
        """
        Adds one or more tags (keys and values) to an application, campaign, journey, message
        template, or segment.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/TagResource>`_

        **Request Syntax**
        ::

          response = client.tag_resource(
              ResourceArn='string',
              TagsModel={
                  'tags': {
                      'string': 'string'
                  }
              }
          )
        :type ResourceArn: string
        :param ResourceArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the resource.

        :type TagsModel: dict
        :param TagsModel: **[REQUIRED]**

          Specifies the tags (keys and values) for an application, campaign, journey, message
          template, or segment.

          - **tags** *(dict) --* **[REQUIRED]**

            A string-to-string map of key-value pairs that defines the tags for an application,
            campaign, journey, message template, or segment. Each of these resources can have a
            maximum of 50 tags.

            Each tag consists of a required tag key and an associated tag value. The maximum length
            of a tag key is 128 characters. The maximum length of a tag value is 256 characters.

            - *(string) --*

              - *(string) --*

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> None:
        """
        Removes one or more tags (keys and values) from an application, campaign, journey, message
        template, or segment.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UntagResource>`_

        **Request Syntax**
        ::

          response = client.untag_resource(
              ResourceArn='string',
              TagKeys=[
                  'string',
              ]
          )
        :type ResourceArn: string
        :param ResourceArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the resource.

        :type TagKeys: list
        :param TagKeys: **[REQUIRED]**

          The key of the tag to remove from the resource. To remove multiple tags, append the
          tagKeys parameter and argument for each additional tag to remove, separated by an
          ampersand (&).

          - *(string) --*

        :returns: None
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_adm_channel(
        self, ADMChannelRequest: ClientUpdateAdmChannelADMChannelRequestTypeDef, ApplicationId: str
    ) -> ClientUpdateAdmChannelResponseTypeDef:
        """
        Enables the ADM channel for an application or updates the status and settings of the ADM
        channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateAdmChannel>`_

        **Request Syntax**
        ::

          response = client.update_adm_channel(
              ADMChannelRequest={
                  'ClientId': 'string',
                  'ClientSecret': 'string',
                  'Enabled': True|False
              },
              ApplicationId='string'
          )
        :type ADMChannelRequest: dict
        :param ADMChannelRequest: **[REQUIRED]**

          Specifies the status and settings of the ADM (Amazon Device Messaging) channel for an
          application.

          - **ClientId** *(string) --* **[REQUIRED]**

            The Client ID that you received from Amazon to send messages by using ADM.

          - **ClientSecret** *(string) --* **[REQUIRED]**

            The Client Secret that you received from Amazon to send messages by using ADM.

          - **Enabled** *(boolean) --*

            Specifies whether to enable the ADM channel for the application.

        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ADMChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ADMChannelResponse** *(dict) --*

              Provides information about the status and settings of the ADM (Amazon Device
              Messaging) channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the ADM channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the ADM channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the ADM channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the ADM channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the ADM channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the ADM channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the ADM channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the ADM channel,
                this value is ADM.

              - **Version** *(integer) --*

                The current version of the ADM channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_apns_channel(
        self,
        APNSChannelRequest: ClientUpdateApnsChannelAPNSChannelRequestTypeDef,
        ApplicationId: str,
    ) -> ClientUpdateApnsChannelResponseTypeDef:
        """
        Enables the APNs channel for an application or updates the status and settings of the APNs
        channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateApnsChannel>`_

        **Request Syntax**
        ::

          response = client.update_apns_channel(
              APNSChannelRequest={
                  'BundleId': 'string',
                  'Certificate': 'string',
                  'DefaultAuthenticationMethod': 'string',
                  'Enabled': True|False,
                  'PrivateKey': 'string',
                  'TeamId': 'string',
                  'TokenKey': 'string',
                  'TokenKeyId': 'string'
              },
              ApplicationId='string'
          )
        :type APNSChannelRequest: dict
        :param APNSChannelRequest: **[REQUIRED]**

          Specifies the status and settings of the APNs (Apple Push Notification service) channel
          for an application.

          - **BundleId** *(string) --*

            The bundle identifier that's assigned to your iOS app. This identifier is used for APNs
            tokens.

          - **Certificate** *(string) --*

            The APNs client certificate that you received from Apple, if you want Amazon Pinpoint to
            communicate with APNs by using an APNs certificate.

          - **DefaultAuthenticationMethod** *(string) --*

            The default authentication method that you want Amazon Pinpoint to use when
            authenticating with APNs, key or certificate.

          - **Enabled** *(boolean) --*

            Specifies whether to enable the APNs channel for the application.

          - **PrivateKey** *(string) --*

            The private key for the APNs client certificate that you want Amazon Pinpoint to use to
            communicate with APNs.

          - **TeamId** *(string) --*

            The identifier that's assigned to your Apple developer account team. This identifier is
            used for APNs tokens.

          - **TokenKey** *(string) --*

            The authentication key to use for APNs tokens.

          - **TokenKeyId** *(string) --*

            The key identifier that's assigned to your APNs signing key, if you want Amazon Pinpoint
            to communicate with APNs by using APNs tokens.

        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the APNs channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with
                APNs for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs channel is configured to communicate with APNs by using
                APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey
                property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs
                channel, this value is APNS.

              - **Version** *(integer) --*

                The current version of the APNs channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_apns_sandbox_channel(
        self,
        APNSSandboxChannelRequest: ClientUpdateApnsSandboxChannelAPNSSandboxChannelRequestTypeDef,
        ApplicationId: str,
    ) -> ClientUpdateApnsSandboxChannelResponseTypeDef:
        """
        Enables the APNs sandbox channel for an application or updates the status and settings of
        the APNs sandbox channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateApnsSandboxChannel>`_

        **Request Syntax**
        ::

          response = client.update_apns_sandbox_channel(
              APNSSandboxChannelRequest={
                  'BundleId': 'string',
                  'Certificate': 'string',
                  'DefaultAuthenticationMethod': 'string',
                  'Enabled': True|False,
                  'PrivateKey': 'string',
                  'TeamId': 'string',
                  'TokenKey': 'string',
                  'TokenKeyId': 'string'
              },
              ApplicationId='string'
          )
        :type APNSSandboxChannelRequest: dict
        :param APNSSandboxChannelRequest: **[REQUIRED]**

          Specifies the status and settings of the APNs (Apple Push Notification service) sandbox
          channel for an application.

          - **BundleId** *(string) --*

            The bundle identifier that's assigned to your iOS app. This identifier is used for APNs
            tokens.

          - **Certificate** *(string) --*

            The APNs client certificate that you received from Apple, if you want Amazon Pinpoint to
            communicate with the APNs sandbox environment by using an APNs certificate.

          - **DefaultAuthenticationMethod** *(string) --*

            The default authentication method that you want Amazon Pinpoint to use when
            authenticating with the APNs sandbox environment, key or certificate.

          - **Enabled** *(boolean) --*

            Specifies whether to enable the APNs sandbox channel for the application.

          - **PrivateKey** *(string) --*

            The private key for the APNs client certificate that you want Amazon Pinpoint to use to
            communicate with the APNs sandbox environment.

          - **TeamId** *(string) --*

            The identifier that's assigned to your Apple developer account team. This identifier is
            used for APNs tokens.

          - **TokenKey** *(string) --*

            The authentication key to use for APNs tokens.

          - **TokenKeyId** *(string) --*

            The key identifier that's assigned to your APNs signing key, if you want Amazon Pinpoint
            to communicate with the APNs sandbox environment by using APNs tokens.

        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSSandboxChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSSandboxChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) sandbox channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs sandbox channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the APNs sandbox channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with the
                APNs sandbox environment for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs sandbox channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs sandbox channel is configured to communicate with APNs by
                using APNs tokens. To provide an authentication key for APNs tokens, set the
                TokenKey property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs sandbox channel. This property is retained
                only for backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs sandbox channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs sandbox channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs sandbox channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs sandbox
                channel, this value is APNS_SANDBOX.

              - **Version** *(integer) --*

                The current version of the APNs sandbox channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_apns_voip_channel(
        self,
        APNSVoipChannelRequest: ClientUpdateApnsVoipChannelAPNSVoipChannelRequestTypeDef,
        ApplicationId: str,
    ) -> ClientUpdateApnsVoipChannelResponseTypeDef:
        """
        Enables the APNs VoIP channel for an application or updates the status and settings of the
        APNs VoIP channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateApnsVoipChannel>`_

        **Request Syntax**
        ::

          response = client.update_apns_voip_channel(
              APNSVoipChannelRequest={
                  'BundleId': 'string',
                  'Certificate': 'string',
                  'DefaultAuthenticationMethod': 'string',
                  'Enabled': True|False,
                  'PrivateKey': 'string',
                  'TeamId': 'string',
                  'TokenKey': 'string',
                  'TokenKeyId': 'string'
              },
              ApplicationId='string'
          )
        :type APNSVoipChannelRequest: dict
        :param APNSVoipChannelRequest: **[REQUIRED]**

          Specifies the status and settings of the APNs (Apple Push Notification service) VoIP
          channel for an application.

          - **BundleId** *(string) --*

            The bundle identifier that's assigned to your iOS app. This identifier is used for APNs
            tokens.

          - **Certificate** *(string) --*

            The APNs client certificate that you received from Apple, if you want Amazon Pinpoint to
            communicate with APNs by using an APNs certificate.

          - **DefaultAuthenticationMethod** *(string) --*

            The default authentication method that you want Amazon Pinpoint to use when
            authenticating with APNs, key or certificate.

          - **Enabled** *(boolean) --*

            Specifies whether to enable the APNs VoIP channel for the application.

          - **PrivateKey** *(string) --*

            The private key for the APNs client certificate that you want Amazon Pinpoint to use to
            communicate with APNs.

          - **TeamId** *(string) --*

            The identifier that's assigned to your Apple developer account team. This identifier is
            used for APNs tokens.

          - **TokenKey** *(string) --*

            The authentication key to use for APNs tokens.

          - **TokenKeyId** *(string) --*

            The key identifier that's assigned to your APNs signing key, if you want Amazon Pinpoint
            to communicate with APNs by using APNs tokens.

        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSVoipChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSVoipChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) VoIP channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs VoIP channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the APNs VoIP channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with
                APNs for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs VoIP channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs VoIP channel is configured to communicate with APNs by
                using APNs tokens. To provide an authentication key for APNs tokens, set the
                TokenKey property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs VoIP channel. This property is retained only
                for backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs VoIP channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs VoIP channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs VoIP channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs VoIP
                channel, this value is APNS_VOIP.

              - **Version** *(integer) --*

                The current version of the APNs VoIP channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_apns_voip_sandbox_channel(
        self,
        APNSVoipSandboxChannelRequest: ClientUpdateApnsVoipSandboxChannelAPNSVoipSandboxChannelRequestTypeDef,
        ApplicationId: str,
    ) -> ClientUpdateApnsVoipSandboxChannelResponseTypeDef:
        """
        Enables the APNs VoIP sandbox channel for an application or updates the status and settings
        of the APNs VoIP sandbox channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateApnsVoipSandboxChannel>`_

        **Request Syntax**
        ::

          response = client.update_apns_voip_sandbox_channel(
              APNSVoipSandboxChannelRequest={
                  'BundleId': 'string',
                  'Certificate': 'string',
                  'DefaultAuthenticationMethod': 'string',
                  'Enabled': True|False,
                  'PrivateKey': 'string',
                  'TeamId': 'string',
                  'TokenKey': 'string',
                  'TokenKeyId': 'string'
              },
              ApplicationId='string'
          )
        :type APNSVoipSandboxChannelRequest: dict
        :param APNSVoipSandboxChannelRequest: **[REQUIRED]**

          Specifies the status and settings of the APNs (Apple Push Notification service) VoIP
          sandbox channel for an application.

          - **BundleId** *(string) --*

            The bundle identifier that's assigned to your iOS app. This identifier is used for APNs
            tokens.

          - **Certificate** *(string) --*

            The APNs client certificate that you received from Apple, if you want Amazon Pinpoint to
            communicate with the APNs sandbox environment by using an APNs certificate.

          - **DefaultAuthenticationMethod** *(string) --*

            The default authentication method that you want Amazon Pinpoint to use when
            authenticating with the APNs sandbox environment for this channel, key or certificate.

          - **Enabled** *(boolean) --*

            Specifies whether the APNs VoIP sandbox channel is enabled for the application.

          - **PrivateKey** *(string) --*

            The private key for the APNs client certificate that you want Amazon Pinpoint to use to
            communicate with the APNs sandbox environment.

          - **TeamId** *(string) --*

            The identifier that's assigned to your Apple developer account team. This identifier is
            used for APNs tokens.

          - **TokenKey** *(string) --*

            The authentication key to use for APNs tokens.

          - **TokenKeyId** *(string) --*

            The key identifier that's assigned to your APNs signing key, if you want Amazon Pinpoint
            to communicate with the APNs sandbox environment by using APNs tokens.

        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'APNSVoipSandboxChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'DefaultAuthenticationMethod': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'HasTokenKey': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **APNSVoipSandboxChannelResponse** *(dict) --*

              Provides information about the status and settings of the APNs (Apple Push
              Notification service) VoIP sandbox channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the APNs VoIP sandbox channel applies
                to.

              - **CreationDate** *(string) --*

                The date and time when the APNs VoIP sandbox channel was enabled.

              - **DefaultAuthenticationMethod** *(string) --*

                The default authentication method that Amazon Pinpoint uses to authenticate with the
                APNs sandbox environment for this channel, key or certificate.

              - **Enabled** *(boolean) --*

                Specifies whether the APNs VoIP sandbox channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **HasTokenKey** *(boolean) --*

                Specifies whether the APNs VoIP sandbox channel is configured to communicate with
                APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the
                TokenKey property of the channel.

              - **Id** *(string) --*

                (Deprecated) An identifier for the APNs VoIP sandbox channel. This property is
                retained only for backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the APNs VoIP sandbox channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the APNs VoIP sandbox channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the APNs VoIP sandbox channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the APNs VoIP
                sandbox channel, this value is APNS_VOIP_SANDBOX.

              - **Version** *(integer) --*

                The current version of the APNs VoIP sandbox channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_application_settings(
        self,
        ApplicationId: str,
        WriteApplicationSettingsRequest: ClientUpdateApplicationSettingsWriteApplicationSettingsRequestTypeDef,
    ) -> ClientUpdateApplicationSettingsResponseTypeDef:
        """
        Updates the settings for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateApplicationSettings>`_

        **Request Syntax**
        ::

          response = client.update_application_settings(
              ApplicationId='string',
              WriteApplicationSettingsRequest={
                  'CampaignHook': {
                      'LambdaFunctionName': 'string',
                      'Mode': 'DELIVERY'|'FILTER',
                      'WebUrl': 'string'
                  },
                  'CloudWatchMetricsEnabled': True|False,
                  'Limits': {
                      'Daily': 123,
                      'MaximumDuration': 123,
                      'MessagesPerSecond': 123,
                      'Total': 123
                  },
                  'QuietTime': {
                      'End': 'string',
                      'Start': 'string'
                  }
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type WriteApplicationSettingsRequest: dict
        :param WriteApplicationSettingsRequest: **[REQUIRED]**

          Specifies the default settings for an application.

          - **CampaignHook** *(dict) --*

            The settings for the AWS Lambda function to use by default as a code hook for campaigns
            in the application. To override these settings for a specific campaign, use the
            Campaignresource to define custom Lambda function settings for the campaign.

            - **LambdaFunctionName** *(string) --*

              The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint
              invokes to send messages for a campaign.

            - **Mode** *(string) --*

              Specifies which Lambda mode to use when invoking the AWS Lambda function.

            - **WebUrl** *(string) --*

              The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.

          - **CloudWatchMetricsEnabled** *(boolean) --*

            Specifies whether to enable application-related alarms in Amazon CloudWatch.

          - **Limits** *(dict) --*

            The default sending limits for campaigns in the application. To override these limits
            for a specific campaign, use the Campaignresource to define custom limits for the
            campaign.

            - **Daily** *(integer) --*

              The maximum number of messages that a campaign can send to a single endpoint during a
              24-hour period. The maximum value is 100.

            - **MaximumDuration** *(integer) --*

              The maximum amount of time, in seconds, that a campaign can attempt to deliver a
              message after the scheduled start time for the campaign. The minimum value is 60
              seconds.

            - **MessagesPerSecond** *(integer) --*

              The maximum number of messages that a campaign can send each second. The minimum value
              is 50. The maximum value is 20,000.

            - **Total** *(integer) --*

              The maximum number of messages that a campaign can send to a single endpoint during
              the course of the campaign. The maximum value is 100.

          - **QuietTime** *(dict) --*

            The default quiet time for campaigns and journeys in the application. Quiet time is a
            specific time range when messages aren't sent to endpoints, if all the following
            conditions are met:

            * The EndpointDemographic.Timezone property of the endpoint is set to a valid value.

            * The current time in the endpoint's time zone is later than or equal to the time
            specified by the QuietTime.Start property for the application (or a campaign or journey
            that has custom quiet time settings).

            * The current time in the endpoint's time zone is earlier than or equal to the time
            specified by the QuietTime.End property for the application (or a campaign or journey
            that has custom quiet time settings).

            If any of the preceding conditions isn't met, the endpoint will receive messages from a
            campaign or journey, even if quiet time is enabled.

            To override the default quiet time settings for a specific campaign or journey, use the
            Campaignresource or the Journeyresource to define a custom quiet time for the campaign
            or journey.

            - **End** *(string) --*

              The specific time when quiet time ends. This value has to use 24-hour notation and be
              in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is
              the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30
              PM.

            - **Start** *(string) --*

              The specific time when quiet time begins. This value has to use 24-hour notation and
              be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM
              is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent
              2:30 PM.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'ApplicationSettingsResource': {
                    'ApplicationId': 'string',
                    'CampaignHook': {
                        'LambdaFunctionName': 'string',
                        'Mode': 'DELIVERY'|'FILTER',
                        'WebUrl': 'string'
                    },
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'Daily': 123,
                        'MaximumDuration': 123,
                        'MessagesPerSecond': 123,
                        'Total': 123
                    },
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **ApplicationSettingsResource** *(dict) --*

              Provides information about an application, including the default settings for an
              application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application. This identifier is displayed as the
                **Project ID** on the Amazon Pinpoint console.

              - **CampaignHook** *(dict) --*

                The settings for the AWS Lambda function to use by default as a code hook for
                campaigns in the application.

                - **LambdaFunctionName** *(string) --*

                  The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon
                  Pinpoint invokes to send messages for a campaign.

                - **Mode** *(string) --*

                  Specifies which Lambda mode to use when invoking the AWS Lambda function.

                - **WebUrl** *(string) --*

                  The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over
                  HTTPS.

              - **LastModifiedDate** *(string) --*

                The date and time, in ISO 8601 format, when the application's settings were last
                modified.

              - **Limits** *(dict) --*

                The default sending limits for campaigns in the application.

                - **Daily** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during a 24-hour period. The maximum value is 100.

                - **MaximumDuration** *(integer) --*

                  The maximum amount of time, in seconds, that a campaign can attempt to deliver a
                  message after the scheduled start time for the campaign. The minimum value is 60
                  seconds.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that a campaign can send each second. The minimum
                  value is 50. The maximum value is 20,000.

                - **Total** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during the course of the campaign. The maximum value is 100.

              - **QuietTime** *(dict) --*

                The default quiet time for campaigns and journeys in the application. Quiet time is
                a specific time range when messages aren't sent to endpoints, if all the following
                conditions are met:

                * The EndpointDemographic.Timezone property of the endpoint is set to a valid value.

                * The current time in the endpoint's time zone is later than or equal to the time
                specified by the QuietTime.Start property for the application (or a campaign or
                journey that has custom quiet time settings).

                * The current time in the endpoint's time zone is earlier than or equal to the time
                specified by the QuietTime.End property for the application (or a campaign or
                journey that has custom quiet time settings).

                If any of the preceding conditions isn't met, the endpoint will receive messages
                from a campaign or journey, even if quiet time is enabled.

                - **End** *(string) --*

                  The specific time when quiet time ends. This value has to use 24-hour notation and
                  be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and
                  MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

                - **Start** *(string) --*

                  The specific time when quiet time begins. This value has to use 24-hour notation
                  and be in HH:MM format, where HH is the hour (with a leading zero, if applicable)
                  and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_baidu_channel(
        self,
        ApplicationId: str,
        BaiduChannelRequest: ClientUpdateBaiduChannelBaiduChannelRequestTypeDef,
    ) -> ClientUpdateBaiduChannelResponseTypeDef:
        """
        Enables the Baidu channel for an application or updates the status and settings of the Baidu
        channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateBaiduChannel>`_

        **Request Syntax**
        ::

          response = client.update_baidu_channel(
              ApplicationId='string',
              BaiduChannelRequest={
                  'ApiKey': 'string',
                  'Enabled': True|False,
                  'SecretKey': 'string'
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type BaiduChannelRequest: dict
        :param BaiduChannelRequest: **[REQUIRED]**

          Specifies the status and settings of the Baidu (Baidu Cloud Push) channel for an
          application.

          - **ApiKey** *(string) --* **[REQUIRED]**

            The API key that you received from the Baidu Cloud Push service to communicate with the
            service.

          - **Enabled** *(boolean) --*

            Specifies whether to enable the Baidu channel for the application.

          - **SecretKey** *(string) --* **[REQUIRED]**

            The secret key that you received from the Baidu Cloud Push service to communicate with
            the service.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'BaiduChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Credential': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **BaiduChannelResponse** *(dict) --*

              Provides information about the status and settings of the Baidu (Baidu Cloud Push)
              channel for an application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the Baidu channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the Baidu channel was enabled.

              - **Credential** *(string) --*

                The API key that you received from the Baidu Cloud Push service to communicate with
                the service.

              - **Enabled** *(boolean) --*

                Specifies whether the Baidu channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the Baidu channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the Baidu channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the Baidu channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the Baidu channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the Baidu
                channel, this value is BAIDU.

              - **Version** *(integer) --*

                The current version of the Baidu channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_campaign(
        self,
        ApplicationId: str,
        CampaignId: str,
        WriteCampaignRequest: ClientUpdateCampaignWriteCampaignRequestTypeDef,
    ) -> ClientUpdateCampaignResponseTypeDef:
        """
        Updates the configuration and other settings for a campaign.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateCampaign>`_

        **Request Syntax**
        ::

          response = client.update_campaign(
              ApplicationId='string',
              CampaignId='string',
              WriteCampaignRequest={
                  'AdditionalTreatments': [
                      {
                          'MessageConfiguration': {
                              'ADMMessage': {
                                  'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                  'Body': 'string',
                                  'ImageIconUrl': 'string',
                                  'ImageSmallIconUrl': 'string',
                                  'ImageUrl': 'string',
                                  'JsonBody': 'string',
                                  'MediaUrl': 'string',
                                  'RawContent': 'string',
                                  'SilentPush': True|False,
                                  'TimeToLive': 123,
                                  'Title': 'string',
                                  'Url': 'string'
                              },
                              'APNSMessage': {
                                  'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                  'Body': 'string',
                                  'ImageIconUrl': 'string',
                                  'ImageSmallIconUrl': 'string',
                                  'ImageUrl': 'string',
                                  'JsonBody': 'string',
                                  'MediaUrl': 'string',
                                  'RawContent': 'string',
                                  'SilentPush': True|False,
                                  'TimeToLive': 123,
                                  'Title': 'string',
                                  'Url': 'string'
                              },
                              'BaiduMessage': {
                                  'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                  'Body': 'string',
                                  'ImageIconUrl': 'string',
                                  'ImageSmallIconUrl': 'string',
                                  'ImageUrl': 'string',
                                  'JsonBody': 'string',
                                  'MediaUrl': 'string',
                                  'RawContent': 'string',
                                  'SilentPush': True|False,
                                  'TimeToLive': 123,
                                  'Title': 'string',
                                  'Url': 'string'
                              },
                              'DefaultMessage': {
                                  'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                  'Body': 'string',
                                  'ImageIconUrl': 'string',
                                  'ImageSmallIconUrl': 'string',
                                  'ImageUrl': 'string',
                                  'JsonBody': 'string',
                                  'MediaUrl': 'string',
                                  'RawContent': 'string',
                                  'SilentPush': True|False,
                                  'TimeToLive': 123,
                                  'Title': 'string',
                                  'Url': 'string'
                              },
                              'EmailMessage': {
                                  'Body': 'string',
                                  'FromAddress': 'string',
                                  'HtmlBody': 'string',
                                  'Title': 'string'
                              },
                              'GCMMessage': {
                                  'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                  'Body': 'string',
                                  'ImageIconUrl': 'string',
                                  'ImageSmallIconUrl': 'string',
                                  'ImageUrl': 'string',
                                  'JsonBody': 'string',
                                  'MediaUrl': 'string',
                                  'RawContent': 'string',
                                  'SilentPush': True|False,
                                  'TimeToLive': 123,
                                  'Title': 'string',
                                  'Url': 'string'
                              },
                              'SMSMessage': {
                                  'Body': 'string',
                                  'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                  'SenderId': 'string'
                              }
                          },
                          'Schedule': {
                              'EndTime': 'string',
                              'EventFilter': {
                                  'Dimensions': {
                                      'Attributes': {
                                          'string': {
                                              'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          }
                                      },
                                      'EventType': {
                                          'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                          'Values': [
                                              'string',
                                          ]
                                      },
                                      'Metrics': {
                                          'string': {
                                              'ComparisonOperator': 'string',
                                              'Value': 123.0
                                          }
                                      }
                                  },
                                  'FilterType': 'SYSTEM'|'ENDPOINT'
                              },
                              'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                              'IsLocalTime': True|False,
                              'QuietTime': {
                                  'End': 'string',
                                  'Start': 'string'
                              },
                              'StartTime': 'string',
                              'Timezone': 'string'
                          },
                          'SizePercent': 123,
                          'TemplateConfiguration': {
                              'EmailTemplate': {
                                  'Name': 'string'
                              },
                              'PushTemplate': {
                                  'Name': 'string'
                              },
                              'SMSTemplate': {
                                  'Name': 'string'
                              },
                              'VoiceTemplate': {
                                  'Name': 'string'
                              }
                          },
                          'TreatmentDescription': 'string',
                          'TreatmentName': 'string'
                      },
                  ],
                  'Description': 'string',
                  'HoldoutPercent': 123,
                  'Hook': {
                      'LambdaFunctionName': 'string',
                      'Mode': 'DELIVERY'|'FILTER',
                      'WebUrl': 'string'
                  },
                  'IsPaused': True|False,
                  'Limits': {
                      'Daily': 123,
                      'MaximumDuration': 123,
                      'MessagesPerSecond': 123,
                      'Total': 123
                  },
                  'MessageConfiguration': {
                      'ADMMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ImageIconUrl': 'string',
                          'ImageSmallIconUrl': 'string',
                          'ImageUrl': 'string',
                          'JsonBody': 'string',
                          'MediaUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'APNSMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ImageIconUrl': 'string',
                          'ImageSmallIconUrl': 'string',
                          'ImageUrl': 'string',
                          'JsonBody': 'string',
                          'MediaUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'BaiduMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ImageIconUrl': 'string',
                          'ImageSmallIconUrl': 'string',
                          'ImageUrl': 'string',
                          'JsonBody': 'string',
                          'MediaUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'DefaultMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ImageIconUrl': 'string',
                          'ImageSmallIconUrl': 'string',
                          'ImageUrl': 'string',
                          'JsonBody': 'string',
                          'MediaUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'EmailMessage': {
                          'Body': 'string',
                          'FromAddress': 'string',
                          'HtmlBody': 'string',
                          'Title': 'string'
                      },
                      'GCMMessage': {
                          'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                          'Body': 'string',
                          'ImageIconUrl': 'string',
                          'ImageSmallIconUrl': 'string',
                          'ImageUrl': 'string',
                          'JsonBody': 'string',
                          'MediaUrl': 'string',
                          'RawContent': 'string',
                          'SilentPush': True|False,
                          'TimeToLive': 123,
                          'Title': 'string',
                          'Url': 'string'
                      },
                      'SMSMessage': {
                          'Body': 'string',
                          'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                          'SenderId': 'string'
                      }
                  },
                  'Name': 'string',
                  'Schedule': {
                      'EndTime': 'string',
                      'EventFilter': {
                          'Dimensions': {
                              'Attributes': {
                                  'string': {
                                      'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                      'Values': [
                                          'string',
                                      ]
                                  }
                              },
                              'EventType': {
                                  'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                  'Values': [
                                      'string',
                                  ]
                              },
                              'Metrics': {
                                  'string': {
                                      'ComparisonOperator': 'string',
                                      'Value': 123.0
                                  }
                              }
                          },
                          'FilterType': 'SYSTEM'|'ENDPOINT'
                      },
                      'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                      'IsLocalTime': True|False,
                      'QuietTime': {
                          'End': 'string',
                          'Start': 'string'
                      },
                      'StartTime': 'string',
                      'Timezone': 'string'
                  },
                  'SegmentId': 'string',
                  'SegmentVersion': 123,
                  'tags': {
                      'string': 'string'
                  },
                  'TemplateConfiguration': {
                      'EmailTemplate': {
                          'Name': 'string'
                      },
                      'PushTemplate': {
                          'Name': 'string'
                      },
                      'SMSTemplate': {
                          'Name': 'string'
                      },
                      'VoiceTemplate': {
                          'Name': 'string'
                      }
                  },
                  'TreatmentDescription': 'string',
                  'TreatmentName': 'string'
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type CampaignId: string
        :param CampaignId: **[REQUIRED]**

          The unique identifier for the campaign.

        :type WriteCampaignRequest: dict
        :param WriteCampaignRequest: **[REQUIRED]**

          Specifies the configuration and other settings for a campaign.

          - **AdditionalTreatments** *(list) --*

            An array of requests that defines additional treatments for the campaign, in addition to
            the default treatment for the campaign.

            - *(dict) --*

              Specifies the settings for a campaign treatment. A treatment is a variation of a
              campaign that's used for A/B testing of a campaign.

              - **MessageConfiguration** *(dict) --*

                The message configuration settings for the treatment.

                - **ADMMessage** *(dict) --*

                  The message that the campaign sends through the ADM (Amazon Device Messaging)
                  channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **APNSMessage** *(dict) --*

                  The message that the campaign sends through the APNs (Apple Push Notification
                  service) channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **BaiduMessage** *(dict) --*

                  The message that the campaign sends through the Baidu (Baidu Cloud Push) channel.
                  This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **DefaultMessage** *(dict) --*

                  The default message that the campaign sends through all the channels that are
                  configured for the campaign.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **EmailMessage** *(dict) --*

                  The message that the campaign sends through the email channel.

                  - **Body** *(string) --*

                    The body of the email for recipients whose email clients don't render HTML
                    content.

                  - **FromAddress** *(string) --*

                    The verified email address to send the email from. The default address is the
                    FromAddress specified for the email channel for the application.

                  - **HtmlBody** *(string) --*

                    The body of the email, in HTML format, for recipients whose email clients render
                    HTML content.

                  - **Title** *(string) --* **[REQUIRED]**

                    The subject line, or title, of the email.

                - **GCMMessage** *(dict) --*

                  The message that the campaign sends through the GCM channel, which enables Amazon
                  Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM),
                  formerly Google Cloud Messaging (GCM), service. This message overrides the default
                  message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **SMSMessage** *(dict) --*

                  The message that the campaign sends through the SMS channel.

                  - **Body** *(string) --*

                    The body of the SMS message.

                  - **MessageType** *(string) --*

                    The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                    critical or time-sensitive, such as a one-time password that supports a customer
                    transaction; and, PROMOTIONAL, the message isn't critical or time-sensitive,
                    such as a marketing message.

                  - **SenderId** *(string) --*

                    The sender ID to display on recipients' devices when they receive the SMS
                    message.

              - **Schedule** *(dict) --*

                The schedule settings for the treatment.

                - **EndTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                - **EventFilter** *(dict) --*

                  The type of event that causes the campaign to be sent, if the value of the
                  Frequency property is EVENT.

                  - **Dimensions** *(dict) --* **[REQUIRED]**

                    The dimension settings of the event filter for the campaign.

                    - **Attributes** *(dict) --*

                      One or more custom attributes that your application reports to Amazon
                      Pinpoint. You can use these attributes as selection criteria when you create
                      an event filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --* **[REQUIRED]**

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                    - **EventType** *(dict) --*

                      The name of the event that causes the campaign to be sent or the journey
                      activity to be performed. This can be a standard type of event that Amazon
                      Pinpoint generates, such as _email.delivered, or a custom event that's
                      specific to your application.

                      - **DimensionType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --* **[REQUIRED]**

                        The criteria values to use for the segment dimension. Depending on the value
                        of the DimensionType property, endpoints are included or excluded from the
                        segment if their values match the criteria values.

                        - *(string) --*

                    - **Metrics** *(dict) --*

                      One or more custom metrics that your application reports to Amazon Pinpoint.
                      You can use these metrics as selection criteria when you create an event
                      filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies metric-based criteria for including or excluding endpoints from
                          a segment. These criteria derive from custom metrics that you define for
                          endpoints.

                          - **ComparisonOperator** *(string) --* **[REQUIRED]**

                            The operator to use when comparing metric values. Valid values are:
                            GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                            EQUAL.

                          - **Value** *(float) --* **[REQUIRED]**

                            The value to compare.

                  - **FilterType** *(string) --* **[REQUIRED]**

                    The type of event that causes the campaign to be sent. Valid values are: SYSTEM,
                    sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign
                    when an endpoint event (Events resource) occurs.

                - **Frequency** *(string) --*

                  Specifies how often the campaign is sent or whether the campaign is sent in
                  response to a specific event.

                - **IsLocalTime** *(boolean) --*

                  Specifies whether the start and end times for the campaign schedule use each
                  recipient's local time. To base the schedule on each recipient's local time, set
                  this value to true.

                - **QuietTime** *(dict) --*

                  The default quiet time for the campaign. Quiet time is a specific time range when
                  a campaign doesn't send messages to endpoints, if all the following conditions are
                  met:

                  * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                  value.

                  * The current time in the endpoint's time zone is later than or equal to the time
                  specified by the QuietTime.Start property for the campaign.

                  * The current time in the endpoint's time zone is earlier than or equal to the
                  time specified by the QuietTime.End property for the campaign.

                  If any of the preceding conditions isn't met, the endpoint will receive messages
                  from the campaign, even if quiet time is enabled.

                  - **End** *(string) --*

                    The specific time when quiet time ends. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                  - **Start** *(string) --*

                    The specific time when quiet time begins. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                - **StartTime** *(string) --* **[REQUIRED]**

                  The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the campaign schedule, if the value of the IsLocalTime
                  property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30,
                  UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07,
                  UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02,
                  UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.

              - **SizePercent** *(integer) --* **[REQUIRED]**

                The allocated percentage of users (segment members) to send the treatment to.

              - **TemplateConfiguration** *(dict) --*

                The message template to use for the treatment.

                - **EmailTemplate** *(dict) --*

                  The email template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **PushTemplate** *(dict) --*

                  The push notification template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **SMSTemplate** *(dict) --*

                  The SMS template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **VoiceTemplate** *(dict) --*

                  The voice template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

              - **TreatmentDescription** *(string) --*

                A custom description of the treatment.

              - **TreatmentName** *(string) --*

                The custom name of the treatment. A treatment is a variation of a campaign that's
                used for A/B testing of a campaign.

          - **Description** *(string) --*

            A custom description of the campaign.

          - **HoldoutPercent** *(integer) --*

            The allocated percentage of users (segment members) who shouldn't receive messages from
            the campaign.

          - **Hook** *(dict) --*

            The settings for the AWS Lambda function to use as a code hook for the campaign.

            - **LambdaFunctionName** *(string) --*

              The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint
              invokes to send messages for a campaign.

            - **Mode** *(string) --*

              Specifies which Lambda mode to use when invoking the AWS Lambda function.

            - **WebUrl** *(string) --*

              The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.

          - **IsPaused** *(boolean) --*

            Specifies whether to pause the campaign. A paused campaign doesn't run unless you resume
            it by setting this value to false.

          - **Limits** *(dict) --*

            The messaging limits for the campaign.

            - **Daily** *(integer) --*

              The maximum number of messages that a campaign can send to a single endpoint during a
              24-hour period. The maximum value is 100.

            - **MaximumDuration** *(integer) --*

              The maximum amount of time, in seconds, that a campaign can attempt to deliver a
              message after the scheduled start time for the campaign. The minimum value is 60
              seconds.

            - **MessagesPerSecond** *(integer) --*

              The maximum number of messages that a campaign can send each second. The minimum value
              is 50. The maximum value is 20,000.

            - **Total** *(integer) --*

              The maximum number of messages that a campaign can send to a single endpoint during
              the course of the campaign. The maximum value is 100.

          - **MessageConfiguration** *(dict) --*

            The message configuration settings for the campaign.

            - **ADMMessage** *(dict) --*

              The message that the campaign sends through the ADM (Amazon Device Messaging) channel.
              This message overrides the default message.

              - **Action** *(string) --*

                The action to occur if a recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of iOS and Android.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message. The maximum number of characters is 200.

              - **ImageIconUrl** *(string) --*

                The URL of the image to display as the push-notification icon, such as the icon for
                the app.

              - **ImageSmallIconUrl** *(string) --*

                The URL of the image to display as the small, push-notification icon, such as a
                small version of the icon for the app.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **JsonBody** *(string) --*

                The JSON payload to use for a silent push notification.

              - **MediaUrl** *(string) --*

                The URL of the image or video to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration, displaying messages
                in an in-app message center, or supporting phone home functionality.

              - **TimeToLive** *(integer) --*

                The number of seconds that the push-notification service should keep the message, if
                the service is unable to deliver the notification the first time. This value is
                converted to an expiration value when it's sent to a push-notification service. If
                this value is 0, the service treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                This value doesn't apply to messages that are sent through the Amazon Device
                Messaging (ADM) service.

              - **Title** *(string) --*

                The title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The URL to open in a recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **APNSMessage** *(dict) --*

              The message that the campaign sends through the APNs (Apple Push Notification service)
              channel. This message overrides the default message.

              - **Action** *(string) --*

                The action to occur if a recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of iOS and Android.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message. The maximum number of characters is 200.

              - **ImageIconUrl** *(string) --*

                The URL of the image to display as the push-notification icon, such as the icon for
                the app.

              - **ImageSmallIconUrl** *(string) --*

                The URL of the image to display as the small, push-notification icon, such as a
                small version of the icon for the app.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **JsonBody** *(string) --*

                The JSON payload to use for a silent push notification.

              - **MediaUrl** *(string) --*

                The URL of the image or video to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration, displaying messages
                in an in-app message center, or supporting phone home functionality.

              - **TimeToLive** *(integer) --*

                The number of seconds that the push-notification service should keep the message, if
                the service is unable to deliver the notification the first time. This value is
                converted to an expiration value when it's sent to a push-notification service. If
                this value is 0, the service treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                This value doesn't apply to messages that are sent through the Amazon Device
                Messaging (ADM) service.

              - **Title** *(string) --*

                The title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The URL to open in a recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **BaiduMessage** *(dict) --*

              The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. This
              message overrides the default message.

              - **Action** *(string) --*

                The action to occur if a recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of iOS and Android.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message. The maximum number of characters is 200.

              - **ImageIconUrl** *(string) --*

                The URL of the image to display as the push-notification icon, such as the icon for
                the app.

              - **ImageSmallIconUrl** *(string) --*

                The URL of the image to display as the small, push-notification icon, such as a
                small version of the icon for the app.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **JsonBody** *(string) --*

                The JSON payload to use for a silent push notification.

              - **MediaUrl** *(string) --*

                The URL of the image or video to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration, displaying messages
                in an in-app message center, or supporting phone home functionality.

              - **TimeToLive** *(integer) --*

                The number of seconds that the push-notification service should keep the message, if
                the service is unable to deliver the notification the first time. This value is
                converted to an expiration value when it's sent to a push-notification service. If
                this value is 0, the service treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                This value doesn't apply to messages that are sent through the Amazon Device
                Messaging (ADM) service.

              - **Title** *(string) --*

                The title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The URL to open in a recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **DefaultMessage** *(dict) --*

              The default message that the campaign sends through all the channels that are
              configured for the campaign.

              - **Action** *(string) --*

                The action to occur if a recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of iOS and Android.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message. The maximum number of characters is 200.

              - **ImageIconUrl** *(string) --*

                The URL of the image to display as the push-notification icon, such as the icon for
                the app.

              - **ImageSmallIconUrl** *(string) --*

                The URL of the image to display as the small, push-notification icon, such as a
                small version of the icon for the app.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **JsonBody** *(string) --*

                The JSON payload to use for a silent push notification.

              - **MediaUrl** *(string) --*

                The URL of the image or video to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration, displaying messages
                in an in-app message center, or supporting phone home functionality.

              - **TimeToLive** *(integer) --*

                The number of seconds that the push-notification service should keep the message, if
                the service is unable to deliver the notification the first time. This value is
                converted to an expiration value when it's sent to a push-notification service. If
                this value is 0, the service treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                This value doesn't apply to messages that are sent through the Amazon Device
                Messaging (ADM) service.

              - **Title** *(string) --*

                The title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The URL to open in a recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **EmailMessage** *(dict) --*

              The message that the campaign sends through the email channel.

              - **Body** *(string) --*

                The body of the email for recipients whose email clients don't render HTML content.

              - **FromAddress** *(string) --*

                The verified email address to send the email from. The default address is the
                FromAddress specified for the email channel for the application.

              - **HtmlBody** *(string) --*

                The body of the email, in HTML format, for recipients whose email clients render
                HTML content.

              - **Title** *(string) --* **[REQUIRED]**

                The subject line, or title, of the email.

            - **GCMMessage** *(dict) --*

              The message that the campaign sends through the GCM channel, which enables Amazon
              Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM),
              formerly Google Cloud Messaging (GCM), service. This message overrides the default
              message.

              - **Action** *(string) --*

                The action to occur if a recipient taps the push notification. Valid values are:

                * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
                background. This is the default action.

                * DEEP_LINK - Your app opens and displays a designated user interface in the app.
                This setting uses the deep-linking features of iOS and Android.

                * URL - The default mobile browser on the recipient's device opens and loads the web
                page at a URL that you specify.

              - **Body** *(string) --*

                The body of the notification message. The maximum number of characters is 200.

              - **ImageIconUrl** *(string) --*

                The URL of the image to display as the push-notification icon, such as the icon for
                the app.

              - **ImageSmallIconUrl** *(string) --*

                The URL of the image to display as the small, push-notification icon, such as a
                small version of the icon for the app.

              - **ImageUrl** *(string) --*

                The URL of an image to display in the push notification.

              - **JsonBody** *(string) --*

                The JSON payload to use for a silent push notification.

              - **MediaUrl** *(string) --*

                The URL of the image or video to display in the push notification.

              - **RawContent** *(string) --*

                The raw, JSON-formatted string to use as the payload for the notification message.
                If specified, this value overrides all other content for the message.

              - **SilentPush** *(boolean) --*

                Specifies whether the notification is a silent push notification, which is a push
                notification that doesn't display on a recipient's device. Silent push notifications
                can be used for cases such as updating an app's configuration, displaying messages
                in an in-app message center, or supporting phone home functionality.

              - **TimeToLive** *(integer) --*

                The number of seconds that the push-notification service should keep the message, if
                the service is unable to deliver the notification the first time. This value is
                converted to an expiration value when it's sent to a push-notification service. If
                this value is 0, the service treats the notification as if it expires immediately
                and the service doesn't store or try to deliver the notification again.

                This value doesn't apply to messages that are sent through the Amazon Device
                Messaging (ADM) service.

              - **Title** *(string) --*

                The title to display above the notification message on a recipient's device.

              - **Url** *(string) --*

                The URL to open in a recipient's default mobile browser, if a recipient taps the
                push notification and the value of the Action property is URL.

            - **SMSMessage** *(dict) --*

              The message that the campaign sends through the SMS channel.

              - **Body** *(string) --*

                The body of the SMS message.

              - **MessageType** *(string) --*

                The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or
                time-sensitive, such as a one-time password that supports a customer transaction;
                and, PROMOTIONAL, the message isn't critical or time-sensitive, such as a marketing
                message.

              - **SenderId** *(string) --*

                The sender ID to display on recipients' devices when they receive the SMS message.

          - **Name** *(string) --*

            The custom name of the campaign.

          - **Schedule** *(dict) --*

            The schedule settings for the campaign.

            - **EndTime** *(string) --*

              The scheduled time, in ISO 8601 format, when the campaign ended or will end.

            - **EventFilter** *(dict) --*

              The type of event that causes the campaign to be sent, if the value of the Frequency
              property is EVENT.

              - **Dimensions** *(dict) --* **[REQUIRED]**

                The dimension settings of the event filter for the campaign.

                - **Attributes** *(dict) --*

                  One or more custom attributes that your application reports to Amazon Pinpoint.
                  You can use these attributes as selection criteria when you create an event
                  filter.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --* **[REQUIRED]**

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

                - **EventType** *(dict) --*

                  The name of the event that causes the campaign to be sent or the journey activity
                  to be performed. This can be a standard type of event that Amazon Pinpoint
                  generates, such as _email.delivered, or a custom event that's specific to your
                  application.

                  - **DimensionType** *(string) --*

                    The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                    that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                    that match the criteria are excluded from the segment.

                  - **Values** *(list) --* **[REQUIRED]**

                    The criteria values to use for the segment dimension. Depending on the value of
                    the DimensionType property, endpoints are included or excluded from the segment
                    if their values match the criteria values.

                    - *(string) --*

                - **Metrics** *(dict) --*

                  One or more custom metrics that your application reports to Amazon Pinpoint. You
                  can use these metrics as selection criteria when you create an event filter.

                  - *(string) --*

                    - *(dict) --*

                      Specifies metric-based criteria for including or excluding endpoints from a
                      segment. These criteria derive from custom metrics that you define for
                      endpoints.

                      - **ComparisonOperator** *(string) --* **[REQUIRED]**

                        The operator to use when comparing metric values. Valid values are:
                        GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                        EQUAL.

                      - **Value** *(float) --* **[REQUIRED]**

                        The value to compare.

              - **FilterType** *(string) --* **[REQUIRED]**

                The type of event that causes the campaign to be sent. Valid values are: SYSTEM,
                sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign
                when an endpoint event (Events resource) occurs.

            - **Frequency** *(string) --*

              Specifies how often the campaign is sent or whether the campaign is sent in response
              to a specific event.

            - **IsLocalTime** *(boolean) --*

              Specifies whether the start and end times for the campaign schedule use each
              recipient's local time. To base the schedule on each recipient's local time, set this
              value to true.

            - **QuietTime** *(dict) --*

              The default quiet time for the campaign. Quiet time is a specific time range when a
              campaign doesn't send messages to endpoints, if all the following conditions are met:

              * The EndpointDemographic.Timezone property of the endpoint is set to a valid value.

              * The current time in the endpoint's time zone is later than or equal to the time
              specified by the QuietTime.Start property for the campaign.

              * The current time in the endpoint's time zone is earlier than or equal to the time
              specified by the QuietTime.End property for the campaign.

              If any of the preceding conditions isn't met, the endpoint will receive messages from
              the campaign, even if quiet time is enabled.

              - **End** *(string) --*

                The specific time when quiet time ends. This value has to use 24-hour notation and
                be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM
                is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent
                2:30 PM.

              - **Start** *(string) --*

                The specific time when quiet time begins. This value has to use 24-hour notation and
                be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM
                is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent
                2:30 PM.

            - **StartTime** *(string) --* **[REQUIRED]**

              The scheduled time, in ISO 8601 format, when the campaign began or will begin.

            - **Timezone** *(string) --*

              The starting UTC offset for the campaign schedule, if the value of the IsLocalTime
              property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04,
              UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09,
              UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05,
              UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.

          - **SegmentId** *(string) --*

            The unique identifier for the segment to associate with the campaign.

          - **SegmentVersion** *(integer) --*

            The version of the segment to associate with the campaign.

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            campaign. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

          - **TemplateConfiguration** *(dict) --*

            The message template to use for the campaign.

            - **EmailTemplate** *(dict) --*

              The email template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **PushTemplate** *(dict) --*

              The push notification template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **SMSTemplate** *(dict) --*

              The SMS template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

            - **VoiceTemplate** *(dict) --*

              The voice template to use for the message.

              - **Name** *(string) --*

                The name of the message template to use for the message. If specified, this value
                must match the name of an existing message template.

          - **TreatmentDescription** *(string) --*

            A custom description of a variation of the campaign to use for A/B testing.

          - **TreatmentName** *(string) --*

            The custom name of a variation of the campaign to use for A/B testing.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'CampaignResponse': {
                    'AdditionalTreatments': [
                        {
                            'Id': 'string',
                            'MessageConfiguration': {
                                'ADMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'APNSMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'BaiduMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'DefaultMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'EmailMessage': {
                                    'Body': 'string',
                                    'FromAddress': 'string',
                                    'HtmlBody': 'string',
                                    'Title': 'string'
                                },
                                'GCMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'SMSMessage': {
                                    'Body': 'string',
                                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                    'SenderId': 'string'
                                }
                            },
                            'Schedule': {
                                'EndTime': 'string',
                                'EventFilter': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'FilterType': 'SYSTEM'|'ENDPOINT'
                                },
                                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                                'IsLocalTime': True|False,
                                'QuietTime': {
                                    'End': 'string',
                                    'Start': 'string'
                                },
                                'StartTime': 'string',
                                'Timezone': 'string'
                            },
                            'SizePercent': 123,
                            'State': {
                                'CampaignStatus':
                                'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'
                                |'COMPLETED'|'PAUSED'|'DELETED'
                            },
                            'TemplateConfiguration': {
                                'EmailTemplate': {
                                    'Name': 'string'
                                },
                                'PushTemplate': {
                                    'Name': 'string'
                                },
                                'SMSTemplate': {
                                    'Name': 'string'
                                },
                                'VoiceTemplate': {
                                    'Name': 'string'
                                }
                            },
                            'TreatmentDescription': 'string',
                            'TreatmentName': 'string'
                        },
                    ],
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'DefaultState': {
                        'CampaignStatus':
                        'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'
                        |'PAUSED'|'DELETED'
                    },
                    'Description': 'string',
                    'HoldoutPercent': 123,
                    'Hook': {
                        'LambdaFunctionName': 'string',
                        'Mode': 'DELIVERY'|'FILTER',
                        'WebUrl': 'string'
                    },
                    'Id': 'string',
                    'IsPaused': True|False,
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'Daily': 123,
                        'MaximumDuration': 123,
                        'MessagesPerSecond': 123,
                        'Total': 123
                    },
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Name': 'string',
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SegmentId': 'string',
                    'SegmentVersion': 123,
                    'State': {
                        'CampaignStatus':
                        'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'
                        |'PAUSED'|'DELETED'
                    },
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **CampaignResponse** *(dict) --*

              Provides information about the status, configuration, and other settings for a
              campaign.

              - **AdditionalTreatments** *(list) --*

                An array of responses, one for each treatment that you defined for the campaign, in
                addition to the default treatment.

                - *(dict) --*

                  Specifies the settings for a campaign treatment. A treatment is a variation of a
                  campaign that's used for A/B testing of a campaign.

                  - **Id** *(string) --*

                    The unique identifier for the treatment.

                  - **MessageConfiguration** *(dict) --*

                    The message configuration settings for the treatment.

                    - **ADMMessage** *(dict) --*

                      The message that the campaign sends through the ADM (Amazon Device Messaging)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **APNSMessage** *(dict) --*

                      The message that the campaign sends through the APNs (Apple Push Notification
                      service) channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **BaiduMessage** *(dict) --*

                      The message that the campaign sends through the Baidu (Baidu Cloud Push)
                      channel. This message overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **DefaultMessage** *(dict) --*

                      The default message that the campaign sends through all the channels that are
                      configured for the campaign.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **EmailMessage** *(dict) --*

                      The message that the campaign sends through the email channel.

                      - **Body** *(string) --*

                        The body of the email for recipients whose email clients don't render HTML
                        content.

                      - **FromAddress** *(string) --*

                        The verified email address to send the email from. The default address is
                        the FromAddress specified for the email channel for the application.

                      - **HtmlBody** *(string) --*

                        The body of the email, in HTML format, for recipients whose email clients
                        render HTML content.

                      - **Title** *(string) --*

                        The subject line, or title, of the email.

                    - **GCMMessage** *(dict) --*

                      The message that the campaign sends through the GCM channel, which enables
                      Amazon Pinpoint to send push notifications through the Firebase Cloud
                      Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message
                      overrides the default message.

                      - **Action** *(string) --*

                        The action to occur if a recipient taps the push notification. Valid values
                        are:

                        * OPEN_APP - Your app opens or it becomes the foreground app if it was sent
                        to the background. This is the default action.

                        * DEEP_LINK - Your app opens and displays a designated user interface in the
                        app. This setting uses the deep-linking features of iOS and Android.

                        * URL - The default mobile browser on the recipient's device opens and loads
                        the web page at a URL that you specify.

                      - **Body** *(string) --*

                        The body of the notification message. The maximum number of characters is
                        200.

                      - **ImageIconUrl** *(string) --*

                        The URL of the image to display as the push-notification icon, such as the
                        icon for the app.

                      - **ImageSmallIconUrl** *(string) --*

                        The URL of the image to display as the small, push-notification icon, such
                        as a small version of the icon for the app.

                      - **ImageUrl** *(string) --*

                        The URL of an image to display in the push notification.

                      - **JsonBody** *(string) --*

                        The JSON payload to use for a silent push notification.

                      - **MediaUrl** *(string) --*

                        The URL of the image or video to display in the push notification.

                      - **RawContent** *(string) --*

                        The raw, JSON-formatted string to use as the payload for the notification
                        message. If specified, this value overrides all other content for the
                        message.

                      - **SilentPush** *(boolean) --*

                        Specifies whether the notification is a silent push notification, which is a
                        push notification that doesn't display on a recipient's device. Silent push
                        notifications can be used for cases such as updating an app's configuration,
                        displaying messages in an in-app message center, or supporting phone home
                        functionality.

                      - **TimeToLive** *(integer) --*

                        The number of seconds that the push-notification service should keep the
                        message, if the service is unable to deliver the notification the first
                        time. This value is converted to an expiration value when it's sent to a
                        push-notification service. If this value is 0, the service treats the
                        notification as if it expires immediately and the service doesn't store or
                        try to deliver the notification again.

                        This value doesn't apply to messages that are sent through the Amazon Device
                        Messaging (ADM) service.

                      - **Title** *(string) --*

                        The title to display above the notification message on a recipient's device.

                      - **Url** *(string) --*

                        The URL to open in a recipient's default mobile browser, if a recipient taps
                        the push notification and the value of the Action property is URL.

                    - **SMSMessage** *(dict) --*

                      The message that the campaign sends through the SMS channel.

                      - **Body** *(string) --*

                        The body of the SMS message.

                      - **MessageType** *(string) --*

                        The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                        critical or time-sensitive, such as a one-time password that supports a
                        customer transaction; and, PROMOTIONAL, the message isn't critical or
                        time-sensitive, such as a marketing message.

                      - **SenderId** *(string) --*

                        The sender ID to display on recipients' devices when they receive the SMS
                        message.

                  - **Schedule** *(dict) --*

                    The schedule settings for the treatment.

                    - **EndTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                    - **EventFilter** *(dict) --*

                      The type of event that causes the campaign to be sent, if the value of the
                      Frequency property is EVENT.

                      - **Dimensions** *(dict) --*

                        The dimension settings of the event filter for the campaign.

                        - **Attributes** *(dict) --*

                          One or more custom attributes that your application reports to Amazon
                          Pinpoint. You can use these attributes as selection criteria when you
                          create an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **EventType** *(dict) --*

                          The name of the event that causes the campaign to be sent or the journey
                          activity to be performed. This can be a standard type of event that Amazon
                          Pinpoint generates, such as _email.delivered, or a custom event that's
                          specific to your application.

                          - **DimensionType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the DimensionType property, endpoints are included or excluded
                            from the segment if their values match the criteria values.

                            - *(string) --*

                        - **Metrics** *(dict) --*

                          One or more custom metrics that your application reports to Amazon
                          Pinpoint. You can use these metrics as selection criteria when you create
                          an event filter.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                      - **FilterType** *(string) --*

                        The type of event that causes the campaign to be sent. Valid values are:
                        SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends
                        the campaign when an endpoint event (Events resource) occurs.

                    - **Frequency** *(string) --*

                      Specifies how often the campaign is sent or whether the campaign is sent in
                      response to a specific event.

                    - **IsLocalTime** *(boolean) --*

                      Specifies whether the start and end times for the campaign schedule use each
                      recipient's local time. To base the schedule on each recipient's local time,
                      set this value to true.

                    - **QuietTime** *(dict) --*

                      The default quiet time for the campaign. Quiet time is a specific time range
                      when a campaign doesn't send messages to endpoints, if all the following
                      conditions are met:

                      * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                      value.

                      * The current time in the endpoint's time zone is later than or equal to the
                      time specified by the QuietTime.Start property for the campaign.

                      * The current time in the endpoint's time zone is earlier than or equal to the
                      time specified by the QuietTime.End property for the campaign.

                      If any of the preceding conditions isn't met, the endpoint will receive
                      messages from the campaign, even if quiet time is enabled.

                      - **End** *(string) --*

                        The specific time when quiet time ends. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                      - **Start** *(string) --*

                        The specific time when quiet time begins. This value has to use 24-hour
                        notation and be in HH:MM format, where HH is the hour (with a leading zero,
                        if applicable) and MM is the minutes. For example, use 02:30 to represent
                        2:30 AM, or 14:30 to represent 2:30 PM.

                    - **StartTime** *(string) --*

                      The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                    - **Timezone** *(string) --*

                      The starting UTC offset for the campaign schedule, if the value of the
                      IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                      UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                      UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13,
                      UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and
                      UTC-11.

                  - **SizePercent** *(integer) --*

                    The allocated percentage of users (segment members) that the treatment is sent
                    to.

                  - **State** *(dict) --*

                    The current status of the treatment.

                    - **CampaignStatus** *(string) --*

                      The current status of the campaign, or the current status of a treatment that
                      belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign
                      has a status of COMPLETED only if all campaign treatments have a status of
                      COMPLETED.

                  - **TemplateConfiguration** *(dict) --*

                    The message template to use for the treatment.

                    - **EmailTemplate** *(dict) --*

                      The email template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **PushTemplate** *(dict) --*

                      The push notification template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **SMSTemplate** *(dict) --*

                      The SMS template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                    - **VoiceTemplate** *(dict) --*

                      The voice template to use for the message.

                      - **Name** *(string) --*

                        The name of the message template to use for the message. If specified, this
                        value must match the name of an existing message template.

                  - **TreatmentDescription** *(string) --*

                    The custom description of the treatment.

                  - **TreatmentName** *(string) --*

                    The custom name of the treatment. A treatment is a variation of a campaign
                    that's used for A/B testing of a campaign.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the campaign applies to.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the campaign.

              - **CreationDate** *(string) --*

                The date, ISO 8601 format, when the campaign was created.

              - **DefaultState** *(dict) --*

                The current status of the campaign's default treatment. This value exists only for
                campaigns that have more than one treatment, to support A/B testing.

                - **CampaignStatus** *(string) --*

                  The current status of the campaign, or the current status of a treatment that
                  belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign has
                  a status of COMPLETED only if all campaign treatments have a status of COMPLETED.

              - **Description** *(string) --*

                The custom description of the campaign.

              - **HoldoutPercent** *(integer) --*

                The allocated percentage of users (segment members) who shouldn't receive messages
                from the campaign.

              - **Hook** *(dict) --*

                The settings for the AWS Lambda function to use as a code hook for the campaign.

                - **LambdaFunctionName** *(string) --*

                  The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon
                  Pinpoint invokes to send messages for a campaign.

                - **Mode** *(string) --*

                  Specifies which Lambda mode to use when invoking the AWS Lambda function.

                - **WebUrl** *(string) --*

                  The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over
                  HTTPS.

              - **Id** *(string) --*

                The unique identifier for the campaign.

              - **IsPaused** *(boolean) --*

                Specifies whether the campaign is paused. A paused campaign doesn't run unless you
                resume it by changing this value to false.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the campaign was last modified.

              - **Limits** *(dict) --*

                The messaging limits for the campaign.

                - **Daily** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during a 24-hour period. The maximum value is 100.

                - **MaximumDuration** *(integer) --*

                  The maximum amount of time, in seconds, that a campaign can attempt to deliver a
                  message after the scheduled start time for the campaign. The minimum value is 60
                  seconds.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that a campaign can send each second. The minimum
                  value is 50. The maximum value is 20,000.

                - **Total** *(integer) --*

                  The maximum number of messages that a campaign can send to a single endpoint
                  during the course of the campaign. The maximum value is 100.

              - **MessageConfiguration** *(dict) --*

                The message configuration settings for the campaign.

                - **ADMMessage** *(dict) --*

                  The message that the campaign sends through the ADM (Amazon Device Messaging)
                  channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **APNSMessage** *(dict) --*

                  The message that the campaign sends through the APNs (Apple Push Notification
                  service) channel. This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **BaiduMessage** *(dict) --*

                  The message that the campaign sends through the Baidu (Baidu Cloud Push) channel.
                  This message overrides the default message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **DefaultMessage** *(dict) --*

                  The default message that the campaign sends through all the channels that are
                  configured for the campaign.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **EmailMessage** *(dict) --*

                  The message that the campaign sends through the email channel.

                  - **Body** *(string) --*

                    The body of the email for recipients whose email clients don't render HTML
                    content.

                  - **FromAddress** *(string) --*

                    The verified email address to send the email from. The default address is the
                    FromAddress specified for the email channel for the application.

                  - **HtmlBody** *(string) --*

                    The body of the email, in HTML format, for recipients whose email clients render
                    HTML content.

                  - **Title** *(string) --*

                    The subject line, or title, of the email.

                - **GCMMessage** *(dict) --*

                  The message that the campaign sends through the GCM channel, which enables Amazon
                  Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM),
                  formerly Google Cloud Messaging (GCM), service. This message overrides the default
                  message.

                  - **Action** *(string) --*

                    The action to occur if a recipient taps the push notification. Valid values are:

                    * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to
                    the background. This is the default action.

                    * DEEP_LINK - Your app opens and displays a designated user interface in the
                    app. This setting uses the deep-linking features of iOS and Android.

                    * URL - The default mobile browser on the recipient's device opens and loads the
                    web page at a URL that you specify.

                  - **Body** *(string) --*

                    The body of the notification message. The maximum number of characters is 200.

                  - **ImageIconUrl** *(string) --*

                    The URL of the image to display as the push-notification icon, such as the icon
                    for the app.

                  - **ImageSmallIconUrl** *(string) --*

                    The URL of the image to display as the small, push-notification icon, such as a
                    small version of the icon for the app.

                  - **ImageUrl** *(string) --*

                    The URL of an image to display in the push notification.

                  - **JsonBody** *(string) --*

                    The JSON payload to use for a silent push notification.

                  - **MediaUrl** *(string) --*

                    The URL of the image or video to display in the push notification.

                  - **RawContent** *(string) --*

                    The raw, JSON-formatted string to use as the payload for the notification
                    message. If specified, this value overrides all other content for the message.

                  - **SilentPush** *(boolean) --*

                    Specifies whether the notification is a silent push notification, which is a
                    push notification that doesn't display on a recipient's device. Silent push
                    notifications can be used for cases such as updating an app's configuration,
                    displaying messages in an in-app message center, or supporting phone home
                    functionality.

                  - **TimeToLive** *(integer) --*

                    The number of seconds that the push-notification service should keep the
                    message, if the service is unable to deliver the notification the first time.
                    This value is converted to an expiration value when it's sent to a
                    push-notification service. If this value is 0, the service treats the
                    notification as if it expires immediately and the service doesn't store or try
                    to deliver the notification again.

                    This value doesn't apply to messages that are sent through the Amazon Device
                    Messaging (ADM) service.

                  - **Title** *(string) --*

                    The title to display above the notification message on a recipient's device.

                  - **Url** *(string) --*

                    The URL to open in a recipient's default mobile browser, if a recipient taps the
                    push notification and the value of the Action property is URL.

                - **SMSMessage** *(dict) --*

                  The message that the campaign sends through the SMS channel.

                  - **Body** *(string) --*

                    The body of the SMS message.

                  - **MessageType** *(string) --*

                    The type of SMS message. Valid values are: TRANSACTIONAL, the message is
                    critical or time-sensitive, such as a one-time password that supports a customer
                    transaction; and, PROMOTIONAL, the message isn't critical or time-sensitive,
                    such as a marketing message.

                  - **SenderId** *(string) --*

                    The sender ID to display on recipients' devices when they receive the SMS
                    message.

              - **Name** *(string) --*

                The name of the campaign.

              - **Schedule** *(dict) --*

                The schedule settings for the campaign.

                - **EndTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign ended or will end.

                - **EventFilter** *(dict) --*

                  The type of event that causes the campaign to be sent, if the value of the
                  Frequency property is EVENT.

                  - **Dimensions** *(dict) --*

                    The dimension settings of the event filter for the campaign.

                    - **Attributes** *(dict) --*

                      One or more custom attributes that your application reports to Amazon
                      Pinpoint. You can use these attributes as selection criteria when you create
                      an event filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --*

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                    - **EventType** *(dict) --*

                      The name of the event that causes the campaign to be sent or the journey
                      activity to be performed. This can be a standard type of event that Amazon
                      Pinpoint generates, such as _email.delivered, or a custom event that's
                      specific to your application.

                      - **DimensionType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the DimensionType property, endpoints are included or excluded from the
                        segment if their values match the criteria values.

                        - *(string) --*

                    - **Metrics** *(dict) --*

                      One or more custom metrics that your application reports to Amazon Pinpoint.
                      You can use these metrics as selection criteria when you create an event
                      filter.

                      - *(string) --*

                        - *(dict) --*

                          Specifies metric-based criteria for including or excluding endpoints from
                          a segment. These criteria derive from custom metrics that you define for
                          endpoints.

                          - **ComparisonOperator** *(string) --*

                            The operator to use when comparing metric values. Valid values are:
                            GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                            EQUAL.

                          - **Value** *(float) --*

                            The value to compare.

                  - **FilterType** *(string) --*

                    The type of event that causes the campaign to be sent. Valid values are: SYSTEM,
                    sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign
                    when an endpoint event (Events resource) occurs.

                - **Frequency** *(string) --*

                  Specifies how often the campaign is sent or whether the campaign is sent in
                  response to a specific event.

                - **IsLocalTime** *(boolean) --*

                  Specifies whether the start and end times for the campaign schedule use each
                  recipient's local time. To base the schedule on each recipient's local time, set
                  this value to true.

                - **QuietTime** *(dict) --*

                  The default quiet time for the campaign. Quiet time is a specific time range when
                  a campaign doesn't send messages to endpoints, if all the following conditions are
                  met:

                  * The EndpointDemographic.Timezone property of the endpoint is set to a valid
                  value.

                  * The current time in the endpoint's time zone is later than or equal to the time
                  specified by the QuietTime.Start property for the campaign.

                  * The current time in the endpoint's time zone is earlier than or equal to the
                  time specified by the QuietTime.End property for the campaign.

                  If any of the preceding conditions isn't met, the endpoint will receive messages
                  from the campaign, even if quiet time is enabled.

                  - **End** *(string) --*

                    The specific time when quiet time ends. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                  - **Start** *(string) --*

                    The specific time when quiet time begins. This value has to use 24-hour notation
                    and be in HH:MM format, where HH is the hour (with a leading zero, if
                    applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM,
                    or 14:30 to represent 2:30 PM.

                - **StartTime** *(string) --*

                  The scheduled time, in ISO 8601 format, when the campaign began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the campaign schedule, if the value of the IsLocalTime
                  property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30,
                  UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07,
                  UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02,
                  UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.

              - **SegmentId** *(string) --*

                The unique identifier for the segment that's associated with the campaign.

              - **SegmentVersion** *(integer) --*

                The version number of the segment that's associated with the campaign.

              - **State** *(dict) --*

                The current status of the campaign.

                - **CampaignStatus** *(string) --*

                  The current status of the campaign, or the current status of a treatment that
                  belongs to an A/B test campaign. If a campaign uses A/B testing, the campaign has
                  a status of COMPLETED only if all campaign treatments have a status of COMPLETED.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the campaign. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **TemplateConfiguration** *(dict) --*

                The message template that’s used for the campaign.

                - **EmailTemplate** *(dict) --*

                  The email template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **PushTemplate** *(dict) --*

                  The push notification template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **SMSTemplate** *(dict) --*

                  The SMS template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

                - **VoiceTemplate** *(dict) --*

                  The voice template to use for the message.

                  - **Name** *(string) --*

                    The name of the message template to use for the message. If specified, this
                    value must match the name of an existing message template.

              - **TreatmentDescription** *(string) --*

                The custom description of a variation of the campaign that's used for A/B testing.

              - **TreatmentName** *(string) --*

                The custom name of a variation of the campaign that's used for A/B testing.

              - **Version** *(integer) --*

                The version number of the campaign.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_email_channel(
        self,
        ApplicationId: str,
        EmailChannelRequest: ClientUpdateEmailChannelEmailChannelRequestTypeDef,
    ) -> ClientUpdateEmailChannelResponseTypeDef:
        """
        Enables the email channel for an application or updates the status and settings of the email
        channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateEmailChannel>`_

        **Request Syntax**
        ::

          response = client.update_email_channel(
              ApplicationId='string',
              EmailChannelRequest={
                  'ConfigurationSet': 'string',
                  'Enabled': True|False,
                  'FromAddress': 'string',
                  'Identity': 'string',
                  'RoleArn': 'string'
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type EmailChannelRequest: dict
        :param EmailChannelRequest: **[REQUIRED]**

          Specifies the status and settings of the email channel for an application.

          - **ConfigurationSet** *(string) --*

            The configuration set that you want to apply to email that you send through the channel
            by using the `Amazon Pinpoint Email API <emailAPIreference.html>`__ .

          - **Enabled** *(boolean) --*

            Specifies whether to enable the email channel for the application.

          - **FromAddress** *(string) --* **[REQUIRED]**

            The verified email address that you want to send email from when you send email through
            the channel.

          - **Identity** *(string) --* **[REQUIRED]**

            The Amazon Resource Name (ARN) of the identity, verified with Amazon Simple Email
            Service (Amazon SES), that you want to use when you send email through the channel.

          - **RoleArn** *(string) --*

            The ARN of the AWS Identity and Access Management (IAM) role that you want Amazon
            Pinpoint to use when it submits email-related event data for the channel.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'EmailChannelResponse': {
                    'ApplicationId': 'string',
                    'ConfigurationSet': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'FromAddress': 'string',
                    'HasCredential': True|False,
                    'Id': 'string',
                    'Identity': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'MessagesPerSecond': 123,
                    'Platform': 'string',
                    'RoleArn': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **EmailChannelResponse** *(dict) --*

              Provides information about the status and settings of the email channel for an
              application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the email channel applies to.

              - **ConfigurationSet** *(string) --*

                The configuration set that's applied to email that's sent through the channel by
                using the `Amazon Pinpoint Email API <emailAPIreference.html>`__ .

              - **CreationDate** *(string) --*

                The date and time, in ISO 8601 format, when the email channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the email channel is enabled for the application.

              - **FromAddress** *(string) --*

                The verified email address that you send email from when you send email through the
                channel.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the email channel. This property is retained only for
                backward compatibility.

              - **Identity** *(string) --*

                The Amazon Resource Name (ARN) of the identity, verified with Amazon Simple Email
                Service (Amazon SES), that you use when you send email through the channel.

              - **IsArchived** *(boolean) --*

                Specifies whether the email channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the email channel.

              - **LastModifiedDate** *(string) --*

                The date and time, in ISO 8601 format, when the email channel was last modified.

              - **MessagesPerSecond** *(integer) --*

                The maximum number of emails that you can send through the channel each second.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the email
                channel, this value is EMAIL.

              - **RoleArn** *(string) --*

                The ARN of the AWS Identity and Access Management (IAM) role that Amazon Pinpoint
                uses to submit email-related event data for the channel.

              - **Version** *(integer) --*

                The current version of the email channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_email_template(
        self,
        EmailTemplateRequest: ClientUpdateEmailTemplateEmailTemplateRequestTypeDef,
        TemplateName: str,
    ) -> ClientUpdateEmailTemplateResponseTypeDef:
        """
        Updates an existing message template that you can use in messages that are sent through the
        email channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateEmailTemplate>`_

        **Request Syntax**
        ::

          response = client.update_email_template(
              EmailTemplateRequest={
                  'DefaultSubstitutions': 'string',
                  'HtmlPart': 'string',
                  'Subject': 'string',
                  'tags': {
                      'string': 'string'
                  },
                  'TemplateDescription': 'string',
                  'TextPart': 'string'
              },
              TemplateName='string'
          )
        :type EmailTemplateRequest: dict
        :param EmailTemplateRequest: **[REQUIRED]**

          Specifies the content and settings for a message template that can be used in messages
          that are sent through the email channel.

          - **DefaultSubstitutions** *(string) --*

            A JSON object that specifies the default values to use for message variables in the
            message template. This object is a set of key-value pairs. Each key defines a message
            variable in the template. The corresponding value defines the default value for that
            variable. When you create a message that's based on the template, you can override these
            defaults with message-specific and address-specific variables and values.

          - **HtmlPart** *(string) --*

            The message body, in HTML format, to use in email messages that are based on the message
            template. We recommend using HTML format for email clients that render HTML content. You
            can include links, formatted text, and more in an HTML message.

          - **Subject** *(string) --*

            The subject line, or title, to use in email messages that are based on the message
            template.

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            message template. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

          - **TemplateDescription** *(string) --*

            A custom description of the message template.

          - **TextPart** *(string) --*

            The message body, in plain text format, to use in email messages that are based on the
            message template. We recommend using plain text format for email clients that don't
            render HTML content and clients that are connected to high-latency networks, such as
            mobile devices.

        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MessageBody': {
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **MessageBody** *(dict) --*

              Provides information about an API request or response.

              - **Message** *(string) --*

                The message that's returned from the API.

              - **RequestID** *(string) --*

                The unique identifier for the request or response.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_endpoint(
        self,
        ApplicationId: str,
        EndpointId: str,
        EndpointRequest: ClientUpdateEndpointEndpointRequestTypeDef,
    ) -> ClientUpdateEndpointResponseTypeDef:
        """
        Creates a new endpoint for an application or updates the settings and attributes of an
        existing endpoint for an application. You can also use this operation to define custom
        attributes (Attributes, Metrics, and UserAttributes properties) for an endpoint.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateEndpoint>`_

        **Request Syntax**
        ::

          response = client.update_endpoint(
              ApplicationId='string',
              EndpointId='string',
              EndpointRequest={
                  'Address': 'string',
                  'Attributes': {
                      'string': [
                          'string',
                      ]
                  },
                  'ChannelType':
                  'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'
                  |'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                  'Demographic': {
                      'AppVersion': 'string',
                      'Locale': 'string',
                      'Make': 'string',
                      'Model': 'string',
                      'ModelVersion': 'string',
                      'Platform': 'string',
                      'PlatformVersion': 'string',
                      'Timezone': 'string'
                  },
                  'EffectiveDate': 'string',
                  'EndpointStatus': 'string',
                  'Location': {
                      'City': 'string',
                      'Country': 'string',
                      'Latitude': 123.0,
                      'Longitude': 123.0,
                      'PostalCode': 'string',
                      'Region': 'string'
                  },
                  'Metrics': {
                      'string': 123.0
                  },
                  'OptOut': 'string',
                  'RequestId': 'string',
                  'User': {
                      'UserAttributes': {
                          'string': [
                              'string',
                          ]
                      },
                      'UserId': 'string'
                  }
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type EndpointId: string
        :param EndpointId: **[REQUIRED]**

          The unique identifier for the endpoint.

        :type EndpointRequest: dict
        :param EndpointRequest: **[REQUIRED]**

          Specifies the channel type and other settings for an endpoint.

          - **Address** *(string) --*

            The destination address for messages or push notifications that you send to the
            endpoint. The address varies by channel. For a push-notification channel, use the token
            provided by the push notification service, such as an Apple Push Notification service
            (APNs) device token or a Firebase Cloud Messaging (FCM) registration token. For the SMS
            channel, use a phone number in E.164 format, such as +12065550100. For the email
            channel, use an email address.

          - **Attributes** *(dict) --*

            One or more custom attributes that describe the endpoint by associating a name with an
            array of values. For example, the value of a custom attribute named Interests might be:
            ["science", "music", "travel"]. You can use these attributes as filter criteria when you
            create segments.

            When you define the name of a custom attribute, avoid using the following characters:
            number sign (#), colon (:), question mark (?), backslash (\\), and slash (/). The Amazon
            Pinpoint console can't display attribute names that contain these characters. This
            limitation doesn't apply to attribute values.

            - *(string) --*

              - *(list) --*

                - *(string) --*

          - **ChannelType** *(string) --*

            The channel to use when sending messages or push notifications to the endpoint.

          - **Demographic** *(dict) --*

            The demographic information for the endpoint, such as the time zone and platform.

            - **AppVersion** *(string) --*

              The version of the app that's associated with the endpoint.

            - **Locale** *(string) --*

              The locale of the endpoint, in the following format: the ISO 639-1 alpha-2 code,
              followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.

            - **Make** *(string) --*

              The manufacturer of the endpoint device, such as Apple or Samsung.

            - **Model** *(string) --*

              The model name or number of the endpoint device, such as iPhone.

            - **ModelVersion** *(string) --*

              The model version of the endpoint device.

            - **Platform** *(string) --*

              The platform of the endpoint device, such as iOS or Android.

            - **PlatformVersion** *(string) --*

              The platform version of the endpoint device.

            - **Timezone** *(string) --*

              The time zone of the endpoint, specified as a tz database name value, such as
              America/Los_Angeles.

          - **EffectiveDate** *(string) --*

            The date and time, in ISO 8601 format, when the endpoint is updated.

          - **EndpointStatus** *(string) --*

            Specifies whether to send messages or push notifications to the endpoint. Valid values
            are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages aren’t sent to
            the endpoint.

            Amazon Pinpoint automatically sets this value to ACTIVE when you create an endpoint or
            update an existing endpoint. Amazon Pinpoint automatically sets this value to INACTIVE
            if you update another endpoint that has the same address specified by the Address
            property.

          - **Location** *(dict) --*

            The geographic information for the endpoint.

            - **City** *(string) --*

              The name of the city where the endpoint is located.

            - **Country** *(string) --*

              The two-character code, in ISO 3166-1 alpha-2 format, for the country or region where
              the endpoint is located. For example, US for the United States.

            - **Latitude** *(float) --*

              The latitude coordinate of the endpoint location, rounded to one decimal place.

            - **Longitude** *(float) --*

              The longitude coordinate of the endpoint location, rounded to one decimal place.

            - **PostalCode** *(string) --*

              The postal or ZIP code for the area where the endpoint is located.

            - **Region** *(string) --*

              The name of the region where the endpoint is located. For locations in the United
              States, this value is the name of a state.

          - **Metrics** *(dict) --*

            One or more custom metrics that your app reports to Amazon Pinpoint for the endpoint.

            - *(string) --*

              - *(float) --*

          - **OptOut** *(string) --*

            Specifies whether the user who's associated with the endpoint has opted out of receiving
            messages and push notifications from you. Possible values are: ALL, the user has opted
            out and doesn't want to receive any messages or push notifications; and, NONE, the user
            hasn't opted out and wants to receive all messages and push notifications.

          - **RequestId** *(string) --*

            The unique identifier for the most recent request to update the endpoint.

          - **User** *(dict) --*

            One or more custom user attributes that describe the user who's associated with the
            endpoint.

            - **UserAttributes** *(dict) --*

              One or more custom attributes that describe the user by associating a name with an
              array of values. For example, the value of an attribute named Interests might be:
              ["science", "music", "travel"]. You can use these attributes as filter criteria when
              you create segments.

              When you define the name of a custom attribute, avoid using the following characters:
              number sign (#), colon (:), question mark (?), backslash (\\), and slash (/). The
              Amazon Pinpoint console can't display attribute names that contain these characters.
              This limitation doesn't apply to attribute values.

              - *(string) --*

                - *(list) --*

                  - *(string) --*

            - **UserId** *(string) --*

              The unique identifier for the user.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MessageBody': {
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **MessageBody** *(dict) --*

              Provides information about an API request or response.

              - **Message** *(string) --*

                The message that's returned from the API.

              - **RequestID** *(string) --*

                The unique identifier for the request or response.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_endpoints_batch(
        self,
        ApplicationId: str,
        EndpointBatchRequest: ClientUpdateEndpointsBatchEndpointBatchRequestTypeDef,
    ) -> ClientUpdateEndpointsBatchResponseTypeDef:
        """
        Creates a new batch of endpoints for an application or updates the settings and attributes
        of a batch of existing endpoints for an application. You can also use this operation to
        define custom attributes (Attributes, Metrics, and UserAttributes properties) for a batch of
        endpoints.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateEndpointsBatch>`_

        **Request Syntax**
        ::

          response = client.update_endpoints_batch(
              ApplicationId='string',
              EndpointBatchRequest={
                  'Item': [
                      {
                          'Address': 'string',
                          'Attributes': {
                              'string': [
                                  'string',
                              ]
                          },
                          'ChannelType':
                          'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'
                          |'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'
                          |'CUSTOM',
                          'Demographic': {
                              'AppVersion': 'string',
                              'Locale': 'string',
                              'Make': 'string',
                              'Model': 'string',
                              'ModelVersion': 'string',
                              'Platform': 'string',
                              'PlatformVersion': 'string',
                              'Timezone': 'string'
                          },
                          'EffectiveDate': 'string',
                          'EndpointStatus': 'string',
                          'Id': 'string',
                          'Location': {
                              'City': 'string',
                              'Country': 'string',
                              'Latitude': 123.0,
                              'Longitude': 123.0,
                              'PostalCode': 'string',
                              'Region': 'string'
                          },
                          'Metrics': {
                              'string': 123.0
                          },
                          'OptOut': 'string',
                          'RequestId': 'string',
                          'User': {
                              'UserAttributes': {
                                  'string': [
                                      'string',
                                  ]
                              },
                              'UserId': 'string'
                          }
                      },
                  ]
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type EndpointBatchRequest: dict
        :param EndpointBatchRequest: **[REQUIRED]**

          Specifies a batch of endpoints to create or update and the settings and attributes to set
          or change for each endpoint.

          - **Item** *(list) --* **[REQUIRED]**

            An array that defines the endpoints to create or update and, for each endpoint, the
            property values to set or change. An array can contain a maximum of 100 items.

            - *(dict) --*

              Specifies an endpoint to create or update and the settings and attributes to set or
              change for the endpoint.

              - **Address** *(string) --*

                The destination address for messages or push notifications that you send to the
                endpoint. The address varies by channel. For a push-notification channel, use the
                token provided by the push notification service, such as an Apple Push Notification
                service (APNs) device token or a Firebase Cloud Messaging (FCM) registration token.
                For the SMS channel, use a phone number in E.164 format, such as +12065550100. For
                the email channel, use an email address.

              - **Attributes** *(dict) --*

                One or more custom attributes that describe the endpoint by associating a name with
                an array of values. For example, the value of a custom attribute named Interests
                might be: ["science", "music", "travel"]. You can use these attributes as filter
                criteria when you create segments.

                When you define the name of a custom attribute, avoid using the following
                characters: number sign (#), colon (:), question mark (?), backslash (\\), and slash
                (/). The Amazon Pinpoint console can't display attribute names that contain these
                characters. This limitation doesn't apply to attribute values.

                - *(string) --*

                  - *(list) --*

                    - *(string) --*

              - **ChannelType** *(string) --*

                The channel to use when sending messages or push notifications to the endpoint.

              - **Demographic** *(dict) --*

                The demographic information for the endpoint, such as the time zone and platform.

                - **AppVersion** *(string) --*

                  The version of the app that's associated with the endpoint.

                - **Locale** *(string) --*

                  The locale of the endpoint, in the following format: the ISO 639-1 alpha-2 code,
                  followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.

                - **Make** *(string) --*

                  The manufacturer of the endpoint device, such as Apple or Samsung.

                - **Model** *(string) --*

                  The model name or number of the endpoint device, such as iPhone.

                - **ModelVersion** *(string) --*

                  The model version of the endpoint device.

                - **Platform** *(string) --*

                  The platform of the endpoint device, such as iOS or Android.

                - **PlatformVersion** *(string) --*

                  The platform version of the endpoint device.

                - **Timezone** *(string) --*

                  The time zone of the endpoint, specified as a tz database name value, such as
                  America/Los_Angeles.

              - **EffectiveDate** *(string) --*

                The date and time, in ISO 8601 format, when the endpoint was created or updated.

              - **EndpointStatus** *(string) --*

                Specifies whether to send messages or push notifications to the endpoint. Valid
                values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages
                aren’t sent to the endpoint.

                Amazon Pinpoint automatically sets this value to ACTIVE when you create an endpoint
                or update an existing endpoint. Amazon Pinpoint automatically sets this value to
                INACTIVE if you update another endpoint that has the same address specified by the
                Address property.

              - **Id** *(string) --*

                The unique identifier for the endpoint in the context of the batch.

              - **Location** *(dict) --*

                The geographic information for the endpoint.

                - **City** *(string) --*

                  The name of the city where the endpoint is located.

                - **Country** *(string) --*

                  The two-character code, in ISO 3166-1 alpha-2 format, for the country or region
                  where the endpoint is located. For example, US for the United States.

                - **Latitude** *(float) --*

                  The latitude coordinate of the endpoint location, rounded to one decimal place.

                - **Longitude** *(float) --*

                  The longitude coordinate of the endpoint location, rounded to one decimal place.

                - **PostalCode** *(string) --*

                  The postal or ZIP code for the area where the endpoint is located.

                - **Region** *(string) --*

                  The name of the region where the endpoint is located. For locations in the United
                  States, this value is the name of a state.

              - **Metrics** *(dict) --*

                One or more custom metrics that your app reports to Amazon Pinpoint for the
                endpoint.

                - *(string) --*

                  - *(float) --*

              - **OptOut** *(string) --*

                Specifies whether the user who's associated with the endpoint has opted out of
                receiving messages and push notifications from you. Possible values are: ALL, the
                user has opted out and doesn't want to receive any messages or push notifications;
                and, NONE, the user hasn't opted out and wants to receive all messages and push
                notifications.

              - **RequestId** *(string) --*

                The unique identifier for the request to create or update the endpoint.

              - **User** *(dict) --*

                One or more custom user attributes that your app reports to Amazon Pinpoint for the
                user who's associated with the endpoint.

                - **UserAttributes** *(dict) --*

                  One or more custom attributes that describe the user by associating a name with an
                  array of values. For example, the value of an attribute named Interests might be:
                  ["science", "music", "travel"]. You can use these attributes as filter criteria
                  when you create segments.

                  When you define the name of a custom attribute, avoid using the following
                  characters: number sign (#), colon (:), question mark (?), backslash (\\), and
                  slash (/). The Amazon Pinpoint console can't display attribute names that contain
                  these characters. This limitation doesn't apply to attribute values.

                  - *(string) --*

                    - *(list) --*

                      - *(string) --*

                - **UserId** *(string) --*

                  The unique identifier for the user.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MessageBody': {
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **MessageBody** *(dict) --*

              Provides information about an API request or response.

              - **Message** *(string) --*

                The message that's returned from the API.

              - **RequestID** *(string) --*

                The unique identifier for the request or response.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_gcm_channel(
        self, ApplicationId: str, GCMChannelRequest: ClientUpdateGcmChannelGCMChannelRequestTypeDef
    ) -> ClientUpdateGcmChannelResponseTypeDef:
        """
        Enables the GCM channel for an application or updates the status and settings of the GCM
        channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateGcmChannel>`_

        **Request Syntax**
        ::

          response = client.update_gcm_channel(
              ApplicationId='string',
              GCMChannelRequest={
                  'ApiKey': 'string',
                  'Enabled': True|False
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type GCMChannelRequest: dict
        :param GCMChannelRequest: **[REQUIRED]**

          Specifies the status and settings of the GCM channel for an application. This channel
          enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging
          (FCM), formerly Google Cloud Messaging (GCM), service.

          - **ApiKey** *(string) --* **[REQUIRED]**

            The Web API Key, also referred to as an *API_KEY* or *server key* , that you received
            from Google to communicate with Google services.

          - **Enabled** *(boolean) --*

            Specifies whether to enable the GCM channel for the application.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'GCMChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Credential': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **GCMChannelResponse** *(dict) --*

              Provides information about the status and settings of the GCM channel for an
              application. The GCM channel enables Amazon Pinpoint to send push notifications
              through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM),
              service.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the GCM channel applies to.

              - **CreationDate** *(string) --*

                The date and time when the GCM channel was enabled.

              - **Credential** *(string) --*

                The Web API Key, also referred to as an *API_KEY* or *server key* , that you
                received from Google to communicate with Google services.

              - **Enabled** *(boolean) --*

                Specifies whether the GCM channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the GCM channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the GCM channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the GCM channel.

              - **LastModifiedDate** *(string) --*

                The date and time when the GCM channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the GCM channel,
                this value is GCM.

              - **Version** *(integer) --*

                The current version of the GCM channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_journey(
        self,
        ApplicationId: str,
        JourneyId: str,
        WriteJourneyRequest: ClientUpdateJourneyWriteJourneyRequestTypeDef,
    ) -> ClientUpdateJourneyResponseTypeDef:
        """
        Updates the configuration and other settings for a journey.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateJourney>`_

        **Request Syntax**
        ::

          response = client.update_journey(
              ApplicationId='string',
              JourneyId='string',
              WriteJourneyRequest={
                  'Activities': {
                      'string': {
                          'ConditionalSplit': {
                              'Condition': {
                                  'Conditions': [
                                      {
                                          'EventCondition': {
                                              'Dimensions': {
                                                  'Attributes': {
                                                      'string': {
                                                          'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                          'Values': [
                                                              'string',
                                                          ]
                                                      }
                                                  },
                                                  'EventType': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Metrics': {
                                                      'string': {
                                                          'ComparisonOperator': 'string',
                                                          'Value': 123.0
                                                      }
                                                  }
                                              },
                                              'MessageActivity': 'string'
                                          },
                                          'SegmentCondition': {
                                              'SegmentId': 'string'
                                          },
                                          'SegmentDimensions': {
                                              'Attributes': {
                                                  'string': {
                                                      'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              },
                                              'Behavior': {
                                                  'Recency': {
                                                      'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                      'RecencyType': 'ACTIVE'|'INACTIVE'
                                                  }
                                              },
                                              'Demographic': {
                                                  'AppVersion': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Channel': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'DeviceType': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Make': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Model': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Platform': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              },
                                              'Location': {
                                                  'Country': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'GPSPoint': {
                                                      'Coordinates': {
                                                          'Latitude': 123.0,
                                                          'Longitude': 123.0
                                                      },
                                                      'RangeInKilometers': 123.0
                                                  }
                                              },
                                              'Metrics': {
                                                  'string': {
                                                      'ComparisonOperator': 'string',
                                                      'Value': 123.0
                                                  }
                                              },
                                              'UserAttributes': {
                                                  'string': {
                                                      'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              }
                                          }
                                      },
                                  ],
                                  'Operator': 'ALL'|'ANY'
                              },
                              'EvaluationWaitTime': {
                                  'WaitFor': 'string',
                                  'WaitUntil': 'string'
                              },
                              'FalseActivity': 'string',
                              'TrueActivity': 'string'
                          },
                          'Description': 'string',
                          'EMAIL': {
                              'MessageConfig': {
                                  'FromAddress': 'string'
                              },
                              'NextActivity': 'string',
                              'TemplateName': 'string'
                          },
                          'Holdout': {
                              'NextActivity': 'string',
                              'Percentage': 123
                          },
                          'MultiCondition': {
                              'Branches': [
                                  {
                                      'Condition': {
                                          'EventCondition': {
                                              'Dimensions': {
                                                  'Attributes': {
                                                      'string': {
                                                          'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                          'Values': [
                                                              'string',
                                                          ]
                                                      }
                                                  },
                                                  'EventType': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Metrics': {
                                                      'string': {
                                                          'ComparisonOperator': 'string',
                                                          'Value': 123.0
                                                      }
                                                  }
                                              },
                                              'MessageActivity': 'string'
                                          },
                                          'SegmentCondition': {
                                              'SegmentId': 'string'
                                          },
                                          'SegmentDimensions': {
                                              'Attributes': {
                                                  'string': {
                                                      'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              },
                                              'Behavior': {
                                                  'Recency': {
                                                      'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                      'RecencyType': 'ACTIVE'|'INACTIVE'
                                                  }
                                              },
                                              'Demographic': {
                                                  'AppVersion': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Channel': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'DeviceType': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Make': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Model': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'Platform': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              },
                                              'Location': {
                                                  'Country': {
                                                      'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  },
                                                  'GPSPoint': {
                                                      'Coordinates': {
                                                          'Latitude': 123.0,
                                                          'Longitude': 123.0
                                                      },
                                                      'RangeInKilometers': 123.0
                                                  }
                                              },
                                              'Metrics': {
                                                  'string': {
                                                      'ComparisonOperator': 'string',
                                                      'Value': 123.0
                                                  }
                                              },
                                              'UserAttributes': {
                                                  'string': {
                                                      'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                      'Values': [
                                                          'string',
                                                      ]
                                                  }
                                              }
                                          }
                                      },
                                      'NextActivity': 'string'
                                  },
                              ],
                              'DefaultActivity': 'string',
                              'EvaluationWaitTime': {
                                  'WaitFor': 'string',
                                  'WaitUntil': 'string'
                              }
                          },
                          'RandomSplit': {
                              'Branches': [
                                  {
                                      'NextActivity': 'string',
                                      'Percentage': 123
                                  },
                              ]
                          },
                          'Wait': {
                              'NextActivity': 'string',
                              'WaitTime': {
                                  'WaitFor': 'string',
                                  'WaitUntil': 'string'
                              }
                          }
                      }
                  },
                  'CreationDate': 'string',
                  'LastModifiedDate': 'string',
                  'Limits': {
                      'DailyCap': 123,
                      'EndpointReentryCap': 123,
                      'MessagesPerSecond': 123
                  },
                  'LocalTime': True|False,
                  'Name': 'string',
                  'QuietTime': {
                      'End': 'string',
                      'Start': 'string'
                  },
                  'RefreshFrequency': 'string',
                  'Schedule': {
                      'EndTime': datetime(2015, 1, 1),
                      'StartTime': datetime(2015, 1, 1),
                      'Timezone': 'string'
                  },
                  'StartActivity': 'string',
                  'StartCondition': {
                      'Description': 'string',
                      'SegmentStartCondition': {
                          'SegmentId': 'string'
                      }
                  },
                  'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED'
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type JourneyId: string
        :param JourneyId: **[REQUIRED]**

          The unique identifier for the journey.

        :type WriteJourneyRequest: dict
        :param WriteJourneyRequest: **[REQUIRED]**

          Specifies the configuration and other settings for a journey.

          - **Activities** *(dict) --*

            The configuration and other settings for the activities that comprise the journey.

            - *(string) --*

              - *(dict) --*

                Specifies the configuration and other settings for an activity in a journey.

                - **ConditionalSplit** *(dict) --*

                  The settings for a yes/no split activity. This type of activity sends participants
                  down one of two paths in a journey, based on conditions that you specify.

                  - **Condition** *(dict) --*

                    The conditions that define the paths for the activity, and the relationship
                    between the conditions.

                    - **Conditions** *(list) --*

                      The conditions to evaluate for the activity.

                      - *(dict) --*

                        Specifies a condition to evaluate for an activity in a journey.

                        - **EventCondition** *(dict) --*

                          The dimension settings for the event that's associated with the activity.

                          - **Dimensions** *(dict) --* **[REQUIRED]**

                            The dimensions for the event filter to use for the activity.

                            - **Attributes** *(dict) --*

                              One or more custom attributes that your application reports to Amazon
                              Pinpoint. You can use these attributes as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies attribute-based criteria for including or excluding
                                  endpoints from a segment.

                                  - **AttributeType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --* **[REQUIRED]**

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the AttributeType property, endpoints are
                                    included or excluded from the segment if their attribute values
                                    match the criteria values.

                                    - *(string) --*

                            - **EventType** *(dict) --*

                              The name of the event that causes the campaign to be sent or the
                              journey activity to be performed. This can be a standard type of event
                              that Amazon Pinpoint generates, such as _email.delivered, or a custom
                              event that's specific to your application.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Metrics** *(dict) --*

                              One or more custom metrics that your application reports to Amazon
                              Pinpoint. You can use these metrics as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies metric-based criteria for including or excluding
                                  endpoints from a segment. These criteria derive from custom
                                  metrics that you define for endpoints.

                                  - **ComparisonOperator** *(string) --* **[REQUIRED]**

                                    The operator to use when comparing metric values. Valid values
                                    are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                    LESS_THAN_OR_EQUAL, and EQUAL.

                                  - **Value** *(float) --* **[REQUIRED]**

                                    The value to compare.

                          - **MessageActivity** *(string) --*

                            The message identifier (message_id) for the message to use when
                            determining whether message events meet the condition.

                        - **SegmentCondition** *(dict) --*

                          The segment that's associated with the activity.

                          - **SegmentId** *(string) --* **[REQUIRED]**

                            The unique identifier for the segment to associate with the activity.

                        - **SegmentDimensions** *(dict) --*

                          The dimension settings for the segment that's associated with the
                          activity.

                          - **Attributes** *(dict) --*

                            One or more custom attributes to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies attribute-based criteria for including or excluding
                                endpoints from a segment.

                                - **AttributeType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --* **[REQUIRED]**

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the AttributeType property, endpoints are included or
                                  excluded from the segment if their attribute values match the
                                  criteria values.

                                  - *(string) --*

                          - **Behavior** *(dict) --*

                            The behavior-based criteria, such as how recently users have used your
                            app, for the segment.

                            - **Recency** *(dict) --*

                              The dimension settings that are based on how recently an endpoint was
                              active.

                              - **Duration** *(string) --* **[REQUIRED]**

                                The duration to use when determining whether an endpoint is active
                                or inactive.

                              - **RecencyType** *(string) --* **[REQUIRED]**

                                The type of recency dimension to use for the segment. Valid values
                                are: ACTIVE, endpoints that were active within the specified
                                duration are included in the segment; and, INACTIVE, endpoints that
                                weren't active within the specified duration are included in the
                                segment.

                          - **Demographic** *(dict) --*

                            The demographic-based criteria, such as device platform, for the
                            segment.

                            - **AppVersion** *(dict) --*

                              The app version criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Channel** *(dict) --*

                              The channel criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **DeviceType** *(dict) --*

                              The device type criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Make** *(dict) --*

                              The device make criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Model** *(dict) --*

                              The device model criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Platform** *(dict) --*

                              The device platform criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                          - **Location** *(dict) --*

                            The location-based criteria, such as region or GPS coordinates, for the
                            segment.

                            - **Country** *(dict) --*

                              The country or region code, in ISO 3166-1 alpha-2 format, for the
                              segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **GPSPoint** *(dict) --*

                              The GPS location and range for the segment.

                              - **Coordinates** *(dict) --* **[REQUIRED]**

                                The GPS coordinates to measure distance from.

                                - **Latitude** *(float) --* **[REQUIRED]**

                                  The latitude coordinate of the location.

                                - **Longitude** *(float) --* **[REQUIRED]**

                                  The longitude coordinate of the location.

                              - **RangeInKilometers** *(float) --*

                                The range, in kilometers, from the GPS coordinates.

                          - **Metrics** *(dict) --*

                            One or more custom metrics to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies metric-based criteria for including or excluding endpoints
                                from a segment. These criteria derive from custom metrics that you
                                define for endpoints.

                                - **ComparisonOperator** *(string) --* **[REQUIRED]**

                                  The operator to use when comparing metric values. Valid values
                                  are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                  LESS_THAN_OR_EQUAL, and EQUAL.

                                - **Value** *(float) --* **[REQUIRED]**

                                  The value to compare.

                          - **UserAttributes** *(dict) --*

                            One or more custom user attributes to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies attribute-based criteria for including or excluding
                                endpoints from a segment.

                                - **AttributeType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --* **[REQUIRED]**

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the AttributeType property, endpoints are included or
                                  excluded from the segment if their attribute values match the
                                  criteria values.

                                  - *(string) --*

                    - **Operator** *(string) --*

                      Specifies how to handle multiple conditions for the activity. For example, if
                      you specify two conditions for an activity, whether both or only one of the
                      conditions must be met for the activity to be performed.

                  - **EvaluationWaitTime** *(dict) --*

                    The amount of time to wait before determining whether the conditions are met, or
                    the date and time when Amazon Pinpoint determines whether the conditions are
                    met.

                    - **WaitFor** *(string) --*

                      The amount of time to wait, as a duration in ISO 8601 format, before
                      determining whether the activity's conditions have been met or moving
                      participants to the next activity in the journey.

                    - **WaitUntil** *(string) --*

                      The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether
                      the activity's conditions have been met or the activity moves participants to
                      the next activity in the journey.

                  - **FalseActivity** *(string) --*

                    The unique identifier for the activity to perform if the condition isn't met.

                  - **TrueActivity** *(string) --*

                    The unique identifier for the activity to perform if the condition is met.

                - **Description** *(string) --*

                  The custom description of the activity.

                - **EMAIL** *(dict) --*

                  The settings for an email activity. This type of activity sends an email message
                  to participants.

                  - **MessageConfig** *(dict) --*

                    The "From" address to use for the message.

                    - **FromAddress** *(string) --*

                      The verified email address to send the email message from. The default address
                      is the FromAddress specified for the email channel for the application.

                  - **NextActivity** *(string) --*

                    The unique identifier for the next activity to perform, after the message is
                    sent.

                  - **TemplateName** *(string) --*

                    The name of the email template to use for the message.

                - **Holdout** *(dict) --*

                  The settings for a holdout activity. This type of activity stops a journey for a
                  specified percentage of participants.

                  - **NextActivity** *(string) --*

                    The unique identifier for the next activity to perform, after performing the
                    holdout activity.

                  - **Percentage** *(integer) --* **[REQUIRED]**

                    The percentage of participants who shouldn't continue the journey.

                - **MultiCondition** *(dict) --*

                  The settings for a multivariate split activity. This type of activity sends
                  participants down one of as many as five paths in a journey, based on conditions
                  that you specify.

                  - **Branches** *(list) --*

                    The paths for the activity, including the conditions for entering each path and
                    the activity to perform for each path.

                    - *(dict) --*

                      Specifies a condition to evaluate for an activity path in a journey.

                      - **Condition** *(dict) --*

                        The condition to evaluate for the activity path.

                        - **EventCondition** *(dict) --*

                          The dimension settings for the event that's associated with the activity.

                          - **Dimensions** *(dict) --* **[REQUIRED]**

                            The dimensions for the event filter to use for the activity.

                            - **Attributes** *(dict) --*

                              One or more custom attributes that your application reports to Amazon
                              Pinpoint. You can use these attributes as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies attribute-based criteria for including or excluding
                                  endpoints from a segment.

                                  - **AttributeType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --* **[REQUIRED]**

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the AttributeType property, endpoints are
                                    included or excluded from the segment if their attribute values
                                    match the criteria values.

                                    - *(string) --*

                            - **EventType** *(dict) --*

                              The name of the event that causes the campaign to be sent or the
                              journey activity to be performed. This can be a standard type of event
                              that Amazon Pinpoint generates, such as _email.delivered, or a custom
                              event that's specific to your application.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Metrics** *(dict) --*

                              One or more custom metrics that your application reports to Amazon
                              Pinpoint. You can use these metrics as selection criteria when you
                              create an event filter.

                              - *(string) --*

                                - *(dict) --*

                                  Specifies metric-based criteria for including or excluding
                                  endpoints from a segment. These criteria derive from custom
                                  metrics that you define for endpoints.

                                  - **ComparisonOperator** *(string) --* **[REQUIRED]**

                                    The operator to use when comparing metric values. Valid values
                                    are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                    LESS_THAN_OR_EQUAL, and EQUAL.

                                  - **Value** *(float) --* **[REQUIRED]**

                                    The value to compare.

                          - **MessageActivity** *(string) --*

                            The message identifier (message_id) for the message to use when
                            determining whether message events meet the condition.

                        - **SegmentCondition** *(dict) --*

                          The segment that's associated with the activity.

                          - **SegmentId** *(string) --* **[REQUIRED]**

                            The unique identifier for the segment to associate with the activity.

                        - **SegmentDimensions** *(dict) --*

                          The dimension settings for the segment that's associated with the
                          activity.

                          - **Attributes** *(dict) --*

                            One or more custom attributes to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies attribute-based criteria for including or excluding
                                endpoints from a segment.

                                - **AttributeType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --* **[REQUIRED]**

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the AttributeType property, endpoints are included or
                                  excluded from the segment if their attribute values match the
                                  criteria values.

                                  - *(string) --*

                          - **Behavior** *(dict) --*

                            The behavior-based criteria, such as how recently users have used your
                            app, for the segment.

                            - **Recency** *(dict) --*

                              The dimension settings that are based on how recently an endpoint was
                              active.

                              - **Duration** *(string) --* **[REQUIRED]**

                                The duration to use when determining whether an endpoint is active
                                or inactive.

                              - **RecencyType** *(string) --* **[REQUIRED]**

                                The type of recency dimension to use for the segment. Valid values
                                are: ACTIVE, endpoints that were active within the specified
                                duration are included in the segment; and, INACTIVE, endpoints that
                                weren't active within the specified duration are included in the
                                segment.

                          - **Demographic** *(dict) --*

                            The demographic-based criteria, such as device platform, for the
                            segment.

                            - **AppVersion** *(dict) --*

                              The app version criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Channel** *(dict) --*

                              The channel criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **DeviceType** *(dict) --*

                              The device type criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Make** *(dict) --*

                              The device make criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Model** *(dict) --*

                              The device model criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **Platform** *(dict) --*

                              The device platform criteria for the segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                          - **Location** *(dict) --*

                            The location-based criteria, such as region or GPS coordinates, for the
                            segment.

                            - **Country** *(dict) --*

                              The country or region code, in ISO 3166-1 alpha-2 format, for the
                              segment.

                              - **DimensionType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --* **[REQUIRED]**

                                The criteria values to use for the segment dimension. Depending on
                                the value of the DimensionType property, endpoints are included or
                                excluded from the segment if their values match the criteria values.

                                - *(string) --*

                            - **GPSPoint** *(dict) --*

                              The GPS location and range for the segment.

                              - **Coordinates** *(dict) --* **[REQUIRED]**

                                The GPS coordinates to measure distance from.

                                - **Latitude** *(float) --* **[REQUIRED]**

                                  The latitude coordinate of the location.

                                - **Longitude** *(float) --* **[REQUIRED]**

                                  The longitude coordinate of the location.

                              - **RangeInKilometers** *(float) --*

                                The range, in kilometers, from the GPS coordinates.

                          - **Metrics** *(dict) --*

                            One or more custom metrics to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies metric-based criteria for including or excluding endpoints
                                from a segment. These criteria derive from custom metrics that you
                                define for endpoints.

                                - **ComparisonOperator** *(string) --* **[REQUIRED]**

                                  The operator to use when comparing metric values. Valid values
                                  are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                  LESS_THAN_OR_EQUAL, and EQUAL.

                                - **Value** *(float) --* **[REQUIRED]**

                                  The value to compare.

                          - **UserAttributes** *(dict) --*

                            One or more custom user attributes to use as criteria for the segment.

                            - *(string) --*

                              - *(dict) --*

                                Specifies attribute-based criteria for including or excluding
                                endpoints from a segment.

                                - **AttributeType** *(string) --*

                                  The type of segment dimension to use. Valid values are: INCLUSIVE,
                                  endpoints that match the criteria are included in the segment;
                                  and, EXCLUSIVE, endpoints that match the criteria are excluded
                                  from the segment.

                                - **Values** *(list) --* **[REQUIRED]**

                                  The criteria values to use for the segment dimension. Depending on
                                  the value of the AttributeType property, endpoints are included or
                                  excluded from the segment if their attribute values match the
                                  criteria values.

                                  - *(string) --*

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after completing the
                        activity for the path.

                  - **DefaultActivity** *(string) --*

                    The activity to perform by default for any path in the activity.

                  - **EvaluationWaitTime** *(dict) --*

                    The amount of time to wait or the date and time when Amazon Pinpoint determines
                    whether the conditions are met.

                    - **WaitFor** *(string) --*

                      The amount of time to wait, as a duration in ISO 8601 format, before
                      determining whether the activity's conditions have been met or moving
                      participants to the next activity in the journey.

                    - **WaitUntil** *(string) --*

                      The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether
                      the activity's conditions have been met or the activity moves participants to
                      the next activity in the journey.

                - **RandomSplit** *(dict) --*

                  The settings for a random split activity. This type of activity randomly sends
                  specified percentages of participants down one of as many as five paths in a
                  journey, based on conditions that you specify.

                  - **Branches** *(list) --*

                    The paths for the activity, including the percentage of participants to enter
                    each path and the activity to perform for each path.

                    - *(dict) --*

                      Specifies the settings for a path in a random split activity in a journey.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after completing the
                        activity for the path.

                      - **Percentage** *(integer) --*

                        The percentage of participants to send down the activity path.

                - **Wait** *(dict) --*

                  The settings for a wait activity. This type of activity waits for a certain amount
                  of time or until a specific date and time before moving participants to the next
                  activity in a journey.

                  - **NextActivity** *(string) --*

                    The unique identifier for the next activity to perform, after performing the
                    wait activity.

                  - **WaitTime** *(dict) --*

                    The amount of time to wait or the date and time when the activity moves
                    participants to the next activity in the journey.

                    - **WaitFor** *(string) --*

                      The amount of time to wait, as a duration in ISO 8601 format, before
                      determining whether the activity's conditions have been met or moving
                      participants to the next activity in the journey.

                    - **WaitUntil** *(string) --*

                      The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether
                      the activity's conditions have been met or the activity moves participants to
                      the next activity in the journey.

          - **CreationDate** *(string) --*

            The date, in ISO 8601 format, when the journey was created.

          - **LastModifiedDate** *(string) --*

            The date, in ISO 8601 format, when the journey was last modified.

          - **Limits** *(dict) --*

            The messaging and entry limits for the journey.

            - **DailyCap** *(integer) --*

              The maximum number of messages that the journey can send to a single participant
              during a 24-hour period. The maximum value is 100.

            - **EndpointReentryCap** *(integer) --*

              The maximum number of times that a participant can enter the journey. The maximum
              value is 100. To allow participants to enter the journey an unlimited number of times,
              set this value to 0.

            - **MessagesPerSecond** *(integer) --*

              The maximum number of messages that the journey can send each second.

          - **LocalTime** *(boolean) --*

            Specifies whether the journey's scheduled start and end times use each participant's
            local time. To base the schedule on each participant's local time, set this value to
            true.

          - **Name** *(string) --* **[REQUIRED]**

            The name of the journey. A journey name can contain a maximum of 150 characters. The
            characters can be alphanumeric characters or symbols, such as underscores (_) or hyphens
            (-). A journey name can't contain any spaces.

          - **QuietTime** *(dict) --*

            The quiet time settings for the journey. Quiet time is a specific time range when a
            journey doesn't send messages to participants, if all the following conditions are met:

            * The EndpointDemographic.Timezone property of the endpoint for the participant is set
            to a valid value.

            * The current time in the participant's time zone is later than or equal to the time
            specified by the QuietTime.Start property for the journey.

            * The current time in the participant's time zone is earlier than or equal to the time
            specified by the QuietTime.End property for the journey.

            If any of the preceding conditions isn't met, the participant will receive messages from
            the journey, even if quiet time is enabled.

            - **End** *(string) --*

              The specific time when quiet time ends. This value has to use 24-hour notation and be
              in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is
              the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30
              PM.

            - **Start** *(string) --*

              The specific time when quiet time begins. This value has to use 24-hour notation and
              be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM
              is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent
              2:30 PM.

          - **RefreshFrequency** *(string) --*

            The frequency with which Amazon Pinpoint evaluates segment and event data for the
            journey, as a duration in ISO 8601 format.

          - **Schedule** *(dict) --*

            The schedule settings for the journey.

            - **EndTime** *(datetime) --*

              The scheduled time, in ISO 8601 format, when the journey ended or will end.

            - **StartTime** *(datetime) --*

              The scheduled time, in ISO 8601 format, when the journey began or will begin.

            - **Timezone** *(string) --*

              The starting UTC offset for the journey schedule, if the value of the journey's
              LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30,
              UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08,
              UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+12:45, UTC+13,
              UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04, UTC-05, UTC-06, UTC-07,
              UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.

          - **StartActivity** *(string) --*

            The unique identifier for the first activity in the journey.

          - **StartCondition** *(dict) --*

            The segment that defines which users are participants in the journey.

            - **Description** *(string) --*

              The custom description of the condition.

            - **SegmentStartCondition** *(dict) --*

              The segment that's associated with the first activity in the journey. This segment
              determines which users are participants in the journey.

              - **SegmentId** *(string) --* **[REQUIRED]**

                The unique identifier for the segment to associate with the activity.

          - **State** *(string) --*

            The status of the journey. Valid values are:

            * DRAFT - Saves the journey and doesn't publish it.

            * ACTIVE - Saves and publishes the journey. Depending on the journey's schedule, the
            journey starts running immediately or at the scheduled start time. If a journey's status
            is ACTIVE, you can't add, change, or remove activities from it.

            The CANCELLED, COMPLETED, and CLOSED values are not supported in requests to create or
            update a journey. To cancel a journey, use the Journey Stateresource.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'JourneyResponse': {
                    'Activities': {
                        'string': {
                            'ConditionalSplit': {
                                'Condition': {
                                    'Conditions': [
                                        {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType':
                                                            'INCLUSIVE'
                                                            |'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                    ],
                                    'Operator': 'ALL'|'ANY'
                                },
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                },
                                'FalseActivity': 'string',
                                'TrueActivity': 'string'
                            },
                            'Description': 'string',
                            'EMAIL': {
                                'MessageConfig': {
                                    'FromAddress': 'string'
                                },
                                'NextActivity': 'string',
                                'TemplateName': 'string'
                            },
                            'Holdout': {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                            'MultiCondition': {
                                'Branches': [
                                    {
                                        'Condition': {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType':
                                                            'INCLUSIVE'
                                                            |'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                        'NextActivity': 'string'
                                    },
                                ],
                                'DefaultActivity': 'string',
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            },
                            'RandomSplit': {
                                'Branches': [
                                    {
                                        'NextActivity': 'string',
                                        'Percentage': 123
                                    },
                                ]
                            },
                            'Wait': {
                                'NextActivity': 'string',
                                'WaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            }
                        }
                    },
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Id': 'string',
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'DailyCap': 123,
                        'EndpointReentryCap': 123,
                        'MessagesPerSecond': 123
                    },
                    'LocalTime': True|False,
                    'Name': 'string',
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'RefreshFrequency': 'string',
                    'Schedule': {
                        'EndTime': datetime(2015, 1, 1),
                        'StartTime': datetime(2015, 1, 1),
                        'Timezone': 'string'
                    },
                    'StartActivity': 'string',
                    'StartCondition': {
                        'Description': 'string',
                        'SegmentStartCondition': {
                            'SegmentId': 'string'
                        }
                    },
                    'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
                    'tags': {
                        'string': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **JourneyResponse** *(dict) --*

              Provides information about the status, configuration, and other settings for a
              journey.

              - **Activities** *(dict) --*

                The configuration and other settings for the activities that comprise the journey.

                - *(string) --*

                  - *(dict) --*

                    Specifies the configuration and other settings for an activity in a journey.

                    - **ConditionalSplit** *(dict) --*

                      The settings for a yes/no split activity. This type of activity sends
                      participants down one of two paths in a journey, based on conditions that you
                      specify.

                      - **Condition** *(dict) --*

                        The conditions that define the paths for the activity, and the relationship
                        between the conditions.

                        - **Conditions** *(list) --*

                          The conditions to evaluate for the activity.

                          - *(dict) --*

                            Specifies a condition to evaluate for an activity in a journey.

                            - **EventCondition** *(dict) --*

                              The dimension settings for the event that's associated with the
                              activity.

                              - **Dimensions** *(dict) --*

                                The dimensions for the event filter to use for the activity.

                                - **Attributes** *(dict) --*

                                  One or more custom attributes that your application reports to
                                  Amazon Pinpoint. You can use these attributes as selection
                                  criteria when you create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies attribute-based criteria for including or excluding
                                      endpoints from a segment.

                                      - **AttributeType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the AttributeType property,
                                        endpoints are included or excluded from the segment if their
                                        attribute values match the criteria values.

                                        - *(string) --*

                                - **EventType** *(dict) --*

                                  The name of the event that causes the campaign to be sent or the
                                  journey activity to be performed. This can be a standard type of
                                  event that Amazon Pinpoint generates, such as _email.delivered, or
                                  a custom event that's specific to your application.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Metrics** *(dict) --*

                                  One or more custom metrics that your application reports to Amazon
                                  Pinpoint. You can use these metrics as selection criteria when you
                                  create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies metric-based criteria for including or excluding
                                      endpoints from a segment. These criteria derive from custom
                                      metrics that you define for endpoints.

                                      - **ComparisonOperator** *(string) --*

                                        The operator to use when comparing metric values. Valid
                                        values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                        LESS_THAN_OR_EQUAL, and EQUAL.

                                      - **Value** *(float) --*

                                        The value to compare.

                              - **MessageActivity** *(string) --*

                                The message identifier (message_id) for the message to use when
                                determining whether message events meet the condition.

                            - **SegmentCondition** *(dict) --*

                              The segment that's associated with the activity.

                              - **SegmentId** *(string) --*

                                The unique identifier for the segment to associate with the
                                activity.

                            - **SegmentDimensions** *(dict) --*

                              The dimension settings for the segment that's associated with the
                              activity.

                              - **Attributes** *(dict) --*

                                One or more custom attributes to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                              - **Behavior** *(dict) --*

                                The behavior-based criteria, such as how recently users have used
                                your app, for the segment.

                                - **Recency** *(dict) --*

                                  The dimension settings that are based on how recently an endpoint
                                  was active.

                                  - **Duration** *(string) --*

                                    The duration to use when determining whether an endpoint is
                                    active or inactive.

                                  - **RecencyType** *(string) --*

                                    The type of recency dimension to use for the segment. Valid
                                    values are: ACTIVE, endpoints that were active within the
                                    specified duration are included in the segment; and, INACTIVE,
                                    endpoints that weren't active within the specified duration are
                                    included in the segment.

                              - **Demographic** *(dict) --*

                                The demographic-based criteria, such as device platform, for the
                                segment.

                                - **AppVersion** *(dict) --*

                                  The app version criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Channel** *(dict) --*

                                  The channel criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **DeviceType** *(dict) --*

                                  The device type criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Make** *(dict) --*

                                  The device make criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Model** *(dict) --*

                                  The device model criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Platform** *(dict) --*

                                  The device platform criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                              - **Location** *(dict) --*

                                The location-based criteria, such as region or GPS coordinates, for
                                the segment.

                                - **Country** *(dict) --*

                                  The country or region code, in ISO 3166-1 alpha-2 format, for the
                                  segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **GPSPoint** *(dict) --*

                                  The GPS location and range for the segment.

                                  - **Coordinates** *(dict) --*

                                    The GPS coordinates to measure distance from.

                                    - **Latitude** *(float) --*

                                      The latitude coordinate of the location.

                                    - **Longitude** *(float) --*

                                      The longitude coordinate of the location.

                                  - **RangeInKilometers** *(float) --*

                                    The range, in kilometers, from the GPS coordinates.

                              - **Metrics** *(dict) --*

                                One or more custom metrics to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies metric-based criteria for including or excluding
                                    endpoints from a segment. These criteria derive from custom
                                    metrics that you define for endpoints.

                                    - **ComparisonOperator** *(string) --*

                                      The operator to use when comparing metric values. Valid values
                                      are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                      LESS_THAN_OR_EQUAL, and EQUAL.

                                    - **Value** *(float) --*

                                      The value to compare.

                              - **UserAttributes** *(dict) --*

                                One or more custom user attributes to use as criteria for the
                                segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                        - **Operator** *(string) --*

                          Specifies how to handle multiple conditions for the activity. For example,
                          if you specify two conditions for an activity, whether both or only one of
                          the conditions must be met for the activity to be performed.

                      - **EvaluationWaitTime** *(dict) --*

                        The amount of time to wait before determining whether the conditions are
                        met, or the date and time when Amazon Pinpoint determines whether the
                        conditions are met.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

                      - **FalseActivity** *(string) --*

                        The unique identifier for the activity to perform if the condition isn't
                        met.

                      - **TrueActivity** *(string) --*

                        The unique identifier for the activity to perform if the condition is met.

                    - **Description** *(string) --*

                      The custom description of the activity.

                    - **EMAIL** *(dict) --*

                      The settings for an email activity. This type of activity sends an email
                      message to participants.

                      - **MessageConfig** *(dict) --*

                        The "From" address to use for the message.

                        - **FromAddress** *(string) --*

                          The verified email address to send the email message from. The default
                          address is the FromAddress specified for the email channel for the
                          application.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after the message is
                        sent.

                      - **TemplateName** *(string) --*

                        The name of the email template to use for the message.

                    - **Holdout** *(dict) --*

                      The settings for a holdout activity. This type of activity stops a journey for
                      a specified percentage of participants.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after performing the
                        holdout activity.

                      - **Percentage** *(integer) --*

                        The percentage of participants who shouldn't continue the journey.

                    - **MultiCondition** *(dict) --*

                      The settings for a multivariate split activity. This type of activity sends
                      participants down one of as many as five paths in a journey, based on
                      conditions that you specify.

                      - **Branches** *(list) --*

                        The paths for the activity, including the conditions for entering each path
                        and the activity to perform for each path.

                        - *(dict) --*

                          Specifies a condition to evaluate for an activity path in a journey.

                          - **Condition** *(dict) --*

                            The condition to evaluate for the activity path.

                            - **EventCondition** *(dict) --*

                              The dimension settings for the event that's associated with the
                              activity.

                              - **Dimensions** *(dict) --*

                                The dimensions for the event filter to use for the activity.

                                - **Attributes** *(dict) --*

                                  One or more custom attributes that your application reports to
                                  Amazon Pinpoint. You can use these attributes as selection
                                  criteria when you create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies attribute-based criteria for including or excluding
                                      endpoints from a segment.

                                      - **AttributeType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the AttributeType property,
                                        endpoints are included or excluded from the segment if their
                                        attribute values match the criteria values.

                                        - *(string) --*

                                - **EventType** *(dict) --*

                                  The name of the event that causes the campaign to be sent or the
                                  journey activity to be performed. This can be a standard type of
                                  event that Amazon Pinpoint generates, such as _email.delivered, or
                                  a custom event that's specific to your application.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Metrics** *(dict) --*

                                  One or more custom metrics that your application reports to Amazon
                                  Pinpoint. You can use these metrics as selection criteria when you
                                  create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies metric-based criteria for including or excluding
                                      endpoints from a segment. These criteria derive from custom
                                      metrics that you define for endpoints.

                                      - **ComparisonOperator** *(string) --*

                                        The operator to use when comparing metric values. Valid
                                        values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                        LESS_THAN_OR_EQUAL, and EQUAL.

                                      - **Value** *(float) --*

                                        The value to compare.

                              - **MessageActivity** *(string) --*

                                The message identifier (message_id) for the message to use when
                                determining whether message events meet the condition.

                            - **SegmentCondition** *(dict) --*

                              The segment that's associated with the activity.

                              - **SegmentId** *(string) --*

                                The unique identifier for the segment to associate with the
                                activity.

                            - **SegmentDimensions** *(dict) --*

                              The dimension settings for the segment that's associated with the
                              activity.

                              - **Attributes** *(dict) --*

                                One or more custom attributes to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                              - **Behavior** *(dict) --*

                                The behavior-based criteria, such as how recently users have used
                                your app, for the segment.

                                - **Recency** *(dict) --*

                                  The dimension settings that are based on how recently an endpoint
                                  was active.

                                  - **Duration** *(string) --*

                                    The duration to use when determining whether an endpoint is
                                    active or inactive.

                                  - **RecencyType** *(string) --*

                                    The type of recency dimension to use for the segment. Valid
                                    values are: ACTIVE, endpoints that were active within the
                                    specified duration are included in the segment; and, INACTIVE,
                                    endpoints that weren't active within the specified duration are
                                    included in the segment.

                              - **Demographic** *(dict) --*

                                The demographic-based criteria, such as device platform, for the
                                segment.

                                - **AppVersion** *(dict) --*

                                  The app version criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Channel** *(dict) --*

                                  The channel criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **DeviceType** *(dict) --*

                                  The device type criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Make** *(dict) --*

                                  The device make criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Model** *(dict) --*

                                  The device model criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Platform** *(dict) --*

                                  The device platform criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                              - **Location** *(dict) --*

                                The location-based criteria, such as region or GPS coordinates, for
                                the segment.

                                - **Country** *(dict) --*

                                  The country or region code, in ISO 3166-1 alpha-2 format, for the
                                  segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **GPSPoint** *(dict) --*

                                  The GPS location and range for the segment.

                                  - **Coordinates** *(dict) --*

                                    The GPS coordinates to measure distance from.

                                    - **Latitude** *(float) --*

                                      The latitude coordinate of the location.

                                    - **Longitude** *(float) --*

                                      The longitude coordinate of the location.

                                  - **RangeInKilometers** *(float) --*

                                    The range, in kilometers, from the GPS coordinates.

                              - **Metrics** *(dict) --*

                                One or more custom metrics to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies metric-based criteria for including or excluding
                                    endpoints from a segment. These criteria derive from custom
                                    metrics that you define for endpoints.

                                    - **ComparisonOperator** *(string) --*

                                      The operator to use when comparing metric values. Valid values
                                      are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                      LESS_THAN_OR_EQUAL, and EQUAL.

                                    - **Value** *(float) --*

                                      The value to compare.

                              - **UserAttributes** *(dict) --*

                                One or more custom user attributes to use as criteria for the
                                segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after completing
                            the activity for the path.

                      - **DefaultActivity** *(string) --*

                        The activity to perform by default for any path in the activity.

                      - **EvaluationWaitTime** *(dict) --*

                        The amount of time to wait or the date and time when Amazon Pinpoint
                        determines whether the conditions are met.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

                    - **RandomSplit** *(dict) --*

                      The settings for a random split activity. This type of activity randomly sends
                      specified percentages of participants down one of as many as five paths in a
                      journey, based on conditions that you specify.

                      - **Branches** *(list) --*

                        The paths for the activity, including the percentage of participants to
                        enter each path and the activity to perform for each path.

                        - *(dict) --*

                          Specifies the settings for a path in a random split activity in a journey.

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after completing
                            the activity for the path.

                          - **Percentage** *(integer) --*

                            The percentage of participants to send down the activity path.

                    - **Wait** *(dict) --*

                      The settings for a wait activity. This type of activity waits for a certain
                      amount of time or until a specific date and time before moving participants to
                      the next activity in a journey.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after performing the
                        wait activity.

                      - **WaitTime** *(dict) --*

                        The amount of time to wait or the date and time when the activity moves
                        participants to the next activity in the journey.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the journey applies to.

              - **CreationDate** *(string) --*

                The date, in ISO 8601 format, when the journey was created.

              - **Id** *(string) --*

                The unique identifier for the journey.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the journey was last modified.

              - **Limits** *(dict) --*

                The messaging and entry limits for the journey.

                - **DailyCap** *(integer) --*

                  The maximum number of messages that the journey can send to a single participant
                  during a 24-hour period. The maximum value is 100.

                - **EndpointReentryCap** *(integer) --*

                  The maximum number of times that a participant can enter the journey. The maximum
                  value is 100. To allow participants to enter the journey an unlimited number of
                  times, set this value to 0.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that the journey can send each second.

              - **LocalTime** *(boolean) --*

                Specifies whether the journey's scheduled start and end times use each participant's
                local time. If this value is true, the schedule uses each participant's local time.

              - **Name** *(string) --*

                The name of the journey.

              - **QuietTime** *(dict) --*

                The quiet time settings for the journey. Quiet time is a specific time range when a
                journey doesn't send messages to participants, if all the following conditions are
                met:

                * The EndpointDemographic.Timezone property of the endpoint for the participant is
                set to a valid value.

                * The current time in the participant's time zone is later than or equal to the time
                specified by the QuietTime.Start property for the journey.

                * The current time in the participant's time zone is earlier than or equal to the
                time specified by the QuietTime.End property for the journey.

                If any of the preceding conditions isn't met, the participant will receive messages
                from the journey, even if quiet time is enabled.

                - **End** *(string) --*

                  The specific time when quiet time ends. This value has to use 24-hour notation and
                  be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and
                  MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

                - **Start** *(string) --*

                  The specific time when quiet time begins. This value has to use 24-hour notation
                  and be in HH:MM format, where HH is the hour (with a leading zero, if applicable)
                  and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

              - **RefreshFrequency** *(string) --*

                The frequency with which Amazon Pinpoint evaluates segment and event data for the
                journey, as a duration in ISO 8601 format.

              - **Schedule** *(dict) --*

                The schedule settings for the journey.

                - **EndTime** *(datetime) --*

                  The scheduled time, in ISO 8601 format, when the journey ended or will end.

                - **StartTime** *(datetime) --*

                  The scheduled time, in ISO 8601 format, when the journey began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the journey schedule, if the value of the journey's
                  LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                  UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                  UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12,
                  UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04,
                  UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.

              - **StartActivity** *(string) --*

                The unique identifier for the first activity in the journey.

              - **StartCondition** *(dict) --*

                The segment that defines which users are participants in the journey.

                - **Description** *(string) --*

                  The custom description of the condition.

                - **SegmentStartCondition** *(dict) --*

                  The segment that's associated with the first activity in the journey. This segment
                  determines which users are participants in the journey.

                  - **SegmentId** *(string) --*

                    The unique identifier for the segment to associate with the activity.

              - **State** *(string) --*

                The current status of the journey. Possible values are:

                * DRAFT - The journey is being developed and hasn't been published yet.

                * ACTIVE - The journey has been developed and published. Depending on the journey's
                schedule, the journey may currently be running or scheduled to start running at a
                later time. If a journey's status is ACTIVE, you can't add, change, or remove
                activities from it.

                * COMPLETED - The journey has been published and has finished running. All
                participants have entered the journey and no participants are waiting to complete
                the journey or any activities in the journey.

                * CANCELLED - The journey has been stopped. If a journey's status is CANCELLED, you
                can't add, change, or remove activities or segment settings from the journey.

                * CLOSED - The journey has been published and has started running. It may have also
                passed its scheduled end time, or passed its scheduled start time and a refresh
                frequency hasn't been specified for it. If a journey's status is CLOSED, you can't
                add participants to it, and no existing participants can enter the journey for the
                first time. However, any existing participants who are currently waiting to start an
                activity may resume the journey.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the journey. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_journey_state(
        self,
        ApplicationId: str,
        JourneyId: str,
        JourneyStateRequest: ClientUpdateJourneyStateJourneyStateRequestTypeDef,
    ) -> ClientUpdateJourneyStateResponseTypeDef:
        """
        Cancels an active journey.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateJourneyState>`_

        **Request Syntax**
        ::

          response = client.update_journey_state(
              ApplicationId='string',
              JourneyId='string',
              JourneyStateRequest={
                  'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED'
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type JourneyId: string
        :param JourneyId: **[REQUIRED]**

          The unique identifier for the journey.

        :type JourneyStateRequest: dict
        :param JourneyStateRequest: **[REQUIRED]**

          Changes the status of a journey.

          - **State** *(string) --*

            The status of the journey. Currently, the only supported value is CANCELLED.

            If you cancel a journey, Amazon Pinpoint continues to perform activities that are
            currently in progress, until those activities are complete. Amazon Pinpoint also
            continues to collect and aggregate analytics data for those activities, until they are
            complete, and any activities that were complete when you cancelled the journey.

            After you cancel a journey, you can't add, change, or remove any activities from the
            journey. In addition, Amazon Pinpoint stops evaluating the journey and doesn't perform
            any activities that haven't started.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'JourneyResponse': {
                    'Activities': {
                        'string': {
                            'ConditionalSplit': {
                                'Condition': {
                                    'Conditions': [
                                        {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType':
                                                            'INCLUSIVE'
                                                            |'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                    ],
                                    'Operator': 'ALL'|'ANY'
                                },
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                },
                                'FalseActivity': 'string',
                                'TrueActivity': 'string'
                            },
                            'Description': 'string',
                            'EMAIL': {
                                'MessageConfig': {
                                    'FromAddress': 'string'
                                },
                                'NextActivity': 'string',
                                'TemplateName': 'string'
                            },
                            'Holdout': {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                            'MultiCondition': {
                                'Branches': [
                                    {
                                        'Condition': {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType':
                                                            'INCLUSIVE'
                                                            |'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration':
                                                        'HR_24'|'DAY_7'|'DAY_14'
                                                        |'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                        'NextActivity': 'string'
                                    },
                                ],
                                'DefaultActivity': 'string',
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            },
                            'RandomSplit': {
                                'Branches': [
                                    {
                                        'NextActivity': 'string',
                                        'Percentage': 123
                                    },
                                ]
                            },
                            'Wait': {
                                'NextActivity': 'string',
                                'WaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            }
                        }
                    },
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Id': 'string',
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'DailyCap': 123,
                        'EndpointReentryCap': 123,
                        'MessagesPerSecond': 123
                    },
                    'LocalTime': True|False,
                    'Name': 'string',
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'RefreshFrequency': 'string',
                    'Schedule': {
                        'EndTime': datetime(2015, 1, 1),
                        'StartTime': datetime(2015, 1, 1),
                        'Timezone': 'string'
                    },
                    'StartActivity': 'string',
                    'StartCondition': {
                        'Description': 'string',
                        'SegmentStartCondition': {
                            'SegmentId': 'string'
                        }
                    },
                    'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
                    'tags': {
                        'string': 'string'
                    }
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **JourneyResponse** *(dict) --*

              Provides information about the status, configuration, and other settings for a
              journey.

              - **Activities** *(dict) --*

                The configuration and other settings for the activities that comprise the journey.

                - *(string) --*

                  - *(dict) --*

                    Specifies the configuration and other settings for an activity in a journey.

                    - **ConditionalSplit** *(dict) --*

                      The settings for a yes/no split activity. This type of activity sends
                      participants down one of two paths in a journey, based on conditions that you
                      specify.

                      - **Condition** *(dict) --*

                        The conditions that define the paths for the activity, and the relationship
                        between the conditions.

                        - **Conditions** *(list) --*

                          The conditions to evaluate for the activity.

                          - *(dict) --*

                            Specifies a condition to evaluate for an activity in a journey.

                            - **EventCondition** *(dict) --*

                              The dimension settings for the event that's associated with the
                              activity.

                              - **Dimensions** *(dict) --*

                                The dimensions for the event filter to use for the activity.

                                - **Attributes** *(dict) --*

                                  One or more custom attributes that your application reports to
                                  Amazon Pinpoint. You can use these attributes as selection
                                  criteria when you create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies attribute-based criteria for including or excluding
                                      endpoints from a segment.

                                      - **AttributeType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the AttributeType property,
                                        endpoints are included or excluded from the segment if their
                                        attribute values match the criteria values.

                                        - *(string) --*

                                - **EventType** *(dict) --*

                                  The name of the event that causes the campaign to be sent or the
                                  journey activity to be performed. This can be a standard type of
                                  event that Amazon Pinpoint generates, such as _email.delivered, or
                                  a custom event that's specific to your application.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Metrics** *(dict) --*

                                  One or more custom metrics that your application reports to Amazon
                                  Pinpoint. You can use these metrics as selection criteria when you
                                  create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies metric-based criteria for including or excluding
                                      endpoints from a segment. These criteria derive from custom
                                      metrics that you define for endpoints.

                                      - **ComparisonOperator** *(string) --*

                                        The operator to use when comparing metric values. Valid
                                        values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                        LESS_THAN_OR_EQUAL, and EQUAL.

                                      - **Value** *(float) --*

                                        The value to compare.

                              - **MessageActivity** *(string) --*

                                The message identifier (message_id) for the message to use when
                                determining whether message events meet the condition.

                            - **SegmentCondition** *(dict) --*

                              The segment that's associated with the activity.

                              - **SegmentId** *(string) --*

                                The unique identifier for the segment to associate with the
                                activity.

                            - **SegmentDimensions** *(dict) --*

                              The dimension settings for the segment that's associated with the
                              activity.

                              - **Attributes** *(dict) --*

                                One or more custom attributes to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                              - **Behavior** *(dict) --*

                                The behavior-based criteria, such as how recently users have used
                                your app, for the segment.

                                - **Recency** *(dict) --*

                                  The dimension settings that are based on how recently an endpoint
                                  was active.

                                  - **Duration** *(string) --*

                                    The duration to use when determining whether an endpoint is
                                    active or inactive.

                                  - **RecencyType** *(string) --*

                                    The type of recency dimension to use for the segment. Valid
                                    values are: ACTIVE, endpoints that were active within the
                                    specified duration are included in the segment; and, INACTIVE,
                                    endpoints that weren't active within the specified duration are
                                    included in the segment.

                              - **Demographic** *(dict) --*

                                The demographic-based criteria, such as device platform, for the
                                segment.

                                - **AppVersion** *(dict) --*

                                  The app version criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Channel** *(dict) --*

                                  The channel criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **DeviceType** *(dict) --*

                                  The device type criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Make** *(dict) --*

                                  The device make criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Model** *(dict) --*

                                  The device model criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Platform** *(dict) --*

                                  The device platform criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                              - **Location** *(dict) --*

                                The location-based criteria, such as region or GPS coordinates, for
                                the segment.

                                - **Country** *(dict) --*

                                  The country or region code, in ISO 3166-1 alpha-2 format, for the
                                  segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **GPSPoint** *(dict) --*

                                  The GPS location and range for the segment.

                                  - **Coordinates** *(dict) --*

                                    The GPS coordinates to measure distance from.

                                    - **Latitude** *(float) --*

                                      The latitude coordinate of the location.

                                    - **Longitude** *(float) --*

                                      The longitude coordinate of the location.

                                  - **RangeInKilometers** *(float) --*

                                    The range, in kilometers, from the GPS coordinates.

                              - **Metrics** *(dict) --*

                                One or more custom metrics to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies metric-based criteria for including or excluding
                                    endpoints from a segment. These criteria derive from custom
                                    metrics that you define for endpoints.

                                    - **ComparisonOperator** *(string) --*

                                      The operator to use when comparing metric values. Valid values
                                      are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                      LESS_THAN_OR_EQUAL, and EQUAL.

                                    - **Value** *(float) --*

                                      The value to compare.

                              - **UserAttributes** *(dict) --*

                                One or more custom user attributes to use as criteria for the
                                segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                        - **Operator** *(string) --*

                          Specifies how to handle multiple conditions for the activity. For example,
                          if you specify two conditions for an activity, whether both or only one of
                          the conditions must be met for the activity to be performed.

                      - **EvaluationWaitTime** *(dict) --*

                        The amount of time to wait before determining whether the conditions are
                        met, or the date and time when Amazon Pinpoint determines whether the
                        conditions are met.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

                      - **FalseActivity** *(string) --*

                        The unique identifier for the activity to perform if the condition isn't
                        met.

                      - **TrueActivity** *(string) --*

                        The unique identifier for the activity to perform if the condition is met.

                    - **Description** *(string) --*

                      The custom description of the activity.

                    - **EMAIL** *(dict) --*

                      The settings for an email activity. This type of activity sends an email
                      message to participants.

                      - **MessageConfig** *(dict) --*

                        The "From" address to use for the message.

                        - **FromAddress** *(string) --*

                          The verified email address to send the email message from. The default
                          address is the FromAddress specified for the email channel for the
                          application.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after the message is
                        sent.

                      - **TemplateName** *(string) --*

                        The name of the email template to use for the message.

                    - **Holdout** *(dict) --*

                      The settings for a holdout activity. This type of activity stops a journey for
                      a specified percentage of participants.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after performing the
                        holdout activity.

                      - **Percentage** *(integer) --*

                        The percentage of participants who shouldn't continue the journey.

                    - **MultiCondition** *(dict) --*

                      The settings for a multivariate split activity. This type of activity sends
                      participants down one of as many as five paths in a journey, based on
                      conditions that you specify.

                      - **Branches** *(list) --*

                        The paths for the activity, including the conditions for entering each path
                        and the activity to perform for each path.

                        - *(dict) --*

                          Specifies a condition to evaluate for an activity path in a journey.

                          - **Condition** *(dict) --*

                            The condition to evaluate for the activity path.

                            - **EventCondition** *(dict) --*

                              The dimension settings for the event that's associated with the
                              activity.

                              - **Dimensions** *(dict) --*

                                The dimensions for the event filter to use for the activity.

                                - **Attributes** *(dict) --*

                                  One or more custom attributes that your application reports to
                                  Amazon Pinpoint. You can use these attributes as selection
                                  criteria when you create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies attribute-based criteria for including or excluding
                                      endpoints from a segment.

                                      - **AttributeType** *(string) --*

                                        The type of segment dimension to use. Valid values are:
                                        INCLUSIVE, endpoints that match the criteria are included in
                                        the segment; and, EXCLUSIVE, endpoints that match the
                                        criteria are excluded from the segment.

                                      - **Values** *(list) --*

                                        The criteria values to use for the segment dimension.
                                        Depending on the value of the AttributeType property,
                                        endpoints are included or excluded from the segment if their
                                        attribute values match the criteria values.

                                        - *(string) --*

                                - **EventType** *(dict) --*

                                  The name of the event that causes the campaign to be sent or the
                                  journey activity to be performed. This can be a standard type of
                                  event that Amazon Pinpoint generates, such as _email.delivered, or
                                  a custom event that's specific to your application.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Metrics** *(dict) --*

                                  One or more custom metrics that your application reports to Amazon
                                  Pinpoint. You can use these metrics as selection criteria when you
                                  create an event filter.

                                  - *(string) --*

                                    - *(dict) --*

                                      Specifies metric-based criteria for including or excluding
                                      endpoints from a segment. These criteria derive from custom
                                      metrics that you define for endpoints.

                                      - **ComparisonOperator** *(string) --*

                                        The operator to use when comparing metric values. Valid
                                        values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                        LESS_THAN_OR_EQUAL, and EQUAL.

                                      - **Value** *(float) --*

                                        The value to compare.

                              - **MessageActivity** *(string) --*

                                The message identifier (message_id) for the message to use when
                                determining whether message events meet the condition.

                            - **SegmentCondition** *(dict) --*

                              The segment that's associated with the activity.

                              - **SegmentId** *(string) --*

                                The unique identifier for the segment to associate with the
                                activity.

                            - **SegmentDimensions** *(dict) --*

                              The dimension settings for the segment that's associated with the
                              activity.

                              - **Attributes** *(dict) --*

                                One or more custom attributes to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                              - **Behavior** *(dict) --*

                                The behavior-based criteria, such as how recently users have used
                                your app, for the segment.

                                - **Recency** *(dict) --*

                                  The dimension settings that are based on how recently an endpoint
                                  was active.

                                  - **Duration** *(string) --*

                                    The duration to use when determining whether an endpoint is
                                    active or inactive.

                                  - **RecencyType** *(string) --*

                                    The type of recency dimension to use for the segment. Valid
                                    values are: ACTIVE, endpoints that were active within the
                                    specified duration are included in the segment; and, INACTIVE,
                                    endpoints that weren't active within the specified duration are
                                    included in the segment.

                              - **Demographic** *(dict) --*

                                The demographic-based criteria, such as device platform, for the
                                segment.

                                - **AppVersion** *(dict) --*

                                  The app version criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Channel** *(dict) --*

                                  The channel criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **DeviceType** *(dict) --*

                                  The device type criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Make** *(dict) --*

                                  The device make criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Model** *(dict) --*

                                  The device model criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **Platform** *(dict) --*

                                  The device platform criteria for the segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                              - **Location** *(dict) --*

                                The location-based criteria, such as region or GPS coordinates, for
                                the segment.

                                - **Country** *(dict) --*

                                  The country or region code, in ISO 3166-1 alpha-2 format, for the
                                  segment.

                                  - **DimensionType** *(string) --*

                                    The type of segment dimension to use. Valid values are:
                                    INCLUSIVE, endpoints that match the criteria are included in the
                                    segment; and, EXCLUSIVE, endpoints that match the criteria are
                                    excluded from the segment.

                                  - **Values** *(list) --*

                                    The criteria values to use for the segment dimension. Depending
                                    on the value of the DimensionType property, endpoints are
                                    included or excluded from the segment if their values match the
                                    criteria values.

                                    - *(string) --*

                                - **GPSPoint** *(dict) --*

                                  The GPS location and range for the segment.

                                  - **Coordinates** *(dict) --*

                                    The GPS coordinates to measure distance from.

                                    - **Latitude** *(float) --*

                                      The latitude coordinate of the location.

                                    - **Longitude** *(float) --*

                                      The longitude coordinate of the location.

                                  - **RangeInKilometers** *(float) --*

                                    The range, in kilometers, from the GPS coordinates.

                              - **Metrics** *(dict) --*

                                One or more custom metrics to use as criteria for the segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies metric-based criteria for including or excluding
                                    endpoints from a segment. These criteria derive from custom
                                    metrics that you define for endpoints.

                                    - **ComparisonOperator** *(string) --*

                                      The operator to use when comparing metric values. Valid values
                                      are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL,
                                      LESS_THAN_OR_EQUAL, and EQUAL.

                                    - **Value** *(float) --*

                                      The value to compare.

                              - **UserAttributes** *(dict) --*

                                One or more custom user attributes to use as criteria for the
                                segment.

                                - *(string) --*

                                  - *(dict) --*

                                    Specifies attribute-based criteria for including or excluding
                                    endpoints from a segment.

                                    - **AttributeType** *(string) --*

                                      The type of segment dimension to use. Valid values are:
                                      INCLUSIVE, endpoints that match the criteria are included in
                                      the segment; and, EXCLUSIVE, endpoints that match the criteria
                                      are excluded from the segment.

                                    - **Values** *(list) --*

                                      The criteria values to use for the segment dimension.
                                      Depending on the value of the AttributeType property,
                                      endpoints are included or excluded from the segment if their
                                      attribute values match the criteria values.

                                      - *(string) --*

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after completing
                            the activity for the path.

                      - **DefaultActivity** *(string) --*

                        The activity to perform by default for any path in the activity.

                      - **EvaluationWaitTime** *(dict) --*

                        The amount of time to wait or the date and time when Amazon Pinpoint
                        determines whether the conditions are met.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

                    - **RandomSplit** *(dict) --*

                      The settings for a random split activity. This type of activity randomly sends
                      specified percentages of participants down one of as many as five paths in a
                      journey, based on conditions that you specify.

                      - **Branches** *(list) --*

                        The paths for the activity, including the percentage of participants to
                        enter each path and the activity to perform for each path.

                        - *(dict) --*

                          Specifies the settings for a path in a random split activity in a journey.

                          - **NextActivity** *(string) --*

                            The unique identifier for the next activity to perform, after completing
                            the activity for the path.

                          - **Percentage** *(integer) --*

                            The percentage of participants to send down the activity path.

                    - **Wait** *(dict) --*

                      The settings for a wait activity. This type of activity waits for a certain
                      amount of time or until a specific date and time before moving participants to
                      the next activity in a journey.

                      - **NextActivity** *(string) --*

                        The unique identifier for the next activity to perform, after performing the
                        wait activity.

                      - **WaitTime** *(dict) --*

                        The amount of time to wait or the date and time when the activity moves
                        participants to the next activity in the journey.

                        - **WaitFor** *(string) --*

                          The amount of time to wait, as a duration in ISO 8601 format, before
                          determining whether the activity's conditions have been met or moving
                          participants to the next activity in the journey.

                        - **WaitUntil** *(string) --*

                          The date and time, in ISO 8601 format, when Amazon Pinpoint determines
                          whether the activity's conditions have been met or the activity moves
                          participants to the next activity in the journey.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the journey applies to.

              - **CreationDate** *(string) --*

                The date, in ISO 8601 format, when the journey was created.

              - **Id** *(string) --*

                The unique identifier for the journey.

              - **LastModifiedDate** *(string) --*

                The date, in ISO 8601 format, when the journey was last modified.

              - **Limits** *(dict) --*

                The messaging and entry limits for the journey.

                - **DailyCap** *(integer) --*

                  The maximum number of messages that the journey can send to a single participant
                  during a 24-hour period. The maximum value is 100.

                - **EndpointReentryCap** *(integer) --*

                  The maximum number of times that a participant can enter the journey. The maximum
                  value is 100. To allow participants to enter the journey an unlimited number of
                  times, set this value to 0.

                - **MessagesPerSecond** *(integer) --*

                  The maximum number of messages that the journey can send each second.

              - **LocalTime** *(boolean) --*

                Specifies whether the journey's scheduled start and end times use each participant's
                local time. If this value is true, the schedule uses each participant's local time.

              - **Name** *(string) --*

                The name of the journey.

              - **QuietTime** *(dict) --*

                The quiet time settings for the journey. Quiet time is a specific time range when a
                journey doesn't send messages to participants, if all the following conditions are
                met:

                * The EndpointDemographic.Timezone property of the endpoint for the participant is
                set to a valid value.

                * The current time in the participant's time zone is later than or equal to the time
                specified by the QuietTime.Start property for the journey.

                * The current time in the participant's time zone is earlier than or equal to the
                time specified by the QuietTime.End property for the journey.

                If any of the preceding conditions isn't met, the participant will receive messages
                from the journey, even if quiet time is enabled.

                - **End** *(string) --*

                  The specific time when quiet time ends. This value has to use 24-hour notation and
                  be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and
                  MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

                - **Start** *(string) --*

                  The specific time when quiet time begins. This value has to use 24-hour notation
                  and be in HH:MM format, where HH is the hour (with a leading zero, if applicable)
                  and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to
                  represent 2:30 PM.

              - **RefreshFrequency** *(string) --*

                The frequency with which Amazon Pinpoint evaluates segment and event data for the
                journey, as a duration in ISO 8601 format.

              - **Schedule** *(dict) --*

                The schedule settings for the journey.

                - **EndTime** *(datetime) --*

                  The scheduled time, in ISO 8601 format, when the journey ended or will end.

                - **StartTime** *(datetime) --*

                  The scheduled time, in ISO 8601 format, when the journey began or will begin.

                - **Timezone** *(string) --*

                  The starting UTC offset for the journey schedule, if the value of the journey's
                  LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03,
                  UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30,
                  UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12,
                  UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04,
                  UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.

              - **StartActivity** *(string) --*

                The unique identifier for the first activity in the journey.

              - **StartCondition** *(dict) --*

                The segment that defines which users are participants in the journey.

                - **Description** *(string) --*

                  The custom description of the condition.

                - **SegmentStartCondition** *(dict) --*

                  The segment that's associated with the first activity in the journey. This segment
                  determines which users are participants in the journey.

                  - **SegmentId** *(string) --*

                    The unique identifier for the segment to associate with the activity.

              - **State** *(string) --*

                The current status of the journey. Possible values are:

                * DRAFT - The journey is being developed and hasn't been published yet.

                * ACTIVE - The journey has been developed and published. Depending on the journey's
                schedule, the journey may currently be running or scheduled to start running at a
                later time. If a journey's status is ACTIVE, you can't add, change, or remove
                activities from it.

                * COMPLETED - The journey has been published and has finished running. All
                participants have entered the journey and no participants are waiting to complete
                the journey or any activities in the journey.

                * CANCELLED - The journey has been stopped. If a journey's status is CANCELLED, you
                can't add, change, or remove activities or segment settings from the journey.

                * CLOSED - The journey has been published and has started running. It may have also
                passed its scheduled end time, or passed its scheduled start time and a refresh
                frequency hasn't been specified for it. If a journey's status is CLOSED, you can't
                add participants to it, and no existing participants can enter the journey for the
                first time. However, any existing participants who are currently waiting to start an
                activity may resume the journey.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the journey. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_push_template(
        self,
        PushNotificationTemplateRequest: ClientUpdatePushTemplatePushNotificationTemplateRequestTypeDef,
        TemplateName: str,
    ) -> ClientUpdatePushTemplateResponseTypeDef:
        """
        Updates an existing message template that you can use in messages that are sent through a
        push notification channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdatePushTemplate>`_

        **Request Syntax**
        ::

          response = client.update_push_template(
              PushNotificationTemplateRequest={
                  'ADM': {
                      'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                      'Body': 'string',
                      'ImageIconUrl': 'string',
                      'ImageUrl': 'string',
                      'RawContent': 'string',
                      'SmallImageIconUrl': 'string',
                      'Sound': 'string',
                      'Title': 'string',
                      'Url': 'string'
                  },
                  'APNS': {
                      'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                      'Body': 'string',
                      'MediaUrl': 'string',
                      'RawContent': 'string',
                      'Sound': 'string',
                      'Title': 'string',
                      'Url': 'string'
                  },
                  'Baidu': {
                      'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                      'Body': 'string',
                      'ImageIconUrl': 'string',
                      'ImageUrl': 'string',
                      'RawContent': 'string',
                      'SmallImageIconUrl': 'string',
                      'Sound': 'string',
                      'Title': 'string',
                      'Url': 'string'
                  },
                  'Default': {
                      'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                      'Body': 'string',
                      'Sound': 'string',
                      'Title': 'string',
                      'Url': 'string'
                  },
                  'DefaultSubstitutions': 'string',
                  'GCM': {
                      'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                      'Body': 'string',
                      'ImageIconUrl': 'string',
                      'ImageUrl': 'string',
                      'RawContent': 'string',
                      'SmallImageIconUrl': 'string',
                      'Sound': 'string',
                      'Title': 'string',
                      'Url': 'string'
                  },
                  'tags': {
                      'string': 'string'
                  },
                  'TemplateDescription': 'string'
              },
              TemplateName='string'
          )
        :type PushNotificationTemplateRequest: dict
        :param PushNotificationTemplateRequest: **[REQUIRED]**

          Updates an existing message template that you can use in messages that are sent through a
          push notification channel.

          - **ADM** *(dict) --*

            The message template to use for the ADM (Amazon Device Messaging) channel. This message
            template overrides the default template for push notification channels
            (DefaultPushNotificationTemplate).

            - **Action** *(string) --*

              The action to occur if a recipient taps a push notification that's based on the
              message template. Valid values are:

              * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
              background. This is the default action.

              * DEEP_LINK - Your app opens and displays a designated user interface in the app. This
              action uses the deep-linking features of the Android platform.

              * URL - The default mobile browser on the recipient's device opens and loads the web
              page at a URL that you specify.

            - **Body** *(string) --*

              The message body to use in a push notification that's based on the message template.

            - **ImageIconUrl** *(string) --*

              The URL of the large icon image to display in the content view of a push notification
              that's based on the message template.

            - **ImageUrl** *(string) --*

              The URL of an image to display in a push notification that's based on the message
              template.

            - **RawContent** *(string) --*

              The raw, JSON-formatted string to use as the payload for a push notification that's
              based on the message template. If specified, this value overrides all other content
              for the message template.

            - **SmallImageIconUrl** *(string) --*

              The URL of the small icon image to display in the status bar and the content view of a
              push notification that's based on the message template.

            - **Sound** *(string) --*

              The sound to play when a recipient receives a push notification that's based on the
              message template. You can use the default stream or specify the file name of a sound
              resource that's bundled in your app. On an Android platform, the sound file must
              reside in /res/raw/.

            - **Title** *(string) --*

              The title to use in a push notification that's based on the message template. This
              title appears above the notification message on a recipient's device.

            - **Url** *(string) --*

              The URL to open in a recipient's default mobile browser, if a recipient taps a a push
              notification that's based on the message template and the value of the Action property
              is URL.

          - **APNS** *(dict) --*

            The message template to use for the APNs (Apple Push Notification service) channel. This
            message template overrides the default template for push notification channels
            (DefaultPushNotificationTemplate).

            - **Action** *(string) --*

              The action to occur if a recipient taps a push notification that's based on the
              message template. Valid values are:

              * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
              background. This is the default action.

              * DEEP_LINK - Your app opens and displays a designated user interface in the app. This
              setting uses the deep-linking features of the iOS platform.

              * URL - The default mobile browser on the recipient's device opens and loads the web
              page at a URL that you specify.

            - **Body** *(string) --*

              The message body to use in push notifications that are based on the message template.

            - **MediaUrl** *(string) --*

              The URL of an image or video to display in push notifications that are based on the
              message template.

            - **RawContent** *(string) --*

              The raw, JSON-formatted string to use as the payload for push notifications that are
              based on the message template. If specified, this value overrides all other content
              for the message template.

            - **Sound** *(string) --*

              The key for the sound to play when the recipient receives a push notification that's
              based on the message template. The value for this key is the name of a sound file in
              your app's main bundle or the Library/Sounds folder in your app's data container. If
              the sound file can't be found or you specify default for the value, the system plays
              the default alert sound.

            - **Title** *(string) --*

              The title to use in push notifications that are based on the message template. This
              title appears above the notification message on a recipient's device.

            - **Url** *(string) --*

              The URL to open in the recipient's default mobile browser, if a recipient taps a push
              notification that's based on the message template and the value of the Action property
              is URL.

          - **Baidu** *(dict) --*

            The message template to use for the Baidu (Baidu Cloud Push) channel. This message
            template overrides the default template for push notification channels
            (DefaultPushNotificationTemplate).

            - **Action** *(string) --*

              The action to occur if a recipient taps a push notification that's based on the
              message template. Valid values are:

              * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
              background. This is the default action.

              * DEEP_LINK - Your app opens and displays a designated user interface in the app. This
              action uses the deep-linking features of the Android platform.

              * URL - The default mobile browser on the recipient's device opens and loads the web
              page at a URL that you specify.

            - **Body** *(string) --*

              The message body to use in a push notification that's based on the message template.

            - **ImageIconUrl** *(string) --*

              The URL of the large icon image to display in the content view of a push notification
              that's based on the message template.

            - **ImageUrl** *(string) --*

              The URL of an image to display in a push notification that's based on the message
              template.

            - **RawContent** *(string) --*

              The raw, JSON-formatted string to use as the payload for a push notification that's
              based on the message template. If specified, this value overrides all other content
              for the message template.

            - **SmallImageIconUrl** *(string) --*

              The URL of the small icon image to display in the status bar and the content view of a
              push notification that's based on the message template.

            - **Sound** *(string) --*

              The sound to play when a recipient receives a push notification that's based on the
              message template. You can use the default stream or specify the file name of a sound
              resource that's bundled in your app. On an Android platform, the sound file must
              reside in /res/raw/.

            - **Title** *(string) --*

              The title to use in a push notification that's based on the message template. This
              title appears above the notification message on a recipient's device.

            - **Url** *(string) --*

              The URL to open in a recipient's default mobile browser, if a recipient taps a a push
              notification that's based on the message template and the value of the Action property
              is URL.

          - **Default** *(dict) --*

            The default message template to use for push notification channels.

            - **Action** *(string) --*

              The action to occur if a recipient taps a push notification that's based on the
              message template. Valid values are:

              * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
              background. This is the default action.

              * DEEP_LINK - Your app opens and displays a designated user interface in the app. This
              setting uses the deep-linking features of the iOS and Android platforms.

              * URL - The default mobile browser on the recipient's device opens and loads the web
              page at a URL that you specify.

            - **Body** *(string) --*

              The message body to use in push notifications that are based on the message template.

            - **Sound** *(string) --*

              The sound to play when a recipient receives a push notification that's based on the
              message template. You can use the default stream or specify the file name of a sound
              resource that's bundled in your app. On an Android platform, the sound file must
              reside in /res/raw/.

              For an iOS platform, this value is the key for the name of a sound file in your app's
              main bundle or the Library/Sounds folder in your app's data container. If the sound
              file can't be found or you specify default for the value, the system plays the default
              alert sound.

            - **Title** *(string) --*

              The title to use in push notifications that are based on the message template. This
              title appears above the notification message on a recipient's device.

            - **Url** *(string) --*

              The URL to open in a recipient's default mobile browser, if a recipient taps a push
              notification that's based on the message template and the value of the Action property
              is URL.

          - **DefaultSubstitutions** *(string) --*

            A JSON object that specifies the default values to use for message variables in the
            message template. This object is a set of key-value pairs. Each key defines a message
            variable in the template. The corresponding value defines the default value for that
            variable. When you create a message that's based on the template, you can override these
            defaults with message-specific and address-specific variables and values.

          - **GCM** *(dict) --*

            The message template to use for the GCM channel, which is used to send notifications
            through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM),
            service. This message template overrides the default template for push notification
            channels (DefaultPushNotificationTemplate).

            - **Action** *(string) --*

              The action to occur if a recipient taps a push notification that's based on the
              message template. Valid values are:

              * OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the
              background. This is the default action.

              * DEEP_LINK - Your app opens and displays a designated user interface in the app. This
              action uses the deep-linking features of the Android platform.

              * URL - The default mobile browser on the recipient's device opens and loads the web
              page at a URL that you specify.

            - **Body** *(string) --*

              The message body to use in a push notification that's based on the message template.

            - **ImageIconUrl** *(string) --*

              The URL of the large icon image to display in the content view of a push notification
              that's based on the message template.

            - **ImageUrl** *(string) --*

              The URL of an image to display in a push notification that's based on the message
              template.

            - **RawContent** *(string) --*

              The raw, JSON-formatted string to use as the payload for a push notification that's
              based on the message template. If specified, this value overrides all other content
              for the message template.

            - **SmallImageIconUrl** *(string) --*

              The URL of the small icon image to display in the status bar and the content view of a
              push notification that's based on the message template.

            - **Sound** *(string) --*

              The sound to play when a recipient receives a push notification that's based on the
              message template. You can use the default stream or specify the file name of a sound
              resource that's bundled in your app. On an Android platform, the sound file must
              reside in /res/raw/.

            - **Title** *(string) --*

              The title to use in a push notification that's based on the message template. This
              title appears above the notification message on a recipient's device.

            - **Url** *(string) --*

              The URL to open in a recipient's default mobile browser, if a recipient taps a a push
              notification that's based on the message template and the value of the Action property
              is URL.

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            message template. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

          - **TemplateDescription** *(string) --*

            A custom description of the message template.

        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MessageBody': {
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **MessageBody** *(dict) --*

              Provides information about an API request or response.

              - **Message** *(string) --*

                The message that's returned from the API.

              - **RequestID** *(string) --*

                The unique identifier for the request or response.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_segment(
        self,
        ApplicationId: str,
        SegmentId: str,
        WriteSegmentRequest: ClientUpdateSegmentWriteSegmentRequestTypeDef,
    ) -> ClientUpdateSegmentResponseTypeDef:
        """
        Creates a new segment for an application or updates the configuration, dimension, and other
        settings for an existing segment that's associated with an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateSegment>`_

        **Request Syntax**
        ::

          response = client.update_segment(
              ApplicationId='string',
              SegmentId='string',
              WriteSegmentRequest={
                  'Dimensions': {
                      'Attributes': {
                          'string': {
                              'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          }
                      },
                      'Behavior': {
                          'Recency': {
                              'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                              'RecencyType': 'ACTIVE'|'INACTIVE'
                          }
                      },
                      'Demographic': {
                          'AppVersion': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'Channel': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'DeviceType': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'Make': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'Model': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'Platform': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          }
                      },
                      'Location': {
                          'Country': {
                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          },
                          'GPSPoint': {
                              'Coordinates': {
                                  'Latitude': 123.0,
                                  'Longitude': 123.0
                              },
                              'RangeInKilometers': 123.0
                          }
                      },
                      'Metrics': {
                          'string': {
                              'ComparisonOperator': 'string',
                              'Value': 123.0
                          }
                      },
                      'UserAttributes': {
                          'string': {
                              'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                              'Values': [
                                  'string',
                              ]
                          }
                      }
                  },
                  'Name': 'string',
                  'SegmentGroups': {
                      'Groups': [
                          {
                              'Dimensions': [
                                  {
                                      'Attributes': {
                                          'string': {
                                              'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          }
                                      },
                                      'Behavior': {
                                          'Recency': {
                                              'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                              'RecencyType': 'ACTIVE'|'INACTIVE'
                                          }
                                      },
                                      'Demographic': {
                                          'AppVersion': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'Channel': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'DeviceType': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'Make': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'Model': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'Platform': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          }
                                      },
                                      'Location': {
                                          'Country': {
                                              'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          },
                                          'GPSPoint': {
                                              'Coordinates': {
                                                  'Latitude': 123.0,
                                                  'Longitude': 123.0
                                              },
                                              'RangeInKilometers': 123.0
                                          }
                                      },
                                      'Metrics': {
                                          'string': {
                                              'ComparisonOperator': 'string',
                                              'Value': 123.0
                                          }
                                      },
                                      'UserAttributes': {
                                          'string': {
                                              'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                              'Values': [
                                                  'string',
                                              ]
                                          }
                                      }
                                  },
                              ],
                              'SourceSegments': [
                                  {
                                      'Id': 'string',
                                      'Version': 123
                                  },
                              ],
                              'SourceType': 'ALL'|'ANY'|'NONE',
                              'Type': 'ALL'|'ANY'|'NONE'
                          },
                      ],
                      'Include': 'ALL'|'ANY'|'NONE'
                  },
                  'tags': {
                      'string': 'string'
                  }
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type SegmentId: string
        :param SegmentId: **[REQUIRED]**

          The unique identifier for the segment.

        :type WriteSegmentRequest: dict
        :param WriteSegmentRequest: **[REQUIRED]**

          Specifies the configuration, dimension, and other settings for a segment. A
          WriteSegmentRequest object can include a Dimensions object or a SegmentGroups object, but
          not both.

          - **Dimensions** *(dict) --*

            The criteria that define the dimensions for the segment.

            - **Attributes** *(dict) --*

              One or more custom attributes to use as criteria for the segment.

              - *(string) --*

                - *(dict) --*

                  Specifies attribute-based criteria for including or excluding endpoints from a
                  segment.

                  - **AttributeType** *(string) --*

                    The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                    that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                    that match the criteria are excluded from the segment.

                  - **Values** *(list) --* **[REQUIRED]**

                    The criteria values to use for the segment dimension. Depending on the value of
                    the AttributeType property, endpoints are included or excluded from the segment
                    if their attribute values match the criteria values.

                    - *(string) --*

            - **Behavior** *(dict) --*

              The behavior-based criteria, such as how recently users have used your app, for the
              segment.

              - **Recency** *(dict) --*

                The dimension settings that are based on how recently an endpoint was active.

                - **Duration** *(string) --* **[REQUIRED]**

                  The duration to use when determining whether an endpoint is active or inactive.

                - **RecencyType** *(string) --* **[REQUIRED]**

                  The type of recency dimension to use for the segment. Valid values are: ACTIVE,
                  endpoints that were active within the specified duration are included in the
                  segment; and, INACTIVE, endpoints that weren't active within the specified
                  duration are included in the segment.

            - **Demographic** *(dict) --*

              The demographic-based criteria, such as device platform, for the segment.

              - **AppVersion** *(dict) --*

                The app version criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **Channel** *(dict) --*

                The channel criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **DeviceType** *(dict) --*

                The device type criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **Make** *(dict) --*

                The device make criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **Model** *(dict) --*

                The device model criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **Platform** *(dict) --*

                The device platform criteria for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

            - **Location** *(dict) --*

              The location-based criteria, such as region or GPS coordinates, for the segment.

              - **Country** *(dict) --*

                The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

                - **DimensionType** *(string) --*

                  The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that
                  match the criteria are included in the segment; and, EXCLUSIVE, endpoints that
                  match the criteria are excluded from the segment.

                - **Values** *(list) --* **[REQUIRED]**

                  The criteria values to use for the segment dimension. Depending on the value of
                  the DimensionType property, endpoints are included or excluded from the segment if
                  their values match the criteria values.

                  - *(string) --*

              - **GPSPoint** *(dict) --*

                The GPS location and range for the segment.

                - **Coordinates** *(dict) --* **[REQUIRED]**

                  The GPS coordinates to measure distance from.

                  - **Latitude** *(float) --* **[REQUIRED]**

                    The latitude coordinate of the location.

                  - **Longitude** *(float) --* **[REQUIRED]**

                    The longitude coordinate of the location.

                - **RangeInKilometers** *(float) --*

                  The range, in kilometers, from the GPS coordinates.

            - **Metrics** *(dict) --*

              One or more custom metrics to use as criteria for the segment.

              - *(string) --*

                - *(dict) --*

                  Specifies metric-based criteria for including or excluding endpoints from a
                  segment. These criteria derive from custom metrics that you define for endpoints.

                  - **ComparisonOperator** *(string) --* **[REQUIRED]**

                    The operator to use when comparing metric values. Valid values are:
                    GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

                  - **Value** *(float) --* **[REQUIRED]**

                    The value to compare.

            - **UserAttributes** *(dict) --*

              One or more custom user attributes to use as criteria for the segment.

              - *(string) --*

                - *(dict) --*

                  Specifies attribute-based criteria for including or excluding endpoints from a
                  segment.

                  - **AttributeType** *(string) --*

                    The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                    that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                    that match the criteria are excluded from the segment.

                  - **Values** *(list) --* **[REQUIRED]**

                    The criteria values to use for the segment dimension. Depending on the value of
                    the AttributeType property, endpoints are included or excluded from the segment
                    if their attribute values match the criteria values.

                    - *(string) --*

          - **Name** *(string) --*

            The name of the segment.

          - **SegmentGroups** *(dict) --*

            The segment group to use and the dimensions to apply to the group's base segments in
            order to build the segment. A segment group can consist of zero or more base segments.
            Your request can include only one segment group.

            - **Groups** *(list) --*

              An array that defines the set of segment criteria to evaluate when handling segment
              groups for the segment.

              - *(dict) --*

                Specifies the base segments and dimensions for a segment, and the relationships
                between these base segments and dimensions.

                - **Dimensions** *(list) --*

                  An array that defines the dimensions for the segment.

                  - *(dict) --*

                    Specifies the dimension settings for a segment.

                    - **Attributes** *(dict) --*

                      One or more custom attributes to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --* **[REQUIRED]**

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                    - **Behavior** *(dict) --*

                      The behavior-based criteria, such as how recently users have used your app,
                      for the segment.

                      - **Recency** *(dict) --*

                        The dimension settings that are based on how recently an endpoint was
                        active.

                        - **Duration** *(string) --* **[REQUIRED]**

                          The duration to use when determining whether an endpoint is active or
                          inactive.

                        - **RecencyType** *(string) --* **[REQUIRED]**

                          The type of recency dimension to use for the segment. Valid values are:
                          ACTIVE, endpoints that were active within the specified duration are
                          included in the segment; and, INACTIVE, endpoints that weren't active
                          within the specified duration are included in the segment.

                    - **Demographic** *(dict) --*

                      The demographic-based criteria, such as device platform, for the segment.

                      - **AppVersion** *(dict) --*

                        The app version criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Channel** *(dict) --*

                        The channel criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **DeviceType** *(dict) --*

                        The device type criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Make** *(dict) --*

                        The device make criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Model** *(dict) --*

                        The device model criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **Platform** *(dict) --*

                        The device platform criteria for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                    - **Location** *(dict) --*

                      The location-based criteria, such as region or GPS coordinates, for the
                      segment.

                      - **Country** *(dict) --*

                        The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

                        - **DimensionType** *(string) --*

                          The type of segment dimension to use. Valid values are: INCLUSIVE,
                          endpoints that match the criteria are included in the segment; and,
                          EXCLUSIVE, endpoints that match the criteria are excluded from the
                          segment.

                        - **Values** *(list) --* **[REQUIRED]**

                          The criteria values to use for the segment dimension. Depending on the
                          value of the DimensionType property, endpoints are included or excluded
                          from the segment if their values match the criteria values.

                          - *(string) --*

                      - **GPSPoint** *(dict) --*

                        The GPS location and range for the segment.

                        - **Coordinates** *(dict) --* **[REQUIRED]**

                          The GPS coordinates to measure distance from.

                          - **Latitude** *(float) --* **[REQUIRED]**

                            The latitude coordinate of the location.

                          - **Longitude** *(float) --* **[REQUIRED]**

                            The longitude coordinate of the location.

                        - **RangeInKilometers** *(float) --*

                          The range, in kilometers, from the GPS coordinates.

                    - **Metrics** *(dict) --*

                      One or more custom metrics to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies metric-based criteria for including or excluding endpoints from
                          a segment. These criteria derive from custom metrics that you define for
                          endpoints.

                          - **ComparisonOperator** *(string) --* **[REQUIRED]**

                            The operator to use when comparing metric values. Valid values are:
                            GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                            EQUAL.

                          - **Value** *(float) --* **[REQUIRED]**

                            The value to compare.

                    - **UserAttributes** *(dict) --*

                      One or more custom user attributes to use as criteria for the segment.

                      - *(string) --*

                        - *(dict) --*

                          Specifies attribute-based criteria for including or excluding endpoints
                          from a segment.

                          - **AttributeType** *(string) --*

                            The type of segment dimension to use. Valid values are: INCLUSIVE,
                            endpoints that match the criteria are included in the segment; and,
                            EXCLUSIVE, endpoints that match the criteria are excluded from the
                            segment.

                          - **Values** *(list) --* **[REQUIRED]**

                            The criteria values to use for the segment dimension. Depending on the
                            value of the AttributeType property, endpoints are included or excluded
                            from the segment if their attribute values match the criteria values.

                            - *(string) --*

                - **SourceSegments** *(list) --*

                  The base segment to build the segment on. A base segment, also referred to as a
                  *source segment* , defines the initial population of endpoints for a segment. When
                  you add dimensions to a segment, Amazon Pinpoint filters the base segment by using
                  the dimensions that you specify.

                  You can specify more than one dimensional segment or only one imported segment. If
                  you specify an imported segment, the Amazon Pinpoint console displays a segment
                  size estimate that indicates the size of the imported segment without any filters
                  applied to it.

                  - *(dict) --*

                    Specifies the segment identifier and version of a segment.

                    - **Id** *(string) --* **[REQUIRED]**

                      The unique identifier for the segment.

                    - **Version** *(integer) --*

                      The version number of the segment.

                - **SourceType** *(string) --*

                  Specifies how to handle multiple base segments for the segment. For example, if
                  you specify three base segments for the segment, whether the resulting segment is
                  based on all, any, or none of the base segments.

                - **Type** *(string) --*

                  Specifies how to handle multiple dimensions for the segment. For example, if you
                  specify three dimensions for the segment, whether the resulting segment includes
                  endpoints that match all, any, or none of the dimensions.

            - **Include** *(string) --*

              Specifies how to handle multiple segment groups for the segment. For example, if the
              segment includes three segment groups, whether the resulting segment includes
              endpoints that match all, any, or none of the segment groups.

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            segment. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SegmentResponse': {
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Behavior': {
                            'Recency': {
                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                'RecencyType': 'ACTIVE'|'INACTIVE'
                            }
                        },
                        'Demographic': {
                            'AppVersion': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Channel': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'DeviceType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Make': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Model': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Platform': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Location': {
                            'Country': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'GPSPoint': {
                                'Coordinates': {
                                    'Latitude': 123.0,
                                    'Longitude': 123.0
                                },
                                'RangeInKilometers': 123.0
                            }
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        },
                        'UserAttributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        }
                    },
                    'Id': 'string',
                    'ImportDefinition': {
                        'ChannelCounts': {
                            'string': 123
                        },
                        'ExternalId': 'string',
                        'Format': 'CSV'|'JSON',
                        'RoleArn': 'string',
                        'S3Url': 'string',
                        'Size': 123
                    },
                    'LastModifiedDate': 'string',
                    'Name': 'string',
                    'SegmentGroups': {
                        'Groups': [
                            {
                                'Dimensions': [
                                    {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    },
                                ],
                                'SourceSegments': [
                                    {
                                        'Id': 'string',
                                        'Version': 123
                                    },
                                ],
                                'SourceType': 'ALL'|'ANY'|'NONE',
                                'Type': 'ALL'|'ANY'|'NONE'
                            },
                        ],
                        'Include': 'ALL'|'ANY'|'NONE'
                    },
                    'SegmentType': 'DIMENSIONAL'|'IMPORT',
                    'tags': {
                        'string': 'string'
                    },
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **SegmentResponse** *(dict) --*

              Provides information about the configuration, dimension, and other settings for a
              segment.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the segment is associated with.

              - **Arn** *(string) --*

                The Amazon Resource Name (ARN) of the segment.

              - **CreationDate** *(string) --*

                The date and time when the segment was created.

              - **Dimensions** *(dict) --*

                The dimension settings for the segment.

                - **Attributes** *(dict) --*

                  One or more custom attributes to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

                - **Behavior** *(dict) --*

                  The behavior-based criteria, such as how recently users have used your app, for
                  the segment.

                  - **Recency** *(dict) --*

                    The dimension settings that are based on how recently an endpoint was active.

                    - **Duration** *(string) --*

                      The duration to use when determining whether an endpoint is active or
                      inactive.

                    - **RecencyType** *(string) --*

                      The type of recency dimension to use for the segment. Valid values are:
                      ACTIVE, endpoints that were active within the specified duration are included
                      in the segment; and, INACTIVE, endpoints that weren't active within the
                      specified duration are included in the segment.

                - **Demographic** *(dict) --*

                  The demographic-based criteria, such as device platform, for the segment.

                  - **AppVersion** *(dict) --*

                    The app version criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Channel** *(dict) --*

                    The channel criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **DeviceType** *(dict) --*

                    The device type criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Make** *(dict) --*

                    The device make criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Model** *(dict) --*

                    The device model criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **Platform** *(dict) --*

                    The device platform criteria for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                - **Location** *(dict) --*

                  The location-based criteria, such as region or GPS coordinates, for the segment.

                  - **Country** *(dict) --*

                    The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

                    - **DimensionType** *(string) --*

                      The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                      that match the criteria are included in the segment; and, EXCLUSIVE, endpoints
                      that match the criteria are excluded from the segment.

                    - **Values** *(list) --*

                      The criteria values to use for the segment dimension. Depending on the value
                      of the DimensionType property, endpoints are included or excluded from the
                      segment if their values match the criteria values.

                      - *(string) --*

                  - **GPSPoint** *(dict) --*

                    The GPS location and range for the segment.

                    - **Coordinates** *(dict) --*

                      The GPS coordinates to measure distance from.

                      - **Latitude** *(float) --*

                        The latitude coordinate of the location.

                      - **Longitude** *(float) --*

                        The longitude coordinate of the location.

                    - **RangeInKilometers** *(float) --*

                      The range, in kilometers, from the GPS coordinates.

                - **Metrics** *(dict) --*

                  One or more custom metrics to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies metric-based criteria for including or excluding endpoints from a
                      segment. These criteria derive from custom metrics that you define for
                      endpoints.

                      - **ComparisonOperator** *(string) --*

                        The operator to use when comparing metric values. Valid values are:
                        GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and
                        EQUAL.

                      - **Value** *(float) --*

                        The value to compare.

                - **UserAttributes** *(dict) --*

                  One or more custom user attributes to use as criteria for the segment.

                  - *(string) --*

                    - *(dict) --*

                      Specifies attribute-based criteria for including or excluding endpoints from a
                      segment.

                      - **AttributeType** *(string) --*

                        The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints
                        that match the criteria are included in the segment; and, EXCLUSIVE,
                        endpoints that match the criteria are excluded from the segment.

                      - **Values** *(list) --*

                        The criteria values to use for the segment dimension. Depending on the value
                        of the AttributeType property, endpoints are included or excluded from the
                        segment if their attribute values match the criteria values.

                        - *(string) --*

              - **Id** *(string) --*

                The unique identifier for the segment.

              - **ImportDefinition** *(dict) --*

                The settings for the import job that's associated with the segment.

                - **ChannelCounts** *(dict) --*

                  The number of channel types in the endpoint definitions that were imported to
                  create the segment.

                  - *(string) --*

                    - *(integer) --*

                - **ExternalId** *(string) --*

                  (Deprecated) Your AWS account ID, which you assigned to an external ID key in an
                  IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role
                  when importing endpoint definitions, but we removed this requirement. We don't
                  recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

                - **Format** *(string) --*

                  The format of the files that were imported to create the segment. Valid values
                  are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON
                  format.

                - **RoleArn** *(string) --*

                  The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM)
                  role that authorized Amazon Pinpoint to access the Amazon S3 location to import
                  endpoint definitions from.

                - **S3Url** *(string) --*

                  The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint
                  definitions were imported from to create the segment.

                - **Size** *(integer) --*

                  The number of endpoint definitions that were imported successfully to create the
                  segment.

              - **LastModifiedDate** *(string) --*

                The date and time when the segment was last modified.

              - **Name** *(string) --*

                The name of the segment.

              - **SegmentGroups** *(dict) --*

                A list of one or more segment groups that apply to the segment. Each segment group
                consists of zero or more base segments and the dimensions that are applied to those
                base segments.

                - **Groups** *(list) --*

                  An array that defines the set of segment criteria to evaluate when handling
                  segment groups for the segment.

                  - *(dict) --*

                    Specifies the base segments and dimensions for a segment, and the relationships
                    between these base segments and dimensions.

                    - **Dimensions** *(list) --*

                      An array that defines the dimensions for the segment.

                      - *(dict) --*

                        Specifies the dimension settings for a segment.

                        - **Attributes** *(dict) --*

                          One or more custom attributes to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                        - **Behavior** *(dict) --*

                          The behavior-based criteria, such as how recently users have used your
                          app, for the segment.

                          - **Recency** *(dict) --*

                            The dimension settings that are based on how recently an endpoint was
                            active.

                            - **Duration** *(string) --*

                              The duration to use when determining whether an endpoint is active or
                              inactive.

                            - **RecencyType** *(string) --*

                              The type of recency dimension to use for the segment. Valid values
                              are: ACTIVE, endpoints that were active within the specified duration
                              are included in the segment; and, INACTIVE, endpoints that weren't
                              active within the specified duration are included in the segment.

                        - **Demographic** *(dict) --*

                          The demographic-based criteria, such as device platform, for the segment.

                          - **AppVersion** *(dict) --*

                            The app version criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Channel** *(dict) --*

                            The channel criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **DeviceType** *(dict) --*

                            The device type criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Make** *(dict) --*

                            The device make criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Model** *(dict) --*

                            The device model criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **Platform** *(dict) --*

                            The device platform criteria for the segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                        - **Location** *(dict) --*

                          The location-based criteria, such as region or GPS coordinates, for the
                          segment.

                          - **Country** *(dict) --*

                            The country or region code, in ISO 3166-1 alpha-2 format, for the
                            segment.

                            - **DimensionType** *(string) --*

                              The type of segment dimension to use. Valid values are: INCLUSIVE,
                              endpoints that match the criteria are included in the segment; and,
                              EXCLUSIVE, endpoints that match the criteria are excluded from the
                              segment.

                            - **Values** *(list) --*

                              The criteria values to use for the segment dimension. Depending on the
                              value of the DimensionType property, endpoints are included or
                              excluded from the segment if their values match the criteria values.

                              - *(string) --*

                          - **GPSPoint** *(dict) --*

                            The GPS location and range for the segment.

                            - **Coordinates** *(dict) --*

                              The GPS coordinates to measure distance from.

                              - **Latitude** *(float) --*

                                The latitude coordinate of the location.

                              - **Longitude** *(float) --*

                                The longitude coordinate of the location.

                            - **RangeInKilometers** *(float) --*

                              The range, in kilometers, from the GPS coordinates.

                        - **Metrics** *(dict) --*

                          One or more custom metrics to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies metric-based criteria for including or excluding endpoints
                              from a segment. These criteria derive from custom metrics that you
                              define for endpoints.

                              - **ComparisonOperator** *(string) --*

                                The operator to use when comparing metric values. Valid values are:
                                GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL,
                                and EQUAL.

                              - **Value** *(float) --*

                                The value to compare.

                        - **UserAttributes** *(dict) --*

                          One or more custom user attributes to use as criteria for the segment.

                          - *(string) --*

                            - *(dict) --*

                              Specifies attribute-based criteria for including or excluding
                              endpoints from a segment.

                              - **AttributeType** *(string) --*

                                The type of segment dimension to use. Valid values are: INCLUSIVE,
                                endpoints that match the criteria are included in the segment; and,
                                EXCLUSIVE, endpoints that match the criteria are excluded from the
                                segment.

                              - **Values** *(list) --*

                                The criteria values to use for the segment dimension. Depending on
                                the value of the AttributeType property, endpoints are included or
                                excluded from the segment if their attribute values match the
                                criteria values.

                                - *(string) --*

                    - **SourceSegments** *(list) --*

                      The base segment to build the segment on. A base segment, also referred to as
                      a *source segment* , defines the initial population of endpoints for a
                      segment. When you add dimensions to a segment, Amazon Pinpoint filters the
                      base segment by using the dimensions that you specify.

                      You can specify more than one dimensional segment or only one imported
                      segment. If you specify an imported segment, the Amazon Pinpoint console
                      displays a segment size estimate that indicates the size of the imported
                      segment without any filters applied to it.

                      - *(dict) --*

                        Specifies the segment identifier and version of a segment.

                        - **Id** *(string) --*

                          The unique identifier for the segment.

                        - **Version** *(integer) --*

                          The version number of the segment.

                    - **SourceType** *(string) --*

                      Specifies how to handle multiple base segments for the segment. For example,
                      if you specify three base segments for the segment, whether the resulting
                      segment is based on all, any, or none of the base segments.

                    - **Type** *(string) --*

                      Specifies how to handle multiple dimensions for the segment. For example, if
                      you specify three dimensions for the segment, whether the resulting segment
                      includes endpoints that match all, any, or none of the dimensions.

                - **Include** *(string) --*

                  Specifies how to handle multiple segment groups for the segment. For example, if
                  the segment includes three segment groups, whether the resulting segment includes
                  endpoints that match all, any, or none of the segment groups.

              - **SegmentType** *(string) --*

                The segment type. Valid values are:

                * DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria
                that you specify and is based on endpoint data that's reported by your app. Dynamic
                segments can change over time.

                * IMPORT - A static segment, which is a segment that uses selection criteria that
                you specify and is based on endpoint definitions that you import from a file.
                Imported segments are static; they don't change over time.

              - **tags** *(dict) --*

                A string-to-string map of key-value pairs that identifies the tags that are
                associated with the segment. Each tag consists of a required tag key and an
                associated tag value.

                - *(string) --*

                  - *(string) --*

              - **Version** *(integer) --*

                The version number of the segment.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_sms_channel(
        self, ApplicationId: str, SMSChannelRequest: ClientUpdateSmsChannelSMSChannelRequestTypeDef
    ) -> ClientUpdateSmsChannelResponseTypeDef:
        """
        Enables the SMS channel for an application or updates the status and settings of the SMS
        channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateSmsChannel>`_

        **Request Syntax**
        ::

          response = client.update_sms_channel(
              ApplicationId='string',
              SMSChannelRequest={
                  'Enabled': True|False,
                  'SenderId': 'string',
                  'ShortCode': 'string'
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type SMSChannelRequest: dict
        :param SMSChannelRequest: **[REQUIRED]**

          Specifies the status and settings of the SMS channel for an application.

          - **Enabled** *(boolean) --*

            Specifies whether to enable the SMS channel for the application.

          - **SenderId** *(string) --*

            The identity that you want to display on recipients' devices when they receive messages
            from the SMS channel.

          - **ShortCode** *(string) --*

            The registered short code that you want to use when you send messages through the SMS
            channel.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'SMSChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'PromotionalMessagesPerSecond': 123,
                    'SenderId': 'string',
                    'ShortCode': 'string',
                    'TransactionalMessagesPerSecond': 123,
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **SMSChannelResponse** *(dict) --*

              Provides information about the status and settings of the SMS channel for an
              application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the SMS channel applies to.

              - **CreationDate** *(string) --*

                The date and time, in ISO 8601 format, when the SMS channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the SMS channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the SMS channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the SMS channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the SMS channel.

              - **LastModifiedDate** *(string) --*

                The date and time, in ISO 8601 format, when the SMS channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the SMS channel,
                this value is SMS.

              - **PromotionalMessagesPerSecond** *(integer) --*

                The maximum number of promotional messages that you can send through the SMS channel
                each second.

              - **SenderId** *(string) --*

                The identity that displays on recipients' devices when they receive messages from
                the SMS channel.

              - **ShortCode** *(string) --*

                The registered short code to use when you send messages through the SMS channel.

              - **TransactionalMessagesPerSecond** *(integer) --*

                The maximum number of transactional messages that you can send through the SMS
                channel each second.

              - **Version** *(integer) --*

                The current version of the SMS channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_sms_template(
        self,
        SMSTemplateRequest: ClientUpdateSmsTemplateSMSTemplateRequestTypeDef,
        TemplateName: str,
    ) -> ClientUpdateSmsTemplateResponseTypeDef:
        """
        Updates an existing message template that you can use in messages that are sent through the
        SMS channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateSmsTemplate>`_

        **Request Syntax**
        ::

          response = client.update_sms_template(
              SMSTemplateRequest={
                  'Body': 'string',
                  'DefaultSubstitutions': 'string',
                  'tags': {
                      'string': 'string'
                  },
                  'TemplateDescription': 'string'
              },
              TemplateName='string'
          )
        :type SMSTemplateRequest: dict
        :param SMSTemplateRequest: **[REQUIRED]**

          Specifies the content and settings for a message template that can be used in text
          messages that are sent through the SMS channel.

          - **Body** *(string) --*

            The message body to use in text messages that are based on the message template.

          - **DefaultSubstitutions** *(string) --*

            A JSON object that specifies the default values to use for message variables in the
            message template. This object is a set of key-value pairs. Each key defines a message
            variable in the template. The corresponding value defines the default value for that
            variable. When you create a message that's based on the template, you can override these
            defaults with message-specific and address-specific variables and values.

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            message template. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

          - **TemplateDescription** *(string) --*

            A custom description of the message template.

        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MessageBody': {
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **MessageBody** *(dict) --*

              Provides information about an API request or response.

              - **Message** *(string) --*

                The message that's returned from the API.

              - **RequestID** *(string) --*

                The unique identifier for the request or response.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_voice_channel(
        self,
        ApplicationId: str,
        VoiceChannelRequest: ClientUpdateVoiceChannelVoiceChannelRequestTypeDef,
    ) -> ClientUpdateVoiceChannelResponseTypeDef:
        """
        Enables the voice channel for an application or updates the status and settings of the voice
        channel for an application.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateVoiceChannel>`_

        **Request Syntax**
        ::

          response = client.update_voice_channel(
              ApplicationId='string',
              VoiceChannelRequest={
                  'Enabled': True|False
              }
          )
        :type ApplicationId: string
        :param ApplicationId: **[REQUIRED]**

          The unique identifier for the application. This identifier is displayed as the **Project
          ID** on the Amazon Pinpoint console.

        :type VoiceChannelRequest: dict
        :param VoiceChannelRequest: **[REQUIRED]**

          Specifies the status and settings of the voice channel for an application.

          - **Enabled** *(boolean) --*

            Specifies whether to enable the voice channel for the application.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'VoiceChannelResponse': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Platform': 'string',
                    'Version': 123
                }
            }
          **Response Structure**

          - *(dict) --*

            The request succeeded.

            - **VoiceChannelResponse** *(dict) --*

              Provides information about the status and settings of the voice channel for an
              application.

              - **ApplicationId** *(string) --*

                The unique identifier for the application that the voice channel applies to.

              - **CreationDate** *(string) --*

                The date and time, in ISO 8601 format, when the voice channel was enabled.

              - **Enabled** *(boolean) --*

                Specifies whether the voice channel is enabled for the application.

              - **HasCredential** *(boolean) --*

                (Not used) This property is retained only for backward compatibility.

              - **Id** *(string) --*

                (Deprecated) An identifier for the voice channel. This property is retained only for
                backward compatibility.

              - **IsArchived** *(boolean) --*

                Specifies whether the voice channel is archived.

              - **LastModifiedBy** *(string) --*

                The user who last modified the voice channel.

              - **LastModifiedDate** *(string) --*

                The date and time, in ISO 8601 format, when the voice channel was last modified.

              - **Platform** *(string) --*

                The type of messaging or notification platform for the channel. For the voice
                channel, this value is VOICE.

              - **Version** *(integer) --*

                The current version of the voice channel.

        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_voice_template(
        self,
        TemplateName: str,
        VoiceTemplateRequest: ClientUpdateVoiceTemplateVoiceTemplateRequestTypeDef,
    ) -> ClientUpdateVoiceTemplateResponseTypeDef:
        """
        Updates an existing message template that you can use in messages that are sent through the
        voice channel.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/UpdateVoiceTemplate>`_

        **Request Syntax**
        ::

          response = client.update_voice_template(
              TemplateName='string',
              VoiceTemplateRequest={
                  'Body': 'string',
                  'DefaultSubstitutions': 'string',
                  'LanguageCode': 'string',
                  'tags': {
                      'string': 'string'
                  },
                  'TemplateDescription': 'string',
                  'VoiceId': 'string'
              }
          )
        :type TemplateName: string
        :param TemplateName: **[REQUIRED]**

          The name of the message template. A template name must start with an alphanumeric
          character and can contain a maximum of 128 characters. The characters can be alphanumeric
          characters, underscores (_), or hyphens (-). Template names are case sensitive.

        :type VoiceTemplateRequest: dict
        :param VoiceTemplateRequest: **[REQUIRED]**

          Specifies the content and settings for a message template that can be used in messages
          that are sent through the voice channel.

          - **Body** *(string) --*

            The text of the script to use in messages that are based on the message template, in
            plain text format.

          - **DefaultSubstitutions** *(string) --*

            A JSON object that specifies the default values to use for message variables in the
            message template. This object is a set of key-value pairs. Each key defines a message
            variable in the template. The corresponding value defines the default value for that
            variable. When you create a message that's based on the template, you can override these
            defaults with message-specific and address-specific variables and values.

          - **LanguageCode** *(string) --*

            The code for the language to use when synthesizing the text of the script in messages
            that are based on the message template. For a list of supported languages and the code
            for each one, see the `Amazon Polly Developer Guide
            <https://docs.aws.amazon.com/polly/latest/dg/what-is.html>`__ .

          - **tags** *(dict) --*

            A string-to-string map of key-value pairs that defines the tags to associate with the
            message template. Each tag consists of a required tag key and an associated tag value.

            - *(string) --*

              - *(string) --*

          - **TemplateDescription** *(string) --*

            A custom description of the message template.

          - **VoiceId** *(string) --*

            The name of the voice to use when delivering messages that are based on the message
            template. For a list of supported voices, see the `Amazon Polly Developer Guide
            <https://docs.aws.amazon.com/polly/latest/dg/what-is.html>`__ .

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'MessageBody': {
                    'Message': 'string',
                    'RequestID': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            The request was accepted for processing. Processing may not be complete.

            - **MessageBody** *(dict) --*

              Provides information about an API request or response.

              - **Message** *(string) --*

                The message that's returned from the API.

              - **RequestID** *(string) --*

                The unique identifier for the request or response.

        """


class Exceptions:
    BadRequestException: Boto3ClientError
    ClientError: Boto3ClientError
    ForbiddenException: Boto3ClientError
    InternalServerErrorException: Boto3ClientError
    MethodNotAllowedException: Boto3ClientError
    NotFoundException: Boto3ClientError
    TooManyRequestsException: Boto3ClientError
